Class: Aws::IoTSiteWise::Types::AssetCompositeModel
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTSiteWise::Types::AssetCompositeModel
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotsitewise/types.rb
Overview
Contains information about a composite model in an asset. This object contains the asset's properties that you define in the composite model.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
The description of the composite model.
-
#external_id ⇒ String
The external ID of the asset composite model.
-
#id ⇒ String
The ID of the asset composite model.
-
#name ⇒ String
The name of the composite model.
-
#properties ⇒ Array<Types::AssetProperty>
The asset properties that this composite model defines.
-
#type ⇒ String
The type of the composite model.
Instance Attribute Details
#description ⇒ String
The description of the composite model.
320 321 322 323 324 325 326 327 328 329 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 320 class AssetCompositeModel < Struct.new( :name, :description, :type, :properties, :id, :external_id) SENSITIVE = [] include Aws::Structure end |
#external_id ⇒ String
The external ID of the asset composite model. For more information, see Using external IDs in the IoT SiteWise User Guide.
320 321 322 323 324 325 326 327 328 329 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 320 class AssetCompositeModel < Struct.new( :name, :description, :type, :properties, :id, :external_id) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The ID of the asset composite model.
320 321 322 323 324 325 326 327 328 329 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 320 class AssetCompositeModel < Struct.new( :name, :description, :type, :properties, :id, :external_id) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the composite model.
320 321 322 323 324 325 326 327 328 329 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 320 class AssetCompositeModel < Struct.new( :name, :description, :type, :properties, :id, :external_id) SENSITIVE = [] include Aws::Structure end |
#properties ⇒ Array<Types::AssetProperty>
The asset properties that this composite model defines.
320 321 322 323 324 325 326 327 328 329 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 320 class AssetCompositeModel < Struct.new( :name, :description, :type, :properties, :id, :external_id) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of the composite model. For alarm composite models, this
type is AWS/ALARM.
320 321 322 323 324 325 326 327 328 329 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 320 class AssetCompositeModel < Struct.new( :name, :description, :type, :properties, :id, :external_id) SENSITIVE = [] include Aws::Structure end |