Class: Aws::IoTSiteWise::Types::AssetHierarchy
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTSiteWise::Types::AssetHierarchy
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotsitewise/types.rb
Overview
Describes an asset hierarchy that contains a hierarchy's name and ID.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#external_id ⇒ String
The external ID of the hierarchy, if it has one.
-
#id ⇒ String
The ID of the hierarchy.
-
#name ⇒ String
The hierarchy name provided in the [CreateAssetModel][1] or [UpdateAssetModel][2] API operation.
Instance Attribute Details
#external_id ⇒ String
The external ID of the hierarchy, if it has one. When you update an asset hierarchy, you may assign an external ID if it doesn't already have one. You can't change the external ID of an asset hierarchy that already has one. For more information, see Using external IDs in the IoT SiteWise User Guide.
451 452 453 454 455 456 457 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 451 class AssetHierarchy < Struct.new( :id, :external_id, :name) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The ID of the hierarchy. This ID is a hierarchyId.
451 452 453 454 455 456 457 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 451 class AssetHierarchy < Struct.new( :id, :external_id, :name) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The hierarchy name provided in the CreateAssetModel or UpdateAssetModel API operation.
451 452 453 454 455 456 457 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 451 class AssetHierarchy < Struct.new( :id, :external_id, :name) SENSITIVE = [] include Aws::Structure end |