Class: Aws::IoTSiteWise::Types::AssetModelCompositeModel
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTSiteWise::Types::AssetModelCompositeModel
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotsitewise/types.rb
Overview
Contains information about a composite model in an asset model. This object contains the asset property definitions that you define in the composite model.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
The description of the composite model.
-
#external_id ⇒ String
The external ID of the asset model composite model.
-
#id ⇒ String
The ID of the asset model composite model.
-
#name ⇒ String
The name of the composite model.
-
#properties ⇒ Array<Types::AssetModelProperty>
The asset property definitions for this composite model.
-
#type ⇒ String
The type of the composite model.
Instance Attribute Details
#description ⇒ String
The description of the composite model.
527 528 529 530 531 532 533 534 535 536 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 527 class AssetModelCompositeModel < Struct.new( :name, :description, :type, :properties, :id, :external_id) SENSITIVE = [] include Aws::Structure end |
#external_id ⇒ String
The external ID of the asset model composite model. For more information, see Using external IDs in the IoT SiteWise User Guide.
527 528 529 530 531 532 533 534 535 536 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 527 class AssetModelCompositeModel < Struct.new( :name, :description, :type, :properties, :id, :external_id) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The ID of the asset model composite model.
527 528 529 530 531 532 533 534 535 536 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 527 class AssetModelCompositeModel < Struct.new( :name, :description, :type, :properties, :id, :external_id) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the composite model.
527 528 529 530 531 532 533 534 535 536 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 527 class AssetModelCompositeModel < Struct.new( :name, :description, :type, :properties, :id, :external_id) SENSITIVE = [] include Aws::Structure end |
#properties ⇒ Array<Types::AssetModelProperty>
The asset property definitions for this composite model.
527 528 529 530 531 532 533 534 535 536 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 527 class AssetModelCompositeModel < Struct.new( :name, :description, :type, :properties, :id, :external_id) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of the composite model. For alarm composite models, this
type is AWS/ALARM.
527 528 529 530 531 532 533 534 535 536 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 527 class AssetModelCompositeModel < Struct.new( :name, :description, :type, :properties, :id, :external_id) SENSITIVE = [] include Aws::Structure end |