Class: Aws::IoTSiteWise::Types::AssetModelPropertySummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTSiteWise::Types::AssetModelPropertySummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotsitewise/types.rb
Overview
Contains a summary of a property associated with a model. This includes information about which interfaces the property belongs to, if any.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#asset_model_composite_model_id ⇒ String
The ID of the composite model that contains the asset model property.
-
#data_type ⇒ String
The data type of the property.
-
#data_type_spec ⇒ String
The data type of the structure for this property.
-
#external_id ⇒ String
The external ID of the property.
-
#id ⇒ String
The ID of the property.
-
#interface_summaries ⇒ Array<Types::InterfaceSummary>
A list of interface summaries that describe which interfaces this property belongs to, including the interface asset model ID and the corresponding property ID in the interface.
-
#name ⇒ String
The name of the property.
-
#path ⇒ Array<Types::AssetModelPropertyPathSegment>
The structured path to the property from the root of the asset model.
-
#type ⇒ Types::PropertyType
Contains a property type, which can be one of
attribute,measurement,metric, ortransform. -
#unit ⇒ String
The unit (such as
NewtonsorRPM) of the property.
Instance Attribute Details
#asset_model_composite_model_id ⇒ String
The ID of the composite model that contains the asset model property.
1046 1047 1048 1049 1050 1051 1052 1053 1054 1055 1056 1057 1058 1059 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 1046 class AssetModelPropertySummary < Struct.new( :id, :external_id, :name, :data_type, :data_type_spec, :unit, :type, :asset_model_composite_model_id, :path, :interface_summaries) SENSITIVE = [] include Aws::Structure end |
#data_type ⇒ String
The data type of the property.
1046 1047 1048 1049 1050 1051 1052 1053 1054 1055 1056 1057 1058 1059 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 1046 class AssetModelPropertySummary < Struct.new( :id, :external_id, :name, :data_type, :data_type_spec, :unit, :type, :asset_model_composite_model_id, :path, :interface_summaries) SENSITIVE = [] include Aws::Structure end |
#data_type_spec ⇒ String
The data type of the structure for this property. This parameter
exists on properties that have the STRUCT data type.
1046 1047 1048 1049 1050 1051 1052 1053 1054 1055 1056 1057 1058 1059 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 1046 class AssetModelPropertySummary < Struct.new( :id, :external_id, :name, :data_type, :data_type_spec, :unit, :type, :asset_model_composite_model_id, :path, :interface_summaries) SENSITIVE = [] include Aws::Structure end |
#external_id ⇒ String
The external ID of the property. For more information, see Using external IDs in the IoT SiteWise User Guide.
1046 1047 1048 1049 1050 1051 1052 1053 1054 1055 1056 1057 1058 1059 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 1046 class AssetModelPropertySummary < Struct.new( :id, :external_id, :name, :data_type, :data_type_spec, :unit, :type, :asset_model_composite_model_id, :path, :interface_summaries) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The ID of the property.
1046 1047 1048 1049 1050 1051 1052 1053 1054 1055 1056 1057 1058 1059 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 1046 class AssetModelPropertySummary < Struct.new( :id, :external_id, :name, :data_type, :data_type_spec, :unit, :type, :asset_model_composite_model_id, :path, :interface_summaries) SENSITIVE = [] include Aws::Structure end |
#interface_summaries ⇒ Array<Types::InterfaceSummary>
A list of interface summaries that describe which interfaces this property belongs to, including the interface asset model ID and the corresponding property ID in the interface.
1046 1047 1048 1049 1050 1051 1052 1053 1054 1055 1056 1057 1058 1059 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 1046 class AssetModelPropertySummary < Struct.new( :id, :external_id, :name, :data_type, :data_type_spec, :unit, :type, :asset_model_composite_model_id, :path, :interface_summaries) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the property.
1046 1047 1048 1049 1050 1051 1052 1053 1054 1055 1056 1057 1058 1059 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 1046 class AssetModelPropertySummary < Struct.new( :id, :external_id, :name, :data_type, :data_type_spec, :unit, :type, :asset_model_composite_model_id, :path, :interface_summaries) SENSITIVE = [] include Aws::Structure end |
#path ⇒ Array<Types::AssetModelPropertyPathSegment>
The structured path to the property from the root of the asset model.
1046 1047 1048 1049 1050 1051 1052 1053 1054 1055 1056 1057 1058 1059 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 1046 class AssetModelPropertySummary < Struct.new( :id, :external_id, :name, :data_type, :data_type_spec, :unit, :type, :asset_model_composite_model_id, :path, :interface_summaries) SENSITIVE = [] include Aws::Structure end |
#type ⇒ Types::PropertyType
Contains a property type, which can be one of attribute,
measurement, metric, or transform.
1046 1047 1048 1049 1050 1051 1052 1053 1054 1055 1056 1057 1058 1059 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 1046 class AssetModelPropertySummary < Struct.new( :id, :external_id, :name, :data_type, :data_type_spec, :unit, :type, :asset_model_composite_model_id, :path, :interface_summaries) SENSITIVE = [] include Aws::Structure end |
#unit ⇒ String
The unit (such as Newtons or RPM) of the property.
1046 1047 1048 1049 1050 1051 1052 1053 1054 1055 1056 1057 1058 1059 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 1046 class AssetModelPropertySummary < Struct.new( :id, :external_id, :name, :data_type, :data_type_spec, :unit, :type, :asset_model_composite_model_id, :path, :interface_summaries) SENSITIVE = [] include Aws::Structure end |