Class: Aws::IoTSiteWise::Types::AssetSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTSiteWise::Types::AssetSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotsitewise/types.rb
Overview
Contains a summary of an asset.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The [ARN][1] of the asset, which has the following format.
-
#asset_model_id ⇒ String
The ID of the asset model used to create this asset.
-
#creation_date ⇒ Time
The date the asset was created, in Unix epoch time.
-
#description ⇒ String
A description for the asset.
-
#external_id ⇒ String
The external ID of the asset.
-
#hierarchies ⇒ Array<Types::AssetHierarchy>
A list of asset hierarchies that each contain a
hierarchyId. -
#id ⇒ String
The ID of the asset, in UUID format.
-
#last_update_date ⇒ Time
The date the asset was last updated, in Unix epoch time.
-
#name ⇒ String
The name of the asset.
-
#status ⇒ Types::AssetStatus
The current status of the asset.
Instance Attribute Details
#arn ⇒ String
The ARN of the asset, which has the following format.
arn:${Partition}:iotsitewise:${Region}:${Account}:asset/${AssetId}
1481 1482 1483 1484 1485 1486 1487 1488 1489 1490 1491 1492 1493 1494 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 1481 class AssetSummary < Struct.new( :id, :external_id, :arn, :name, :asset_model_id, :creation_date, :last_update_date, :status, :hierarchies, :description) SENSITIVE = [] include Aws::Structure end |
#asset_model_id ⇒ String
The ID of the asset model used to create this asset.
1481 1482 1483 1484 1485 1486 1487 1488 1489 1490 1491 1492 1493 1494 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 1481 class AssetSummary < Struct.new( :id, :external_id, :arn, :name, :asset_model_id, :creation_date, :last_update_date, :status, :hierarchies, :description) SENSITIVE = [] include Aws::Structure end |
#creation_date ⇒ Time
The date the asset was created, in Unix epoch time.
1481 1482 1483 1484 1485 1486 1487 1488 1489 1490 1491 1492 1493 1494 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 1481 class AssetSummary < Struct.new( :id, :external_id, :arn, :name, :asset_model_id, :creation_date, :last_update_date, :status, :hierarchies, :description) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description for the asset.
1481 1482 1483 1484 1485 1486 1487 1488 1489 1490 1491 1492 1493 1494 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 1481 class AssetSummary < Struct.new( :id, :external_id, :arn, :name, :asset_model_id, :creation_date, :last_update_date, :status, :hierarchies, :description) SENSITIVE = [] include Aws::Structure end |
#external_id ⇒ String
The external ID of the asset. For more information, see Using external IDs in the IoT SiteWise User Guide.
1481 1482 1483 1484 1485 1486 1487 1488 1489 1490 1491 1492 1493 1494 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 1481 class AssetSummary < Struct.new( :id, :external_id, :arn, :name, :asset_model_id, :creation_date, :last_update_date, :status, :hierarchies, :description) SENSITIVE = [] include Aws::Structure end |
#hierarchies ⇒ Array<Types::AssetHierarchy>
A list of asset hierarchies that each contain a hierarchyId. A
hierarchy specifies allowed parent/child asset relationships.
1481 1482 1483 1484 1485 1486 1487 1488 1489 1490 1491 1492 1493 1494 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 1481 class AssetSummary < Struct.new( :id, :external_id, :arn, :name, :asset_model_id, :creation_date, :last_update_date, :status, :hierarchies, :description) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The ID of the asset, in UUID format.
1481 1482 1483 1484 1485 1486 1487 1488 1489 1490 1491 1492 1493 1494 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 1481 class AssetSummary < Struct.new( :id, :external_id, :arn, :name, :asset_model_id, :creation_date, :last_update_date, :status, :hierarchies, :description) SENSITIVE = [] include Aws::Structure end |
#last_update_date ⇒ Time
The date the asset was last updated, in Unix epoch time.
1481 1482 1483 1484 1485 1486 1487 1488 1489 1490 1491 1492 1493 1494 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 1481 class AssetSummary < Struct.new( :id, :external_id, :arn, :name, :asset_model_id, :creation_date, :last_update_date, :status, :hierarchies, :description) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the asset.
1481 1482 1483 1484 1485 1486 1487 1488 1489 1490 1491 1492 1493 1494 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 1481 class AssetSummary < Struct.new( :id, :external_id, :arn, :name, :asset_model_id, :creation_date, :last_update_date, :status, :hierarchies, :description) SENSITIVE = [] include Aws::Structure end |
#status ⇒ Types::AssetStatus
The current status of the asset.
1481 1482 1483 1484 1485 1486 1487 1488 1489 1490 1491 1492 1493 1494 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 1481 class AssetSummary < Struct.new( :id, :external_id, :arn, :name, :asset_model_id, :creation_date, :last_update_date, :status, :hierarchies, :description) SENSITIVE = [] include Aws::Structure end |