Class: Aws::IoTSiteWise::Types::AssociateAssetsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotsitewise/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#asset_idString

The ID of the parent asset. This can be either the actual ID in UUID format, or else externalId: followed by the external ID, if it has one. For more information, see Referencing objects with external IDs in the IoT SiteWise User Guide.

Returns:

  • (String)


1543
1544
1545
1546
1547
1548
1549
1550
# File 'lib/aws-sdk-iotsitewise/types.rb', line 1543

class AssociateAssetsRequest < Struct.new(
  :asset_id,
  :hierarchy_id,
  :child_asset_id,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#child_asset_idString

The ID of the child asset to be associated. This can be either the actual ID in UUID format, or else externalId: followed by the external ID, if it has one. For more information, see Referencing objects with external IDs in the IoT SiteWise User Guide.

Returns:

  • (String)


1543
1544
1545
1546
1547
1548
1549
1550
# File 'lib/aws-sdk-iotsitewise/types.rb', line 1543

class AssociateAssetsRequest < Struct.new(
  :asset_id,
  :hierarchy_id,
  :child_asset_id,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#client_tokenString

A unique case-sensitive identifier that you can provide to ensure the idempotency of the request. Don't reuse this client token if a new idempotent request is required.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


1543
1544
1545
1546
1547
1548
1549
1550
# File 'lib/aws-sdk-iotsitewise/types.rb', line 1543

class AssociateAssetsRequest < Struct.new(
  :asset_id,
  :hierarchy_id,
  :child_asset_id,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#hierarchy_idString

The ID of a hierarchy in the parent asset's model. (This can be either the actual ID in UUID format, or else externalId: followed by the external ID, if it has one. For more information, see Referencing objects with external IDs in the IoT SiteWise User Guide.) Hierarchies allow different groupings of assets to be formed that all come from the same asset model. For more information, see Asset hierarchies in the IoT SiteWise User Guide.

Returns:

  • (String)


1543
1544
1545
1546
1547
1548
1549
1550
# File 'lib/aws-sdk-iotsitewise/types.rb', line 1543

class AssociateAssetsRequest < Struct.new(
  :asset_id,
  :hierarchy_id,
  :child_asset_id,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end