Class: Aws::IoTSiteWise::Types::AssociatedAssetsSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTSiteWise::Types::AssociatedAssetsSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotsitewise/types.rb
Overview
Contains a summary of an associated asset.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The [ARN][1] of the asset, which has the following format.
-
#asset_model_id ⇒ String
The ID of the asset model used to create the asset.
-
#creation_date ⇒ Time
The date the asset was created, in Unix epoch time.
-
#description ⇒ String
A description for the asset.
-
#external_id ⇒ String
The external ID of the asset.
-
#hierarchies ⇒ Array<Types::AssetHierarchy>
A list of asset hierarchies that each contain a
hierarchyId. -
#id ⇒ String
The ID of the asset, in UUID format.
-
#last_update_date ⇒ Time
The date the asset was last updated, in Unix epoch time.
-
#name ⇒ String
The name of the asset.
-
#status ⇒ Types::AssetStatus
The current status of the asset.
Instance Attribute Details
#arn ⇒ String
The ARN of the asset, which has the following format.
arn:${Partition}:iotsitewise:${Region}:${Account}:asset/${AssetId}
1680 1681 1682 1683 1684 1685 1686 1687 1688 1689 1690 1691 1692 1693 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 1680 class AssociatedAssetsSummary < Struct.new( :id, :external_id, :arn, :name, :asset_model_id, :creation_date, :last_update_date, :status, :hierarchies, :description) SENSITIVE = [] include Aws::Structure end |
#asset_model_id ⇒ String
The ID of the asset model used to create the asset.
1680 1681 1682 1683 1684 1685 1686 1687 1688 1689 1690 1691 1692 1693 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 1680 class AssociatedAssetsSummary < Struct.new( :id, :external_id, :arn, :name, :asset_model_id, :creation_date, :last_update_date, :status, :hierarchies, :description) SENSITIVE = [] include Aws::Structure end |
#creation_date ⇒ Time
The date the asset was created, in Unix epoch time.
1680 1681 1682 1683 1684 1685 1686 1687 1688 1689 1690 1691 1692 1693 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 1680 class AssociatedAssetsSummary < Struct.new( :id, :external_id, :arn, :name, :asset_model_id, :creation_date, :last_update_date, :status, :hierarchies, :description) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description for the asset.
1680 1681 1682 1683 1684 1685 1686 1687 1688 1689 1690 1691 1692 1693 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 1680 class AssociatedAssetsSummary < Struct.new( :id, :external_id, :arn, :name, :asset_model_id, :creation_date, :last_update_date, :status, :hierarchies, :description) SENSITIVE = [] include Aws::Structure end |
#external_id ⇒ String
The external ID of the asset. For more information, see Using external IDs in the IoT SiteWise User Guide.
1680 1681 1682 1683 1684 1685 1686 1687 1688 1689 1690 1691 1692 1693 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 1680 class AssociatedAssetsSummary < Struct.new( :id, :external_id, :arn, :name, :asset_model_id, :creation_date, :last_update_date, :status, :hierarchies, :description) SENSITIVE = [] include Aws::Structure end |
#hierarchies ⇒ Array<Types::AssetHierarchy>
A list of asset hierarchies that each contain a hierarchyId. A
hierarchy specifies allowed parent/child asset relationships.
1680 1681 1682 1683 1684 1685 1686 1687 1688 1689 1690 1691 1692 1693 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 1680 class AssociatedAssetsSummary < Struct.new( :id, :external_id, :arn, :name, :asset_model_id, :creation_date, :last_update_date, :status, :hierarchies, :description) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The ID of the asset, in UUID format.
1680 1681 1682 1683 1684 1685 1686 1687 1688 1689 1690 1691 1692 1693 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 1680 class AssociatedAssetsSummary < Struct.new( :id, :external_id, :arn, :name, :asset_model_id, :creation_date, :last_update_date, :status, :hierarchies, :description) SENSITIVE = [] include Aws::Structure end |
#last_update_date ⇒ Time
The date the asset was last updated, in Unix epoch time.
1680 1681 1682 1683 1684 1685 1686 1687 1688 1689 1690 1691 1692 1693 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 1680 class AssociatedAssetsSummary < Struct.new( :id, :external_id, :arn, :name, :asset_model_id, :creation_date, :last_update_date, :status, :hierarchies, :description) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the asset.
1680 1681 1682 1683 1684 1685 1686 1687 1688 1689 1690 1691 1692 1693 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 1680 class AssociatedAssetsSummary < Struct.new( :id, :external_id, :arn, :name, :asset_model_id, :creation_date, :last_update_date, :status, :hierarchies, :description) SENSITIVE = [] include Aws::Structure end |
#status ⇒ Types::AssetStatus
The current status of the asset.
1680 1681 1682 1683 1684 1685 1686 1687 1688 1689 1690 1691 1692 1693 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 1680 class AssociatedAssetsSummary < Struct.new( :id, :external_id, :arn, :name, :asset_model_id, :creation_date, :last_update_date, :status, :hierarchies, :description) SENSITIVE = [] include Aws::Structure end |