Class: Aws::IoTSiteWise::Types::BatchAssociateDataSegmentsToDatasetRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotsitewise/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#associate_data_segment_entriesArray<Types::AssociateDataSegmentEntry>

The list of data segment entries to associate with the dataset.



1742
1743
1744
1745
1746
1747
1748
1749
# File 'lib/aws-sdk-iotsitewise/types.rb', line 1742

class BatchAssociateDataSegmentsToDatasetRequest < Struct.new(
  :dataset_id,
  :workspace_name,
  :associate_data_segment_entries,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#client_tokenString

A unique, case-sensitive identifier that you provide to ensure that the request is idempotent. If you retry a request that completed successfully using the same client token, the retry succeeds without performing any further actions.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


1742
1743
1744
1745
1746
1747
1748
1749
# File 'lib/aws-sdk-iotsitewise/types.rb', line 1742

class BatchAssociateDataSegmentsToDatasetRequest < Struct.new(
  :dataset_id,
  :workspace_name,
  :associate_data_segment_entries,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#dataset_idString

The ID of the curated dataset to associate data segments with.

Returns:

  • (String)


1742
1743
1744
1745
1746
1747
1748
1749
# File 'lib/aws-sdk-iotsitewise/types.rb', line 1742

class BatchAssociateDataSegmentsToDatasetRequest < Struct.new(
  :dataset_id,
  :workspace_name,
  :associate_data_segment_entries,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#workspace_nameString

The name of the workspace that contains the dataset.

Returns:

  • (String)


1742
1743
1744
1745
1746
1747
1748
1749
# File 'lib/aws-sdk-iotsitewise/types.rb', line 1742

class BatchAssociateDataSegmentsToDatasetRequest < Struct.new(
  :dataset_id,
  :workspace_name,
  :associate_data_segment_entries,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end