Class: Aws::IoTSiteWise::Types::BatchDeleteDatasetDataSegmentsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotsitewise/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique, case-sensitive identifier that you provide to ensure that the request is idempotent. If you retry a request that completed successfully using the same client token, the retry succeeds without performing any further actions.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


1828
1829
1830
1831
1832
1833
1834
1835
# File 'lib/aws-sdk-iotsitewise/types.rb', line 1828

class BatchDeleteDatasetDataSegmentsRequest < Struct.new(
  :dataset_id,
  :workspace_name,
  :delete_data_segment_entries,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#dataset_idString

The ID of the session dataset from which to delete data segments.

Returns:

  • (String)


1828
1829
1830
1831
1832
1833
1834
1835
# File 'lib/aws-sdk-iotsitewise/types.rb', line 1828

class BatchDeleteDatasetDataSegmentsRequest < Struct.new(
  :dataset_id,
  :workspace_name,
  :delete_data_segment_entries,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#delete_data_segment_entriesArray<Types::DeleteDataSegmentEntry>

The list of data segment entries to delete.

Returns:



1828
1829
1830
1831
1832
1833
1834
1835
# File 'lib/aws-sdk-iotsitewise/types.rb', line 1828

class BatchDeleteDatasetDataSegmentsRequest < Struct.new(
  :dataset_id,
  :workspace_name,
  :delete_data_segment_entries,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#workspace_nameString

The name of the workspace that contains the dataset.

Returns:

  • (String)


1828
1829
1830
1831
1832
1833
1834
1835
# File 'lib/aws-sdk-iotsitewise/types.rb', line 1828

class BatchDeleteDatasetDataSegmentsRequest < Struct.new(
  :dataset_id,
  :workspace_name,
  :delete_data_segment_entries,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end