Class: Aws::IoTSiteWise::Types::BatchDisassociateDataSegmentsFromDatasetRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotsitewise/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique, case-sensitive identifier that you provide to ensure that the request is idempotent. If you retry a request that completed successfully using the same client token, the retry succeeds without performing any further actions.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


1879
1880
1881
1882
1883
1884
1885
1886
# File 'lib/aws-sdk-iotsitewise/types.rb', line 1879

class BatchDisassociateDataSegmentsFromDatasetRequest < Struct.new(
  :dataset_id,
  :workspace_name,
  :disassociate_data_segment_entries,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#dataset_idString

The ID of the curated dataset to disassociate data segments from.

Returns:

  • (String)


1879
1880
1881
1882
1883
1884
1885
1886
# File 'lib/aws-sdk-iotsitewise/types.rb', line 1879

class BatchDisassociateDataSegmentsFromDatasetRequest < Struct.new(
  :dataset_id,
  :workspace_name,
  :disassociate_data_segment_entries,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#disassociate_data_segment_entriesArray<Types::DisassociateDataSegmentEntry>

The list of data segment entries to disassociate from the dataset.



1879
1880
1881
1882
1883
1884
1885
1886
# File 'lib/aws-sdk-iotsitewise/types.rb', line 1879

class BatchDisassociateDataSegmentsFromDatasetRequest < Struct.new(
  :dataset_id,
  :workspace_name,
  :disassociate_data_segment_entries,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#workspace_nameString

The name of the workspace that contains the dataset.

Returns:

  • (String)


1879
1880
1881
1882
1883
1884
1885
1886
# File 'lib/aws-sdk-iotsitewise/types.rb', line 1879

class BatchDisassociateDataSegmentsFromDatasetRequest < Struct.new(
  :dataset_id,
  :workspace_name,
  :disassociate_data_segment_entries,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end