Class: Aws::IoTSiteWise::Types::BatchGetAssetPropertyAggregatesErrorInfo

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotsitewise/types.rb

Overview

Contains the error code and the timestamp for an asset property aggregate entry that is associated with the BatchGetAssetPropertyAggregates API.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#error_codeString

The error code.

Returns:

  • (String)


2069
2070
2071
2072
2073
2074
# File 'lib/aws-sdk-iotsitewise/types.rb', line 2069

class BatchGetAssetPropertyAggregatesErrorInfo < Struct.new(
  :error_code,
  :error_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#error_timestampTime

The date the error occurred, in Unix epoch time.

Returns:

  • (Time)


2069
2070
2071
2072
2073
2074
# File 'lib/aws-sdk-iotsitewise/types.rb', line 2069

class BatchGetAssetPropertyAggregatesErrorInfo < Struct.new(
  :error_code,
  :error_timestamp)
  SENSITIVE = []
  include Aws::Structure
end