Class: Aws::IoTSiteWise::Types::BatchGetAssetPropertyAggregatesResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotsitewise/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#error_entriesArray<Types::BatchGetAssetPropertyAggregatesErrorEntry>

A list of the errors (if any) associated with the batch request. Each error entry contains the entryId of the entry that failed.



2126
2127
2128
2129
2130
2131
2132
2133
# File 'lib/aws-sdk-iotsitewise/types.rb', line 2126

class BatchGetAssetPropertyAggregatesResponse < Struct.new(
  :error_entries,
  :success_entries,
  :skipped_entries,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next set of results, or null if there are no additional results.

Returns:

  • (String)


2126
2127
2128
2129
2130
2131
2132
2133
# File 'lib/aws-sdk-iotsitewise/types.rb', line 2126

class BatchGetAssetPropertyAggregatesResponse < Struct.new(
  :error_entries,
  :success_entries,
  :skipped_entries,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#skipped_entriesArray<Types::BatchGetAssetPropertyAggregatesSkippedEntry>

A list of entries that were not processed by this batch request. because these entries had been completely processed by previous paginated requests. Each skipped entry contains the entryId of the entry that skipped.



2126
2127
2128
2129
2130
2131
2132
2133
# File 'lib/aws-sdk-iotsitewise/types.rb', line 2126

class BatchGetAssetPropertyAggregatesResponse < Struct.new(
  :error_entries,
  :success_entries,
  :skipped_entries,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#success_entriesArray<Types::BatchGetAssetPropertyAggregatesSuccessEntry>

A list of entries that were processed successfully by this batch request. Each success entry contains the entryId of the entry that succeeded and the latest query result.



2126
2127
2128
2129
2130
2131
2132
2133
# File 'lib/aws-sdk-iotsitewise/types.rb', line 2126

class BatchGetAssetPropertyAggregatesResponse < Struct.new(
  :error_entries,
  :success_entries,
  :skipped_entries,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end