Class: Aws::IoTSiteWise::Types::BatchGetAssetPropertyValueErrorInfo

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotsitewise/types.rb

Overview

The error information, such as the error code and the timestamp.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#error_codeString

The error code.

Returns:

  • (String)


2276
2277
2278
2279
2280
2281
# File 'lib/aws-sdk-iotsitewise/types.rb', line 2276

class BatchGetAssetPropertyValueErrorInfo < Struct.new(
  :error_code,
  :error_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#error_timestampTime

The date the error occurred, in Unix epoch time.

Returns:

  • (Time)


2276
2277
2278
2279
2280
2281
# File 'lib/aws-sdk-iotsitewise/types.rb', line 2276

class BatchGetAssetPropertyValueErrorInfo < Struct.new(
  :error_code,
  :error_timestamp)
  SENSITIVE = []
  include Aws::Structure
end