Class: Aws::IoTSiteWise::Types::BatchGetAssetPropertyValueHistoryEntry
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTSiteWise::Types::BatchGetAssetPropertyValueHistoryEntry
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotsitewise/types.rb
Overview
Contains information for an asset property historical value entry that is associated with the BatchGetAssetPropertyValueHistory API.
To identify an asset property, you must specify one of the following:
-
The
assetIdandpropertyIdof an asset property. -
A
propertyAlias, which is a data stream alias (for example,/company/windfarm/3/turbine/7/temperature). To define an asset property's alias, see UpdateAssetProperty.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#asset_id ⇒ String
The ID of the asset in which the asset property was created.
-
#end_date ⇒ Time
The inclusive end of the range from which to query historical data, expressed in seconds in Unix epoch time.
-
#entry_id ⇒ String
The ID of the entry.
-
#property_alias ⇒ String
The alias that identifies the property, such as an OPC-UA server data stream path (for example,
/company/windfarm/3/turbine/7/temperature). -
#property_id ⇒ String
The ID of the asset property, in UUID format.
-
#qualities ⇒ Array<String>
The quality by which to filter asset data.
-
#start_date ⇒ Time
The exclusive start of the range from which to query historical data, expressed in seconds in Unix epoch time.
-
#time_ordering ⇒ String
The chronological sorting order of the requested information.
Instance Attribute Details
#asset_id ⇒ String
The ID of the asset in which the asset property was created.
2343 2344 2345 2346 2347 2348 2349 2350 2351 2352 2353 2354 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 2343 class BatchGetAssetPropertyValueHistoryEntry < Struct.new( :entry_id, :asset_id, :property_id, :property_alias, :start_date, :end_date, :qualities, :time_ordering) SENSITIVE = [] include Aws::Structure end |
#end_date ⇒ Time
The inclusive end of the range from which to query historical data, expressed in seconds in Unix epoch time.
2343 2344 2345 2346 2347 2348 2349 2350 2351 2352 2353 2354 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 2343 class BatchGetAssetPropertyValueHistoryEntry < Struct.new( :entry_id, :asset_id, :property_id, :property_alias, :start_date, :end_date, :qualities, :time_ordering) SENSITIVE = [] include Aws::Structure end |
#entry_id ⇒ String
The ID of the entry.
2343 2344 2345 2346 2347 2348 2349 2350 2351 2352 2353 2354 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 2343 class BatchGetAssetPropertyValueHistoryEntry < Struct.new( :entry_id, :asset_id, :property_id, :property_alias, :start_date, :end_date, :qualities, :time_ordering) SENSITIVE = [] include Aws::Structure end |
#property_alias ⇒ String
The alias that identifies the property, such as an OPC-UA server
data stream path (for example,
/company/windfarm/3/turbine/7/temperature). For more information,
see Mapping industrial data streams to asset properties in the
IoT SiteWise User Guide.
2343 2344 2345 2346 2347 2348 2349 2350 2351 2352 2353 2354 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 2343 class BatchGetAssetPropertyValueHistoryEntry < Struct.new( :entry_id, :asset_id, :property_id, :property_alias, :start_date, :end_date, :qualities, :time_ordering) SENSITIVE = [] include Aws::Structure end |
#property_id ⇒ String
The ID of the asset property, in UUID format.
2343 2344 2345 2346 2347 2348 2349 2350 2351 2352 2353 2354 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 2343 class BatchGetAssetPropertyValueHistoryEntry < Struct.new( :entry_id, :asset_id, :property_id, :property_alias, :start_date, :end_date, :qualities, :time_ordering) SENSITIVE = [] include Aws::Structure end |
#qualities ⇒ Array<String>
The quality by which to filter asset data.
2343 2344 2345 2346 2347 2348 2349 2350 2351 2352 2353 2354 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 2343 class BatchGetAssetPropertyValueHistoryEntry < Struct.new( :entry_id, :asset_id, :property_id, :property_alias, :start_date, :end_date, :qualities, :time_ordering) SENSITIVE = [] include Aws::Structure end |
#start_date ⇒ Time
The exclusive start of the range from which to query historical data, expressed in seconds in Unix epoch time.
2343 2344 2345 2346 2347 2348 2349 2350 2351 2352 2353 2354 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 2343 class BatchGetAssetPropertyValueHistoryEntry < Struct.new( :entry_id, :asset_id, :property_id, :property_alias, :start_date, :end_date, :qualities, :time_ordering) SENSITIVE = [] include Aws::Structure end |
#time_ordering ⇒ String
The chronological sorting order of the requested information.
Default: ASCENDING
2343 2344 2345 2346 2347 2348 2349 2350 2351 2352 2353 2354 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 2343 class BatchGetAssetPropertyValueHistoryEntry < Struct.new( :entry_id, :asset_id, :property_id, :property_alias, :start_date, :end_date, :qualities, :time_ordering) SENSITIVE = [] include Aws::Structure end |