Class: Aws::IoTSiteWise::Types::BatchGetAssetPropertyValueHistoryResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotsitewise/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#error_entriesArray<Types::BatchGetAssetPropertyValueHistoryErrorEntry>

A list of the errors (if any) associated with the batch request. Each error entry contains the entryId of the entry that failed.



2446
2447
2448
2449
2450
2451
2452
2453
# File 'lib/aws-sdk-iotsitewise/types.rb', line 2446

class BatchGetAssetPropertyValueHistoryResponse < Struct.new(
  :error_entries,
  :success_entries,
  :skipped_entries,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next set of results, or null if there are no additional results.

Returns:

  • (String)


2446
2447
2448
2449
2450
2451
2452
2453
# File 'lib/aws-sdk-iotsitewise/types.rb', line 2446

class BatchGetAssetPropertyValueHistoryResponse < Struct.new(
  :error_entries,
  :success_entries,
  :skipped_entries,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#skipped_entriesArray<Types::BatchGetAssetPropertyValueHistorySkippedEntry>

A list of entries that were not processed by this batch request. because these entries had been completely processed by previous paginated requests. Each skipped entry contains the entryId of the entry that skipped.



2446
2447
2448
2449
2450
2451
2452
2453
# File 'lib/aws-sdk-iotsitewise/types.rb', line 2446

class BatchGetAssetPropertyValueHistoryResponse < Struct.new(
  :error_entries,
  :success_entries,
  :skipped_entries,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#success_entriesArray<Types::BatchGetAssetPropertyValueHistorySuccessEntry>

A list of entries that were processed successfully by this batch request. Each success entry contains the entryId of the entry that succeeded and the latest query result.



2446
2447
2448
2449
2450
2451
2452
2453
# File 'lib/aws-sdk-iotsitewise/types.rb', line 2446

class BatchGetAssetPropertyValueHistoryResponse < Struct.new(
  :error_entries,
  :success_entries,
  :skipped_entries,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end