Class: Aws::IoTSiteWise::Types::BatchGetAssetPropertyValueHistorySkippedEntry

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotsitewise/types.rb

Overview

Contains information for an entry that has been processed by the previous BatchGetAssetPropertyValueHistory request.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#completion_statusString

The completion status of each entry that is associated with the BatchGetAssetPropertyValueHistory API.

Returns:

  • (String)


2479
2480
2481
2482
2483
2484
2485
# File 'lib/aws-sdk-iotsitewise/types.rb', line 2479

class BatchGetAssetPropertyValueHistorySkippedEntry < Struct.new(
  :entry_id,
  :completion_status,
  :error_info)
  SENSITIVE = []
  include Aws::Structure
end

#entry_idString

The ID of the entry.

Returns:

  • (String)


2479
2480
2481
2482
2483
2484
2485
# File 'lib/aws-sdk-iotsitewise/types.rb', line 2479

class BatchGetAssetPropertyValueHistorySkippedEntry < Struct.new(
  :entry_id,
  :completion_status,
  :error_info)
  SENSITIVE = []
  include Aws::Structure
end

#error_infoTypes::BatchGetAssetPropertyValueHistoryErrorInfo

The error information, such as the error code and the timestamp.



2479
2480
2481
2482
2483
2484
2485
# File 'lib/aws-sdk-iotsitewise/types.rb', line 2479

class BatchGetAssetPropertyValueHistorySkippedEntry < Struct.new(
  :entry_id,
  :completion_status,
  :error_info)
  SENSITIVE = []
  include Aws::Structure
end