Class: Aws::IoTSiteWise::Types::BatchPutAssetPropertyValueRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotsitewise/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#enable_partial_entry_processingBoolean

This setting enables partial ingestion at entry-level. If set to true, we ingest all TQVs not resulting in an error. If set to false, an invalid TQV fails ingestion of the entire entry that contains it.

Returns:

  • (Boolean)


2668
2669
2670
2671
2672
2673
# File 'lib/aws-sdk-iotsitewise/types.rb', line 2668

class BatchPutAssetPropertyValueRequest < Struct.new(
  :enable_partial_entry_processing,
  :entries)
  SENSITIVE = []
  include Aws::Structure
end

#entriesArray<Types::PutAssetPropertyValueEntry>

The list of asset property value entries for the batch put request. You can specify up to 10 entries per request.



2668
2669
2670
2671
2672
2673
# File 'lib/aws-sdk-iotsitewise/types.rb', line 2668

class BatchPutAssetPropertyValueRequest < Struct.new(
  :enable_partial_entry_processing,
  :entries)
  SENSITIVE = []
  include Aws::Structure
end