Class: Aws::IoTSiteWise::Types::CancelEnrichmentJobRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTSiteWise::Types::CancelEnrichmentJobRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotsitewise/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#job_id ⇒ String
The unique identifier of the enrichment job to cancel.
-
#workspace_name ⇒ String
The name of the IoT SiteWise workspace containing the enrichment job to cancel.
Instance Attribute Details
#job_id ⇒ String
The unique identifier of the enrichment job to cancel. This is the jobId returned by CreateEnrichmentJob.
2696 2697 2698 2699 2700 2701 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 2696 class CancelEnrichmentJobRequest < Struct.new( :workspace_name, :job_id) SENSITIVE = [] include Aws::Structure end |
#workspace_name ⇒ String
The name of the IoT SiteWise workspace containing the enrichment job to cancel.
2696 2697 2698 2699 2700 2701 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 2696 class CancelEnrichmentJobRequest < Struct.new( :workspace_name, :job_id) SENSITIVE = [] include Aws::Structure end |