Class: Aws::IoTSiteWise::Types::CancelPipelineExecutionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTSiteWise::Types::CancelPipelineExecutionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotsitewise/types.rb
Overview
Request structure for CancelPipelineExecution operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#pipeline_execution_id ⇒ String
The unique identifier of the pipeline execution.
-
#pipeline_name ⇒ String
The name of the pipeline.
-
#reason ⇒ String
A message describing why the pipeline execution is being cancelled.
-
#workspace_name ⇒ String
The name of the workspace.
Instance Attribute Details
#pipeline_execution_id ⇒ String
The unique identifier of the pipeline execution.
2738 2739 2740 2741 2742 2743 2744 2745 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 2738 class CancelPipelineExecutionRequest < Struct.new( :workspace_name, :pipeline_name, :pipeline_execution_id, :reason) SENSITIVE = [] include Aws::Structure end |
#pipeline_name ⇒ String
The name of the pipeline.
2738 2739 2740 2741 2742 2743 2744 2745 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 2738 class CancelPipelineExecutionRequest < Struct.new( :workspace_name, :pipeline_name, :pipeline_execution_id, :reason) SENSITIVE = [] include Aws::Structure end |
#reason ⇒ String
A message describing why the pipeline execution is being cancelled.
2738 2739 2740 2741 2742 2743 2744 2745 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 2738 class CancelPipelineExecutionRequest < Struct.new( :workspace_name, :pipeline_name, :pipeline_execution_id, :reason) SENSITIVE = [] include Aws::Structure end |
#workspace_name ⇒ String
The name of the workspace.
2738 2739 2740 2741 2742 2743 2744 2745 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 2738 class CancelPipelineExecutionRequest < Struct.new( :workspace_name, :pipeline_name, :pipeline_execution_id, :reason) SENSITIVE = [] include Aws::Structure end |