Class: Aws::IoTSiteWise::Types::CancelQueryRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotsitewise/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#query_idString

The unique identifier for the query execution to cancel.

Returns:

  • (String)


2768
2769
2770
2771
2772
2773
# File 'lib/aws-sdk-iotsitewise/types.rb', line 2768

class CancelQueryRequest < Struct.new(
  :workspace_name,
  :query_id)
  SENSITIVE = []
  include Aws::Structure
end

#workspace_nameString

The name of the workspace associated with the query.

Returns:

  • (String)


2768
2769
2770
2771
2772
2773
# File 'lib/aws-sdk-iotsitewise/types.rb', line 2768

class CancelQueryRequest < Struct.new(
  :workspace_name,
  :query_id)
  SENSITIVE = []
  include Aws::Structure
end