Class: Aws::IoTSiteWise::Types::CompositeModelProperty
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTSiteWise::Types::CompositeModelProperty
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotsitewise/types.rb
Overview
Contains information about a composite model property on an asset.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#asset_property ⇒ Types::Property
Contains asset property information.
-
#external_id ⇒ String
The external ID of the composite model that contains the property.
-
#id ⇒ String
The ID of the composite model that contains the property.
-
#name ⇒ String
The name of the property.
-
#type ⇒ String
The type of the composite model that defines this property.
Instance Attribute Details
#asset_property ⇒ Types::Property
Contains asset property information.
2886 2887 2888 2889 2890 2891 2892 2893 2894 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 2886 class CompositeModelProperty < Struct.new( :name, :type, :asset_property, :id, :external_id) SENSITIVE = [] include Aws::Structure end |
#external_id ⇒ String
The external ID of the composite model that contains the property. For more information, see Using external IDs in the IoT SiteWise User Guide.
2886 2887 2888 2889 2890 2891 2892 2893 2894 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 2886 class CompositeModelProperty < Struct.new( :name, :type, :asset_property, :id, :external_id) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The ID of the composite model that contains the property.
2886 2887 2888 2889 2890 2891 2892 2893 2894 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 2886 class CompositeModelProperty < Struct.new( :name, :type, :asset_property, :id, :external_id) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the property.
2886 2887 2888 2889 2890 2891 2892 2893 2894 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 2886 class CompositeModelProperty < Struct.new( :name, :type, :asset_property, :id, :external_id) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of the composite model that defines this property.
2886 2887 2888 2889 2890 2891 2892 2893 2894 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 2886 class CompositeModelProperty < Struct.new( :name, :type, :asset_property, :id, :external_id) SENSITIVE = [] include Aws::Structure end |