Class: Aws::IoTSiteWise::Types::ComputationModelSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTSiteWise::Types::ComputationModelSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotsitewise/types.rb
Overview
Contains a summary of a computation model.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The [ARN][1] of the computation model, which has the following format.
-
#creation_date ⇒ Time
The model creation date, in Unix epoch time.
-
#description ⇒ String
The description of the computation model.
-
#id ⇒ String
The ID of the computation model.
-
#last_update_date ⇒ Time
The time the model was last updated, in Unix epoch time.
-
#name ⇒ String
The name of the computation model.
-
#status ⇒ Types::ComputationModelStatus
The current status of the computation model.
-
#type ⇒ String
The type of the computation model.
-
#version ⇒ String
The version of the computation model.
Instance Attribute Details
#arn ⇒ String
The ARN of the computation model, which has the following format.
arn:${Partition}:iotsitewise:${Region}:${Account}:computation-model/${ComputationModelId}
3103 3104 3105 3106 3107 3108 3109 3110 3111 3112 3113 3114 3115 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 3103 class ComputationModelSummary < Struct.new( :id, :arn, :name, :description, :type, :creation_date, :last_update_date, :status, :version) SENSITIVE = [] include Aws::Structure end |
#creation_date ⇒ Time
The model creation date, in Unix epoch time.
3103 3104 3105 3106 3107 3108 3109 3110 3111 3112 3113 3114 3115 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 3103 class ComputationModelSummary < Struct.new( :id, :arn, :name, :description, :type, :creation_date, :last_update_date, :status, :version) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the computation model.
3103 3104 3105 3106 3107 3108 3109 3110 3111 3112 3113 3114 3115 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 3103 class ComputationModelSummary < Struct.new( :id, :arn, :name, :description, :type, :creation_date, :last_update_date, :status, :version) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The ID of the computation model.
3103 3104 3105 3106 3107 3108 3109 3110 3111 3112 3113 3114 3115 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 3103 class ComputationModelSummary < Struct.new( :id, :arn, :name, :description, :type, :creation_date, :last_update_date, :status, :version) SENSITIVE = [] include Aws::Structure end |
#last_update_date ⇒ Time
The time the model was last updated, in Unix epoch time.
3103 3104 3105 3106 3107 3108 3109 3110 3111 3112 3113 3114 3115 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 3103 class ComputationModelSummary < Struct.new( :id, :arn, :name, :description, :type, :creation_date, :last_update_date, :status, :version) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the computation model.
3103 3104 3105 3106 3107 3108 3109 3110 3111 3112 3113 3114 3115 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 3103 class ComputationModelSummary < Struct.new( :id, :arn, :name, :description, :type, :creation_date, :last_update_date, :status, :version) SENSITIVE = [] include Aws::Structure end |
#status ⇒ Types::ComputationModelStatus
The current status of the computation model.
3103 3104 3105 3106 3107 3108 3109 3110 3111 3112 3113 3114 3115 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 3103 class ComputationModelSummary < Struct.new( :id, :arn, :name, :description, :type, :creation_date, :last_update_date, :status, :version) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of the computation model.
3103 3104 3105 3106 3107 3108 3109 3110 3111 3112 3113 3114 3115 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 3103 class ComputationModelSummary < Struct.new( :id, :arn, :name, :description, :type, :creation_date, :last_update_date, :status, :version) SENSITIVE = [] include Aws::Structure end |
#version ⇒ String
The version of the computation model.
3103 3104 3105 3106 3107 3108 3109 3110 3111 3112 3113 3114 3115 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 3103 class ComputationModelSummary < Struct.new( :id, :arn, :name, :description, :type, :creation_date, :last_update_date, :status, :version) SENSITIVE = [] include Aws::Structure end |