Class: Aws::IoTSiteWise::Types::ComputeNodeExecutionDetails

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotsitewise/types.rb

Overview

Contains detailed execution information for a compute node within a pipeline execution.

Constant Summary collapse

SENSITIVE =
[:execution_environment_variables]

Instance Attribute Summary collapse

Instance Attribute Details

#compute_node_nameString

The name of the compute node.

Returns:

  • (String)


3187
3188
3189
3190
3191
3192
3193
3194
3195
3196
3197
3198
3199
# File 'lib/aws-sdk-iotsitewise/types.rb', line 3187

class ComputeNodeExecutionDetails < Struct.new(
  :compute_node_name,
  :task_name,
  :task_arn,
  :task_version,
  :depends_on,
  :status,
  :start_time,
  :end_time,
  :execution_environment_variables)
  SENSITIVE = [:execution_environment_variables]
  include Aws::Structure
end

#depends_onArray<String>

A list of compute node names that this node depends on.

Returns:

  • (Array<String>)


3187
3188
3189
3190
3191
3192
3193
3194
3195
3196
3197
3198
3199
# File 'lib/aws-sdk-iotsitewise/types.rb', line 3187

class ComputeNodeExecutionDetails < Struct.new(
  :compute_node_name,
  :task_name,
  :task_arn,
  :task_version,
  :depends_on,
  :status,
  :start_time,
  :end_time,
  :execution_environment_variables)
  SENSITIVE = [:execution_environment_variables]
  include Aws::Structure
end

#end_timeTime

The time the compute node execution completed, in Unix epoch time.

Returns:

  • (Time)


3187
3188
3189
3190
3191
3192
3193
3194
3195
3196
3197
3198
3199
# File 'lib/aws-sdk-iotsitewise/types.rb', line 3187

class ComputeNodeExecutionDetails < Struct.new(
  :compute_node_name,
  :task_name,
  :task_arn,
  :task_version,
  :depends_on,
  :status,
  :start_time,
  :end_time,
  :execution_environment_variables)
  SENSITIVE = [:execution_environment_variables]
  include Aws::Structure
end

#execution_environment_variablesHash<String,String>

The fully resolved environment variables used for this compute node execution.

Returns:

  • (Hash<String,String>)


3187
3188
3189
3190
3191
3192
3193
3194
3195
3196
3197
3198
3199
# File 'lib/aws-sdk-iotsitewise/types.rb', line 3187

class ComputeNodeExecutionDetails < Struct.new(
  :compute_node_name,
  :task_name,
  :task_arn,
  :task_version,
  :depends_on,
  :status,
  :start_time,
  :end_time,
  :execution_environment_variables)
  SENSITIVE = [:execution_environment_variables]
  include Aws::Structure
end

#start_timeTime

The time the compute node execution started, in Unix epoch time.

Returns:

  • (Time)


3187
3188
3189
3190
3191
3192
3193
3194
3195
3196
3197
3198
3199
# File 'lib/aws-sdk-iotsitewise/types.rb', line 3187

class ComputeNodeExecutionDetails < Struct.new(
  :compute_node_name,
  :task_name,
  :task_arn,
  :task_version,
  :depends_on,
  :status,
  :start_time,
  :end_time,
  :execution_environment_variables)
  SENSITIVE = [:execution_environment_variables]
  include Aws::Structure
end

#statusTypes::ComputeNodeExecutionStatus

The current execution status of the compute node.



3187
3188
3189
3190
3191
3192
3193
3194
3195
3196
3197
3198
3199
# File 'lib/aws-sdk-iotsitewise/types.rb', line 3187

class ComputeNodeExecutionDetails < Struct.new(
  :compute_node_name,
  :task_name,
  :task_arn,
  :task_version,
  :depends_on,
  :status,
  :start_time,
  :end_time,
  :execution_environment_variables)
  SENSITIVE = [:execution_environment_variables]
  include Aws::Structure
end

#task_arnString

The ARN of the task.

Returns:

  • (String)


3187
3188
3189
3190
3191
3192
3193
3194
3195
3196
3197
3198
3199
# File 'lib/aws-sdk-iotsitewise/types.rb', line 3187

class ComputeNodeExecutionDetails < Struct.new(
  :compute_node_name,
  :task_name,
  :task_arn,
  :task_version,
  :depends_on,
  :status,
  :start_time,
  :end_time,
  :execution_environment_variables)
  SENSITIVE = [:execution_environment_variables]
  include Aws::Structure
end

#task_nameString

The name of the task executed for this compute node.

Returns:

  • (String)


3187
3188
3189
3190
3191
3192
3193
3194
3195
3196
3197
3198
3199
# File 'lib/aws-sdk-iotsitewise/types.rb', line 3187

class ComputeNodeExecutionDetails < Struct.new(
  :compute_node_name,
  :task_name,
  :task_arn,
  :task_version,
  :depends_on,
  :status,
  :start_time,
  :end_time,
  :execution_environment_variables)
  SENSITIVE = [:execution_environment_variables]
  include Aws::Structure
end

#task_versionString

The task version that executed for this compute node.

Returns:

  • (String)


3187
3188
3189
3190
3191
3192
3193
3194
3195
3196
3197
3198
3199
# File 'lib/aws-sdk-iotsitewise/types.rb', line 3187

class ComputeNodeExecutionDetails < Struct.new(
  :compute_node_name,
  :task_name,
  :task_arn,
  :task_version,
  :depends_on,
  :status,
  :start_time,
  :end_time,
  :execution_environment_variables)
  SENSITIVE = [:execution_environment_variables]
  include Aws::Structure
end