Class: Aws::IoTSiteWise::Types::ContainerTaskConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotsitewise/types.rb

Overview

Configuration for a container task, including the container image, IAM role, and compute settings.

Constant Summary collapse

SENSITIVE =
[:ecr_uri, :task_execution_role, :command, :environment_variables]

Instance Attribute Summary collapse

Instance Attribute Details

#commandArray<String>

The command to execute in the container.

Returns:

  • (Array<String>)


3333
3334
3335
3336
3337
3338
3339
3340
3341
3342
3343
# File 'lib/aws-sdk-iotsitewise/types.rb', line 3333

class ContainerTaskConfiguration < Struct.new(
  :ecr_uri,
  :task_execution_role,
  :processing_type,
  :processing_unit,
  :command,
  :timeout_seconds,
  :environment_variables)
  SENSITIVE = [:ecr_uri, :task_execution_role, :command, :environment_variables]
  include Aws::Structure
end

#ecr_uriString

The Amazon ECR image URI for the task container.

Returns:

  • (String)


3333
3334
3335
3336
3337
3338
3339
3340
3341
3342
3343
# File 'lib/aws-sdk-iotsitewise/types.rb', line 3333

class ContainerTaskConfiguration < Struct.new(
  :ecr_uri,
  :task_execution_role,
  :processing_type,
  :processing_unit,
  :command,
  :timeout_seconds,
  :environment_variables)
  SENSITIVE = [:ecr_uri, :task_execution_role, :command, :environment_variables]
  include Aws::Structure
end

#environment_variablesHash<String,String>

Environment variables passed to the container at runtime.

Returns:

  • (Hash<String,String>)


3333
3334
3335
3336
3337
3338
3339
3340
3341
3342
3343
# File 'lib/aws-sdk-iotsitewise/types.rb', line 3333

class ContainerTaskConfiguration < Struct.new(
  :ecr_uri,
  :task_execution_role,
  :processing_type,
  :processing_unit,
  :command,
  :timeout_seconds,
  :environment_variables)
  SENSITIVE = [:ecr_uri, :task_execution_role, :command, :environment_variables]
  include Aws::Structure
end

#processing_typeString

The processing type for compute resources.

Returns:

  • (String)


3333
3334
3335
3336
3337
3338
3339
3340
3341
3342
3343
# File 'lib/aws-sdk-iotsitewise/types.rb', line 3333

class ContainerTaskConfiguration < Struct.new(
  :ecr_uri,
  :task_execution_role,
  :processing_type,
  :processing_unit,
  :command,
  :timeout_seconds,
  :environment_variables)
  SENSITIVE = [:ecr_uri, :task_execution_role, :command, :environment_variables]
  include Aws::Structure
end

#processing_unitString

The processing unit allocation that determines the vCPU, memory, and GPU resources.

Returns:

  • (String)


3333
3334
3335
3336
3337
3338
3339
3340
3341
3342
3343
# File 'lib/aws-sdk-iotsitewise/types.rb', line 3333

class ContainerTaskConfiguration < Struct.new(
  :ecr_uri,
  :task_execution_role,
  :processing_type,
  :processing_unit,
  :command,
  :timeout_seconds,
  :environment_variables)
  SENSITIVE = [:ecr_uri, :task_execution_role, :command, :environment_variables]
  include Aws::Structure
end

#task_execution_roleString

The ARN of the IAM role that grants the containerized workload permissions to access AWS resources.

Returns:

  • (String)


3333
3334
3335
3336
3337
3338
3339
3340
3341
3342
3343
# File 'lib/aws-sdk-iotsitewise/types.rb', line 3333

class ContainerTaskConfiguration < Struct.new(
  :ecr_uri,
  :task_execution_role,
  :processing_type,
  :processing_unit,
  :command,
  :timeout_seconds,
  :environment_variables)
  SENSITIVE = [:ecr_uri, :task_execution_role, :command, :environment_variables]
  include Aws::Structure
end

#timeout_secondsInteger

The timeout in seconds for task execution. Default: 3600 (1 hour).

Returns:

  • (Integer)


3333
3334
3335
3336
3337
3338
3339
3340
3341
3342
3343
# File 'lib/aws-sdk-iotsitewise/types.rb', line 3333

class ContainerTaskConfiguration < Struct.new(
  :ecr_uri,
  :task_execution_role,
  :processing_type,
  :processing_unit,
  :command,
  :timeout_seconds,
  :environment_variables)
  SENSITIVE = [:ecr_uri, :task_execution_role, :command, :environment_variables]
  include Aws::Structure
end