Class: Aws::IoTSiteWise::Types::CreateApplicationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotsitewise/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

Unique client token for idempotent request handling

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


3449
3450
3451
3452
3453
3454
3455
3456
3457
3458
# File 'lib/aws-sdk-iotsitewise/types.rb', line 3449

class CreateApplicationRequest < Struct.new(
  :client_token,
  :idc_instance_arn,
  :workspace_name,
  :name,
  :description,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

Description of the application

Returns:

  • (String)


3449
3450
3451
3452
3453
3454
3455
3456
3457
3458
# File 'lib/aws-sdk-iotsitewise/types.rb', line 3449

class CreateApplicationRequest < Struct.new(
  :client_token,
  :idc_instance_arn,
  :workspace_name,
  :name,
  :description,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#idc_instance_arnString

Identity Center Instance ARN to create the application in

Returns:

  • (String)


3449
3450
3451
3452
3453
3454
3455
3456
3457
3458
# File 'lib/aws-sdk-iotsitewise/types.rb', line 3449

class CreateApplicationRequest < Struct.new(
  :client_token,
  :idc_instance_arn,
  :workspace_name,
  :name,
  :description,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

Name of the application

Returns:

  • (String)


3449
3450
3451
3452
3453
3454
3455
3456
3457
3458
# File 'lib/aws-sdk-iotsitewise/types.rb', line 3449

class CreateApplicationRequest < Struct.new(
  :client_token,
  :idc_instance_arn,
  :workspace_name,
  :name,
  :description,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

A list of key-value pairs that contain metadata for the application.

Returns:

  • (Hash<String,String>)


3449
3450
3451
3452
3453
3454
3455
3456
3457
3458
# File 'lib/aws-sdk-iotsitewise/types.rb', line 3449

class CreateApplicationRequest < Struct.new(
  :client_token,
  :idc_instance_arn,
  :workspace_name,
  :name,
  :description,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#workspace_nameString

Name of the workspace to associate with the underlying Application

Returns:

  • (String)


3449
3450
3451
3452
3453
3454
3455
3456
3457
3458
# File 'lib/aws-sdk-iotsitewise/types.rb', line 3449

class CreateApplicationRequest < Struct.new(
  :client_token,
  :idc_instance_arn,
  :workspace_name,
  :name,
  :description,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end