Class: Aws::IoTSiteWise::Types::CreateAssetModelCompositeModelResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTSiteWise::Types::CreateAssetModelCompositeModelResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotsitewise/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#asset_model_composite_model_id ⇒ String
The ID of the composed asset model.
-
#asset_model_composite_model_path ⇒ Array<Types::AssetModelCompositeModelPathSegment>
The path to the composite model listing the parent composite models.
-
#asset_model_id ⇒ String
The ID of the asset model.
-
#asset_model_status ⇒ Types::AssetModelStatus
Contains current status information for an asset model.
Instance Attribute Details
#asset_model_composite_model_id ⇒ String
The ID of the composed asset model. You can use this ID when you call other IoT SiteWise APIs.
3622 3623 3624 3625 3626 3627 3628 3629 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 3622 class CreateAssetModelCompositeModelResponse < Struct.new( :asset_model_composite_model_id, :asset_model_composite_model_path, :asset_model_status, :asset_model_id) SENSITIVE = [] include Aws::Structure end |
#asset_model_composite_model_path ⇒ Array<Types::AssetModelCompositeModelPathSegment>
The path to the composite model listing the parent composite models.
3622 3623 3624 3625 3626 3627 3628 3629 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 3622 class CreateAssetModelCompositeModelResponse < Struct.new( :asset_model_composite_model_id, :asset_model_composite_model_path, :asset_model_status, :asset_model_id) SENSITIVE = [] include Aws::Structure end |
#asset_model_id ⇒ String
The ID of the asset model.
3622 3623 3624 3625 3626 3627 3628 3629 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 3622 class CreateAssetModelCompositeModelResponse < Struct.new( :asset_model_composite_model_id, :asset_model_composite_model_path, :asset_model_status, :asset_model_id) SENSITIVE = [] include Aws::Structure end |
#asset_model_status ⇒ Types::AssetModelStatus
Contains current status information for an asset model. For more information, see Asset and model states in the IoT SiteWise User Guide.
3622 3623 3624 3625 3626 3627 3628 3629 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 3622 class CreateAssetModelCompositeModelResponse < Struct.new( :asset_model_composite_model_id, :asset_model_composite_model_path, :asset_model_status, :asset_model_id) SENSITIVE = [] include Aws::Structure end |