Class: Aws::IoTSiteWise::Types::CreateAssetResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTSiteWise::Types::CreateAssetResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotsitewise/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#asset_arn ⇒ String
The [ARN][1] of the asset, which has the following format.
-
#asset_id ⇒ String
The ID of the asset, in UUID format.
-
#asset_status ⇒ Types::AssetStatus
The status of the asset, which contains a state (
CREATINGafter successfully calling this operation) and any error message.
Instance Attribute Details
#asset_arn ⇒ String
The ARN of the asset, which has the following format.
arn:${Partition}:iotsitewise:${Region}:${Account}:asset/${AssetId}
3872 3873 3874 3875 3876 3877 3878 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 3872 class CreateAssetResponse < Struct.new( :asset_id, :asset_arn, :asset_status) SENSITIVE = [] include Aws::Structure end |
#asset_id ⇒ String
The ID of the asset, in UUID format. This ID uniquely identifies the asset within IoT SiteWise and can be used with other IoT SiteWise API operations.
3872 3873 3874 3875 3876 3877 3878 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 3872 class CreateAssetResponse < Struct.new( :asset_id, :asset_arn, :asset_status) SENSITIVE = [] include Aws::Structure end |
#asset_status ⇒ Types::AssetStatus
The status of the asset, which contains a state (CREATING after
successfully calling this operation) and any error message.
3872 3873 3874 3875 3876 3877 3878 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 3872 class CreateAssetResponse < Struct.new( :asset_id, :asset_arn, :asset_status) SENSITIVE = [] include Aws::Structure end |