Class: Aws::IoTSiteWise::Types::CreateBulkImportJobResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTSiteWise::Types::CreateBulkImportJobResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotsitewise/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#job_id ⇒ String
The ID of the job.
-
#job_name ⇒ String
The unique name that helps identify the job request.
-
#job_status ⇒ String
The status of the bulk import job can be one of following values:.
Instance Attribute Details
#job_id ⇒ String
The ID of the job.
4005 4006 4007 4008 4009 4010 4011 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 4005 class CreateBulkImportJobResponse < Struct.new( :job_id, :job_name, :job_status) SENSITIVE = [] include Aws::Structure end |
#job_name ⇒ String
The unique name that helps identify the job request.
4005 4006 4007 4008 4009 4010 4011 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 4005 class CreateBulkImportJobResponse < Struct.new( :job_id, :job_name, :job_status) SENSITIVE = [] include Aws::Structure end |
#job_status ⇒ String
The status of the bulk import job can be one of following values:
-
PENDING– IoT SiteWise is waiting for the current bulk import job to finish. -
CANCELLED– The bulk import job has been canceled. -
RUNNING– IoT SiteWise is processing your request to import your data from Amazon S3. -
COMPLETED– IoT SiteWise successfully completed your request to import data from Amazon S3. -
FAILED– IoT SiteWise couldn't process your request to import data from Amazon S3. You can use logs saved in the specified error report location in Amazon S3 to troubleshoot issues. -
COMPLETED_WITH_FAILURES– IoT SiteWise completed your request to import data from Amazon S3 with errors. You can use logs saved in the specified error report location in Amazon S3 to troubleshoot issues.
4005 4006 4007 4008 4009 4010 4011 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 4005 class CreateBulkImportJobResponse < Struct.new( :job_id, :job_name, :job_status) SENSITIVE = [] include Aws::Structure end |