Class: Aws::IoTSiteWise::Types::CreateComputationModelRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTSiteWise::Types::CreateComputationModelRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotsitewise/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique case-sensitive identifier that you can provide to ensure the idempotency of the request.
-
#computation_model_configuration ⇒ Types::ComputationModelConfiguration
The configuration for the computation model.
-
#computation_model_data_binding ⇒ Hash<String,Types::ComputationModelDataBindingValue>
The data binding for the computation model.
-
#computation_model_description ⇒ String
The description of the computation model.
-
#computation_model_name ⇒ String
The name of the computation model.
-
#tags ⇒ Hash<String,String>
A list of key-value pairs that contain metadata for the asset.
Instance Attribute Details
#client_token ⇒ String
A unique case-sensitive identifier that you can provide to ensure the idempotency of the request. Don't reuse this client token if a new idempotent request is required.
A suitable default value is auto-generated. You should normally not need to pass this option.
4027 4028 4029 4030 4031 4032 4033 4034 4035 4036 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 4027 class CreateComputationModelRequest < Struct.new( :computation_model_name, :computation_model_description, :computation_model_configuration, :computation_model_data_binding, :client_token, :tags) SENSITIVE = [] include Aws::Structure end |
#computation_model_configuration ⇒ Types::ComputationModelConfiguration
The configuration for the computation model.
4027 4028 4029 4030 4031 4032 4033 4034 4035 4036 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 4027 class CreateComputationModelRequest < Struct.new( :computation_model_name, :computation_model_description, :computation_model_configuration, :computation_model_data_binding, :client_token, :tags) SENSITIVE = [] include Aws::Structure end |
#computation_model_data_binding ⇒ Hash<String,Types::ComputationModelDataBindingValue>
The data binding for the computation model. Key is a variable name
defined in configuration. Value is a
ComputationModelDataBindingValue referenced by the variable.
4027 4028 4029 4030 4031 4032 4033 4034 4035 4036 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 4027 class CreateComputationModelRequest < Struct.new( :computation_model_name, :computation_model_description, :computation_model_configuration, :computation_model_data_binding, :client_token, :tags) SENSITIVE = [] include Aws::Structure end |
#computation_model_description ⇒ String
The description of the computation model.
4027 4028 4029 4030 4031 4032 4033 4034 4035 4036 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 4027 class CreateComputationModelRequest < Struct.new( :computation_model_name, :computation_model_description, :computation_model_configuration, :computation_model_data_binding, :client_token, :tags) SENSITIVE = [] include Aws::Structure end |
#computation_model_name ⇒ String
The name of the computation model.
4027 4028 4029 4030 4031 4032 4033 4034 4035 4036 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 4027 class CreateComputationModelRequest < Struct.new( :computation_model_name, :computation_model_description, :computation_model_configuration, :computation_model_data_binding, :client_token, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
A list of key-value pairs that contain metadata for the asset. For more information, see Tagging your IoT SiteWise resources in the IoT SiteWise User Guide.
4027 4028 4029 4030 4031 4032 4033 4034 4035 4036 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 4027 class CreateComputationModelRequest < Struct.new( :computation_model_name, :computation_model_description, :computation_model_configuration, :computation_model_data_binding, :client_token, :tags) SENSITIVE = [] include Aws::Structure end |