Class: Aws::IoTSiteWise::Types::CreateDatasetExportJobRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotsitewise/types.rb

Overview

Request to create a dataset export job.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. The AWS SDKs and CLI populate this automatically.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


4171
4172
4173
4174
4175
4176
4177
4178
4179
# File 'lib/aws-sdk-iotsitewise/types.rb', line 4171

class CreateDatasetExportJobRequest < Struct.new(
  :workspace_name,
  :client_token,
  :destination_s3_uri,
  :input,
  :error_report_location)
  SENSITIVE = []
  include Aws::Structure
end

#destination_s3_uriString

The S3 URI where output clips will be written.

Returns:

  • (String)


4171
4172
4173
4174
4175
4176
4177
4178
4179
# File 'lib/aws-sdk-iotsitewise/types.rb', line 4171

class CreateDatasetExportJobRequest < Struct.new(
  :workspace_name,
  :client_token,
  :destination_s3_uri,
  :input,
  :error_report_location)
  SENSITIVE = []
  include Aws::Structure
end

#error_report_locationTypes::ExportErrorReportLocation

The location where the error report will be written on failure.



4171
4172
4173
4174
4175
4176
4177
4178
4179
# File 'lib/aws-sdk-iotsitewise/types.rb', line 4171

class CreateDatasetExportJobRequest < Struct.new(
  :workspace_name,
  :client_token,
  :destination_s3_uri,
  :input,
  :error_report_location)
  SENSITIVE = []
  include Aws::Structure
end

#inputTypes::ProcessingInput

The processing input source.



4171
4172
4173
4174
4175
4176
4177
4178
4179
# File 'lib/aws-sdk-iotsitewise/types.rb', line 4171

class CreateDatasetExportJobRequest < Struct.new(
  :workspace_name,
  :client_token,
  :destination_s3_uri,
  :input,
  :error_report_location)
  SENSITIVE = []
  include Aws::Structure
end

#workspace_nameString

The name of the workspace in which to create the dataset export job.

Returns:

  • (String)


4171
4172
4173
4174
4175
4176
4177
4178
4179
# File 'lib/aws-sdk-iotsitewise/types.rb', line 4171

class CreateDatasetExportJobRequest < Struct.new(
  :workspace_name,
  :client_token,
  :destination_s3_uri,
  :input,
  :error_report_location)
  SENSITIVE = []
  include Aws::Structure
end