Class: Aws::IoTSiteWise::Types::CreateDatasetExportJobResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTSiteWise::Types::CreateDatasetExportJobResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotsitewise/types.rb
Overview
Response for create dataset export job request.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#job_id ⇒ String
The unique identifier for the dataset export job.
-
#workspace_name ⇒ String
The name of the workspace in which the dataset export job was created.
Instance Attribute Details
#job_id ⇒ String
The unique identifier for the dataset export job.
4192 4193 4194 4195 4196 4197 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 4192 class CreateDatasetExportJobResponse < Struct.new( :job_id, :workspace_name) SENSITIVE = [] include Aws::Structure end |
#workspace_name ⇒ String
The name of the workspace in which the dataset export job was created.
4192 4193 4194 4195 4196 4197 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 4192 class CreateDatasetExportJobResponse < Struct.new( :job_id, :workspace_name) SENSITIVE = [] include Aws::Structure end |