Class: Aws::IoTSiteWise::Types::CreateDatasetRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotsitewise/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique case-sensitive identifier that you can provide to ensure the idempotency of the request. Don't reuse this client token if a new idempotent request is required.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


4253
4254
4255
4256
4257
4258
4259
4260
4261
4262
4263
4264
4265
4266
# File 'lib/aws-sdk-iotsitewise/types.rb', line 4253

class CreateDatasetRequest < Struct.new(
  :dataset_id,
  :dataset_name,
  :dataset_description,
  :dataset_type,
  :dataset_config,
  :workspace_name,
  :metadata,
  :dataset_source,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#dataset_configTypes::DatasetConfig

The configuration for the dataset.



4253
4254
4255
4256
4257
4258
4259
4260
4261
4262
4263
4264
4265
4266
# File 'lib/aws-sdk-iotsitewise/types.rb', line 4253

class CreateDatasetRequest < Struct.new(
  :dataset_id,
  :dataset_name,
  :dataset_description,
  :dataset_type,
  :dataset_config,
  :workspace_name,
  :metadata,
  :dataset_source,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#dataset_descriptionString

A description about the dataset, and its functionality.

Returns:

  • (String)


4253
4254
4255
4256
4257
4258
4259
4260
4261
4262
4263
4264
4265
4266
# File 'lib/aws-sdk-iotsitewise/types.rb', line 4253

class CreateDatasetRequest < Struct.new(
  :dataset_id,
  :dataset_name,
  :dataset_description,
  :dataset_type,
  :dataset_config,
  :workspace_name,
  :metadata,
  :dataset_source,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#dataset_idString

The ID of the dataset.

Returns:

  • (String)


4253
4254
4255
4256
4257
4258
4259
4260
4261
4262
4263
4264
4265
4266
# File 'lib/aws-sdk-iotsitewise/types.rb', line 4253

class CreateDatasetRequest < Struct.new(
  :dataset_id,
  :dataset_name,
  :dataset_description,
  :dataset_type,
  :dataset_config,
  :workspace_name,
  :metadata,
  :dataset_source,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#dataset_nameString

The name of the dataset.

Returns:

  • (String)


4253
4254
4255
4256
4257
4258
4259
4260
4261
4262
4263
4264
4265
4266
# File 'lib/aws-sdk-iotsitewise/types.rb', line 4253

class CreateDatasetRequest < Struct.new(
  :dataset_id,
  :dataset_name,
  :dataset_description,
  :dataset_type,
  :dataset_config,
  :workspace_name,
  :metadata,
  :dataset_source,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#dataset_sourceTypes::DatasetSource

The data source for the dataset.



4253
4254
4255
4256
4257
4258
4259
4260
4261
4262
4263
4264
4265
4266
# File 'lib/aws-sdk-iotsitewise/types.rb', line 4253

class CreateDatasetRequest < Struct.new(
  :dataset_id,
  :dataset_name,
  :dataset_description,
  :dataset_type,
  :dataset_config,
  :workspace_name,
  :metadata,
  :dataset_source,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#dataset_typeString

The type of dataset: a session dataset, a curated dataset, or a connection to an external datasource.

Returns:

  • (String)


4253
4254
4255
4256
4257
4258
4259
4260
4261
4262
4263
4264
4265
4266
# File 'lib/aws-sdk-iotsitewise/types.rb', line 4253

class CreateDatasetRequest < Struct.new(
  :dataset_id,
  :dataset_name,
  :dataset_description,
  :dataset_type,
  :dataset_config,
  :workspace_name,
  :metadata,
  :dataset_source,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#metadataHash<String,String>

The metadata for the dataset, provided as key-value pairs.

Returns:

  • (Hash<String,String>)


4253
4254
4255
4256
4257
4258
4259
4260
4261
4262
4263
4264
4265
4266
# File 'lib/aws-sdk-iotsitewise/types.rb', line 4253

class CreateDatasetRequest < Struct.new(
  :dataset_id,
  :dataset_name,
  :dataset_description,
  :dataset_type,
  :dataset_config,
  :workspace_name,
  :metadata,
  :dataset_source,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

A list of key-value pairs that contain metadata for the access policy. For more information, see Tagging your IoT SiteWise resources in the IoT SiteWise User Guide.

Returns:

  • (Hash<String,String>)


4253
4254
4255
4256
4257
4258
4259
4260
4261
4262
4263
4264
4265
4266
# File 'lib/aws-sdk-iotsitewise/types.rb', line 4253

class CreateDatasetRequest < Struct.new(
  :dataset_id,
  :dataset_name,
  :dataset_description,
  :dataset_type,
  :dataset_config,
  :workspace_name,
  :metadata,
  :dataset_source,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#workspace_nameString

The name of the workspace that contains the dataset. Required for session and curated datasets. Omit this field for datasets that connect to an external datasource.

Returns:

  • (String)


4253
4254
4255
4256
4257
4258
4259
4260
4261
4262
4263
4264
4265
4266
# File 'lib/aws-sdk-iotsitewise/types.rb', line 4253

class CreateDatasetRequest < Struct.new(
  :dataset_id,
  :dataset_name,
  :dataset_description,
  :dataset_type,
  :dataset_config,
  :workspace_name,
  :metadata,
  :dataset_source,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end