Class: Aws::IoTSiteWise::Types::CreateGatewayRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTSiteWise::Types::CreateGatewayRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotsitewise/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#gateway_name ⇒ String
A unique name for the gateway.
-
#gateway_platform ⇒ Types::GatewayPlatform
The gateway's platform.
-
#gateway_version ⇒ String
The version of the gateway to create.
-
#tags ⇒ Hash<String,String>
A list of key-value pairs that contain metadata for the gateway.
Instance Attribute Details
#gateway_name ⇒ String
A unique name for the gateway.
4392 4393 4394 4395 4396 4397 4398 4399 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 4392 class CreateGatewayRequest < Struct.new( :gateway_name, :gateway_platform, :gateway_version, :tags) SENSITIVE = [] include Aws::Structure end |
#gateway_platform ⇒ Types::GatewayPlatform
The gateway's platform. You can only specify one platform in a gateway.
4392 4393 4394 4395 4396 4397 4398 4399 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 4392 class CreateGatewayRequest < Struct.new( :gateway_name, :gateway_platform, :gateway_version, :tags) SENSITIVE = [] include Aws::Structure end |
#gateway_version ⇒ String
The version of the gateway to create. Specify 3 to create an
MQTT-enabled, V3 gateway and 2 to create a Classic streams, V2
gateway. If not specified, the default is 2 (Classic streams, V2
gateway).
gatewayVersion=3) with the
GreengrassV2 platform, you must also specify the
coreDeviceOperatingSystem parameter.
We recommend creating an MQTT-enabled gateway for self-hosted gateways and Siemens Industrial Edge gateways. For more information on gateway versions, see Use Amazon Web Services IoT SiteWise Edge Edge gateways.
4392 4393 4394 4395 4396 4397 4398 4399 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 4392 class CreateGatewayRequest < Struct.new( :gateway_name, :gateway_platform, :gateway_version, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
A list of key-value pairs that contain metadata for the gateway. For more information, see Tagging your IoT SiteWise resources in the IoT SiteWise User Guide.
4392 4393 4394 4395 4396 4397 4398 4399 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 4392 class CreateGatewayRequest < Struct.new( :gateway_name, :gateway_platform, :gateway_version, :tags) SENSITIVE = [] include Aws::Structure end |