Class: Aws::IoTSiteWise::Types::CreatePipelineRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotsitewise/types.rb

Overview

Request structure for CreatePipeline operation.

Constant Summary collapse

SENSITIVE =
[:environment_variables]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If you retry a request that completed successfully using the same client token, the server returns the cached result from the original successful request without performing the operation again.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


4470
4471
4472
4473
4474
4475
4476
4477
4478
4479
4480
# File 'lib/aws-sdk-iotsitewise/types.rb', line 4470

class CreatePipelineRequest < Struct.new(
  :workspace_name,
  :pipeline_name,
  :description,
  :environment_variables,
  :computations,
  :tags,
  :client_token)
  SENSITIVE = [:environment_variables]
  include Aws::Structure
end

#computationsArray<Types::ComputeNode>

The list of compute nodes that form the pipeline DAG. Each compute node references a task and can declare dependencies on other nodes.

Returns:



4470
4471
4472
4473
4474
4475
4476
4477
4478
4479
4480
# File 'lib/aws-sdk-iotsitewise/types.rb', line 4470

class CreatePipelineRequest < Struct.new(
  :workspace_name,
  :pipeline_name,
  :description,
  :environment_variables,
  :computations,
  :tags,
  :client_token)
  SENSITIVE = [:environment_variables]
  include Aws::Structure
end

#descriptionString

A description of the pipeline.

Returns:

  • (String)


4470
4471
4472
4473
4474
4475
4476
4477
4478
4479
4480
# File 'lib/aws-sdk-iotsitewise/types.rb', line 4470

class CreatePipelineRequest < Struct.new(
  :workspace_name,
  :pipeline_name,
  :description,
  :environment_variables,
  :computations,
  :tags,
  :client_token)
  SENSITIVE = [:environment_variables]
  include Aws::Structure
end

#environment_variablesHash<String,String>

Environment variables shared across all compute nodes in the pipeline. Individual compute nodes can override these values with their own environment variables.

Returns:

  • (Hash<String,String>)


4470
4471
4472
4473
4474
4475
4476
4477
4478
4479
4480
# File 'lib/aws-sdk-iotsitewise/types.rb', line 4470

class CreatePipelineRequest < Struct.new(
  :workspace_name,
  :pipeline_name,
  :description,
  :environment_variables,
  :computations,
  :tags,
  :client_token)
  SENSITIVE = [:environment_variables]
  include Aws::Structure
end

#pipeline_nameString

The name of the pipeline to create. Must be unique within the workspace.

Returns:

  • (String)


4470
4471
4472
4473
4474
4475
4476
4477
4478
4479
4480
# File 'lib/aws-sdk-iotsitewise/types.rb', line 4470

class CreatePipelineRequest < Struct.new(
  :workspace_name,
  :pipeline_name,
  :description,
  :environment_variables,
  :computations,
  :tags,
  :client_token)
  SENSITIVE = [:environment_variables]
  include Aws::Structure
end

#tagsHash<String,String>

A list of key-value pairs that contain metadata for the pipeline. For more information, see Tagging your AWS IoT SiteWise resources in the AWS IoT SiteWise User Guide.

Returns:

  • (Hash<String,String>)


4470
4471
4472
4473
4474
4475
4476
4477
4478
4479
4480
# File 'lib/aws-sdk-iotsitewise/types.rb', line 4470

class CreatePipelineRequest < Struct.new(
  :workspace_name,
  :pipeline_name,
  :description,
  :environment_variables,
  :computations,
  :tags,
  :client_token)
  SENSITIVE = [:environment_variables]
  include Aws::Structure
end

#workspace_nameString

The name of the workspace.

Returns:

  • (String)


4470
4471
4472
4473
4474
4475
4476
4477
4478
4479
4480
# File 'lib/aws-sdk-iotsitewise/types.rb', line 4470

class CreatePipelineRequest < Struct.new(
  :workspace_name,
  :pipeline_name,
  :description,
  :environment_variables,
  :computations,
  :tags,
  :client_token)
  SENSITIVE = [:environment_variables]
  include Aws::Structure
end