Class: Aws::IoTSiteWise::Types::CreatePortalResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotsitewise/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#portal_arnString

The ARN of the portal, which has the following format.

arn:${Partition}:iotsitewise:${Region}:${Account}:portal/${PortalId}

Returns:

  • (String)


4689
4690
4691
4692
4693
4694
4695
4696
4697
# File 'lib/aws-sdk-iotsitewise/types.rb', line 4689

class CreatePortalResponse < Struct.new(
  :portal_id,
  :portal_arn,
  :portal_start_url,
  :portal_status,
  :sso_application_id)
  SENSITIVE = []
  include Aws::Structure
end

#portal_idString

The ID of the created portal.

Returns:

  • (String)


4689
4690
4691
4692
4693
4694
4695
4696
4697
# File 'lib/aws-sdk-iotsitewise/types.rb', line 4689

class CreatePortalResponse < Struct.new(
  :portal_id,
  :portal_arn,
  :portal_start_url,
  :portal_status,
  :sso_application_id)
  SENSITIVE = []
  include Aws::Structure
end

#portal_start_urlString

The URL for the IoT SiteWise Monitor portal. You can use this URL to access portals that use IAM Identity Center for authentication. For portals that use IAM for authentication, you must use the IoT SiteWise console to get a URL that you can use to access the portal.

Returns:

  • (String)


4689
4690
4691
4692
4693
4694
4695
4696
4697
# File 'lib/aws-sdk-iotsitewise/types.rb', line 4689

class CreatePortalResponse < Struct.new(
  :portal_id,
  :portal_arn,
  :portal_start_url,
  :portal_status,
  :sso_application_id)
  SENSITIVE = []
  include Aws::Structure
end

#portal_statusTypes::PortalStatus

The status of the portal, which contains a state (CREATING after successfully calling this operation) and any error message.

Returns:



4689
4690
4691
4692
4693
4694
4695
4696
4697
# File 'lib/aws-sdk-iotsitewise/types.rb', line 4689

class CreatePortalResponse < Struct.new(
  :portal_id,
  :portal_arn,
  :portal_start_url,
  :portal_status,
  :sso_application_id)
  SENSITIVE = []
  include Aws::Structure
end

#sso_application_idString

The associated IAM Identity Center application ID, if the portal uses IAM Identity Center.

Returns:

  • (String)


4689
4690
4691
4692
4693
4694
4695
4696
4697
# File 'lib/aws-sdk-iotsitewise/types.rb', line 4689

class CreatePortalResponse < Struct.new(
  :portal_id,
  :portal_arn,
  :portal_start_url,
  :portal_status,
  :sso_application_id)
  SENSITIVE = []
  include Aws::Structure
end