Class: Aws::IoTSiteWise::Types::CreateProjectRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTSiteWise::Types::CreateProjectRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotsitewise/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique case-sensitive identifier that you can provide to ensure the idempotency of the request.
-
#portal_id ⇒ String
The ID of the portal in which to create the project.
-
#project_description ⇒ String
A description for the project.
-
#project_name ⇒ String
A friendly name for the project.
-
#tags ⇒ Hash<String,String>
A list of key-value pairs that contain metadata for the project.
Instance Attribute Details
#client_token ⇒ String
A unique case-sensitive identifier that you can provide to ensure the idempotency of the request. Don't reuse this client token if a new idempotent request is required.
A suitable default value is auto-generated. You should normally not need to pass this option.
4707 4708 4709 4710 4711 4712 4713 4714 4715 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 4707 class CreateProjectRequest < Struct.new( :portal_id, :project_name, :project_description, :client_token, :tags) SENSITIVE = [] include Aws::Structure end |
#portal_id ⇒ String
The ID of the portal in which to create the project.
4707 4708 4709 4710 4711 4712 4713 4714 4715 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 4707 class CreateProjectRequest < Struct.new( :portal_id, :project_name, :project_description, :client_token, :tags) SENSITIVE = [] include Aws::Structure end |
#project_description ⇒ String
A description for the project.
4707 4708 4709 4710 4711 4712 4713 4714 4715 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 4707 class CreateProjectRequest < Struct.new( :portal_id, :project_name, :project_description, :client_token, :tags) SENSITIVE = [] include Aws::Structure end |
#project_name ⇒ String
A friendly name for the project.
4707 4708 4709 4710 4711 4712 4713 4714 4715 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 4707 class CreateProjectRequest < Struct.new( :portal_id, :project_name, :project_description, :client_token, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
A list of key-value pairs that contain metadata for the project. For more information, see Tagging your IoT SiteWise resources in the IoT SiteWise User Guide.
4707 4708 4709 4710 4711 4712 4713 4714 4715 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 4707 class CreateProjectRequest < Struct.new( :portal_id, :project_name, :project_description, :client_token, :tags) SENSITIVE = [] include Aws::Structure end |