Class: Aws::IoTSiteWise::Types::CreateTaskRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotsitewise/types.rb

Overview

Request structure for CreateTask operation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If you retry a request that completed successfully using the same client token, the server returns the cached result from the original successful request without performing the operation again.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


4782
4783
4784
4785
4786
4787
4788
4789
4790
4791
# File 'lib/aws-sdk-iotsitewise/types.rb', line 4782

class CreateTaskRequest < Struct.new(
  :workspace_name,
  :task_name,
  :description,
  :task_configuration,
  :tags,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A description of the task.

Returns:

  • (String)


4782
4783
4784
4785
4786
4787
4788
4789
4790
4791
# File 'lib/aws-sdk-iotsitewise/types.rb', line 4782

class CreateTaskRequest < Struct.new(
  :workspace_name,
  :task_name,
  :description,
  :task_configuration,
  :tags,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

A list of key-value pairs that contain metadata for the task. For more information, see Tagging your AWS IoT SiteWise resources in the AWS IoT SiteWise User Guide.

Returns:

  • (Hash<String,String>)


4782
4783
4784
4785
4786
4787
4788
4789
4790
4791
# File 'lib/aws-sdk-iotsitewise/types.rb', line 4782

class CreateTaskRequest < Struct.new(
  :workspace_name,
  :task_name,
  :description,
  :task_configuration,
  :tags,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#task_configurationTypes::TaskConfiguration

The task execution configuration. Specify a containerTaskConfiguration for custom container workloads.



4782
4783
4784
4785
4786
4787
4788
4789
4790
4791
# File 'lib/aws-sdk-iotsitewise/types.rb', line 4782

class CreateTaskRequest < Struct.new(
  :workspace_name,
  :task_name,
  :description,
  :task_configuration,
  :tags,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#task_nameString

The name of the task to create. Must be unique within the workspace.

Returns:

  • (String)


4782
4783
4784
4785
4786
4787
4788
4789
4790
4791
# File 'lib/aws-sdk-iotsitewise/types.rb', line 4782

class CreateTaskRequest < Struct.new(
  :workspace_name,
  :task_name,
  :description,
  :task_configuration,
  :tags,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#workspace_nameString

The name of the workspace.

Returns:

  • (String)


4782
4783
4784
4785
4786
4787
4788
4789
4790
4791
# File 'lib/aws-sdk-iotsitewise/types.rb', line 4782

class CreateTaskRequest < Struct.new(
  :workspace_name,
  :task_name,
  :description,
  :task_configuration,
  :tags,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end