Class: Aws::IoTSiteWise::Types::CreateWorkspaceRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTSiteWise::Types::CreateWorkspaceRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotsitewise/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure that the request is idempotent.
-
#encryption_configuration ⇒ Types::WorkspaceEncryptionConfiguration
The encryption configuration for the workspace.
-
#tags ⇒ Hash<String,String>
A list of key-value pairs that contain metadata for the workspace.
-
#workspace_description ⇒ String
A description for the workspace.
-
#workspace_name ⇒ String
The name of the workspace to create.
Instance Attribute Details
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure that the request is idempotent. If you retry a request that completed successfully using the same client token, the retry succeeds without performing any further actions.
A suitable default value is auto-generated. You should normally not need to pass this option.
4875 4876 4877 4878 4879 4880 4881 4882 4883 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 4875 class CreateWorkspaceRequest < Struct.new( :workspace_name, :workspace_description, :encryption_configuration, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |
#encryption_configuration ⇒ Types::WorkspaceEncryptionConfiguration
The encryption configuration for the workspace.
4875 4876 4877 4878 4879 4880 4881 4882 4883 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 4875 class CreateWorkspaceRequest < Struct.new( :workspace_name, :workspace_description, :encryption_configuration, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
A list of key-value pairs that contain metadata for the workspace. For more information, see Tagging your IoT SiteWise resources in the IoT SiteWise User Guide.
4875 4876 4877 4878 4879 4880 4881 4882 4883 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 4875 class CreateWorkspaceRequest < Struct.new( :workspace_name, :workspace_description, :encryption_configuration, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |
#workspace_description ⇒ String
A description for the workspace.
4875 4876 4877 4878 4879 4880 4881 4882 4883 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 4875 class CreateWorkspaceRequest < Struct.new( :workspace_name, :workspace_description, :encryption_configuration, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |
#workspace_name ⇒ String
The name of the workspace to create.
4875 4876 4877 4878 4879 4880 4881 4882 4883 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 4875 class CreateWorkspaceRequest < Struct.new( :workspace_name, :workspace_description, :encryption_configuration, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |