Class: Aws::IoTSiteWise::Types::DataBindingValue

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotsitewise/types.rb

Overview

Represents a value used in a data binding. It can be an asset property or an asset model property.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#asset_model_propertyTypes::AssetModelPropertyBindingValue

Contains information about an assetModelProperty binding value.



4967
4968
4969
4970
4971
4972
# File 'lib/aws-sdk-iotsitewise/types.rb', line 4967

class DataBindingValue < Struct.new(
  :asset_model_property,
  :asset_property)
  SENSITIVE = []
  include Aws::Structure
end

#asset_propertyTypes::AssetPropertyBindingValue

The asset property value used in the data binding.



4967
4968
4969
4970
4971
4972
# File 'lib/aws-sdk-iotsitewise/types.rb', line 4967

class DataBindingValue < Struct.new(
  :asset_model_property,
  :asset_property)
  SENSITIVE = []
  include Aws::Structure
end