Class: Aws::IoTSiteWise::Types::DataSegmentEnrichment
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTSiteWise::Types::DataSegmentEnrichment
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotsitewise/types.rb
Overview
Contains enrichment status information for a data segment.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#last_enriched_at ⇒ Time
The date the data segment was last enriched, in Unix epoch time.
-
#status ⇒ String
The enrichment status of the data segment.
Instance Attribute Details
#last_enriched_at ⇒ Time
The date the data segment was last enriched, in Unix epoch time.
5021 5022 5023 5024 5025 5026 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 5021 class DataSegmentEnrichment < Struct.new( :status, :last_enriched_at) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The enrichment status of the data segment.
5021 5022 5023 5024 5025 5026 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 5021 class DataSegmentEnrichment < Struct.new( :status, :last_enriched_at) SENSITIVE = [] include Aws::Structure end |