Class: Aws::IoTSiteWise::Types::DataSegmentRelationshipSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotsitewise/types.rb

Overview

Contains summary information about a data segment relationship between a source session dataset that contains the data and a curated dataset that references it, including the time series and timestamp range.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#end_timestampTypes::TimeInNanos

The nanosecond-precision end time of the data segment.

Returns:



5052
5053
5054
5055
5056
5057
5058
5059
5060
# File 'lib/aws-sdk-iotsitewise/types.rb', line 5052

class DataSegmentRelationshipSummary < Struct.new(
  :target_dataset_id,
  :source_dataset_id,
  :time_series_id,
  :start_timestamp,
  :end_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#source_dataset_idString

The ID of the source session dataset that contains the data segment.

Returns:

  • (String)


5052
5053
5054
5055
5056
5057
5058
5059
5060
# File 'lib/aws-sdk-iotsitewise/types.rb', line 5052

class DataSegmentRelationshipSummary < Struct.new(
  :target_dataset_id,
  :source_dataset_id,
  :time_series_id,
  :start_timestamp,
  :end_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#start_timestampTypes::TimeInNanos

The nanosecond-precision start time of the data segment.

Returns:



5052
5053
5054
5055
5056
5057
5058
5059
5060
# File 'lib/aws-sdk-iotsitewise/types.rb', line 5052

class DataSegmentRelationshipSummary < Struct.new(
  :target_dataset_id,
  :source_dataset_id,
  :time_series_id,
  :start_timestamp,
  :end_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#target_dataset_idString

The ID of the curated dataset that references the data segment.

Returns:

  • (String)


5052
5053
5054
5055
5056
5057
5058
5059
5060
# File 'lib/aws-sdk-iotsitewise/types.rb', line 5052

class DataSegmentRelationshipSummary < Struct.new(
  :target_dataset_id,
  :source_dataset_id,
  :time_series_id,
  :start_timestamp,
  :end_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#time_series_idString

The ID of the time series.

Returns:

  • (String)


5052
5053
5054
5055
5056
5057
5058
5059
5060
# File 'lib/aws-sdk-iotsitewise/types.rb', line 5052

class DataSegmentRelationshipSummary < Struct.new(
  :target_dataset_id,
  :source_dataset_id,
  :time_series_id,
  :start_timestamp,
  :end_timestamp)
  SENSITIVE = []
  include Aws::Structure
end