Class: Aws::IoTSiteWise::Types::DataSegmentSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotsitewise/types.rb

Overview

Contains summary information about a data segment, including its source dataset, time series, timestamp range, and enrichment status.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#aliasString

The alias of the time series.

Returns:

  • (String)


5093
5094
5095
5096
5097
5098
5099
5100
5101
5102
5103
# File 'lib/aws-sdk-iotsitewise/types.rb', line 5093

class DataSegmentSummary < Struct.new(
  :source_dataset_id,
  :time_series_id,
  :start_timestamp,
  :end_timestamp,
  :alias,
  :data_type,
  :enrichment)
  SENSITIVE = []
  include Aws::Structure
end

#data_typeString

The data type of the time series.

Returns:

  • (String)


5093
5094
5095
5096
5097
5098
5099
5100
5101
5102
5103
# File 'lib/aws-sdk-iotsitewise/types.rb', line 5093

class DataSegmentSummary < Struct.new(
  :source_dataset_id,
  :time_series_id,
  :start_timestamp,
  :end_timestamp,
  :alias,
  :data_type,
  :enrichment)
  SENSITIVE = []
  include Aws::Structure
end

#end_timestampTypes::TimeInNanos

The nanosecond-precision end time of the data segment.

Returns:



5093
5094
5095
5096
5097
5098
5099
5100
5101
5102
5103
# File 'lib/aws-sdk-iotsitewise/types.rb', line 5093

class DataSegmentSummary < Struct.new(
  :source_dataset_id,
  :time_series_id,
  :start_timestamp,
  :end_timestamp,
  :alias,
  :data_type,
  :enrichment)
  SENSITIVE = []
  include Aws::Structure
end

#enrichmentTypes::DataSegmentEnrichment

The enrichment information for the data segment.



5093
5094
5095
5096
5097
5098
5099
5100
5101
5102
5103
# File 'lib/aws-sdk-iotsitewise/types.rb', line 5093

class DataSegmentSummary < Struct.new(
  :source_dataset_id,
  :time_series_id,
  :start_timestamp,
  :end_timestamp,
  :alias,
  :data_type,
  :enrichment)
  SENSITIVE = []
  include Aws::Structure
end

#source_dataset_idString

The ID of the source dataset that contains the data segment.

Returns:

  • (String)


5093
5094
5095
5096
5097
5098
5099
5100
5101
5102
5103
# File 'lib/aws-sdk-iotsitewise/types.rb', line 5093

class DataSegmentSummary < Struct.new(
  :source_dataset_id,
  :time_series_id,
  :start_timestamp,
  :end_timestamp,
  :alias,
  :data_type,
  :enrichment)
  SENSITIVE = []
  include Aws::Structure
end

#start_timestampTypes::TimeInNanos

The nanosecond-precision start time of the data segment.

Returns:



5093
5094
5095
5096
5097
5098
5099
5100
5101
5102
5103
# File 'lib/aws-sdk-iotsitewise/types.rb', line 5093

class DataSegmentSummary < Struct.new(
  :source_dataset_id,
  :time_series_id,
  :start_timestamp,
  :end_timestamp,
  :alias,
  :data_type,
  :enrichment)
  SENSITIVE = []
  include Aws::Structure
end

#time_series_idString

The ID of the time series.

Returns:

  • (String)


5093
5094
5095
5096
5097
5098
5099
5100
5101
5102
5103
# File 'lib/aws-sdk-iotsitewise/types.rb', line 5093

class DataSegmentSummary < Struct.new(
  :source_dataset_id,
  :time_series_id,
  :start_timestamp,
  :end_timestamp,
  :alias,
  :data_type,
  :enrichment)
  SENSITIVE = []
  include Aws::Structure
end