Class: Aws::IoTSiteWise::Types::DatasetEnrichment
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTSiteWise::Types::DatasetEnrichment
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotsitewise/types.rb
Overview
Contains the enrichment status information for a dataset across data types.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#video ⇒ Types::DatasetEnrichmentEntry
The enrichment status for video data in the dataset.
Instance Attribute Details
#video ⇒ Types::DatasetEnrichmentEntry
The enrichment status for video data in the dataset.
5146 5147 5148 5149 5150 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 5146 class DatasetEnrichment < Struct.new( :video) SENSITIVE = [] include Aws::Structure end |