Class: Aws::IoTSiteWise::Types::DatasetEnrichmentEntry

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotsitewise/types.rb

Overview

Contains enrichment status information for a specific data type in a dataset.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#last_enriched_atTime

The date the data was last enriched, in Unix epoch time.

Returns:

  • (Time)


5163
5164
5165
5166
5167
5168
# File 'lib/aws-sdk-iotsitewise/types.rb', line 5163

class DatasetEnrichmentEntry < Struct.new(
  :status,
  :last_enriched_at)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The enrichment status of the data type in the dataset.

Returns:

  • (String)


5163
5164
5165
5166
5167
5168
# File 'lib/aws-sdk-iotsitewise/types.rb', line 5163

class DatasetEnrichmentEntry < Struct.new(
  :status,
  :last_enriched_at)
  SENSITIVE = []
  include Aws::Structure
end