Class: Aws::IoTSiteWise::Types::DatasetItem
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTSiteWise::Types::DatasetItem
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotsitewise/types.rb
Overview
<p>A dataset to process.</p>
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dataset_id ⇒ String
<p>The unique identifier for the dataset.</p>.
-
#export_data_types ⇒ Array<String>
<p>The optional subset of data types to export.
-
#trim_settings ⇒ Types::TrimSettings
<p>The trim settings applied to all items in the dataset.
Instance Attribute Details
#dataset_id ⇒ String
<p>The unique identifier for the dataset.</p>
5186 5187 5188 5189 5190 5191 5192 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 5186 class DatasetItem < Struct.new( :dataset_id, :trim_settings, :export_data_types) SENSITIVE = [] include Aws::Structure end |
#export_data_types ⇒ Array<String>
<p>The optional subset of data types to export. If omitted, all data types are exported.</p>
5186 5187 5188 5189 5190 5191 5192 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 5186 class DatasetItem < Struct.new( :dataset_id, :trim_settings, :export_data_types) SENSITIVE = [] include Aws::Structure end |
#trim_settings ⇒ Types::TrimSettings
<p>The trim settings applied to all items in the dataset. When omitted, the full dataset time range is used.</p>
5186 5187 5188 5189 5190 5191 5192 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 5186 class DatasetItem < Struct.new( :dataset_id, :trim_settings, :export_data_types) SENSITIVE = [] include Aws::Structure end |