Class: Aws::IoTSiteWise::Types::DatasetSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotsitewise/types.rb

Overview

The summary details for the dataset.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The ARN of the dataset. The format is arn:${Partition}:iotsitewise:${Region}:${Account}:dataset/${DatasetId}.

Returns:

  • (String)


5283
5284
5285
5286
5287
5288
5289
5290
5291
5292
5293
5294
5295
5296
# File 'lib/aws-sdk-iotsitewise/types.rb', line 5283

class DatasetSummary < Struct.new(
  :id,
  :arn,
  :name,
  :description,
  :source_type,
  :dataset_type,
  :creation_date,
  :last_update_date,
  :status,
  :enrichment_status)
  SENSITIVE = []
  include Aws::Structure
end

#creation_dateTime

The dataset creation date, in Unix epoch time.

Returns:

  • (Time)


5283
5284
5285
5286
5287
5288
5289
5290
5291
5292
5293
5294
5295
5296
# File 'lib/aws-sdk-iotsitewise/types.rb', line 5283

class DatasetSummary < Struct.new(
  :id,
  :arn,
  :name,
  :description,
  :source_type,
  :dataset_type,
  :creation_date,
  :last_update_date,
  :status,
  :enrichment_status)
  SENSITIVE = []
  include Aws::Structure
end

#dataset_typeString

The type of dataset: a session dataset, a curated dataset, or a connection to an external datasource.

Returns:

  • (String)


5283
5284
5285
5286
5287
5288
5289
5290
5291
5292
5293
5294
5295
5296
# File 'lib/aws-sdk-iotsitewise/types.rb', line 5283

class DatasetSummary < Struct.new(
  :id,
  :arn,
  :name,
  :description,
  :source_type,
  :dataset_type,
  :creation_date,
  :last_update_date,
  :status,
  :enrichment_status)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A description about the dataset, and its functionality.

Returns:

  • (String)


5283
5284
5285
5286
5287
5288
5289
5290
5291
5292
5293
5294
5295
5296
# File 'lib/aws-sdk-iotsitewise/types.rb', line 5283

class DatasetSummary < Struct.new(
  :id,
  :arn,
  :name,
  :description,
  :source_type,
  :dataset_type,
  :creation_date,
  :last_update_date,
  :status,
  :enrichment_status)
  SENSITIVE = []
  include Aws::Structure
end

#enrichment_statusTypes::DatasetEnrichment

The enrichment status of the dataset.



5283
5284
5285
5286
5287
5288
5289
5290
5291
5292
5293
5294
5295
5296
# File 'lib/aws-sdk-iotsitewise/types.rb', line 5283

class DatasetSummary < Struct.new(
  :id,
  :arn,
  :name,
  :description,
  :source_type,
  :dataset_type,
  :creation_date,
  :last_update_date,
  :status,
  :enrichment_status)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The ID of the dataset.

Returns:

  • (String)


5283
5284
5285
5286
5287
5288
5289
5290
5291
5292
5293
5294
5295
5296
# File 'lib/aws-sdk-iotsitewise/types.rb', line 5283

class DatasetSummary < Struct.new(
  :id,
  :arn,
  :name,
  :description,
  :source_type,
  :dataset_type,
  :creation_date,
  :last_update_date,
  :status,
  :enrichment_status)
  SENSITIVE = []
  include Aws::Structure
end

#last_update_dateTime

The date the dataset was last updated, in Unix epoch time.

Returns:

  • (Time)


5283
5284
5285
5286
5287
5288
5289
5290
5291
5292
5293
5294
5295
5296
# File 'lib/aws-sdk-iotsitewise/types.rb', line 5283

class DatasetSummary < Struct.new(
  :id,
  :arn,
  :name,
  :description,
  :source_type,
  :dataset_type,
  :creation_date,
  :last_update_date,
  :status,
  :enrichment_status)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the dataset.

Returns:

  • (String)


5283
5284
5285
5286
5287
5288
5289
5290
5291
5292
5293
5294
5295
5296
# File 'lib/aws-sdk-iotsitewise/types.rb', line 5283

class DatasetSummary < Struct.new(
  :id,
  :arn,
  :name,
  :description,
  :source_type,
  :dataset_type,
  :creation_date,
  :last_update_date,
  :status,
  :enrichment_status)
  SENSITIVE = []
  include Aws::Structure
end

#source_typeString

The data source type of the dataset.

Returns:

  • (String)


5283
5284
5285
5286
5287
5288
5289
5290
5291
5292
5293
5294
5295
5296
# File 'lib/aws-sdk-iotsitewise/types.rb', line 5283

class DatasetSummary < Struct.new(
  :id,
  :arn,
  :name,
  :description,
  :source_type,
  :dataset_type,
  :creation_date,
  :last_update_date,
  :status,
  :enrichment_status)
  SENSITIVE = []
  include Aws::Structure
end

#statusTypes::DatasetStatus

The status of the dataset. This contains the state and any error messages. The state is ACTIVE when ready to use.



5283
5284
5285
5286
5287
5288
5289
5290
5291
5292
5293
5294
5295
5296
# File 'lib/aws-sdk-iotsitewise/types.rb', line 5283

class DatasetSummary < Struct.new(
  :id,
  :arn,
  :name,
  :description,
  :source_type,
  :dataset_type,
  :creation_date,
  :last_update_date,
  :status,
  :enrichment_status)
  SENSITIVE = []
  include Aws::Structure
end