Class: Aws::IoTSiteWise::Types::DeleteAccessPolicyRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotsitewise/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#access_policy_idString

The ID of the access policy to be deleted.

Returns:

  • (String)


5339
5340
5341
5342
5343
5344
# File 'lib/aws-sdk-iotsitewise/types.rb', line 5339

class DeleteAccessPolicyRequest < Struct.new(
  :access_policy_id,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#client_tokenString

A unique case-sensitive identifier that you can provide to ensure the idempotency of the request. Don't reuse this client token if a new idempotent request is required.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


5339
5340
5341
5342
5343
5344
# File 'lib/aws-sdk-iotsitewise/types.rb', line 5339

class DeleteAccessPolicyRequest < Struct.new(
  :access_policy_id,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end