Class: Aws::IoTSiteWise::Types::DeleteApplicationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTSiteWise::Types::DeleteApplicationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotsitewise/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#id ⇒ String
ID of the Application to delete.
-
#workspace_name ⇒ String
Name of the workspace to associate with the underlying Application.
Instance Attribute Details
#id ⇒ String
ID of the Application to delete
5356 5357 5358 5359 5360 5361 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 5356 class DeleteApplicationRequest < Struct.new( :workspace_name, :id) SENSITIVE = [] include Aws::Structure end |
#workspace_name ⇒ String
Name of the workspace to associate with the underlying Application
5356 5357 5358 5359 5360 5361 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 5356 class DeleteApplicationRequest < Struct.new( :workspace_name, :id) SENSITIVE = [] include Aws::Structure end |