Class: Aws::IoTSiteWise::Types::DeleteAssetModelCompositeModelRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotsitewise/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#asset_model_composite_model_idString

The ID of a composite model on this asset model.

Returns:

  • (String)


5406
5407
5408
5409
5410
5411
5412
5413
5414
5415
# File 'lib/aws-sdk-iotsitewise/types.rb', line 5406

class DeleteAssetModelCompositeModelRequest < Struct.new(
  :asset_model_id,
  :asset_model_composite_model_id,
  :client_token,
  :if_match,
  :if_none_match,
  :match_for_version_type)
  SENSITIVE = []
  include Aws::Structure
end

#asset_model_idString

The ID of the asset model, in UUID format.

Returns:

  • (String)


5406
5407
5408
5409
5410
5411
5412
5413
5414
5415
# File 'lib/aws-sdk-iotsitewise/types.rb', line 5406

class DeleteAssetModelCompositeModelRequest < Struct.new(
  :asset_model_id,
  :asset_model_composite_model_id,
  :client_token,
  :if_match,
  :if_none_match,
  :match_for_version_type)
  SENSITIVE = []
  include Aws::Structure
end

#client_tokenString

A unique case-sensitive identifier that you can provide to ensure the idempotency of the request. Don't reuse this client token if a new idempotent request is required.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


5406
5407
5408
5409
5410
5411
5412
5413
5414
5415
# File 'lib/aws-sdk-iotsitewise/types.rb', line 5406

class DeleteAssetModelCompositeModelRequest < Struct.new(
  :asset_model_id,
  :asset_model_composite_model_id,
  :client_token,
  :if_match,
  :if_none_match,
  :match_for_version_type)
  SENSITIVE = []
  include Aws::Structure
end

#if_matchString

The expected current entity tag (ETag) for the asset model’s latest or active version (specified using matchForVersionType). The delete request is rejected if the tag does not match the latest or active version's current entity tag. See Optimistic locking for asset model writes in the IoT SiteWise User Guide.

Returns:

  • (String)


5406
5407
5408
5409
5410
5411
5412
5413
5414
5415
# File 'lib/aws-sdk-iotsitewise/types.rb', line 5406

class DeleteAssetModelCompositeModelRequest < Struct.new(
  :asset_model_id,
  :asset_model_composite_model_id,
  :client_token,
  :if_match,
  :if_none_match,
  :match_for_version_type)
  SENSITIVE = []
  include Aws::Structure
end

#if_none_matchString

Accepts ***** to reject the delete request if an active version (specified using matchForVersionType as ACTIVE) already exists for the asset model.

Returns:

  • (String)


5406
5407
5408
5409
5410
5411
5412
5413
5414
5415
# File 'lib/aws-sdk-iotsitewise/types.rb', line 5406

class DeleteAssetModelCompositeModelRequest < Struct.new(
  :asset_model_id,
  :asset_model_composite_model_id,
  :client_token,
  :if_match,
  :if_none_match,
  :match_for_version_type)
  SENSITIVE = []
  include Aws::Structure
end

#match_for_version_typeString

Specifies the asset model version type (LATEST or ACTIVE) used in conjunction with If-Match or If-None-Match headers to determine the target ETag for the delete operation.

Returns:

  • (String)


5406
5407
5408
5409
5410
5411
5412
5413
5414
5415
# File 'lib/aws-sdk-iotsitewise/types.rb', line 5406

class DeleteAssetModelCompositeModelRequest < Struct.new(
  :asset_model_id,
  :asset_model_composite_model_id,
  :client_token,
  :if_match,
  :if_none_match,
  :match_for_version_type)
  SENSITIVE = []
  include Aws::Structure
end