Class: Aws::IoTSiteWise::Types::DeleteAssetModelResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTSiteWise::Types::DeleteAssetModelResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotsitewise/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#asset_model_id ⇒ String
The ID of the asset model.
-
#asset_model_status ⇒ Types::AssetModelStatus
The status of the asset model, which contains a state (
DELETINGafter successfully calling this operation) and any error message.
Instance Attribute Details
#asset_model_id ⇒ String
The ID of the asset model.
5560 5561 5562 5563 5564 5565 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 5560 class DeleteAssetModelResponse < Struct.new( :asset_model_id, :asset_model_status) SENSITIVE = [] include Aws::Structure end |
#asset_model_status ⇒ Types::AssetModelStatus
The status of the asset model, which contains a state (DELETING
after successfully calling this operation) and any error message.
5560 5561 5562 5563 5564 5565 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 5560 class DeleteAssetModelResponse < Struct.new( :asset_model_id, :asset_model_status) SENSITIVE = [] include Aws::Structure end |