Class: Aws::IoTSiteWise::Types::DeleteAssetResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTSiteWise::Types::DeleteAssetResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotsitewise/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#asset_id ⇒ String
The ID of the asset.
-
#asset_status ⇒ Types::AssetStatus
The status of the asset, which contains a state (
DELETINGafter successfully calling this operation) and any error message.
Instance Attribute Details
#asset_id ⇒ String
The ID of the asset.
5603 5604 5605 5606 5607 5608 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 5603 class DeleteAssetResponse < Struct.new( :asset_id, :asset_status) SENSITIVE = [] include Aws::Structure end |
#asset_status ⇒ Types::AssetStatus
The status of the asset, which contains a state (DELETING after
successfully calling this operation) and any error message.
5603 5604 5605 5606 5607 5608 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 5603 class DeleteAssetResponse < Struct.new( :asset_id, :asset_status) SENSITIVE = [] include Aws::Structure end |