Class: Aws::IoTSiteWise::Types::DeleteDataSegmentEntry

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotsitewise/types.rb

Overview

Contains information about a data segment entry to delete.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#end_timestampTypes::TimeInNanos

The nanosecond-precision end time of the data segment to delete.

Returns:



5677
5678
5679
5680
5681
5682
5683
# File 'lib/aws-sdk-iotsitewise/types.rb', line 5677

class DeleteDataSegmentEntry < Struct.new(
  :time_series_id,
  :start_timestamp,
  :end_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#start_timestampTypes::TimeInNanos

The nanosecond-precision start time of the data segment to delete.

Returns:



5677
5678
5679
5680
5681
5682
5683
# File 'lib/aws-sdk-iotsitewise/types.rb', line 5677

class DeleteDataSegmentEntry < Struct.new(
  :time_series_id,
  :start_timestamp,
  :end_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#time_series_idString

The ID of the time series.

Returns:

  • (String)


5677
5678
5679
5680
5681
5682
5683
# File 'lib/aws-sdk-iotsitewise/types.rb', line 5677

class DeleteDataSegmentEntry < Struct.new(
  :time_series_id,
  :start_timestamp,
  :end_timestamp)
  SENSITIVE = []
  include Aws::Structure
end