Class: Aws::IoTSiteWise::Types::DeleteDatasetRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotsitewise/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique case-sensitive identifier that you can provide to ensure the idempotency of the request. Don't reuse this client token if a new idempotent request is required.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


5702
5703
5704
5705
5706
5707
5708
# File 'lib/aws-sdk-iotsitewise/types.rb', line 5702

class DeleteDatasetRequest < Struct.new(
  :dataset_id,
  :workspace_name,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#dataset_idString

The ID of the dataset.

Returns:

  • (String)


5702
5703
5704
5705
5706
5707
5708
# File 'lib/aws-sdk-iotsitewise/types.rb', line 5702

class DeleteDatasetRequest < Struct.new(
  :dataset_id,
  :workspace_name,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#workspace_nameString

The name of the workspace that contains the dataset.

Returns:

  • (String)


5702
5703
5704
5705
5706
5707
5708
# File 'lib/aws-sdk-iotsitewise/types.rb', line 5702

class DeleteDatasetRequest < Struct.new(
  :dataset_id,
  :workspace_name,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end