Class: Aws::IoTSiteWise::Types::DeletePortalResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTSiteWise::Types::DeletePortalResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotsitewise/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#portal_status ⇒ Types::PortalStatus
The status of the portal, which contains a state (
DELETINGafter successfully calling this operation) and any error message.
Instance Attribute Details
#portal_status ⇒ Types::PortalStatus
The status of the portal, which contains a state (DELETING after
successfully calling this operation) and any error message.
5786 5787 5788 5789 5790 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 5786 class DeletePortalResponse < Struct.new( :portal_status) SENSITIVE = [] include Aws::Structure end |