Class: Aws::IoTSiteWise::Types::DeleteTimeSeriesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTSiteWise::Types::DeleteTimeSeriesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotsitewise/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#alias ⇒ String
The alias that identifies the time series.
-
#asset_id ⇒ String
The ID of the asset in which the asset property was created.
-
#client_token ⇒ String
A unique case-sensitive identifier that you can provide to ensure the idempotency of the request.
-
#property_id ⇒ String
The ID of the asset property.
-
#workspace_name ⇒ String
The name of the workspace.
Instance Attribute Details
#alias ⇒ String
The alias that identifies the time series.
5883 5884 5885 5886 5887 5888 5889 5890 5891 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 5883 class DeleteTimeSeriesRequest < Struct.new( :alias, :asset_id, :property_id, :client_token, :workspace_name) SENSITIVE = [] include Aws::Structure end |
#asset_id ⇒ String
The ID of the asset in which the asset property was created. This
can be either the actual ID in UUID format, or else externalId:
followed by the external ID, if it has one. For more information,
see Referencing objects with external IDs in the IoT SiteWise
User Guide.
5883 5884 5885 5886 5887 5888 5889 5890 5891 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 5883 class DeleteTimeSeriesRequest < Struct.new( :alias, :asset_id, :property_id, :client_token, :workspace_name) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
A unique case-sensitive identifier that you can provide to ensure the idempotency of the request. Don't reuse this client token if a new idempotent request is required.
A suitable default value is auto-generated. You should normally not need to pass this option.
5883 5884 5885 5886 5887 5888 5889 5890 5891 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 5883 class DeleteTimeSeriesRequest < Struct.new( :alias, :asset_id, :property_id, :client_token, :workspace_name) SENSITIVE = [] include Aws::Structure end |
#property_id ⇒ String
The ID of the asset property. This can be either the actual ID in
UUID format, or else externalId: followed by the external ID, if
it has one. For more information, see Referencing objects with
external IDs in the IoT SiteWise User Guide.
5883 5884 5885 5886 5887 5888 5889 5890 5891 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 5883 class DeleteTimeSeriesRequest < Struct.new( :alias, :asset_id, :property_id, :client_token, :workspace_name) SENSITIVE = [] include Aws::Structure end |
#workspace_name ⇒ String
The name of the workspace.
5883 5884 5885 5886 5887 5888 5889 5890 5891 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 5883 class DeleteTimeSeriesRequest < Struct.new( :alias, :asset_id, :property_id, :client_token, :workspace_name) SENSITIVE = [] include Aws::Structure end |