Class: Aws::IoTSiteWise::Types::DescribeApplicationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTSiteWise::Types::DescribeApplicationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotsitewise/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#id ⇒ String
ID of the Application.
-
#workspace_name ⇒ String
Name of the workspace to associate with the underlying Application.
Instance Attribute Details
#id ⇒ String
ID of the Application
6037 6038 6039 6040 6041 6042 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 6037 class DescribeApplicationRequest < Struct.new( :workspace_name, :id) SENSITIVE = [] include Aws::Structure end |
#workspace_name ⇒ String
Name of the workspace to associate with the underlying Application
6037 6038 6039 6040 6041 6042 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 6037 class DescribeApplicationRequest < Struct.new( :workspace_name, :id) SENSITIVE = [] include Aws::Structure end |