Class: Aws::IoTSiteWise::Types::DescribeAssetModelResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTSiteWise::Types::DescribeAssetModelResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotsitewise/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#asset_model_arn ⇒ String
The [ARN][1] of the asset model, which has the following format.
-
#asset_model_composite_model_summaries ⇒ Array<Types::AssetModelCompositeModelSummary>
The list of the immediate child custom composite model summaries for the asset model.
-
#asset_model_composite_models ⇒ Array<Types::AssetModelCompositeModel>
The list of built-in composite models for the asset model, such as those with those of type
AWS/ALARMS. -
#asset_model_creation_date ⇒ Time
The date the asset model was created, in Unix epoch time.
-
#asset_model_description ⇒ String
The asset model's description.
-
#asset_model_external_id ⇒ String
The external ID of the asset model, if any.
-
#asset_model_hierarchies ⇒ Array<Types::AssetModelHierarchy>
A list of asset model hierarchies that each contain a
childAssetModelIdand ahierarchyId(namedid). -
#asset_model_id ⇒ String
The ID of the asset model, in UUID format.
-
#asset_model_last_update_date ⇒ Time
The date the asset model was last updated, in Unix epoch time.
-
#asset_model_name ⇒ String
The name of the asset model.
-
#asset_model_properties ⇒ Array<Types::AssetModelProperty>
The list of asset properties for the asset model.
-
#asset_model_status ⇒ Types::AssetModelStatus
The current status of the asset model, which contains a state and any error message.
-
#asset_model_type ⇒ String
The type of asset model.
-
#asset_model_version ⇒ String
The version of the asset model.
-
#e_tag ⇒ String
The entity tag (ETag) is a hash of the retrieved version of the asset model.
-
#interface_details ⇒ Array<Types::InterfaceRelationship>
A list of interface details that describe the interfaces implemented by this asset model, including interface asset model IDs and property mappings.
Instance Attribute Details
#asset_model_arn ⇒ String
The ARN of the asset model, which has the following format.
arn:${Partition}:iotsitewise:${Region}:${Account}:asset-model/${AssetModelId}
6484 6485 6486 6487 6488 6489 6490 6491 6492 6493 6494 6495 6496 6497 6498 6499 6500 6501 6502 6503 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 6484 class DescribeAssetModelResponse < Struct.new( :asset_model_id, :asset_model_external_id, :asset_model_arn, :asset_model_name, :asset_model_type, :asset_model_description, :asset_model_properties, :asset_model_hierarchies, :asset_model_composite_models, :asset_model_composite_model_summaries, :asset_model_creation_date, :asset_model_last_update_date, :asset_model_status, :asset_model_version, :interface_details, :e_tag) SENSITIVE = [] include Aws::Structure end |
#asset_model_composite_model_summaries ⇒ Array<Types::AssetModelCompositeModelSummary>
The list of the immediate child custom composite model summaries for the asset model.
6484 6485 6486 6487 6488 6489 6490 6491 6492 6493 6494 6495 6496 6497 6498 6499 6500 6501 6502 6503 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 6484 class DescribeAssetModelResponse < Struct.new( :asset_model_id, :asset_model_external_id, :asset_model_arn, :asset_model_name, :asset_model_type, :asset_model_description, :asset_model_properties, :asset_model_hierarchies, :asset_model_composite_models, :asset_model_composite_model_summaries, :asset_model_creation_date, :asset_model_last_update_date, :asset_model_status, :asset_model_version, :interface_details, :e_tag) SENSITIVE = [] include Aws::Structure end |
#asset_model_composite_models ⇒ Array<Types::AssetModelCompositeModel>
The list of built-in composite models for the asset model, such as
those with those of type AWS/ALARMS.
6484 6485 6486 6487 6488 6489 6490 6491 6492 6493 6494 6495 6496 6497 6498 6499 6500 6501 6502 6503 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 6484 class DescribeAssetModelResponse < Struct.new( :asset_model_id, :asset_model_external_id, :asset_model_arn, :asset_model_name, :asset_model_type, :asset_model_description, :asset_model_properties, :asset_model_hierarchies, :asset_model_composite_models, :asset_model_composite_model_summaries, :asset_model_creation_date, :asset_model_last_update_date, :asset_model_status, :asset_model_version, :interface_details, :e_tag) SENSITIVE = [] include Aws::Structure end |
#asset_model_creation_date ⇒ Time
The date the asset model was created, in Unix epoch time.
6484 6485 6486 6487 6488 6489 6490 6491 6492 6493 6494 6495 6496 6497 6498 6499 6500 6501 6502 6503 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 6484 class DescribeAssetModelResponse < Struct.new( :asset_model_id, :asset_model_external_id, :asset_model_arn, :asset_model_name, :asset_model_type, :asset_model_description, :asset_model_properties, :asset_model_hierarchies, :asset_model_composite_models, :asset_model_composite_model_summaries, :asset_model_creation_date, :asset_model_last_update_date, :asset_model_status, :asset_model_version, :interface_details, :e_tag) SENSITIVE = [] include Aws::Structure end |
#asset_model_description ⇒ String
The asset model's description.
6484 6485 6486 6487 6488 6489 6490 6491 6492 6493 6494 6495 6496 6497 6498 6499 6500 6501 6502 6503 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 6484 class DescribeAssetModelResponse < Struct.new( :asset_model_id, :asset_model_external_id, :asset_model_arn, :asset_model_name, :asset_model_type, :asset_model_description, :asset_model_properties, :asset_model_hierarchies, :asset_model_composite_models, :asset_model_composite_model_summaries, :asset_model_creation_date, :asset_model_last_update_date, :asset_model_status, :asset_model_version, :interface_details, :e_tag) SENSITIVE = [] include Aws::Structure end |
#asset_model_external_id ⇒ String
The external ID of the asset model, if any.
6484 6485 6486 6487 6488 6489 6490 6491 6492 6493 6494 6495 6496 6497 6498 6499 6500 6501 6502 6503 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 6484 class DescribeAssetModelResponse < Struct.new( :asset_model_id, :asset_model_external_id, :asset_model_arn, :asset_model_name, :asset_model_type, :asset_model_description, :asset_model_properties, :asset_model_hierarchies, :asset_model_composite_models, :asset_model_composite_model_summaries, :asset_model_creation_date, :asset_model_last_update_date, :asset_model_status, :asset_model_version, :interface_details, :e_tag) SENSITIVE = [] include Aws::Structure end |
#asset_model_hierarchies ⇒ Array<Types::AssetModelHierarchy>
A list of asset model hierarchies that each contain a
childAssetModelId and a hierarchyId (named id). A hierarchy
specifies allowed parent/child asset relationships for an asset
model.
6484 6485 6486 6487 6488 6489 6490 6491 6492 6493 6494 6495 6496 6497 6498 6499 6500 6501 6502 6503 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 6484 class DescribeAssetModelResponse < Struct.new( :asset_model_id, :asset_model_external_id, :asset_model_arn, :asset_model_name, :asset_model_type, :asset_model_description, :asset_model_properties, :asset_model_hierarchies, :asset_model_composite_models, :asset_model_composite_model_summaries, :asset_model_creation_date, :asset_model_last_update_date, :asset_model_status, :asset_model_version, :interface_details, :e_tag) SENSITIVE = [] include Aws::Structure end |
#asset_model_id ⇒ String
The ID of the asset model, in UUID format.
6484 6485 6486 6487 6488 6489 6490 6491 6492 6493 6494 6495 6496 6497 6498 6499 6500 6501 6502 6503 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 6484 class DescribeAssetModelResponse < Struct.new( :asset_model_id, :asset_model_external_id, :asset_model_arn, :asset_model_name, :asset_model_type, :asset_model_description, :asset_model_properties, :asset_model_hierarchies, :asset_model_composite_models, :asset_model_composite_model_summaries, :asset_model_creation_date, :asset_model_last_update_date, :asset_model_status, :asset_model_version, :interface_details, :e_tag) SENSITIVE = [] include Aws::Structure end |
#asset_model_last_update_date ⇒ Time
The date the asset model was last updated, in Unix epoch time.
6484 6485 6486 6487 6488 6489 6490 6491 6492 6493 6494 6495 6496 6497 6498 6499 6500 6501 6502 6503 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 6484 class DescribeAssetModelResponse < Struct.new( :asset_model_id, :asset_model_external_id, :asset_model_arn, :asset_model_name, :asset_model_type, :asset_model_description, :asset_model_properties, :asset_model_hierarchies, :asset_model_composite_models, :asset_model_composite_model_summaries, :asset_model_creation_date, :asset_model_last_update_date, :asset_model_status, :asset_model_version, :interface_details, :e_tag) SENSITIVE = [] include Aws::Structure end |
#asset_model_name ⇒ String
The name of the asset model.
6484 6485 6486 6487 6488 6489 6490 6491 6492 6493 6494 6495 6496 6497 6498 6499 6500 6501 6502 6503 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 6484 class DescribeAssetModelResponse < Struct.new( :asset_model_id, :asset_model_external_id, :asset_model_arn, :asset_model_name, :asset_model_type, :asset_model_description, :asset_model_properties, :asset_model_hierarchies, :asset_model_composite_models, :asset_model_composite_model_summaries, :asset_model_creation_date, :asset_model_last_update_date, :asset_model_status, :asset_model_version, :interface_details, :e_tag) SENSITIVE = [] include Aws::Structure end |
#asset_model_properties ⇒ Array<Types::AssetModelProperty>
The list of asset properties for the asset model.
This object doesn't include properties that you define in composite
models. You can find composite model properties in the
assetModelCompositeModels object.
6484 6485 6486 6487 6488 6489 6490 6491 6492 6493 6494 6495 6496 6497 6498 6499 6500 6501 6502 6503 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 6484 class DescribeAssetModelResponse < Struct.new( :asset_model_id, :asset_model_external_id, :asset_model_arn, :asset_model_name, :asset_model_type, :asset_model_description, :asset_model_properties, :asset_model_hierarchies, :asset_model_composite_models, :asset_model_composite_model_summaries, :asset_model_creation_date, :asset_model_last_update_date, :asset_model_status, :asset_model_version, :interface_details, :e_tag) SENSITIVE = [] include Aws::Structure end |
#asset_model_status ⇒ Types::AssetModelStatus
The current status of the asset model, which contains a state and any error message.
6484 6485 6486 6487 6488 6489 6490 6491 6492 6493 6494 6495 6496 6497 6498 6499 6500 6501 6502 6503 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 6484 class DescribeAssetModelResponse < Struct.new( :asset_model_id, :asset_model_external_id, :asset_model_arn, :asset_model_name, :asset_model_type, :asset_model_description, :asset_model_properties, :asset_model_hierarchies, :asset_model_composite_models, :asset_model_composite_model_summaries, :asset_model_creation_date, :asset_model_last_update_date, :asset_model_status, :asset_model_version, :interface_details, :e_tag) SENSITIVE = [] include Aws::Structure end |
#asset_model_type ⇒ String
The type of asset model.
-
ASSET_MODEL – (default) An asset model that you can use to create assets. Can't be included as a component in another asset model.
-
COMPONENT_MODEL – A reusable component that you can include in the composite models of other asset models. You can't create assets directly from this type of asset model.
6484 6485 6486 6487 6488 6489 6490 6491 6492 6493 6494 6495 6496 6497 6498 6499 6500 6501 6502 6503 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 6484 class DescribeAssetModelResponse < Struct.new( :asset_model_id, :asset_model_external_id, :asset_model_arn, :asset_model_name, :asset_model_type, :asset_model_description, :asset_model_properties, :asset_model_hierarchies, :asset_model_composite_models, :asset_model_composite_model_summaries, :asset_model_creation_date, :asset_model_last_update_date, :asset_model_status, :asset_model_version, :interface_details, :e_tag) SENSITIVE = [] include Aws::Structure end |
#asset_model_version ⇒ String
The version of the asset model. See Asset model versions in the IoT SiteWise User Guide.
6484 6485 6486 6487 6488 6489 6490 6491 6492 6493 6494 6495 6496 6497 6498 6499 6500 6501 6502 6503 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 6484 class DescribeAssetModelResponse < Struct.new( :asset_model_id, :asset_model_external_id, :asset_model_arn, :asset_model_name, :asset_model_type, :asset_model_description, :asset_model_properties, :asset_model_hierarchies, :asset_model_composite_models, :asset_model_composite_model_summaries, :asset_model_creation_date, :asset_model_last_update_date, :asset_model_status, :asset_model_version, :interface_details, :e_tag) SENSITIVE = [] include Aws::Structure end |
#e_tag ⇒ String
The entity tag (ETag) is a hash of the retrieved version of the asset model. It's used to make concurrent updates safely to the resource. See Optimistic locking for asset model writes in the IoT SiteWise User Guide.
See Optimistic locking for asset model writes in the IoT SiteWise User Guide.
6484 6485 6486 6487 6488 6489 6490 6491 6492 6493 6494 6495 6496 6497 6498 6499 6500 6501 6502 6503 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 6484 class DescribeAssetModelResponse < Struct.new( :asset_model_id, :asset_model_external_id, :asset_model_arn, :asset_model_name, :asset_model_type, :asset_model_description, :asset_model_properties, :asset_model_hierarchies, :asset_model_composite_models, :asset_model_composite_model_summaries, :asset_model_creation_date, :asset_model_last_update_date, :asset_model_status, :asset_model_version, :interface_details, :e_tag) SENSITIVE = [] include Aws::Structure end |
#interface_details ⇒ Array<Types::InterfaceRelationship>
A list of interface details that describe the interfaces implemented by this asset model, including interface asset model IDs and property mappings.
6484 6485 6486 6487 6488 6489 6490 6491 6492 6493 6494 6495 6496 6497 6498 6499 6500 6501 6502 6503 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 6484 class DescribeAssetModelResponse < Struct.new( :asset_model_id, :asset_model_external_id, :asset_model_arn, :asset_model_name, :asset_model_type, :asset_model_description, :asset_model_properties, :asset_model_hierarchies, :asset_model_composite_models, :asset_model_composite_model_summaries, :asset_model_creation_date, :asset_model_last_update_date, :asset_model_status, :asset_model_version, :interface_details, :e_tag) SENSITIVE = [] include Aws::Structure end |