Class: Aws::IoTSiteWise::Types::DescribeBulkImportJobResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotsitewise/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#adaptive_ingestionBoolean

If set to true, ingest new data into IoT SiteWise storage. Measurements with notifications, metrics and transforms are computed. If set to false, historical data is ingested into IoT SiteWise as is.

Returns:

  • (Boolean)


6788
6789
6790
6791
6792
6793
6794
6795
6796
6797
6798
6799
6800
6801
6802
6803
6804
# File 'lib/aws-sdk-iotsitewise/types.rb', line 6788

class DescribeBulkImportJobResponse < Struct.new(
  :job_id,
  :job_name,
  :job_status,
  :job_role_arn,
  :files,
  :error_report_location,
  :job_configuration,
  :job_creation_date,
  :job_last_update_date,
  :adaptive_ingestion,
  :delete_files_after_import,
  :dataset_id,
  :workspace_name)
  SENSITIVE = []
  include Aws::Structure
end

#dataset_idString

The ID of the dataset.

Returns:

  • (String)


6788
6789
6790
6791
6792
6793
6794
6795
6796
6797
6798
6799
6800
6801
6802
6803
6804
# File 'lib/aws-sdk-iotsitewise/types.rb', line 6788

class DescribeBulkImportJobResponse < Struct.new(
  :job_id,
  :job_name,
  :job_status,
  :job_role_arn,
  :files,
  :error_report_location,
  :job_configuration,
  :job_creation_date,
  :job_last_update_date,
  :adaptive_ingestion,
  :delete_files_after_import,
  :dataset_id,
  :workspace_name)
  SENSITIVE = []
  include Aws::Structure
end

#delete_files_after_importBoolean

If set to true, your data files is deleted from S3, after ingestion into IoT SiteWise storage.

Returns:

  • (Boolean)


6788
6789
6790
6791
6792
6793
6794
6795
6796
6797
6798
6799
6800
6801
6802
6803
6804
# File 'lib/aws-sdk-iotsitewise/types.rb', line 6788

class DescribeBulkImportJobResponse < Struct.new(
  :job_id,
  :job_name,
  :job_status,
  :job_role_arn,
  :files,
  :error_report_location,
  :job_configuration,
  :job_creation_date,
  :job_last_update_date,
  :adaptive_ingestion,
  :delete_files_after_import,
  :dataset_id,
  :workspace_name)
  SENSITIVE = []
  include Aws::Structure
end

#error_report_locationTypes::ErrorReportLocation

The Amazon S3 destination where errors associated with the job creation request are saved.



6788
6789
6790
6791
6792
6793
6794
6795
6796
6797
6798
6799
6800
6801
6802
6803
6804
# File 'lib/aws-sdk-iotsitewise/types.rb', line 6788

class DescribeBulkImportJobResponse < Struct.new(
  :job_id,
  :job_name,
  :job_status,
  :job_role_arn,
  :files,
  :error_report_location,
  :job_configuration,
  :job_creation_date,
  :job_last_update_date,
  :adaptive_ingestion,
  :delete_files_after_import,
  :dataset_id,
  :workspace_name)
  SENSITIVE = []
  include Aws::Structure
end

#filesArray<Types::File>

The files in the specified Amazon S3 bucket that contain your data. You can specify up to 100 files for each bulk import job. Each file supports the following size limits:

  • Parquet files – Up to 256 MiB.

  • Other file formats – Up to 5 GiB.

Returns:



6788
6789
6790
6791
6792
6793
6794
6795
6796
6797
6798
6799
6800
6801
6802
6803
6804
# File 'lib/aws-sdk-iotsitewise/types.rb', line 6788

class DescribeBulkImportJobResponse < Struct.new(
  :job_id,
  :job_name,
  :job_status,
  :job_role_arn,
  :files,
  :error_report_location,
  :job_configuration,
  :job_creation_date,
  :job_last_update_date,
  :adaptive_ingestion,
  :delete_files_after_import,
  :dataset_id,
  :workspace_name)
  SENSITIVE = []
  include Aws::Structure
end

#job_configurationTypes::JobConfiguration

Contains the configuration information of a job, such as the file format used to save data in Amazon S3.



6788
6789
6790
6791
6792
6793
6794
6795
6796
6797
6798
6799
6800
6801
6802
6803
6804
# File 'lib/aws-sdk-iotsitewise/types.rb', line 6788

class DescribeBulkImportJobResponse < Struct.new(
  :job_id,
  :job_name,
  :job_status,
  :job_role_arn,
  :files,
  :error_report_location,
  :job_configuration,
  :job_creation_date,
  :job_last_update_date,
  :adaptive_ingestion,
  :delete_files_after_import,
  :dataset_id,
  :workspace_name)
  SENSITIVE = []
  include Aws::Structure
end

#job_creation_dateTime

The date the job was created, in Unix epoch TIME.

Returns:

  • (Time)


6788
6789
6790
6791
6792
6793
6794
6795
6796
6797
6798
6799
6800
6801
6802
6803
6804
# File 'lib/aws-sdk-iotsitewise/types.rb', line 6788

class DescribeBulkImportJobResponse < Struct.new(
  :job_id,
  :job_name,
  :job_status,
  :job_role_arn,
  :files,
  :error_report_location,
  :job_configuration,
  :job_creation_date,
  :job_last_update_date,
  :adaptive_ingestion,
  :delete_files_after_import,
  :dataset_id,
  :workspace_name)
  SENSITIVE = []
  include Aws::Structure
end

#job_idString

The ID of the job.

Returns:

  • (String)


6788
6789
6790
6791
6792
6793
6794
6795
6796
6797
6798
6799
6800
6801
6802
6803
6804
# File 'lib/aws-sdk-iotsitewise/types.rb', line 6788

class DescribeBulkImportJobResponse < Struct.new(
  :job_id,
  :job_name,
  :job_status,
  :job_role_arn,
  :files,
  :error_report_location,
  :job_configuration,
  :job_creation_date,
  :job_last_update_date,
  :adaptive_ingestion,
  :delete_files_after_import,
  :dataset_id,
  :workspace_name)
  SENSITIVE = []
  include Aws::Structure
end

#job_last_update_dateTime

The date the job was last updated, in Unix epoch time.

Returns:

  • (Time)


6788
6789
6790
6791
6792
6793
6794
6795
6796
6797
6798
6799
6800
6801
6802
6803
6804
# File 'lib/aws-sdk-iotsitewise/types.rb', line 6788

class DescribeBulkImportJobResponse < Struct.new(
  :job_id,
  :job_name,
  :job_status,
  :job_role_arn,
  :files,
  :error_report_location,
  :job_configuration,
  :job_creation_date,
  :job_last_update_date,
  :adaptive_ingestion,
  :delete_files_after_import,
  :dataset_id,
  :workspace_name)
  SENSITIVE = []
  include Aws::Structure
end

#job_nameString

The unique name that helps identify the job request.

Returns:

  • (String)


6788
6789
6790
6791
6792
6793
6794
6795
6796
6797
6798
6799
6800
6801
6802
6803
6804
# File 'lib/aws-sdk-iotsitewise/types.rb', line 6788

class DescribeBulkImportJobResponse < Struct.new(
  :job_id,
  :job_name,
  :job_status,
  :job_role_arn,
  :files,
  :error_report_location,
  :job_configuration,
  :job_creation_date,
  :job_last_update_date,
  :adaptive_ingestion,
  :delete_files_after_import,
  :dataset_id,
  :workspace_name)
  SENSITIVE = []
  include Aws::Structure
end

#job_role_arnString

The ARN of the IAM role that allows IoT SiteWise to read Amazon S3 data.

Returns:

  • (String)


6788
6789
6790
6791
6792
6793
6794
6795
6796
6797
6798
6799
6800
6801
6802
6803
6804
# File 'lib/aws-sdk-iotsitewise/types.rb', line 6788

class DescribeBulkImportJobResponse < Struct.new(
  :job_id,
  :job_name,
  :job_status,
  :job_role_arn,
  :files,
  :error_report_location,
  :job_configuration,
  :job_creation_date,
  :job_last_update_date,
  :adaptive_ingestion,
  :delete_files_after_import,
  :dataset_id,
  :workspace_name)
  SENSITIVE = []
  include Aws::Structure
end

#job_statusString

The status of the bulk import job can be one of following values:

  • PENDING – IoT SiteWise is waiting for the current bulk import job to finish.

  • CANCELLED – The bulk import job has been canceled.

  • RUNNING – IoT SiteWise is processing your request to import your data from Amazon S3.

  • COMPLETED – IoT SiteWise successfully completed your request to import data from Amazon S3.

  • FAILED – IoT SiteWise couldn't process your request to import data from Amazon S3. You can use logs saved in the specified error report location in Amazon S3 to troubleshoot issues.

  • COMPLETED_WITH_FAILURES – IoT SiteWise completed your request to import data from Amazon S3 with errors. You can use logs saved in the specified error report location in Amazon S3 to troubleshoot issues.

Returns:

  • (String)


6788
6789
6790
6791
6792
6793
6794
6795
6796
6797
6798
6799
6800
6801
6802
6803
6804
# File 'lib/aws-sdk-iotsitewise/types.rb', line 6788

class DescribeBulkImportJobResponse < Struct.new(
  :job_id,
  :job_name,
  :job_status,
  :job_role_arn,
  :files,
  :error_report_location,
  :job_configuration,
  :job_creation_date,
  :job_last_update_date,
  :adaptive_ingestion,
  :delete_files_after_import,
  :dataset_id,
  :workspace_name)
  SENSITIVE = []
  include Aws::Structure
end

#workspace_nameString

The name of the workspace.

Returns:

  • (String)


6788
6789
6790
6791
6792
6793
6794
6795
6796
6797
6798
6799
6800
6801
6802
6803
6804
# File 'lib/aws-sdk-iotsitewise/types.rb', line 6788

class DescribeBulkImportJobResponse < Struct.new(
  :job_id,
  :job_name,
  :job_status,
  :job_role_arn,
  :files,
  :error_report_location,
  :job_configuration,
  :job_creation_date,
  :job_last_update_date,
  :adaptive_ingestion,
  :delete_files_after_import,
  :dataset_id,
  :workspace_name)
  SENSITIVE = []
  include Aws::Structure
end