Class: Aws::IoTSiteWise::Types::DescribeDatasetExportJobRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTSiteWise::Types::DescribeDatasetExportJobRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotsitewise/types.rb
Overview
Request to describe a dataset export job.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#job_id ⇒ String
The unique identifier for the dataset export job.
-
#workspace_name ⇒ String
The name of the workspace that contains the dataset export job.
Instance Attribute Details
#job_id ⇒ String
The unique identifier for the dataset export job.
7007 7008 7009 7010 7011 7012 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 7007 class DescribeDatasetExportJobRequest < Struct.new( :workspace_name, :job_id) SENSITIVE = [] include Aws::Structure end |
#workspace_name ⇒ String
The name of the workspace that contains the dataset export job.
7007 7008 7009 7010 7011 7012 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 7007 class DescribeDatasetExportJobRequest < Struct.new( :workspace_name, :job_id) SENSITIVE = [] include Aws::Structure end |