Class: Aws::IoTSiteWise::Types::DescribeDatasetExportJobResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotsitewise/types.rb

Overview

Response for describe dataset export job request.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#completed_atTime

The timestamp when the job completed, or null if the job is still running.

Returns:

  • (Time)


7050
7051
7052
7053
7054
7055
7056
7057
7058
7059
7060
7061
# File 'lib/aws-sdk-iotsitewise/types.rb', line 7050

class DescribeDatasetExportJobResponse < Struct.new(
  :job_id,
  :workspace_name,
  :status,
  :started_at,
  :completed_at,
  :destination_s3_uri,
  :error_report_location,
  :input)
  SENSITIVE = []
  include Aws::Structure
end

#destination_s3_uriString

The S3 URI where output clips are written.

Returns:

  • (String)


7050
7051
7052
7053
7054
7055
7056
7057
7058
7059
7060
7061
# File 'lib/aws-sdk-iotsitewise/types.rb', line 7050

class DescribeDatasetExportJobResponse < Struct.new(
  :job_id,
  :workspace_name,
  :status,
  :started_at,
  :completed_at,
  :destination_s3_uri,
  :error_report_location,
  :input)
  SENSITIVE = []
  include Aws::Structure
end

#error_report_locationTypes::ExportErrorReportLocation

The location where the error report will be written on failure.



7050
7051
7052
7053
7054
7055
7056
7057
7058
7059
7060
7061
# File 'lib/aws-sdk-iotsitewise/types.rb', line 7050

class DescribeDatasetExportJobResponse < Struct.new(
  :job_id,
  :workspace_name,
  :status,
  :started_at,
  :completed_at,
  :destination_s3_uri,
  :error_report_location,
  :input)
  SENSITIVE = []
  include Aws::Structure
end

#inputTypes::ProcessingInput

The processing input that was provided in the CreateDatasetExportJob request.



7050
7051
7052
7053
7054
7055
7056
7057
7058
7059
7060
7061
# File 'lib/aws-sdk-iotsitewise/types.rb', line 7050

class DescribeDatasetExportJobResponse < Struct.new(
  :job_id,
  :workspace_name,
  :status,
  :started_at,
  :completed_at,
  :destination_s3_uri,
  :error_report_location,
  :input)
  SENSITIVE = []
  include Aws::Structure
end

#job_idString

The unique identifier for the dataset export job.

Returns:

  • (String)


7050
7051
7052
7053
7054
7055
7056
7057
7058
7059
7060
7061
# File 'lib/aws-sdk-iotsitewise/types.rb', line 7050

class DescribeDatasetExportJobResponse < Struct.new(
  :job_id,
  :workspace_name,
  :status,
  :started_at,
  :completed_at,
  :destination_s3_uri,
  :error_report_location,
  :input)
  SENSITIVE = []
  include Aws::Structure
end

#started_atTime

The timestamp when the job started processing.

Returns:

  • (Time)


7050
7051
7052
7053
7054
7055
7056
7057
7058
7059
7060
7061
# File 'lib/aws-sdk-iotsitewise/types.rb', line 7050

class DescribeDatasetExportJobResponse < Struct.new(
  :job_id,
  :workspace_name,
  :status,
  :started_at,
  :completed_at,
  :destination_s3_uri,
  :error_report_location,
  :input)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The current status of the dataset export job.

Returns:

  • (String)


7050
7051
7052
7053
7054
7055
7056
7057
7058
7059
7060
7061
# File 'lib/aws-sdk-iotsitewise/types.rb', line 7050

class DescribeDatasetExportJobResponse < Struct.new(
  :job_id,
  :workspace_name,
  :status,
  :started_at,
  :completed_at,
  :destination_s3_uri,
  :error_report_location,
  :input)
  SENSITIVE = []
  include Aws::Structure
end

#workspace_nameString

The name of the workspace that contains the dataset export job.

Returns:

  • (String)


7050
7051
7052
7053
7054
7055
7056
7057
7058
7059
7060
7061
# File 'lib/aws-sdk-iotsitewise/types.rb', line 7050

class DescribeDatasetExportJobResponse < Struct.new(
  :job_id,
  :workspace_name,
  :status,
  :started_at,
  :completed_at,
  :destination_s3_uri,
  :error_report_location,
  :input)
  SENSITIVE = []
  include Aws::Structure
end