Class: Aws::IoTSiteWise::Types::DescribeDatasetRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTSiteWise::Types::DescribeDatasetRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotsitewise/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dataset_id ⇒ String
The ID of the dataset.
-
#dataset_version ⇒ String
The version of the dataset.
-
#workspace_name ⇒ String
The name of the workspace that contains the dataset.
Instance Attribute Details
#dataset_id ⇒ String
The ID of the dataset.
7075 7076 7077 7078 7079 7080 7081 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 7075 class DescribeDatasetRequest < Struct.new( :dataset_id, :workspace_name, :dataset_version) SENSITIVE = [] include Aws::Structure end |
#dataset_version ⇒ String
The version of the dataset.
7075 7076 7077 7078 7079 7080 7081 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 7075 class DescribeDatasetRequest < Struct.new( :dataset_id, :workspace_name, :dataset_version) SENSITIVE = [] include Aws::Structure end |
#workspace_name ⇒ String
The name of the workspace that contains the dataset.
7075 7076 7077 7078 7079 7080 7081 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 7075 class DescribeDatasetRequest < Struct.new( :dataset_id, :workspace_name, :dataset_version) SENSITIVE = [] include Aws::Structure end |