Class: Aws::IoTSiteWise::Types::DescribeEnrichmentJobRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTSiteWise::Types::DescribeEnrichmentJobRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotsitewise/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#job_id ⇒ String
The unique identifier of the enrichment job to retrieve.
-
#workspace_name ⇒ String
The name of the IoT SiteWise workspace containing the enrichment job.
Instance Attribute Details
#job_id ⇒ String
The unique identifier of the enrichment job to retrieve. This is the jobId returned by CreateEnrichmentJob.
7204 7205 7206 7207 7208 7209 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 7204 class DescribeEnrichmentJobRequest < Struct.new( :workspace_name, :job_id) SENSITIVE = [] include Aws::Structure end |
#workspace_name ⇒ String
The name of the IoT SiteWise workspace containing the enrichment job.
7204 7205 7206 7207 7208 7209 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 7204 class DescribeEnrichmentJobRequest < Struct.new( :workspace_name, :job_id) SENSITIVE = [] include Aws::Structure end |