Class: Aws::IoTSiteWise::Types::DescribeExecutionResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTSiteWise::Types::DescribeExecutionResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotsitewise/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#action_type ⇒ String
The type of action exectued.
-
#execution_details ⇒ Hash<String,String>
Provides detailed information about the execution of your anomaly detection models.
-
#execution_end_time ⇒ Time
The time the process ended.
-
#execution_entity_version ⇒ String
Entity version used for the execution.
-
#execution_id ⇒ String
The ID of the execution.
-
#execution_result ⇒ Hash<String,String>
The result of the execution.
-
#execution_start_time ⇒ Time
The time the process started.
-
#execution_status ⇒ Types::ExecutionStatus
The status of the execution process.
-
#resolve_to ⇒ Types::ResolveTo
The detailed resource this execution resolves to.
-
#target_resource ⇒ Types::TargetResource
The resource the action will be taken on.
-
#target_resource_version ⇒ String
The version of the target resource.
Instance Attribute Details
#action_type ⇒ String
The type of action exectued.
7353 7354 7355 7356 7357 7358 7359 7360 7361 7362 7363 7364 7365 7366 7367 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 7353 class DescribeExecutionResponse < Struct.new( :execution_id, :action_type, :target_resource, :target_resource_version, :resolve_to, :execution_start_time, :execution_end_time, :execution_status, :execution_result, :execution_details, :execution_entity_version) SENSITIVE = [] include Aws::Structure end |
#execution_details ⇒ Hash<String,String>
Provides detailed information about the execution of your anomaly detection models. This includes model metrics and training timestamps for both training and inference actions.
-
The training action (Amazon Web Services/ANOMALY_DETECTION_TRAINING), includes performance metrics that help you compare different versions of your anomaly detection models. These metrics provide insights into the model's performance during the training process.
-
The inference action (Amazon Web Services/ANOMALY_DETECTION_INFERENCE), includes information about the results of executing your anomaly detection models. This helps you understand the output of your models and assess their performance.
7353 7354 7355 7356 7357 7358 7359 7360 7361 7362 7363 7364 7365 7366 7367 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 7353 class DescribeExecutionResponse < Struct.new( :execution_id, :action_type, :target_resource, :target_resource_version, :resolve_to, :execution_start_time, :execution_end_time, :execution_status, :execution_result, :execution_details, :execution_entity_version) SENSITIVE = [] include Aws::Structure end |
#execution_end_time ⇒ Time
The time the process ended.
7353 7354 7355 7356 7357 7358 7359 7360 7361 7362 7363 7364 7365 7366 7367 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 7353 class DescribeExecutionResponse < Struct.new( :execution_id, :action_type, :target_resource, :target_resource_version, :resolve_to, :execution_start_time, :execution_end_time, :execution_status, :execution_result, :execution_details, :execution_entity_version) SENSITIVE = [] include Aws::Structure end |
#execution_entity_version ⇒ String
Entity version used for the execution.
7353 7354 7355 7356 7357 7358 7359 7360 7361 7362 7363 7364 7365 7366 7367 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 7353 class DescribeExecutionResponse < Struct.new( :execution_id, :action_type, :target_resource, :target_resource_version, :resolve_to, :execution_start_time, :execution_end_time, :execution_status, :execution_result, :execution_details, :execution_entity_version) SENSITIVE = [] include Aws::Structure end |
#execution_id ⇒ String
The ID of the execution.
7353 7354 7355 7356 7357 7358 7359 7360 7361 7362 7363 7364 7365 7366 7367 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 7353 class DescribeExecutionResponse < Struct.new( :execution_id, :action_type, :target_resource, :target_resource_version, :resolve_to, :execution_start_time, :execution_end_time, :execution_status, :execution_result, :execution_details, :execution_entity_version) SENSITIVE = [] include Aws::Structure end |
#execution_result ⇒ Hash<String,String>
The result of the execution.
7353 7354 7355 7356 7357 7358 7359 7360 7361 7362 7363 7364 7365 7366 7367 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 7353 class DescribeExecutionResponse < Struct.new( :execution_id, :action_type, :target_resource, :target_resource_version, :resolve_to, :execution_start_time, :execution_end_time, :execution_status, :execution_result, :execution_details, :execution_entity_version) SENSITIVE = [] include Aws::Structure end |
#execution_start_time ⇒ Time
The time the process started.
7353 7354 7355 7356 7357 7358 7359 7360 7361 7362 7363 7364 7365 7366 7367 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 7353 class DescribeExecutionResponse < Struct.new( :execution_id, :action_type, :target_resource, :target_resource_version, :resolve_to, :execution_start_time, :execution_end_time, :execution_status, :execution_result, :execution_details, :execution_entity_version) SENSITIVE = [] include Aws::Structure end |
#execution_status ⇒ Types::ExecutionStatus
The status of the execution process.
7353 7354 7355 7356 7357 7358 7359 7360 7361 7362 7363 7364 7365 7366 7367 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 7353 class DescribeExecutionResponse < Struct.new( :execution_id, :action_type, :target_resource, :target_resource_version, :resolve_to, :execution_start_time, :execution_end_time, :execution_status, :execution_result, :execution_details, :execution_entity_version) SENSITIVE = [] include Aws::Structure end |
#resolve_to ⇒ Types::ResolveTo
The detailed resource this execution resolves to.
7353 7354 7355 7356 7357 7358 7359 7360 7361 7362 7363 7364 7365 7366 7367 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 7353 class DescribeExecutionResponse < Struct.new( :execution_id, :action_type, :target_resource, :target_resource_version, :resolve_to, :execution_start_time, :execution_end_time, :execution_status, :execution_result, :execution_details, :execution_entity_version) SENSITIVE = [] include Aws::Structure end |
#target_resource ⇒ Types::TargetResource
The resource the action will be taken on. This can include asset-based resources and computation model resources.
7353 7354 7355 7356 7357 7358 7359 7360 7361 7362 7363 7364 7365 7366 7367 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 7353 class DescribeExecutionResponse < Struct.new( :execution_id, :action_type, :target_resource, :target_resource_version, :resolve_to, :execution_start_time, :execution_end_time, :execution_status, :execution_result, :execution_details, :execution_entity_version) SENSITIVE = [] include Aws::Structure end |
#target_resource_version ⇒ String
The version of the target resource.
7353 7354 7355 7356 7357 7358 7359 7360 7361 7362 7363 7364 7365 7366 7367 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 7353 class DescribeExecutionResponse < Struct.new( :execution_id, :action_type, :target_resource, :target_resource_version, :resolve_to, :execution_start_time, :execution_end_time, :execution_status, :execution_result, :execution_details, :execution_entity_version) SENSITIVE = [] include Aws::Structure end |