Class: Aws::IoTSiteWise::Types::DescribeGatewayCapabilityConfigurationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTSiteWise::Types::DescribeGatewayCapabilityConfigurationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotsitewise/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#capability_namespace ⇒ String
The namespace of the capability configuration.
-
#gateway_id ⇒ String
The ID of the gateway that defines the capability configuration.
Instance Attribute Details
#capability_namespace ⇒ String
The namespace of the capability configuration. For example, if you
configure OPC UA sources for an MQTT-enabled gateway, your OPC-UA
capability configuration has the namespace
iotsitewise:opcuacollector:3.
7380 7381 7382 7383 7384 7385 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 7380 class DescribeGatewayCapabilityConfigurationRequest < Struct.new( :gateway_id, :capability_namespace) SENSITIVE = [] include Aws::Structure end |
#gateway_id ⇒ String
The ID of the gateway that defines the capability configuration.
7380 7381 7382 7383 7384 7385 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 7380 class DescribeGatewayCapabilityConfigurationRequest < Struct.new( :gateway_id, :capability_namespace) SENSITIVE = [] include Aws::Structure end |