Class: Aws::IoTSiteWise::Types::DescribeGatewayCapabilityConfigurationResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTSiteWise::Types::DescribeGatewayCapabilityConfigurationResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotsitewise/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#capability_configuration ⇒ String
The JSON document that defines the gateway capability's configuration.
-
#capability_namespace ⇒ String
The namespace of the gateway capability.
-
#capability_sync_status ⇒ String
The synchronization status of the gateway capability configuration.
-
#gateway_id ⇒ String
The ID of the gateway that defines the capability configuration.
Instance Attribute Details
#capability_configuration ⇒ String
The JSON document that defines the gateway capability's configuration. For more information, see Configuring data sources (CLI) in the IoT SiteWise User Guide.
7423 7424 7425 7426 7427 7428 7429 7430 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 7423 class DescribeGatewayCapabilityConfigurationResponse < Struct.new( :gateway_id, :capability_namespace, :capability_configuration, :capability_sync_status) SENSITIVE = [] include Aws::Structure end |
#capability_namespace ⇒ String
The namespace of the gateway capability.
7423 7424 7425 7426 7427 7428 7429 7430 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 7423 class DescribeGatewayCapabilityConfigurationResponse < Struct.new( :gateway_id, :capability_namespace, :capability_configuration, :capability_sync_status) SENSITIVE = [] include Aws::Structure end |
#capability_sync_status ⇒ String
The synchronization status of the gateway capability configuration. The sync status can be one of the following:
-
IN_SYNC- The gateway is running with the latest configuration. -
OUT_OF_SYNC- The gateway hasn't received the latest configuration. -
SYNC_FAILED- The gateway rejected the latest configuration. -
UNKNOWN- The gateway hasn't reported its sync status. -
NOT_APPLICABLE- The gateway doesn't support this capability. This is most common when integrating partner data sources, because the data integration is handled externally by the partner.
7423 7424 7425 7426 7427 7428 7429 7430 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 7423 class DescribeGatewayCapabilityConfigurationResponse < Struct.new( :gateway_id, :capability_namespace, :capability_configuration, :capability_sync_status) SENSITIVE = [] include Aws::Structure end |
#gateway_id ⇒ String
The ID of the gateway that defines the capability configuration.
7423 7424 7425 7426 7427 7428 7429 7430 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 7423 class DescribeGatewayCapabilityConfigurationResponse < Struct.new( :gateway_id, :capability_namespace, :capability_configuration, :capability_sync_status) SENSITIVE = [] include Aws::Structure end |