Class: Aws::IoTSiteWise::Types::DescribePipelineExecutionRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotsitewise/types.rb

Overview

Request structure for DescribePipelineExecution operation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#max_resultsInteger

The maximum number of compute nodes to return per request. This is an upper bound; the actual number of results may be less. Default: 50.

Returns:

  • (Integer)


7546
7547
7548
7549
7550
7551
7552
7553
7554
# File 'lib/aws-sdk-iotsitewise/types.rb', line 7546

class DescribePipelineExecutionRequest < Struct.new(
  :workspace_name,
  :pipeline_name,
  :pipeline_execution_id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token to be used for the next set of paginated results.

Returns:

  • (String)


7546
7547
7548
7549
7550
7551
7552
7553
7554
# File 'lib/aws-sdk-iotsitewise/types.rb', line 7546

class DescribePipelineExecutionRequest < Struct.new(
  :workspace_name,
  :pipeline_name,
  :pipeline_execution_id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#pipeline_execution_idString

The unique identifier of the pipeline execution.

Returns:

  • (String)


7546
7547
7548
7549
7550
7551
7552
7553
7554
# File 'lib/aws-sdk-iotsitewise/types.rb', line 7546

class DescribePipelineExecutionRequest < Struct.new(
  :workspace_name,
  :pipeline_name,
  :pipeline_execution_id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#pipeline_nameString

The name of the pipeline.

Returns:

  • (String)


7546
7547
7548
7549
7550
7551
7552
7553
7554
# File 'lib/aws-sdk-iotsitewise/types.rb', line 7546

class DescribePipelineExecutionRequest < Struct.new(
  :workspace_name,
  :pipeline_name,
  :pipeline_execution_id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#workspace_nameString

The name of the workspace.

Returns:

  • (String)


7546
7547
7548
7549
7550
7551
7552
7553
7554
# File 'lib/aws-sdk-iotsitewise/types.rb', line 7546

class DescribePipelineExecutionRequest < Struct.new(
  :workspace_name,
  :pipeline_name,
  :pipeline_execution_id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end