Class: Aws::IoTSiteWise::Types::DescribeProjectResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotsitewise/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#portal_idString

The ID of the portal that the project is in.

Returns:

  • (String)


7873
7874
7875
7876
7877
7878
7879
7880
7881
7882
7883
# File 'lib/aws-sdk-iotsitewise/types.rb', line 7873

class DescribeProjectResponse < Struct.new(
  :project_id,
  :project_arn,
  :project_name,
  :portal_id,
  :project_description,
  :project_creation_date,
  :project_last_update_date)
  SENSITIVE = []
  include Aws::Structure
end

#project_arnString

The ARN of the project, which has the following format.

arn:${Partition}:iotsitewise:${Region}:${Account}:project/${ProjectId}

Returns:

  • (String)


7873
7874
7875
7876
7877
7878
7879
7880
7881
7882
7883
# File 'lib/aws-sdk-iotsitewise/types.rb', line 7873

class DescribeProjectResponse < Struct.new(
  :project_id,
  :project_arn,
  :project_name,
  :portal_id,
  :project_description,
  :project_creation_date,
  :project_last_update_date)
  SENSITIVE = []
  include Aws::Structure
end

#project_creation_dateTime

The date the project was created, in Unix epoch time.

Returns:

  • (Time)


7873
7874
7875
7876
7877
7878
7879
7880
7881
7882
7883
# File 'lib/aws-sdk-iotsitewise/types.rb', line 7873

class DescribeProjectResponse < Struct.new(
  :project_id,
  :project_arn,
  :project_name,
  :portal_id,
  :project_description,
  :project_creation_date,
  :project_last_update_date)
  SENSITIVE = []
  include Aws::Structure
end

#project_descriptionString

The project's description.

Returns:

  • (String)


7873
7874
7875
7876
7877
7878
7879
7880
7881
7882
7883
# File 'lib/aws-sdk-iotsitewise/types.rb', line 7873

class DescribeProjectResponse < Struct.new(
  :project_id,
  :project_arn,
  :project_name,
  :portal_id,
  :project_description,
  :project_creation_date,
  :project_last_update_date)
  SENSITIVE = []
  include Aws::Structure
end

#project_idString

The ID of the project.

Returns:

  • (String)


7873
7874
7875
7876
7877
7878
7879
7880
7881
7882
7883
# File 'lib/aws-sdk-iotsitewise/types.rb', line 7873

class DescribeProjectResponse < Struct.new(
  :project_id,
  :project_arn,
  :project_name,
  :portal_id,
  :project_description,
  :project_creation_date,
  :project_last_update_date)
  SENSITIVE = []
  include Aws::Structure
end

#project_last_update_dateTime

The date the project was last updated, in Unix epoch time.

Returns:

  • (Time)


7873
7874
7875
7876
7877
7878
7879
7880
7881
7882
7883
# File 'lib/aws-sdk-iotsitewise/types.rb', line 7873

class DescribeProjectResponse < Struct.new(
  :project_id,
  :project_arn,
  :project_name,
  :portal_id,
  :project_description,
  :project_creation_date,
  :project_last_update_date)
  SENSITIVE = []
  include Aws::Structure
end

#project_nameString

The name of the project.

Returns:

  • (String)


7873
7874
7875
7876
7877
7878
7879
7880
7881
7882
7883
# File 'lib/aws-sdk-iotsitewise/types.rb', line 7873

class DescribeProjectResponse < Struct.new(
  :project_id,
  :project_arn,
  :project_name,
  :portal_id,
  :project_description,
  :project_creation_date,
  :project_last_update_date)
  SENSITIVE = []
  include Aws::Structure
end