Class: Aws::IoTSiteWise::Types::DescribeQueryRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTSiteWise::Types::DescribeQueryRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotsitewise/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#query_id ⇒ String
The unique identifier for the query execution.
-
#workspace_name ⇒ String
The name of the workspace associated with the query.
Instance Attribute Details
#query_id ⇒ String
The unique identifier for the query execution.
7893 7894 7895 7896 7897 7898 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 7893 class DescribeQueryRequest < Struct.new( :workspace_name, :query_id) SENSITIVE = [] include Aws::Structure end |
#workspace_name ⇒ String
The name of the workspace associated with the query.
7893 7894 7895 7896 7897 7898 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 7893 class DescribeQueryRequest < Struct.new( :workspace_name, :query_id) SENSITIVE = [] include Aws::Structure end |