Class: Aws::IoTSiteWise::Types::DescribeSearchRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTSiteWise::Types::DescribeSearchRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotsitewise/types.rb
Overview
Input for the DescribeSearch operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#search_id ⇒ String
The identifier of the search to describe.
-
#workspace_name ⇒ String
The name of the workspace the search belongs to.
Instance Attribute Details
#search_id ⇒ String
The identifier of the search to describe.
7951 7952 7953 7954 7955 7956 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 7951 class DescribeSearchRequest < Struct.new( :workspace_name, :search_id) SENSITIVE = [] include Aws::Structure end |
#workspace_name ⇒ String
The name of the workspace the search belongs to.
7951 7952 7953 7954 7955 7956 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 7951 class DescribeSearchRequest < Struct.new( :workspace_name, :search_id) SENSITIVE = [] include Aws::Structure end |