Class: Aws::IoTSiteWise::Types::DescribeSearchResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTSiteWise::Types::DescribeSearchResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotsitewise/types.rb
Overview
Output of the DescribeSearch operation.
Constant Summary collapse
- SENSITIVE =
[:query_statement]
Instance Attribute Summary collapse
-
#group_id ⇒ String
The group identifier associated with the search, if one was supplied on the request.
-
#query_statement ⇒ String
The natural-language query that was submitted for the search.
-
#search_id ⇒ String
The unique identifier of the search.
-
#search_type ⇒ String
The search strategy used for the search.
-
#started_at ⇒ Time
The time at which the search was started.
-
#status ⇒ String
The current status of the search.
-
#status_reason ⇒ String
A human-readable explanation of the current status.
-
#workspace_name ⇒ String
The name of the workspace the search runs against.
Instance Attribute Details
#group_id ⇒ String
The group identifier associated with the search, if one was supplied on the request.
7994 7995 7996 7997 7998 7999 8000 8001 8002 8003 8004 8005 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 7994 class DescribeSearchResponse < Struct.new( :search_id, :workspace_name, :status, :query_statement, :search_type, :status_reason, :started_at, :group_id) SENSITIVE = [:query_statement] include Aws::Structure end |
#query_statement ⇒ String
The natural-language query that was submitted for the search.
7994 7995 7996 7997 7998 7999 8000 8001 8002 8003 8004 8005 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 7994 class DescribeSearchResponse < Struct.new( :search_id, :workspace_name, :status, :query_statement, :search_type, :status_reason, :started_at, :group_id) SENSITIVE = [:query_statement] include Aws::Structure end |
#search_id ⇒ String
The unique identifier of the search.
7994 7995 7996 7997 7998 7999 8000 8001 8002 8003 8004 8005 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 7994 class DescribeSearchResponse < Struct.new( :search_id, :workspace_name, :status, :query_statement, :search_type, :status_reason, :started_at, :group_id) SENSITIVE = [:query_statement] include Aws::Structure end |
#search_type ⇒ String
The search strategy used for the search.
7994 7995 7996 7997 7998 7999 8000 8001 8002 8003 8004 8005 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 7994 class DescribeSearchResponse < Struct.new( :search_id, :workspace_name, :status, :query_statement, :search_type, :status_reason, :started_at, :group_id) SENSITIVE = [:query_statement] include Aws::Structure end |
#started_at ⇒ Time
The time at which the search was started.
7994 7995 7996 7997 7998 7999 8000 8001 8002 8003 8004 8005 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 7994 class DescribeSearchResponse < Struct.new( :search_id, :workspace_name, :status, :query_statement, :search_type, :status_reason, :started_at, :group_id) SENSITIVE = [:query_statement] include Aws::Structure end |
#status ⇒ String
The current status of the search.
7994 7995 7996 7997 7998 7999 8000 8001 8002 8003 8004 8005 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 7994 class DescribeSearchResponse < Struct.new( :search_id, :workspace_name, :status, :query_statement, :search_type, :status_reason, :started_at, :group_id) SENSITIVE = [:query_statement] include Aws::Structure end |
#status_reason ⇒ String
A human-readable explanation of the current status. Populated when
the search has FAILED.
7994 7995 7996 7997 7998 7999 8000 8001 8002 8003 8004 8005 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 7994 class DescribeSearchResponse < Struct.new( :search_id, :workspace_name, :status, :query_statement, :search_type, :status_reason, :started_at, :group_id) SENSITIVE = [:query_statement] include Aws::Structure end |
#workspace_name ⇒ String
The name of the workspace the search runs against.
7994 7995 7996 7997 7998 7999 8000 8001 8002 8003 8004 8005 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 7994 class DescribeSearchResponse < Struct.new( :search_id, :workspace_name, :status, :query_statement, :search_type, :status_reason, :started_at, :group_id) SENSITIVE = [:query_statement] include Aws::Structure end |