Class: Aws::IoTSiteWise::Types::DescribeWorkspaceResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotsitewise/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#created_atTime

The date the workspace was created, in Unix epoch time.

Returns:

  • (Time)


8324
8325
8326
8327
8328
8329
8330
8331
8332
8333
8334
# File 'lib/aws-sdk-iotsitewise/types.rb', line 8324

class DescribeWorkspaceResponse < Struct.new(
  :workspace_arn,
  :workspace_name,
  :workspace_description,
  :workspace_status,
  :encryption_configuration,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#encryption_configurationTypes::WorkspaceEncryptionConfigurationInfo

The encryption configuration information for the workspace.



8324
8325
8326
8327
8328
8329
8330
8331
8332
8333
8334
# File 'lib/aws-sdk-iotsitewise/types.rb', line 8324

class DescribeWorkspaceResponse < Struct.new(
  :workspace_arn,
  :workspace_name,
  :workspace_description,
  :workspace_status,
  :encryption_configuration,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#updated_atTime

The date the workspace was last updated, in Unix epoch time.

Returns:

  • (Time)


8324
8325
8326
8327
8328
8329
8330
8331
8332
8333
8334
# File 'lib/aws-sdk-iotsitewise/types.rb', line 8324

class DescribeWorkspaceResponse < Struct.new(
  :workspace_arn,
  :workspace_name,
  :workspace_description,
  :workspace_status,
  :encryption_configuration,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#workspace_arnString

The ARN of the workspace.

Returns:

  • (String)


8324
8325
8326
8327
8328
8329
8330
8331
8332
8333
8334
# File 'lib/aws-sdk-iotsitewise/types.rb', line 8324

class DescribeWorkspaceResponse < Struct.new(
  :workspace_arn,
  :workspace_name,
  :workspace_description,
  :workspace_status,
  :encryption_configuration,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#workspace_descriptionString

The description of the workspace.

Returns:

  • (String)


8324
8325
8326
8327
8328
8329
8330
8331
8332
8333
8334
# File 'lib/aws-sdk-iotsitewise/types.rb', line 8324

class DescribeWorkspaceResponse < Struct.new(
  :workspace_arn,
  :workspace_name,
  :workspace_description,
  :workspace_status,
  :encryption_configuration,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#workspace_nameString

The name of the workspace.

Returns:

  • (String)


8324
8325
8326
8327
8328
8329
8330
8331
8332
8333
8334
# File 'lib/aws-sdk-iotsitewise/types.rb', line 8324

class DescribeWorkspaceResponse < Struct.new(
  :workspace_arn,
  :workspace_name,
  :workspace_description,
  :workspace_status,
  :encryption_configuration,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#workspace_statusTypes::WorkspaceStatus

The status of the workspace, which contains the state and any error message.



8324
8325
8326
8327
8328
8329
8330
8331
8332
8333
8334
# File 'lib/aws-sdk-iotsitewise/types.rb', line 8324

class DescribeWorkspaceResponse < Struct.new(
  :workspace_arn,
  :workspace_name,
  :workspace_description,
  :workspace_status,
  :encryption_configuration,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end