Class: Aws::IoTSiteWise::Types::EnrichmentJobConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-iotsitewise/types.rb

Overview

Note:

EnrichmentJobConfiguration is a union - when making an API calls you must set exactly one of the members.

Note:

EnrichmentJobConfiguration is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of EnrichmentJobConfiguration corresponding to the set member.

Configuration for the enrichment job defining which analysis type to perform on video time-series data. Currently supports event detection enrichment. Exactly one member must be specified.

Defined Under Namespace

Classes: EventDetection, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#event_detectionTypes::EventDetection

Event detection configuration that generates embeddings from video time-series data enabling natural language similarity search on events. The service processes video data and creates embeddings stored in IoT SiteWise for semantic querying.

Returns:



8548
8549
8550
8551
8552
8553
8554
8555
8556
8557
# File 'lib/aws-sdk-iotsitewise/types.rb', line 8548

class EnrichmentJobConfiguration < Struct.new(
  :event_detection,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class EventDetection < EnrichmentJobConfiguration; end
  class Unknown < EnrichmentJobConfiguration; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • the current value of unknown



8548
8549
8550
# File 'lib/aws-sdk-iotsitewise/types.rb', line 8548

def unknown
  @unknown
end