Class: Aws::IoTSiteWise::Types::EnrichmentTrimSettings

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotsitewise/types.rb

Overview

<p>Time range settings for extracting a specific window of video time-series data to process.</p> <p>Trim settings define the time bounds for enrichment and must satisfy:</p> <ul> <li>Start and end times must be within the dataset's time bounds</li> <li>Trim settings retrieve fully contained data segments within the specified time range</li> <li>endTime must be greater than startTime</li> <li>Both times should represent valid data ranges in the dataset</li> </ul> <p>Trim settings are required to:</p> <ul> <li>Prevent accidentally analyzing unbounded datasets</li> <li>Ensure predictable processing time and costs</li> <li>Allow focused analysis on specific time periods of interest</li> </ul>

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#end_timeTypes::TimeInNanos

<p>End time for the video analysis time range in nanoseconds since Unix epoch (TimeInNanos format). Data segments at or before this time are included in the enrichment. Must be greater than startTime and within the dataset's time bounds.</p>

Returns:



8636
8637
8638
8639
8640
8641
# File 'lib/aws-sdk-iotsitewise/types.rb', line 8636

class EnrichmentTrimSettings < Struct.new(
  :start_time,
  :end_time)
  SENSITIVE = []
  include Aws::Structure
end

#start_timeTypes::TimeInNanos

<p>Start time for the video analysis time range in nanoseconds since Unix epoch (TimeInNanos format). Data segments at or after this time are included in the enrichment. Must be within the dataset's time bounds.</p> <p>Example (JavaScript): Date.parse('2024-01-01T00:00:00Z') * 1000000 Example (Python): int(datetime.timestamp() * 1e9)</p>

Returns:



8636
8637
8638
8639
8640
8641
# File 'lib/aws-sdk-iotsitewise/types.rb', line 8636

class EnrichmentTrimSettings < Struct.new(
  :start_time,
  :end_time)
  SENSITIVE = []
  include Aws::Structure
end