Class: Aws::IoTSiteWise::Types::ExecuteQueryRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTSiteWise::Types::ExecuteQueryRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotsitewise/types.rb
Constant Summary collapse
- SENSITIVE =
[:query_statement]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique case-sensitive identifier that you can provide to ensure the idempotency of the request.
-
#max_results ⇒ Integer
The maximum number of results to return at one time.
-
#next_token ⇒ String
The string that specifies the next page of results.
-
#query_statement ⇒ String
The IoT SiteWise query statement.
Instance Attribute Details
#client_token ⇒ String
A unique case-sensitive identifier that you can provide to ensure the idempotency of the request. Don't reuse this client token if a new idempotent request is required.
A suitable default value is auto-generated. You should normally not need to pass this option.
8810 8811 8812 8813 8814 8815 8816 8817 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 8810 class ExecuteQueryRequest < Struct.new( :query_statement, :next_token, :max_results, :client_token) SENSITIVE = [:query_statement] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return at one time.
-
Minimum is 1
-
Maximum is 20000
-
Default is 20000
8810 8811 8812 8813 8814 8815 8816 8817 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 8810 class ExecuteQueryRequest < Struct.new( :query_statement, :next_token, :max_results, :client_token) SENSITIVE = [:query_statement] include Aws::Structure end |
#next_token ⇒ String
The string that specifies the next page of results.
8810 8811 8812 8813 8814 8815 8816 8817 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 8810 class ExecuteQueryRequest < Struct.new( :query_statement, :next_token, :max_results, :client_token) SENSITIVE = [:query_statement] include Aws::Structure end |
#query_statement ⇒ String
The IoT SiteWise query statement.
8810 8811 8812 8813 8814 8815 8816 8817 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 8810 class ExecuteQueryRequest < Struct.new( :query_statement, :next_token, :max_results, :client_token) SENSITIVE = [:query_statement] include Aws::Structure end |