Class: Aws::IoTSiteWise::Types::ExportJobSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTSiteWise::Types::ExportJobSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotsitewise/types.rb
Overview
<p>Contains summary information about a dataset export job.</p>
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#completed_at ⇒ Time
<p>The timestamp when the job completed, or null if the job is still running.</p>.
-
#destination_s3_uri ⇒ String
<p>The S3 URI where output clips are written.</p>.
-
#job_id ⇒ String
<p>The unique identifier for the dataset export job.</p>.
-
#started_at ⇒ Time
<p>The timestamp when the job started processing.</p>.
-
#status ⇒ String
<p>The current status of the dataset export job.</p>.
Instance Attribute Details
#completed_at ⇒ Time
<p>The timestamp when the job completed, or null if the job is still running.</p>
8960 8961 8962 8963 8964 8965 8966 8967 8968 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 8960 class ExportJobSummary < Struct.new( :job_id, :status, :started_at, :completed_at, :destination_s3_uri) SENSITIVE = [] include Aws::Structure end |
#destination_s3_uri ⇒ String
<p>The S3 URI where output clips are written.</p>
8960 8961 8962 8963 8964 8965 8966 8967 8968 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 8960 class ExportJobSummary < Struct.new( :job_id, :status, :started_at, :completed_at, :destination_s3_uri) SENSITIVE = [] include Aws::Structure end |
#job_id ⇒ String
<p>The unique identifier for the dataset export job.</p>
8960 8961 8962 8963 8964 8965 8966 8967 8968 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 8960 class ExportJobSummary < Struct.new( :job_id, :status, :started_at, :completed_at, :destination_s3_uri) SENSITIVE = [] include Aws::Structure end |
#started_at ⇒ Time
<p>The timestamp when the job started processing.</p>
8960 8961 8962 8963 8964 8965 8966 8967 8968 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 8960 class ExportJobSummary < Struct.new( :job_id, :status, :started_at, :completed_at, :destination_s3_uri) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
<p>The current status of the dataset export job.</p>
8960 8961 8962 8963 8964 8965 8966 8967 8968 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 8960 class ExportJobSummary < Struct.new( :job_id, :status, :started_at, :completed_at, :destination_s3_uri) SENSITIVE = [] include Aws::Structure end |