Class: Aws::IoTSiteWise::Types::File
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTSiteWise::Types::File
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotsitewise/types.rb
Overview
The file in Amazon S3 where your data is saved.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#alias ⇒ String
The alias associated with the file's time series.
-
#bucket ⇒ String
The name of the Amazon S3 bucket from which data is imported.
-
#file_format ⇒ Types::FileFormat
The file format of the data in S3.
-
#key ⇒ String
The key of the Amazon S3 object that contains your data.
-
#start_time ⇒ Types::TimeInNanos
The nanosecond-precision start time for the file data.
-
#version_id ⇒ String
The version ID to identify a specific version of the Amazon S3 object that contains your data.
Instance Attribute Details
#alias ⇒ String
The alias associated with the file's time series.
9124 9125 9126 9127 9128 9129 9130 9131 9132 9133 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 9124 class File < Struct.new( :bucket, :key, :version_id, :alias, :start_time, :file_format) SENSITIVE = [] include Aws::Structure end |
#bucket ⇒ String
The name of the Amazon S3 bucket from which data is imported.
9124 9125 9126 9127 9128 9129 9130 9131 9132 9133 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 9124 class File < Struct.new( :bucket, :key, :version_id, :alias, :start_time, :file_format) SENSITIVE = [] include Aws::Structure end |
#file_format ⇒ Types::FileFormat
The file format of the data in S3.
9124 9125 9126 9127 9128 9129 9130 9131 9132 9133 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 9124 class File < Struct.new( :bucket, :key, :version_id, :alias, :start_time, :file_format) SENSITIVE = [] include Aws::Structure end |
#key ⇒ String
The key of the Amazon S3 object that contains your data. Each object has a key that is a unique identifier. Each object has exactly one key.
9124 9125 9126 9127 9128 9129 9130 9131 9132 9133 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 9124 class File < Struct.new( :bucket, :key, :version_id, :alias, :start_time, :file_format) SENSITIVE = [] include Aws::Structure end |
#start_time ⇒ Types::TimeInNanos
The nanosecond-precision start time for the file data.
9124 9125 9126 9127 9128 9129 9130 9131 9132 9133 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 9124 class File < Struct.new( :bucket, :key, :version_id, :alias, :start_time, :file_format) SENSITIVE = [] include Aws::Structure end |
#version_id ⇒ String
The version ID to identify a specific version of the Amazon S3 object that contains your data.
9124 9125 9126 9127 9128 9129 9130 9131 9132 9133 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 9124 class File < Struct.new( :bucket, :key, :version_id, :alias, :start_time, :file_format) SENSITIVE = [] include Aws::Structure end |