Class: Aws::IoTSiteWise::Types::GatewayCapabilitySummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotsitewise/types.rb

Overview

Contains a summary of a gateway capability configuration.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#capability_namespaceString

The namespace of the capability configuration. For example, if you configure OPC UA sources for an MQTT-enabled gateway, your OPC-UA capability configuration has the namespace ‘iotsitewise:opcuacollector:3`.

Returns:

  • (String)


6722
6723
6724
6725
6726
6727
# File 'lib/aws-sdk-iotsitewise/types.rb', line 6722

class GatewayCapabilitySummary < Struct.new(
  :capability_namespace,
  :capability_sync_status)
  SENSITIVE = []
  include Aws::Structure
end

#capability_sync_statusString

The synchronization status of the gateway capability configuration. The sync status can be one of the following:

  • ‘IN_SYNC` - The gateway is running with the latest configuration.

  • ‘OUT_OF_SYNC` - The gateway hasn’t received the latest configuration.

  • ‘SYNC_FAILED` - The gateway rejected the latest configuration.

  • ‘UNKNOWN` - The gateway hasn’t reported its sync status.

  • ‘NOT_APPLICABLE` - The gateway doesn’t support this capability. This is most common when integrating partner data sources, because the data integration is handled externally by the partner.

Returns:

  • (String)


6722
6723
6724
6725
6726
6727
# File 'lib/aws-sdk-iotsitewise/types.rb', line 6722

class GatewayCapabilitySummary < Struct.new(
  :capability_namespace,
  :capability_sync_status)
  SENSITIVE = []
  include Aws::Structure
end