Class: Aws::IoTSiteWise::Types::GetAssetPropertyAggregatesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTSiteWise::Types::GetAssetPropertyAggregatesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotsitewise/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aggregate_types ⇒ Array<String>
The data aggregating function.
-
#asset_id ⇒ String
The ID of the asset, in UUID format.
-
#end_date ⇒ Time
The inclusive end of the range from which to query historical data, expressed in seconds in Unix epoch time.
-
#max_results ⇒ Integer
The maximum number of results to return for each paginated request.
-
#next_token ⇒ String
The token to be used for the next set of paginated results.
-
#property_alias ⇒ String
The alias that identifies the property, such as an OPC-UA server data stream path (for example,
/company/windfarm/3/turbine/7/temperature). -
#property_id ⇒ String
The ID of the asset property, in UUID format.
-
#qualities ⇒ Array<String>
The quality by which to filter asset data.
-
#resolution ⇒ String
The time interval over which to aggregate data.
-
#start_date ⇒ Time
The exclusive start of the range from which to query historical data, expressed in seconds in Unix epoch time.
-
#time_ordering ⇒ String
The chronological sorting order of the requested information.
Instance Attribute Details
#aggregate_types ⇒ Array<String>
The data aggregating function.
9391 9392 9393 9394 9395 9396 9397 9398 9399 9400 9401 9402 9403 9404 9405 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 9391 class GetAssetPropertyAggregatesRequest < Struct.new( :asset_id, :property_id, :property_alias, :aggregate_types, :resolution, :qualities, :start_date, :end_date, :time_ordering, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#asset_id ⇒ String
The ID of the asset, in UUID format.
9391 9392 9393 9394 9395 9396 9397 9398 9399 9400 9401 9402 9403 9404 9405 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 9391 class GetAssetPropertyAggregatesRequest < Struct.new( :asset_id, :property_id, :property_alias, :aggregate_types, :resolution, :qualities, :start_date, :end_date, :time_ordering, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#end_date ⇒ Time
The inclusive end of the range from which to query historical data, expressed in seconds in Unix epoch time.
9391 9392 9393 9394 9395 9396 9397 9398 9399 9400 9401 9402 9403 9404 9405 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 9391 class GetAssetPropertyAggregatesRequest < Struct.new( :asset_id, :property_id, :property_alias, :aggregate_types, :resolution, :qualities, :start_date, :end_date, :time_ordering, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return for each paginated request. A result set is returned in the two cases, whichever occurs first.
-
The size of the result set is equal to 1 MB.
-
The number of data points in the result set is equal to the value of
maxResults. The maximum value ofmaxResultsis 2500.
9391 9392 9393 9394 9395 9396 9397 9398 9399 9400 9401 9402 9403 9404 9405 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 9391 class GetAssetPropertyAggregatesRequest < Struct.new( :asset_id, :property_id, :property_alias, :aggregate_types, :resolution, :qualities, :start_date, :end_date, :time_ordering, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token to be used for the next set of paginated results.
9391 9392 9393 9394 9395 9396 9397 9398 9399 9400 9401 9402 9403 9404 9405 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 9391 class GetAssetPropertyAggregatesRequest < Struct.new( :asset_id, :property_id, :property_alias, :aggregate_types, :resolution, :qualities, :start_date, :end_date, :time_ordering, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#property_alias ⇒ String
The alias that identifies the property, such as an OPC-UA server
data stream path (for example,
/company/windfarm/3/turbine/7/temperature). For more information,
see Mapping industrial data streams to asset properties in the
IoT SiteWise User Guide.
9391 9392 9393 9394 9395 9396 9397 9398 9399 9400 9401 9402 9403 9404 9405 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 9391 class GetAssetPropertyAggregatesRequest < Struct.new( :asset_id, :property_id, :property_alias, :aggregate_types, :resolution, :qualities, :start_date, :end_date, :time_ordering, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#property_id ⇒ String
The ID of the asset property, in UUID format.
9391 9392 9393 9394 9395 9396 9397 9398 9399 9400 9401 9402 9403 9404 9405 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 9391 class GetAssetPropertyAggregatesRequest < Struct.new( :asset_id, :property_id, :property_alias, :aggregate_types, :resolution, :qualities, :start_date, :end_date, :time_ordering, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#qualities ⇒ Array<String>
The quality by which to filter asset data.
9391 9392 9393 9394 9395 9396 9397 9398 9399 9400 9401 9402 9403 9404 9405 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 9391 class GetAssetPropertyAggregatesRequest < Struct.new( :asset_id, :property_id, :property_alias, :aggregate_types, :resolution, :qualities, :start_date, :end_date, :time_ordering, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#resolution ⇒ String
The time interval over which to aggregate data.
9391 9392 9393 9394 9395 9396 9397 9398 9399 9400 9401 9402 9403 9404 9405 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 9391 class GetAssetPropertyAggregatesRequest < Struct.new( :asset_id, :property_id, :property_alias, :aggregate_types, :resolution, :qualities, :start_date, :end_date, :time_ordering, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#start_date ⇒ Time
The exclusive start of the range from which to query historical data, expressed in seconds in Unix epoch time.
9391 9392 9393 9394 9395 9396 9397 9398 9399 9400 9401 9402 9403 9404 9405 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 9391 class GetAssetPropertyAggregatesRequest < Struct.new( :asset_id, :property_id, :property_alias, :aggregate_types, :resolution, :qualities, :start_date, :end_date, :time_ordering, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#time_ordering ⇒ String
The chronological sorting order of the requested information.
Default: ASCENDING
9391 9392 9393 9394 9395 9396 9397 9398 9399 9400 9401 9402 9403 9404 9405 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 9391 class GetAssetPropertyAggregatesRequest < Struct.new( :asset_id, :property_id, :property_alias, :aggregate_types, :resolution, :qualities, :start_date, :end_date, :time_ordering, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |