Class: Aws::IoTSiteWise::Types::GetAssetPropertyValueRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTSiteWise::Types::GetAssetPropertyValueRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotsitewise/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#asset_id ⇒ String
The ID of the asset, in UUID format.
-
#property_alias ⇒ String
The alias that identifies the property, such as an OPC-UA server data stream path (for example,
/company/windfarm/3/turbine/7/temperature). -
#property_id ⇒ String
The ID of the asset property, in UUID format.
Instance Attribute Details
#asset_id ⇒ String
The ID of the asset, in UUID format.
9527 9528 9529 9530 9531 9532 9533 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 9527 class GetAssetPropertyValueRequest < Struct.new( :asset_id, :property_id, :property_alias) SENSITIVE = [] include Aws::Structure end |
#property_alias ⇒ String
The alias that identifies the property, such as an OPC-UA server
data stream path (for example,
/company/windfarm/3/turbine/7/temperature). For more information,
see Mapping industrial data streams to asset properties in the
IoT SiteWise User Guide.
9527 9528 9529 9530 9531 9532 9533 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 9527 class GetAssetPropertyValueRequest < Struct.new( :asset_id, :property_id, :property_alias) SENSITIVE = [] include Aws::Structure end |
#property_id ⇒ String
The ID of the asset property, in UUID format.
9527 9528 9529 9530 9531 9532 9533 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 9527 class GetAssetPropertyValueRequest < Struct.new( :asset_id, :property_id, :property_alias) SENSITIVE = [] include Aws::Structure end |