Class: Aws::IoTSiteWise::Types::GetCaptureDataRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotsitewise/types.rb

Overview

Request to retrieve video data for a specific time range. Exactly one of timeSeriesId or propertyAlias must be provided.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#end_timeTypes::TimeInNanos

The end time for the video data range. Must be greater than startTime.

Returns:



9579
9580
9581
9582
9583
9584
9585
9586
9587
9588
9589
# File 'lib/aws-sdk-iotsitewise/types.rb', line 9579

class GetCaptureDataRequest < Struct.new(
  :workspace_name,
  :start_time,
  :end_time,
  :time_series_id,
  :property_alias,
  :format_settings,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#format_settingsTypes::FormatSettings

The optional format settings for the output.



9579
9580
9581
9582
9583
9584
9585
9586
9587
9588
9589
# File 'lib/aws-sdk-iotsitewise/types.rb', line 9579

class GetCaptureDataRequest < Struct.new(
  :workspace_name,
  :start_time,
  :end_time,
  :time_series_id,
  :property_alias,
  :format_settings,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token from a previous response used to continue retrieving data.

Returns:

  • (String)


9579
9580
9581
9582
9583
9584
9585
9586
9587
9588
9589
# File 'lib/aws-sdk-iotsitewise/types.rb', line 9579

class GetCaptureDataRequest < Struct.new(
  :workspace_name,
  :start_time,
  :end_time,
  :time_series_id,
  :property_alias,
  :format_settings,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#property_aliasString

The property alias that identifies the capture source. Mutually exclusive with timeSeriesId.

Returns:

  • (String)


9579
9580
9581
9582
9583
9584
9585
9586
9587
9588
9589
# File 'lib/aws-sdk-iotsitewise/types.rb', line 9579

class GetCaptureDataRequest < Struct.new(
  :workspace_name,
  :start_time,
  :end_time,
  :time_series_id,
  :property_alias,
  :format_settings,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#start_timeTypes::TimeInNanos

The start time for the video data range.

Returns:



9579
9580
9581
9582
9583
9584
9585
9586
9587
9588
9589
# File 'lib/aws-sdk-iotsitewise/types.rb', line 9579

class GetCaptureDataRequest < Struct.new(
  :workspace_name,
  :start_time,
  :end_time,
  :time_series_id,
  :property_alias,
  :format_settings,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#time_series_idString

The time series ID that identifies the capture source. Mutually exclusive with propertyAlias.

Returns:

  • (String)


9579
9580
9581
9582
9583
9584
9585
9586
9587
9588
9589
# File 'lib/aws-sdk-iotsitewise/types.rb', line 9579

class GetCaptureDataRequest < Struct.new(
  :workspace_name,
  :start_time,
  :end_time,
  :time_series_id,
  :property_alias,
  :format_settings,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#workspace_nameString

The name of the workspace that contains the capture source.

Returns:

  • (String)


9579
9580
9581
9582
9583
9584
9585
9586
9587
9588
9589
# File 'lib/aws-sdk-iotsitewise/types.rb', line 9579

class GetCaptureDataRequest < Struct.new(
  :workspace_name,
  :start_time,
  :end_time,
  :time_series_id,
  :property_alias,
  :format_settings,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end