Class: Aws::IoTSiteWise::Types::GetInterpolatedAssetPropertyValuesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotsitewise/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#asset_idString

The ID of the asset, in UUID format.

Returns:

  • (String)


9744
9745
9746
9747
9748
9749
9750
9751
9752
9753
9754
9755
9756
9757
9758
9759
9760
# File 'lib/aws-sdk-iotsitewise/types.rb', line 9744

class GetInterpolatedAssetPropertyValuesRequest < Struct.new(
  :asset_id,
  :property_id,
  :property_alias,
  :start_time_in_seconds,
  :start_time_offset_in_nanos,
  :end_time_in_seconds,
  :end_time_offset_in_nanos,
  :quality,
  :interval_in_seconds,
  :next_token,
  :max_results,
  :type,
  :interval_window_in_seconds)
  SENSITIVE = []
  include Aws::Structure
end

#end_time_in_secondsInteger

The inclusive end of the range from which to interpolate data, expressed in seconds in Unix epoch time.

Returns:

  • (Integer)


9744
9745
9746
9747
9748
9749
9750
9751
9752
9753
9754
9755
9756
9757
9758
9759
9760
# File 'lib/aws-sdk-iotsitewise/types.rb', line 9744

class GetInterpolatedAssetPropertyValuesRequest < Struct.new(
  :asset_id,
  :property_id,
  :property_alias,
  :start_time_in_seconds,
  :start_time_offset_in_nanos,
  :end_time_in_seconds,
  :end_time_offset_in_nanos,
  :quality,
  :interval_in_seconds,
  :next_token,
  :max_results,
  :type,
  :interval_window_in_seconds)
  SENSITIVE = []
  include Aws::Structure
end

#end_time_offset_in_nanosInteger

The nanosecond offset converted from endTimeInSeconds.

Returns:

  • (Integer)


9744
9745
9746
9747
9748
9749
9750
9751
9752
9753
9754
9755
9756
9757
9758
9759
9760
# File 'lib/aws-sdk-iotsitewise/types.rb', line 9744

class GetInterpolatedAssetPropertyValuesRequest < Struct.new(
  :asset_id,
  :property_id,
  :property_alias,
  :start_time_in_seconds,
  :start_time_offset_in_nanos,
  :end_time_in_seconds,
  :end_time_offset_in_nanos,
  :quality,
  :interval_in_seconds,
  :next_token,
  :max_results,
  :type,
  :interval_window_in_seconds)
  SENSITIVE = []
  include Aws::Structure
end

#interval_in_secondsInteger

The time interval in seconds over which to interpolate data. Each interval starts when the previous one ends.

Returns:

  • (Integer)


9744
9745
9746
9747
9748
9749
9750
9751
9752
9753
9754
9755
9756
9757
9758
9759
9760
# File 'lib/aws-sdk-iotsitewise/types.rb', line 9744

class GetInterpolatedAssetPropertyValuesRequest < Struct.new(
  :asset_id,
  :property_id,
  :property_alias,
  :start_time_in_seconds,
  :start_time_offset_in_nanos,
  :end_time_in_seconds,
  :end_time_offset_in_nanos,
  :quality,
  :interval_in_seconds,
  :next_token,
  :max_results,
  :type,
  :interval_window_in_seconds)
  SENSITIVE = []
  include Aws::Structure
end

#interval_window_in_secondsInteger

The query interval for the window, in seconds. IoT SiteWise computes each interpolated value by using data points from the timestamp of each interval, minus the window to the timestamp of each interval plus the window. If not specified, the window ranges between the start time minus the interval and the end time plus the interval.

* If you specify a value for the intervalWindowInSeconds parameter, the value for the type parameter must be LINEAR_INTERPOLATION.

  • If a data point isn't found during the specified query window, IoT SiteWise won't return an interpolated value for the interval. This indicates that there's a gap in the ingested data points.

For example, you can get the interpolated temperature values for a wind turbine every 24 hours over a duration of 7 days. If the interpolation starts on July 1, 2021, at 9 AM with a window of 2 hours, IoT SiteWise uses the data points from 7 AM (9 AM minus 2 hours) to 11 AM (9 AM plus 2 hours) on July 2, 2021 to compute the first interpolated value. Next, IoT SiteWise uses the data points from 7 AM (9 AM minus 2 hours) to 11 AM (9 AM plus 2 hours) on July 3, 2021 to compute the second interpolated value, and so on.

Returns:

  • (Integer)


9744
9745
9746
9747
9748
9749
9750
9751
9752
9753
9754
9755
9756
9757
9758
9759
9760
# File 'lib/aws-sdk-iotsitewise/types.rb', line 9744

class GetInterpolatedAssetPropertyValuesRequest < Struct.new(
  :asset_id,
  :property_id,
  :property_alias,
  :start_time_in_seconds,
  :start_time_offset_in_nanos,
  :end_time_in_seconds,
  :end_time_offset_in_nanos,
  :quality,
  :interval_in_seconds,
  :next_token,
  :max_results,
  :type,
  :interval_window_in_seconds)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return for each paginated request. If not specified, the default value is 10.

Returns:

  • (Integer)


9744
9745
9746
9747
9748
9749
9750
9751
9752
9753
9754
9755
9756
9757
9758
9759
9760
# File 'lib/aws-sdk-iotsitewise/types.rb', line 9744

class GetInterpolatedAssetPropertyValuesRequest < Struct.new(
  :asset_id,
  :property_id,
  :property_alias,
  :start_time_in_seconds,
  :start_time_offset_in_nanos,
  :end_time_in_seconds,
  :end_time_offset_in_nanos,
  :quality,
  :interval_in_seconds,
  :next_token,
  :max_results,
  :type,
  :interval_window_in_seconds)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token to be used for the next set of paginated results.

Returns:

  • (String)


9744
9745
9746
9747
9748
9749
9750
9751
9752
9753
9754
9755
9756
9757
9758
9759
9760
# File 'lib/aws-sdk-iotsitewise/types.rb', line 9744

class GetInterpolatedAssetPropertyValuesRequest < Struct.new(
  :asset_id,
  :property_id,
  :property_alias,
  :start_time_in_seconds,
  :start_time_offset_in_nanos,
  :end_time_in_seconds,
  :end_time_offset_in_nanos,
  :quality,
  :interval_in_seconds,
  :next_token,
  :max_results,
  :type,
  :interval_window_in_seconds)
  SENSITIVE = []
  include Aws::Structure
end

#property_aliasString

The alias that identifies the property, such as an OPC-UA server data stream path (for example, /company/windfarm/3/turbine/7/temperature). For more information, see Mapping industrial data streams to asset properties in the IoT SiteWise User Guide.

Returns:

  • (String)


9744
9745
9746
9747
9748
9749
9750
9751
9752
9753
9754
9755
9756
9757
9758
9759
9760
# File 'lib/aws-sdk-iotsitewise/types.rb', line 9744

class GetInterpolatedAssetPropertyValuesRequest < Struct.new(
  :asset_id,
  :property_id,
  :property_alias,
  :start_time_in_seconds,
  :start_time_offset_in_nanos,
  :end_time_in_seconds,
  :end_time_offset_in_nanos,
  :quality,
  :interval_in_seconds,
  :next_token,
  :max_results,
  :type,
  :interval_window_in_seconds)
  SENSITIVE = []
  include Aws::Structure
end

#property_idString

The ID of the asset property, in UUID format.

Returns:

  • (String)


9744
9745
9746
9747
9748
9749
9750
9751
9752
9753
9754
9755
9756
9757
9758
9759
9760
# File 'lib/aws-sdk-iotsitewise/types.rb', line 9744

class GetInterpolatedAssetPropertyValuesRequest < Struct.new(
  :asset_id,
  :property_id,
  :property_alias,
  :start_time_in_seconds,
  :start_time_offset_in_nanos,
  :end_time_in_seconds,
  :end_time_offset_in_nanos,
  :quality,
  :interval_in_seconds,
  :next_token,
  :max_results,
  :type,
  :interval_window_in_seconds)
  SENSITIVE = []
  include Aws::Structure
end

#qualityString

The quality of the asset property value. You can use this parameter as a filter to choose only the asset property values that have a specific quality.

Returns:

  • (String)


9744
9745
9746
9747
9748
9749
9750
9751
9752
9753
9754
9755
9756
9757
9758
9759
9760
# File 'lib/aws-sdk-iotsitewise/types.rb', line 9744

class GetInterpolatedAssetPropertyValuesRequest < Struct.new(
  :asset_id,
  :property_id,
  :property_alias,
  :start_time_in_seconds,
  :start_time_offset_in_nanos,
  :end_time_in_seconds,
  :end_time_offset_in_nanos,
  :quality,
  :interval_in_seconds,
  :next_token,
  :max_results,
  :type,
  :interval_window_in_seconds)
  SENSITIVE = []
  include Aws::Structure
end

#start_time_in_secondsInteger

The exclusive start of the range from which to interpolate data, expressed in seconds in Unix epoch time.

Returns:

  • (Integer)


9744
9745
9746
9747
9748
9749
9750
9751
9752
9753
9754
9755
9756
9757
9758
9759
9760
# File 'lib/aws-sdk-iotsitewise/types.rb', line 9744

class GetInterpolatedAssetPropertyValuesRequest < Struct.new(
  :asset_id,
  :property_id,
  :property_alias,
  :start_time_in_seconds,
  :start_time_offset_in_nanos,
  :end_time_in_seconds,
  :end_time_offset_in_nanos,
  :quality,
  :interval_in_seconds,
  :next_token,
  :max_results,
  :type,
  :interval_window_in_seconds)
  SENSITIVE = []
  include Aws::Structure
end

#start_time_offset_in_nanosInteger

The nanosecond offset converted from startTimeInSeconds.

Returns:

  • (Integer)


9744
9745
9746
9747
9748
9749
9750
9751
9752
9753
9754
9755
9756
9757
9758
9759
9760
# File 'lib/aws-sdk-iotsitewise/types.rb', line 9744

class GetInterpolatedAssetPropertyValuesRequest < Struct.new(
  :asset_id,
  :property_id,
  :property_alias,
  :start_time_in_seconds,
  :start_time_offset_in_nanos,
  :end_time_in_seconds,
  :end_time_offset_in_nanos,
  :quality,
  :interval_in_seconds,
  :next_token,
  :max_results,
  :type,
  :interval_window_in_seconds)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The interpolation type.

Valid values: LINEAR_INTERPOLATION | LOCF_INTERPOLATION

  • LINEAR_INTERPOLATION – Estimates missing data using linear interpolation.

    For example, you can use this operation to return the interpolated temperature values for a wind turbine every 24 hours over a duration of 7 days. If the interpolation starts July 1, 2021, at 9 AM, IoT SiteWise returns the first interpolated value on July 2, 2021, at 9 AM, the second interpolated value on July 3, 2021, at 9 AM, and so on.

  • LOCF_INTERPOLATION – Estimates missing data using last observation carried forward interpolation

    If no data point is found for an interval, IoT SiteWise returns the last observed data point for the previous interval and carries forward this interpolated value until a new data point is found.

    For example, you can get the state of an on-off valve every 24 hours over a duration of 7 days. If the interpolation starts July 1, 2021, at 9 AM, IoT SiteWise returns the last observed data point between July 1, 2021, at 9 AM and July 2, 2021, at 9 AM as the first interpolated value. If a data point isn't found after 9 AM on July 2, 2021, IoT SiteWise uses the same interpolated value for the rest of the days.

Returns:

  • (String)


9744
9745
9746
9747
9748
9749
9750
9751
9752
9753
9754
9755
9756
9757
9758
9759
9760
# File 'lib/aws-sdk-iotsitewise/types.rb', line 9744

class GetInterpolatedAssetPropertyValuesRequest < Struct.new(
  :asset_id,
  :property_id,
  :property_alias,
  :start_time_in_seconds,
  :start_time_offset_in_nanos,
  :end_time_in_seconds,
  :end_time_offset_in_nanos,
  :quality,
  :interval_in_seconds,
  :next_token,
  :max_results,
  :type,
  :interval_window_in_seconds)
  SENSITIVE = []
  include Aws::Structure
end