Class: Aws::IoTSiteWise::Types::GetQueryResultsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotsitewise/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#max_resultsInteger

The maximum number of results to return for each paginated request.

Returns:

  • (Integer)


9794
9795
9796
9797
9798
9799
9800
9801
# File 'lib/aws-sdk-iotsitewise/types.rb', line 9794

class GetQueryResultsRequest < Struct.new(
  :workspace_name,
  :query_id,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token to be used for the next set of paginated results.

Returns:

  • (String)


9794
9795
9796
9797
9798
9799
9800
9801
# File 'lib/aws-sdk-iotsitewise/types.rb', line 9794

class GetQueryResultsRequest < Struct.new(
  :workspace_name,
  :query_id,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#query_idString

The unique identifier for the query execution.

Returns:

  • (String)


9794
9795
9796
9797
9798
9799
9800
9801
# File 'lib/aws-sdk-iotsitewise/types.rb', line 9794

class GetQueryResultsRequest < Struct.new(
  :workspace_name,
  :query_id,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#workspace_nameString

The name of the workspace associated with the query.

Returns:

  • (String)


9794
9795
9796
9797
9798
9799
9800
9801
# File 'lib/aws-sdk-iotsitewise/types.rb', line 9794

class GetQueryResultsRequest < Struct.new(
  :workspace_name,
  :query_id,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end