Class: Aws::IoTSiteWise::Types::IAMUserIdentity

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotsitewise/types.rb

Overview

Contains information about an Identity and Access Management user.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The ARN of the IAM user. For more information, see IAM ARNs in the IAM User Guide.

If you delete the IAM user, access policies that contain this identity include an empty arn. You can delete the access policy for the IAM user that no longer exists.

Returns:

  • (String)


10007
10008
10009
10010
10011
# File 'lib/aws-sdk-iotsitewise/types.rb', line 10007

class IAMUserIdentity < Struct.new(
  :arn)
  SENSITIVE = []
  include Aws::Structure
end