Class: Aws::IoTSiteWise::Types::InterfaceSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotsitewise/types.rb

Overview

Contains summary information about an interface that a property belongs to.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#interface_asset_model_idString

The ID of the interface asset model that contains this property.

Returns:

  • (String)


10151
10152
10153
10154
10155
10156
# File 'lib/aws-sdk-iotsitewise/types.rb', line 10151

class InterfaceSummary < Struct.new(
  :interface_asset_model_id,
  :interface_asset_model_property_id)
  SENSITIVE = []
  include Aws::Structure
end

#interface_asset_model_property_idString

The ID of the property in the interface asset model that corresponds to this property.

Returns:

  • (String)


10151
10152
10153
10154
10155
10156
# File 'lib/aws-sdk-iotsitewise/types.rb', line 10151

class InterfaceSummary < Struct.new(
  :interface_asset_model_id,
  :interface_asset_model_property_id)
  SENSITIVE = []
  include Aws::Structure
end