Class: Aws::IoTSiteWise::Types::InvokeAssistantRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotsitewise/types.rb

Constant Summary collapse

SENSITIVE =
[:message]

Instance Attribute Summary collapse

Instance Attribute Details

#conversation_idString

The ID assigned to a conversation. IoT SiteWise automatically generates a unique ID for you, and this parameter is never required. However, if you prefer to have your own ID, you must specify it here in UUID format. If you specify your own ID, it must be globally unique.

Returns:

  • (String)


10238
10239
10240
10241
10242
10243
10244
# File 'lib/aws-sdk-iotsitewise/types.rb', line 10238

class InvokeAssistantRequest < Struct.new(
  :conversation_id,
  :message,
  :enable_trace)
  SENSITIVE = [:message]
  include Aws::Structure
end

#enable_traceBoolean

Specifies if to turn trace on or not. It is used to track the SiteWise Assistant's reasoning, and data access process.

Returns:

  • (Boolean)


10238
10239
10240
10241
10242
10243
10244
# File 'lib/aws-sdk-iotsitewise/types.rb', line 10238

class InvokeAssistantRequest < Struct.new(
  :conversation_id,
  :message,
  :enable_trace)
  SENSITIVE = [:message]
  include Aws::Structure
end

#messageString

A text message sent to the SiteWise Assistant by the user.

Returns:

  • (String)


10238
10239
10240
10241
10242
10243
10244
# File 'lib/aws-sdk-iotsitewise/types.rb', line 10238

class InvokeAssistantRequest < Struct.new(
  :conversation_id,
  :message,
  :enable_trace)
  SENSITIVE = [:message]
  include Aws::Structure
end