Class: Aws::IoTSiteWise::Types::JobSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotsitewise/types.rb

Overview

Contains the job summary information.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#idString

The ID of the job.

Returns:

  • (String)


10310
10311
10312
10313
10314
10315
10316
# File 'lib/aws-sdk-iotsitewise/types.rb', line 10310

class JobSummary < Struct.new(
  :id,
  :name,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The unique name that helps identify the job request.

Returns:

  • (String)


10310
10311
10312
10313
10314
10315
10316
# File 'lib/aws-sdk-iotsitewise/types.rb', line 10310

class JobSummary < Struct.new(
  :id,
  :name,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the bulk import job can be one of following values:

  • PENDING – IoT SiteWise is waiting for the current bulk import job to finish.

  • CANCELLED – The bulk import job has been canceled.

  • RUNNING – IoT SiteWise is processing your request to import your data from Amazon S3.

  • COMPLETED – IoT SiteWise successfully completed your request to import data from Amazon S3.

  • FAILED – IoT SiteWise couldn't process your request to import data from Amazon S3. You can use logs saved in the specified error report location in Amazon S3 to troubleshoot issues.

  • COMPLETED_WITH_FAILURES – IoT SiteWise completed your request to import data from Amazon S3 with errors. You can use logs saved in the specified error report location in Amazon S3 to troubleshoot issues.

Returns:

  • (String)


10310
10311
10312
10313
10314
10315
10316
# File 'lib/aws-sdk-iotsitewise/types.rb', line 10310

class JobSummary < Struct.new(
  :id,
  :name,
  :status)
  SENSITIVE = []
  include Aws::Structure
end