Class: Aws::IoTSiteWise::Types::LimitExceededException
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTSiteWise::Types::LimitExceededException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotsitewise/types.rb
Overview
You've reached the quota for a resource. For example, this can occur if you're trying to associate more than the allowed number of child assets or attempting to create more than the allowed number of properties for an asset model.
For more information, see Quotas in the IoT SiteWise User Guide.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#event_type ⇒ Object
Returns the value of attribute event_type.
- #message ⇒ String
Instance Attribute Details
#event_type ⇒ Object
Returns the value of attribute event_type
10350 10351 10352 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 10350 def event_type @event_type end |
#message ⇒ String
10350 10351 10352 10353 10354 10355 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 10350 class LimitExceededException < Struct.new( :message, :event_type) SENSITIVE = [] include Aws::Structure end |