Class: Aws::IoTSiteWise::Types::ListCompositionRelationshipsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotsitewise/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#asset_model_idString

The ID of the asset model. This can be either the actual ID in UUID format, or else externalId: followed by the external ID, if it has one. For more information, see Referencing objects with external IDs in the IoT SiteWise User Guide.

Returns:

  • (String)


11060
11061
11062
11063
11064
11065
11066
# File 'lib/aws-sdk-iotsitewise/types.rb', line 11060

class ListCompositionRelationshipsRequest < Struct.new(
  :asset_model_id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return for each paginated request.

Default: 50

Returns:

  • (Integer)


11060
11061
11062
11063
11064
11065
11066
# File 'lib/aws-sdk-iotsitewise/types.rb', line 11060

class ListCompositionRelationshipsRequest < Struct.new(
  :asset_model_id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token to be used for the next set of paginated results.

Returns:

  • (String)


11060
11061
11062
11063
11064
11065
11066
# File 'lib/aws-sdk-iotsitewise/types.rb', line 11060

class ListCompositionRelationshipsRequest < Struct.new(
  :asset_model_id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end