Class: Aws::IoTSiteWise::Types::ListComputationModelDataBindingUsagesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotsitewise/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#data_binding_value_filterTypes::DataBindingValueFilter

A filter used to limit the returned data binding usages based on specific data binding values. You can filter by asset, asset model, asset property, or asset model property to find all computation models using these specific data sources.



11099
11100
11101
11102
11103
11104
11105
# File 'lib/aws-sdk-iotsitewise/types.rb', line 11099

class ListComputationModelDataBindingUsagesRequest < Struct.new(
  :data_binding_value_filter,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results returned for each paginated request.

Returns:

  • (Integer)


11099
11100
11101
11102
11103
11104
11105
# File 'lib/aws-sdk-iotsitewise/types.rb', line 11099

class ListComputationModelDataBindingUsagesRequest < Struct.new(
  :data_binding_value_filter,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token used for the next set of paginated results.

Returns:

  • (String)


11099
11100
11101
11102
11103
11104
11105
# File 'lib/aws-sdk-iotsitewise/types.rb', line 11099

class ListComputationModelDataBindingUsagesRequest < Struct.new(
  :data_binding_value_filter,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end