Class: Aws::IoTSiteWise::Types::ListComputationModelResolveToResourcesResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotsitewise/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#computation_model_resolve_to_resource_summariesArray<Types::ComputationModelResolveToResourceSummary>

A list of summaries describing the distinct resources that this computation model resolves to when actions were executed.



11156
11157
11158
11159
11160
11161
# File 'lib/aws-sdk-iotsitewise/types.rb', line 11156

class ListComputationModelResolveToResourcesResponse < Struct.new(
  :computation_model_resolve_to_resource_summaries,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next set of paginated results, or null if there are no additional results.

Returns:

  • (String)


11156
11157
11158
11159
11160
11161
# File 'lib/aws-sdk-iotsitewise/types.rb', line 11156

class ListComputationModelResolveToResourcesResponse < Struct.new(
  :computation_model_resolve_to_resource_summaries,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end