Class: Aws::IoTSiteWise::Types::ListComputationModelsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotsitewise/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#computation_model_typeString

The type of computation model. If a computationModelType is not provided, all types of computation models are returned.

Returns:

  • (String)


11176
11177
11178
11179
11180
11181
11182
# File 'lib/aws-sdk-iotsitewise/types.rb', line 11176

class ListComputationModelsRequest < Struct.new(
  :computation_model_type,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return for each paginated request.

Returns:

  • (Integer)


11176
11177
11178
11179
11180
11181
11182
# File 'lib/aws-sdk-iotsitewise/types.rb', line 11176

class ListComputationModelsRequest < Struct.new(
  :computation_model_type,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token to be used for the next set of paginated results.

Returns:

  • (String)


11176
11177
11178
11179
11180
11181
11182
# File 'lib/aws-sdk-iotsitewise/types.rb', line 11176

class ListComputationModelsRequest < Struct.new(
  :computation_model_type,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end