Class: Aws::IoTSiteWise::Types::ListComputationModelsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTSiteWise::Types::ListComputationModelsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotsitewise/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#computation_model_summaries ⇒ Array<Types::ComputationModelSummary>
A list summarizing each computation model.
-
#next_token ⇒ String
The token for the next set of results, or null if there are no additional results.
Instance Attribute Details
#computation_model_summaries ⇒ Array<Types::ComputationModelSummary>
A list summarizing each computation model.
11193 11194 11195 11196 11197 11198 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 11193 class ListComputationModelsResponse < Struct.new( :computation_model_summaries, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results, or null if there are no additional results.
11193 11194 11195 11196 11197 11198 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 11193 class ListComputationModelsResponse < Struct.new( :computation_model_summaries, :next_token) SENSITIVE = [] include Aws::Structure end |