Class: Aws::IoTSiteWise::Types::ListDatasetDataSegmentRelationshipsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotsitewise/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dataset_idString

The ID of the session dataset to list data segment relationships for.

Returns:

  • (String)


11256
11257
11258
11259
11260
11261
11262
11263
# File 'lib/aws-sdk-iotsitewise/types.rb', line 11256

class ListDatasetDataSegmentRelationshipsRequest < Struct.new(
  :dataset_id,
  :workspace_name,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return for each paginated request. Default: 50.

Returns:

  • (Integer)


11256
11257
11258
11259
11260
11261
11262
11263
# File 'lib/aws-sdk-iotsitewise/types.rb', line 11256

class ListDatasetDataSegmentRelationshipsRequest < Struct.new(
  :dataset_id,
  :workspace_name,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token to be used for the next set of paginated results.

Returns:

  • (String)


11256
11257
11258
11259
11260
11261
11262
11263
# File 'lib/aws-sdk-iotsitewise/types.rb', line 11256

class ListDatasetDataSegmentRelationshipsRequest < Struct.new(
  :dataset_id,
  :workspace_name,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#workspace_nameString

The name of the workspace that contains the dataset.

Returns:

  • (String)


11256
11257
11258
11259
11260
11261
11262
11263
# File 'lib/aws-sdk-iotsitewise/types.rb', line 11256

class ListDatasetDataSegmentRelationshipsRequest < Struct.new(
  :dataset_id,
  :workspace_name,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end