Class: Aws::IoTSiteWise::Types::ListDatasetDataSegmentsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotsitewise/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dataset_idString

The ID of the dataset.

Returns:

  • (String)


11302
11303
11304
11305
11306
11307
11308
11309
11310
# File 'lib/aws-sdk-iotsitewise/types.rb', line 11302

class ListDatasetDataSegmentsRequest < Struct.new(
  :dataset_id,
  :workspace_name,
  :dataset_version,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#dataset_versionString

The version of the dataset to list data segments for.

Returns:

  • (String)


11302
11303
11304
11305
11306
11307
11308
11309
11310
# File 'lib/aws-sdk-iotsitewise/types.rb', line 11302

class ListDatasetDataSegmentsRequest < Struct.new(
  :dataset_id,
  :workspace_name,
  :dataset_version,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return for each paginated request. Default: 50.

Returns:

  • (Integer)


11302
11303
11304
11305
11306
11307
11308
11309
11310
# File 'lib/aws-sdk-iotsitewise/types.rb', line 11302

class ListDatasetDataSegmentsRequest < Struct.new(
  :dataset_id,
  :workspace_name,
  :dataset_version,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token to be used for the next set of paginated results.

Returns:

  • (String)


11302
11303
11304
11305
11306
11307
11308
11309
11310
# File 'lib/aws-sdk-iotsitewise/types.rb', line 11302

class ListDatasetDataSegmentsRequest < Struct.new(
  :dataset_id,
  :workspace_name,
  :dataset_version,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#workspace_nameString

The name of the workspace that contains the dataset.

Returns:

  • (String)


11302
11303
11304
11305
11306
11307
11308
11309
11310
# File 'lib/aws-sdk-iotsitewise/types.rb', line 11302

class ListDatasetDataSegmentsRequest < Struct.new(
  :dataset_id,
  :workspace_name,
  :dataset_version,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end