Class: Aws::IoTSiteWise::Types::ListDatasetDataSegmentsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTSiteWise::Types::ListDatasetDataSegmentsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotsitewise/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#data_segments ⇒ Array<Types::DataSegmentSummary>
A list that summarizes each data segment.
-
#next_token ⇒ String
The token for the next set of results, or null if there are no additional results.
Instance Attribute Details
#data_segments ⇒ Array<Types::DataSegmentSummary>
A list that summarizes each data segment.
11321 11322 11323 11324 11325 11326 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 11321 class ListDatasetDataSegmentsResponse < Struct.new( :data_segments, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results, or null if there are no additional results.
11321 11322 11323 11324 11325 11326 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 11321 class ListDatasetDataSegmentsResponse < Struct.new( :data_segments, :next_token) SENSITIVE = [] include Aws::Structure end |