Class: Aws::IoTSiteWise::Types::ListDatasetsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotsitewise/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dataset_typeString

The type of dataset to filter by: a session dataset, a curated dataset, or a connection to an external datasource.

Returns:

  • (String)


11397
11398
11399
11400
11401
11402
11403
11404
11405
# File 'lib/aws-sdk-iotsitewise/types.rb', line 11397

class ListDatasetsRequest < Struct.new(
  :source_type,
  :workspace_name,
  :dataset_type,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return for each paginated request.

Returns:

  • (Integer)


11397
11398
11399
11400
11401
11402
11403
11404
11405
# File 'lib/aws-sdk-iotsitewise/types.rb', line 11397

class ListDatasetsRequest < Struct.new(
  :source_type,
  :workspace_name,
  :dataset_type,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next set of results, or null if there are no additional results.

Returns:

  • (String)


11397
11398
11399
11400
11401
11402
11403
11404
11405
# File 'lib/aws-sdk-iotsitewise/types.rb', line 11397

class ListDatasetsRequest < Struct.new(
  :source_type,
  :workspace_name,
  :dataset_type,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#source_typeString

The type of data source for the dataset.

Returns:

  • (String)


11397
11398
11399
11400
11401
11402
11403
11404
11405
# File 'lib/aws-sdk-iotsitewise/types.rb', line 11397

class ListDatasetsRequest < Struct.new(
  :source_type,
  :workspace_name,
  :dataset_type,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#workspace_nameString

The name of the workspace to filter datasets by.

Returns:

  • (String)


11397
11398
11399
11400
11401
11402
11403
11404
11405
# File 'lib/aws-sdk-iotsitewise/types.rb', line 11397

class ListDatasetsRequest < Struct.new(
  :source_type,
  :workspace_name,
  :dataset_type,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end