Class: Aws::IoTSiteWise::Types::ListDatasetsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTSiteWise::Types::ListDatasetsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotsitewise/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dataset_summaries ⇒ Array<Types::DatasetSummary>
A list that summarizes the dataset response.
-
#next_token ⇒ String
The token for the next set of results, or null if there are no additional results.
-
#workspace_name ⇒ String
The name of the workspace.
Instance Attribute Details
#dataset_summaries ⇒ Array<Types::DatasetSummary>
A list that summarizes the dataset response.
11420 11421 11422 11423 11424 11425 11426 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 11420 class ListDatasetsResponse < Struct.new( :dataset_summaries, :next_token, :workspace_name) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results, or null if there are no additional results.
11420 11421 11422 11423 11424 11425 11426 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 11420 class ListDatasetsResponse < Struct.new( :dataset_summaries, :next_token, :workspace_name) SENSITIVE = [] include Aws::Structure end |
#workspace_name ⇒ String
The name of the workspace.
11420 11421 11422 11423 11424 11425 11426 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 11420 class ListDatasetsResponse < Struct.new( :dataset_summaries, :next_token, :workspace_name) SENSITIVE = [] include Aws::Structure end |