Class: Aws::IoTSiteWise::Types::ListPipelineExecutionsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotsitewise/types.rb

Overview

Request structure for ListPipelineExecutions operation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#end_time_afterTime

Inclusive lower bound on execution end time (ISO-8601). Only executions with endTime >= endTimeAfter are returned. Cannot be combined with startTimeAfter or startTimeBefore. Only matches executions in terminal states.

Returns:

  • (Time)


11699
11700
11701
11702
11703
11704
11705
11706
11707
11708
11709
11710
11711
# File 'lib/aws-sdk-iotsitewise/types.rb', line 11699

class ListPipelineExecutionsRequest < Struct.new(
  :workspace_name,
  :pipeline_name,
  :next_token,
  :max_results,
  :state,
  :start_time_after,
  :start_time_before,
  :end_time_after,
  :end_time_before)
  SENSITIVE = []
  include Aws::Structure
end

#end_time_beforeTime

Exclusive upper bound on execution end time (ISO-8601). Only executions with endTime < endTimeBefore are returned. Cannot be combined with startTimeAfter or startTimeBefore. Only matches executions in terminal states.

Returns:

  • (Time)


11699
11700
11701
11702
11703
11704
11705
11706
11707
11708
11709
11710
11711
# File 'lib/aws-sdk-iotsitewise/types.rb', line 11699

class ListPipelineExecutionsRequest < Struct.new(
  :workspace_name,
  :pipeline_name,
  :next_token,
  :max_results,
  :state,
  :start_time_after,
  :start_time_before,
  :end_time_after,
  :end_time_before)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return per request. This is an upper bound; the actual number of results may be less. Default: 50.

Returns:

  • (Integer)


11699
11700
11701
11702
11703
11704
11705
11706
11707
11708
11709
11710
11711
# File 'lib/aws-sdk-iotsitewise/types.rb', line 11699

class ListPipelineExecutionsRequest < Struct.new(
  :workspace_name,
  :pipeline_name,
  :next_token,
  :max_results,
  :state,
  :start_time_after,
  :start_time_before,
  :end_time_after,
  :end_time_before)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token to be used for the next set of paginated results.

Returns:

  • (String)


11699
11700
11701
11702
11703
11704
11705
11706
11707
11708
11709
11710
11711
# File 'lib/aws-sdk-iotsitewise/types.rb', line 11699

class ListPipelineExecutionsRequest < Struct.new(
  :workspace_name,
  :pipeline_name,
  :next_token,
  :max_results,
  :state,
  :start_time_after,
  :start_time_before,
  :end_time_after,
  :end_time_before)
  SENSITIVE = []
  include Aws::Structure
end

#pipeline_nameString

The name of the pipeline.

Returns:

  • (String)


11699
11700
11701
11702
11703
11704
11705
11706
11707
11708
11709
11710
11711
# File 'lib/aws-sdk-iotsitewise/types.rb', line 11699

class ListPipelineExecutionsRequest < Struct.new(
  :workspace_name,
  :pipeline_name,
  :next_token,
  :max_results,
  :state,
  :start_time_after,
  :start_time_before,
  :end_time_after,
  :end_time_before)
  SENSITIVE = []
  include Aws::Structure
end

#start_time_afterTime

Inclusive lower bound on execution start time (ISO-8601). Only executions with startTime >= startTimeAfter are returned. Cannot be combined with endTimeAfter or endTimeBefore.

Returns:

  • (Time)


11699
11700
11701
11702
11703
11704
11705
11706
11707
11708
11709
11710
11711
# File 'lib/aws-sdk-iotsitewise/types.rb', line 11699

class ListPipelineExecutionsRequest < Struct.new(
  :workspace_name,
  :pipeline_name,
  :next_token,
  :max_results,
  :state,
  :start_time_after,
  :start_time_before,
  :end_time_after,
  :end_time_before)
  SENSITIVE = []
  include Aws::Structure
end

#start_time_beforeTime

Exclusive upper bound on execution start time (ISO-8601). Only executions with startTime < startTimeBefore are returned. Cannot be combined with endTimeAfter or endTimeBefore.

Returns:

  • (Time)


11699
11700
11701
11702
11703
11704
11705
11706
11707
11708
11709
11710
11711
# File 'lib/aws-sdk-iotsitewise/types.rb', line 11699

class ListPipelineExecutionsRequest < Struct.new(
  :workspace_name,
  :pipeline_name,
  :next_token,
  :max_results,
  :state,
  :start_time_after,
  :start_time_before,
  :end_time_after,
  :end_time_before)
  SENSITIVE = []
  include Aws::Structure
end

#stateString

Filter by execution state. If not specified, executions in all states are returned.

Returns:

  • (String)


11699
11700
11701
11702
11703
11704
11705
11706
11707
11708
11709
11710
11711
# File 'lib/aws-sdk-iotsitewise/types.rb', line 11699

class ListPipelineExecutionsRequest < Struct.new(
  :workspace_name,
  :pipeline_name,
  :next_token,
  :max_results,
  :state,
  :start_time_after,
  :start_time_before,
  :end_time_after,
  :end_time_before)
  SENSITIVE = []
  include Aws::Structure
end

#workspace_nameString

The name of the workspace.

Returns:

  • (String)


11699
11700
11701
11702
11703
11704
11705
11706
11707
11708
11709
11710
11711
# File 'lib/aws-sdk-iotsitewise/types.rb', line 11699

class ListPipelineExecutionsRequest < Struct.new(
  :workspace_name,
  :pipeline_name,
  :next_token,
  :max_results,
  :state,
  :start_time_after,
  :start_time_before,
  :end_time_after,
  :end_time_before)
  SENSITIVE = []
  include Aws::Structure
end