Class: Aws::IoTSiteWise::Types::ListPipelineExecutionsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTSiteWise::Types::ListPipelineExecutionsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotsitewise/types.rb
Overview
Response structure for ListPipelineExecutions operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
The token to be used for the next set of paginated results.
-
#pipeline_execution_summaries ⇒ Array<Types::PipelineExecutionSummary>
A list that summarizes each pipeline execution.
Instance Attribute Details
#next_token ⇒ String
The token to be used for the next set of paginated results.
11723 11724 11725 11726 11727 11728 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 11723 class ListPipelineExecutionsResponse < Struct.new( :pipeline_execution_summaries, :next_token) SENSITIVE = [] include Aws::Structure end |
#pipeline_execution_summaries ⇒ Array<Types::PipelineExecutionSummary>
A list that summarizes each pipeline execution.
11723 11724 11725 11726 11727 11728 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 11723 class ListPipelineExecutionsResponse < Struct.new( :pipeline_execution_summaries, :next_token) SENSITIVE = [] include Aws::Structure end |