Class: Aws::IoTSiteWise::Types::ListPipelinesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotsitewise/types.rb

Overview

Request structure for ListPipelines operation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#max_resultsInteger

The maximum number of results to return for each paginated request. Default: 50.

Returns:

  • (Integer)


11745
11746
11747
11748
11749
11750
11751
# File 'lib/aws-sdk-iotsitewise/types.rb', line 11745

class ListPipelinesRequest < Struct.new(
  :workspace_name,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token to be used for the next set of paginated results.

Returns:

  • (String)


11745
11746
11747
11748
11749
11750
11751
# File 'lib/aws-sdk-iotsitewise/types.rb', line 11745

class ListPipelinesRequest < Struct.new(
  :workspace_name,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#workspace_nameString

The name of the workspace.

Returns:

  • (String)


11745
11746
11747
11748
11749
11750
11751
# File 'lib/aws-sdk-iotsitewise/types.rb', line 11745

class ListPipelinesRequest < Struct.new(
  :workspace_name,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end