Class: Aws::IoTSiteWise::Types::ListPipelinesResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTSiteWise::Types::ListPipelinesResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotsitewise/types.rb
Overview
Response structure for ListPipelines operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
The token to be used for the next set of paginated results.
-
#pipeline_summaries ⇒ Array<Types::PipelineSummary>
A list that summarizes each pipeline in the workspace.
Instance Attribute Details
#next_token ⇒ String
The token to be used for the next set of paginated results.
11763 11764 11765 11766 11767 11768 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 11763 class ListPipelinesResponse < Struct.new( :pipeline_summaries, :next_token) SENSITIVE = [] include Aws::Structure end |
#pipeline_summaries ⇒ Array<Types::PipelineSummary>
A list that summarizes each pipeline in the workspace.
11763 11764 11765 11766 11767 11768 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 11763 class ListPipelinesResponse < Struct.new( :pipeline_summaries, :next_token) SENSITIVE = [] include Aws::Structure end |