Class: Aws::IoTSiteWise::Types::ListProjectsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotsitewise/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#max_resultsInteger

The maximum number of results to return for each paginated request.

Default: 50

Returns:



11856
11857
11858
11859
11860
11861
11862
# File 'lib/aws-sdk-iotsitewise/types.rb', line 11856

class ListProjectsRequest < Struct.new(
  :portal_id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token to be used for the next set of paginated results.

Returns:



11856
11857
11858
11859
11860
11861
11862
# File 'lib/aws-sdk-iotsitewise/types.rb', line 11856

class ListProjectsRequest < Struct.new(
  :portal_id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#portal_idString

The ID of the portal.

Returns:



11856
11857
11858
11859
11860
11861
11862
# File 'lib/aws-sdk-iotsitewise/types.rb', line 11856

class ListProjectsRequest < Struct.new(
  :portal_id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end