Class: Aws::IoTSiteWise::Types::ListProjectsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotsitewise/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_tokenString

The token for the next set of results, or null if there are no additional results.

Returns:

  • (String)


11873
11874
11875
11876
11877
11878
# File 'lib/aws-sdk-iotsitewise/types.rb', line 11873

class ListProjectsResponse < Struct.new(
  :project_summaries,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#project_summariesArray<Types::ProjectSummary>

A list that summarizes each project in the portal.

Returns:



11873
11874
11875
11876
11877
11878
# File 'lib/aws-sdk-iotsitewise/types.rb', line 11873

class ListProjectsResponse < Struct.new(
  :project_summaries,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end