Class: Aws::IoTSiteWise::Types::ListQueriesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTSiteWise::Types::ListQueriesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotsitewise/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#filter ⇒ String
An optional filter to return only queries with the specified status.
-
#max_results ⇒ Integer
The maximum number of results to return for each paginated request.
-
#next_token ⇒ String
The token to be used for the next set of paginated results.
-
#workspace_name ⇒ String
The name of the workspace to list queries for.
Instance Attribute Details
#filter ⇒ String
An optional filter to return only queries with the specified status. The value must be one of the supported query statuses: SUBMITTED, RUNNING, COMPLETED, FAILED, CANCELED, or CANCELING.
11898 11899 11900 11901 11902 11903 11904 11905 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 11898 class ListQueriesRequest < Struct.new( :workspace_name, :filter, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return for each paginated request.
11898 11899 11900 11901 11902 11903 11904 11905 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 11898 class ListQueriesRequest < Struct.new( :workspace_name, :filter, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token to be used for the next set of paginated results.
11898 11899 11900 11901 11902 11903 11904 11905 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 11898 class ListQueriesRequest < Struct.new( :workspace_name, :filter, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#workspace_name ⇒ String
The name of the workspace to list queries for.
11898 11899 11900 11901 11902 11903 11904 11905 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 11898 class ListQueriesRequest < Struct.new( :workspace_name, :filter, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |