Class: Aws::IoTSiteWise::Types::ListTasksRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotsitewise/types.rb

Overview

Request structure for ListTasks operation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#max_resultsInteger

The maximum number of results to return for each paginated request. Default: 50.

Returns:

  • (Integer)


12052
12053
12054
12055
12056
12057
12058
# File 'lib/aws-sdk-iotsitewise/types.rb', line 12052

class ListTasksRequest < Struct.new(
  :workspace_name,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token to be used for the next set of paginated results.

Returns:

  • (String)


12052
12053
12054
12055
12056
12057
12058
# File 'lib/aws-sdk-iotsitewise/types.rb', line 12052

class ListTasksRequest < Struct.new(
  :workspace_name,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#workspace_nameString

The name of the workspace.

Returns:

  • (String)


12052
12053
12054
12055
12056
12057
12058
# File 'lib/aws-sdk-iotsitewise/types.rb', line 12052

class ListTasksRequest < Struct.new(
  :workspace_name,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end