Class: Aws::IoTSiteWise::Types::ListTasksResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotsitewise/types.rb

Overview

Response structure for ListTasks operation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_tokenString

The token to be used for the next set of paginated results.

Returns:

  • (String)


12070
12071
12072
12073
12074
12075
# File 'lib/aws-sdk-iotsitewise/types.rb', line 12070

class ListTasksResponse < Struct.new(
  :task_summaries,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#task_summariesArray<Types::TaskSummary>

A list that summarizes each task in the workspace.

Returns:



12070
12071
12072
12073
12074
12075
# File 'lib/aws-sdk-iotsitewise/types.rb', line 12070

class ListTasksResponse < Struct.new(
  :task_summaries,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end