Class: Aws::IoTSiteWise::Types::ListTimeSeriesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTSiteWise::Types::ListTimeSeriesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotsitewise/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#alias_prefix ⇒ String
The alias prefix of the time series.
-
#asset_id ⇒ String
The ID of the asset in which the asset property was created.
-
#max_results ⇒ Integer
The maximum number of results to return for each paginated request.
-
#next_token ⇒ String
The token to be used for the next set of paginated results.
-
#time_series_type ⇒ String
The type of the time series.
-
#workspace_name ⇒ String
The name of the workspace.
Instance Attribute Details
#alias_prefix ⇒ String
The alias prefix of the time series.
12116 12117 12118 12119 12120 12121 12122 12123 12124 12125 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 12116 class ListTimeSeriesRequest < Struct.new( :next_token, :max_results, :asset_id, :alias_prefix, :time_series_type, :workspace_name) SENSITIVE = [] include Aws::Structure end |
#asset_id ⇒ String
The ID of the asset in which the asset property was created. This
can be either the actual ID in UUID format, or else externalId:
followed by the external ID, if it has one. For more information,
see Referencing objects with external IDs in the IoT SiteWise
User Guide.
12116 12117 12118 12119 12120 12121 12122 12123 12124 12125 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 12116 class ListTimeSeriesRequest < Struct.new( :next_token, :max_results, :asset_id, :alias_prefix, :time_series_type, :workspace_name) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return for each paginated request.
12116 12117 12118 12119 12120 12121 12122 12123 12124 12125 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 12116 class ListTimeSeriesRequest < Struct.new( :next_token, :max_results, :asset_id, :alias_prefix, :time_series_type, :workspace_name) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token to be used for the next set of paginated results.
12116 12117 12118 12119 12120 12121 12122 12123 12124 12125 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 12116 class ListTimeSeriesRequest < Struct.new( :next_token, :max_results, :asset_id, :alias_prefix, :time_series_type, :workspace_name) SENSITIVE = [] include Aws::Structure end |
#time_series_type ⇒ String
The type of the time series. The time series type can be one of the following values:
-
ASSOCIATED– The time series is associated with an asset property. -
DISASSOCIATED– The time series isn't associated with any asset property.
12116 12117 12118 12119 12120 12121 12122 12123 12124 12125 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 12116 class ListTimeSeriesRequest < Struct.new( :next_token, :max_results, :asset_id, :alias_prefix, :time_series_type, :workspace_name) SENSITIVE = [] include Aws::Structure end |
#workspace_name ⇒ String
The name of the workspace.
12116 12117 12118 12119 12120 12121 12122 12123 12124 12125 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 12116 class ListTimeSeriesRequest < Struct.new( :next_token, :max_results, :asset_id, :alias_prefix, :time_series_type, :workspace_name) SENSITIVE = [] include Aws::Structure end |