Class: Aws::IoTSiteWise::Types::ListTimeSeriesResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTSiteWise::Types::ListTimeSeriesResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotsitewise/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
The token for the next set of results, or null if there are no additional results.
-
#time_series_summaries ⇒ Array<Types::TimeSeriesSummary>
One or more time series summaries to list.
-
#workspace_name ⇒ String
The name of the workspace.
Instance Attribute Details
#next_token ⇒ String
The token for the next set of results, or null if there are no additional results.
12140 12141 12142 12143 12144 12145 12146 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 12140 class ListTimeSeriesResponse < Struct.new( :time_series_summaries, :next_token, :workspace_name) SENSITIVE = [] include Aws::Structure end |
#time_series_summaries ⇒ Array<Types::TimeSeriesSummary>
One or more time series summaries to list.
12140 12141 12142 12143 12144 12145 12146 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 12140 class ListTimeSeriesResponse < Struct.new( :time_series_summaries, :next_token, :workspace_name) SENSITIVE = [] include Aws::Structure end |
#workspace_name ⇒ String
The name of the workspace.
12140 12141 12142 12143 12144 12145 12146 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 12140 class ListTimeSeriesResponse < Struct.new( :time_series_summaries, :next_token, :workspace_name) SENSITIVE = [] include Aws::Structure end |