Class: Aws::IoTSiteWise::Types::Measurement

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotsitewise/types.rb

Overview

Contains an asset measurement property. For more information, see Measurements in the IoT SiteWise User Guide.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#processing_configTypes::MeasurementProcessingConfig

The processing configuration for the given measurement property. You can configure measurements to be kept at the edge or forwarded to the Amazon Web Services Cloud. By default, measurements are forwarded to the cloud.



12185
12186
12187
12188
12189
# File 'lib/aws-sdk-iotsitewise/types.rb', line 12185

class Measurement < Struct.new(
  :processing_config)
  SENSITIVE = []
  include Aws::Structure
end