Class: Aws::IoTSiteWise::Types::MeasurementProcessingConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTSiteWise::Types::MeasurementProcessingConfig
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotsitewise/types.rb
Overview
The processing configuration for the given measurement property. You can configure measurements to be kept at the edge or forwarded to the Amazon Web Services Cloud. By default, measurements are forwarded to the cloud.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#forwarding_config ⇒ Types::ForwardingConfig
The forwarding configuration for the given measurement property.
Instance Attribute Details
#forwarding_config ⇒ Types::ForwardingConfig
The forwarding configuration for the given measurement property.
12200 12201 12202 12203 12204 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 12200 class MeasurementProcessingConfig < Struct.new( :forwarding_config) SENSITIVE = [] include Aws::Structure end |