Class: Aws::IoTSiteWise::Types::PipelineExecutionSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTSiteWise::Types::PipelineExecutionSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotsitewise/types.rb
Overview
Contains summary information about a pipeline execution.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#end_time ⇒ Time
The time the pipeline execution completed, in Unix epoch time.
-
#execution_priority ⇒ Integer
Scheduling priority for the execution.
-
#pipeline_execution_id ⇒ String
The unique identifier of the pipeline execution.
-
#pipeline_version ⇒ String
The pipeline version this execution ran against.
-
#start_time ⇒ Time
The time the pipeline execution started, in Unix epoch time.
-
#status ⇒ Types::PipelineExecutionStatus
The current execution status of the pipeline.
Instance Attribute Details
#end_time ⇒ Time
The time the pipeline execution completed, in Unix epoch time.
12401 12402 12403 12404 12405 12406 12407 12408 12409 12410 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 12401 class PipelineExecutionSummary < Struct.new( :pipeline_execution_id, :pipeline_version, :status, :execution_priority, :start_time, :end_time) SENSITIVE = [] include Aws::Structure end |
#execution_priority ⇒ Integer
Scheduling priority for the execution. When not specified, defaults to lowest priority.
12401 12402 12403 12404 12405 12406 12407 12408 12409 12410 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 12401 class PipelineExecutionSummary < Struct.new( :pipeline_execution_id, :pipeline_version, :status, :execution_priority, :start_time, :end_time) SENSITIVE = [] include Aws::Structure end |
#pipeline_execution_id ⇒ String
The unique identifier of the pipeline execution.
12401 12402 12403 12404 12405 12406 12407 12408 12409 12410 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 12401 class PipelineExecutionSummary < Struct.new( :pipeline_execution_id, :pipeline_version, :status, :execution_priority, :start_time, :end_time) SENSITIVE = [] include Aws::Structure end |
#pipeline_version ⇒ String
The pipeline version this execution ran against.
12401 12402 12403 12404 12405 12406 12407 12408 12409 12410 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 12401 class PipelineExecutionSummary < Struct.new( :pipeline_execution_id, :pipeline_version, :status, :execution_priority, :start_time, :end_time) SENSITIVE = [] include Aws::Structure end |
#start_time ⇒ Time
The time the pipeline execution started, in Unix epoch time.
12401 12402 12403 12404 12405 12406 12407 12408 12409 12410 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 12401 class PipelineExecutionSummary < Struct.new( :pipeline_execution_id, :pipeline_version, :status, :execution_priority, :start_time, :end_time) SENSITIVE = [] include Aws::Structure end |
#status ⇒ Types::PipelineExecutionStatus
The current execution status of the pipeline.
12401 12402 12403 12404 12405 12406 12407 12408 12409 12410 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 12401 class PipelineExecutionSummary < Struct.new( :pipeline_execution_id, :pipeline_version, :status, :execution_priority, :start_time, :end_time) SENSITIVE = [] include Aws::Structure end |