Class: Aws::IoTSiteWise::Types::PipelineSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTSiteWise::Types::PipelineSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotsitewise/types.rb
Overview
Contains summary information about a pipeline.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The time the pipeline was created, in Unix epoch time.
-
#description ⇒ String
The description of the pipeline.
-
#pipeline_arn ⇒ String
The ARN of the pipeline.
-
#pipeline_name ⇒ String
The name of the pipeline.
-
#status ⇒ Types::ResourceStatus
The current lifecycle status of the pipeline.
-
#updated_at ⇒ Time
The time the pipeline was last updated, in Unix epoch time.
-
#version ⇒ String
The version of the pipeline.
Instance Attribute Details
#created_at ⇒ Time
The time the pipeline was created, in Unix epoch time.
12442 12443 12444 12445 12446 12447 12448 12449 12450 12451 12452 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 12442 class PipelineSummary < Struct.new( :pipeline_name, :description, :pipeline_arn, :version, :status, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the pipeline.
12442 12443 12444 12445 12446 12447 12448 12449 12450 12451 12452 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 12442 class PipelineSummary < Struct.new( :pipeline_name, :description, :pipeline_arn, :version, :status, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#pipeline_arn ⇒ String
The ARN of the pipeline.
12442 12443 12444 12445 12446 12447 12448 12449 12450 12451 12452 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 12442 class PipelineSummary < Struct.new( :pipeline_name, :description, :pipeline_arn, :version, :status, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#pipeline_name ⇒ String
The name of the pipeline.
12442 12443 12444 12445 12446 12447 12448 12449 12450 12451 12452 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 12442 class PipelineSummary < Struct.new( :pipeline_name, :description, :pipeline_arn, :version, :status, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#status ⇒ Types::ResourceStatus
The current lifecycle status of the pipeline.
12442 12443 12444 12445 12446 12447 12448 12449 12450 12451 12452 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 12442 class PipelineSummary < Struct.new( :pipeline_name, :description, :pipeline_arn, :version, :status, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The time the pipeline was last updated, in Unix epoch time.
12442 12443 12444 12445 12446 12447 12448 12449 12450 12451 12452 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 12442 class PipelineSummary < Struct.new( :pipeline_name, :description, :pipeline_arn, :version, :status, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#version ⇒ String
The version of the pipeline.
12442 12443 12444 12445 12446 12447 12448 12449 12450 12451 12452 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 12442 class PipelineSummary < Struct.new( :pipeline_name, :description, :pipeline_arn, :version, :status, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |