Class: Aws::IoTSiteWise::Types::PortalSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotsitewise/types.rb

Overview

Contains a portal summary.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#creation_dateTime

The date the portal was created, in Unix epoch time.

Returns:



12646
12647
12648
12649
12650
12651
12652
12653
12654
12655
12656
12657
12658
# File 'lib/aws-sdk-iotsitewise/types.rb', line 12646

class PortalSummary < Struct.new(
  :id,
  :name,
  :description,
  :start_url,
  :creation_date,
  :last_update_date,
  :role_arn,
  :status,
  :portal_type)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The portal's description.

Returns:



12646
12647
12648
12649
12650
12651
12652
12653
12654
12655
12656
12657
12658
# File 'lib/aws-sdk-iotsitewise/types.rb', line 12646

class PortalSummary < Struct.new(
  :id,
  :name,
  :description,
  :start_url,
  :creation_date,
  :last_update_date,
  :role_arn,
  :status,
  :portal_type)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The ID of the portal.

Returns:



12646
12647
12648
12649
12650
12651
12652
12653
12654
12655
12656
12657
12658
# File 'lib/aws-sdk-iotsitewise/types.rb', line 12646

class PortalSummary < Struct.new(
  :id,
  :name,
  :description,
  :start_url,
  :creation_date,
  :last_update_date,
  :role_arn,
  :status,
  :portal_type)
  SENSITIVE = []
  include Aws::Structure
end

#last_update_dateTime

The date the portal was last updated, in Unix epoch time.

Returns:



12646
12647
12648
12649
12650
12651
12652
12653
12654
12655
12656
12657
12658
# File 'lib/aws-sdk-iotsitewise/types.rb', line 12646

class PortalSummary < Struct.new(
  :id,
  :name,
  :description,
  :start_url,
  :creation_date,
  :last_update_date,
  :role_arn,
  :status,
  :portal_type)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the portal.

Returns:



12646
12647
12648
12649
12650
12651
12652
12653
12654
12655
12656
12657
12658
# File 'lib/aws-sdk-iotsitewise/types.rb', line 12646

class PortalSummary < Struct.new(
  :id,
  :name,
  :description,
  :start_url,
  :creation_date,
  :last_update_date,
  :role_arn,
  :status,
  :portal_type)
  SENSITIVE = []
  include Aws::Structure
end

#portal_typeString

Define the type of portal. The value for IoT SiteWise Monitor (Classic) is SITEWISE_PORTAL_V1. The value for IoT SiteWise Monitor (AI-aware) is SITEWISE_PORTAL_V2.

Returns:



12646
12647
12648
12649
12650
12651
12652
12653
12654
12655
12656
12657
12658
# File 'lib/aws-sdk-iotsitewise/types.rb', line 12646

class PortalSummary < Struct.new(
  :id,
  :name,
  :description,
  :start_url,
  :creation_date,
  :last_update_date,
  :role_arn,
  :status,
  :portal_type)
  SENSITIVE = []
  include Aws::Structure
end

#role_arnString

The ARN of the service role that allows the portal's users to access your IoT SiteWise resources on your behalf. For more information, see Using service roles for IoT SiteWise Monitor in the IoT SiteWise User Guide.

Returns:



12646
12647
12648
12649
12650
12651
12652
12653
12654
12655
12656
12657
12658
# File 'lib/aws-sdk-iotsitewise/types.rb', line 12646

class PortalSummary < Struct.new(
  :id,
  :name,
  :description,
  :start_url,
  :creation_date,
  :last_update_date,
  :role_arn,
  :status,
  :portal_type)
  SENSITIVE = []
  include Aws::Structure
end

#start_urlString

The URL for the IoT SiteWise Monitor portal. You can use this URL to access portals that use IAM Identity Center for authentication. For portals that use IAM for authentication, you must use the IoT SiteWise console to get a URL that you can use to access the portal.

Returns:



12646
12647
12648
12649
12650
12651
12652
12653
12654
12655
12656
12657
12658
# File 'lib/aws-sdk-iotsitewise/types.rb', line 12646

class PortalSummary < Struct.new(
  :id,
  :name,
  :description,
  :start_url,
  :creation_date,
  :last_update_date,
  :role_arn,
  :status,
  :portal_type)
  SENSITIVE = []
  include Aws::Structure
end

#statusTypes::PortalStatus

Contains information about the current status of a portal.

Returns:



12646
12647
12648
12649
12650
12651
12652
12653
12654
12655
12656
12657
12658
# File 'lib/aws-sdk-iotsitewise/types.rb', line 12646

class PortalSummary < Struct.new(
  :id,
  :name,
  :description,
  :start_url,
  :creation_date,
  :last_update_date,
  :role_arn,
  :status,
  :portal_type)
  SENSITIVE = []
  include Aws::Structure
end