Class: Aws::IoTSiteWise::Types::ProcessingInput

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-iotsitewise/types.rb

Overview

Note:

ProcessingInput is a union - when making an API calls you must set exactly one of the members.

Note:

ProcessingInput is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of ProcessingInput corresponding to the set member.

<p>Input source for processing. Specify exactly one option.</p>

Defined Under Namespace

Classes: Dataset, Timeseries, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#datasetTypes::DatasetItem

<p>A dataset containing multiple items to process.</p>

Returns:



12602
12603
12604
12605
12606
12607
12608
12609
12610
12611
12612
12613
# File 'lib/aws-sdk-iotsitewise/types.rb', line 12602

class ProcessingInput < Struct.new(
  :timeseries,
  :dataset,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Timeseries < ProcessingInput; end
  class Dataset < ProcessingInput; end
  class Unknown < ProcessingInput; end
end

#timeseriesArray<Types::TimeseriesItem>

<p>List of individual timeseries items to process.</p>

Returns:



12602
12603
12604
12605
12606
12607
12608
12609
12610
12611
12612
12613
# File 'lib/aws-sdk-iotsitewise/types.rb', line 12602

class ProcessingInput < Struct.new(
  :timeseries,
  :dataset,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Timeseries < ProcessingInput; end
  class Dataset < ProcessingInput; end
  class Unknown < ProcessingInput; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



12602
12603
12604
# File 'lib/aws-sdk-iotsitewise/types.rb', line 12602

def unknown
  @unknown
end