Class: Aws::IoTSiteWise::Types::PropertyMapping
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTSiteWise::Types::PropertyMapping
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotsitewise/types.rb
Overview
Maps a property from an interface asset model to a property in the asset model where the interface is applied.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#asset_model_property_id ⇒ String
The ID of the property in the asset model where the interface is applied.
-
#interface_asset_model_property_id ⇒ String
The ID of the property in the interface asset model.
Instance Attribute Details
#asset_model_property_id ⇒ String
The ID of the property in the asset model where the interface is applied.
12742 12743 12744 12745 12746 12747 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 12742 class PropertyMapping < Struct.new( :asset_model_property_id, :interface_asset_model_property_id) SENSITIVE = [] include Aws::Structure end |
#interface_asset_model_property_id ⇒ String
The ID of the property in the interface asset model.
12742 12743 12744 12745 12746 12747 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 12742 class PropertyMapping < Struct.new( :asset_model_property_id, :interface_asset_model_property_id) SENSITIVE = [] include Aws::Structure end |