Class: Aws::IoTSiteWise::Types::PutAssetModelInterfaceRelationshipRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTSiteWise::Types::PutAssetModelInterfaceRelationshipRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotsitewise/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#asset_model_id ⇒ String
The ID of the asset model.
-
#client_token ⇒ String
A unique case-sensitive identifier that you can provide to ensure the idempotency of the request.
-
#interface_asset_model_id ⇒ String
The ID of the interface asset model.
-
#property_mapping_configuration ⇒ Types::PropertyMappingConfiguration
The configuration for mapping properties from the interface asset model to the asset model where the interface is applied.
Instance Attribute Details
#asset_model_id ⇒ String
The ID of the asset model. This can be either the actual ID in UUID format, or else externalId: followed by the external ID.
12883 12884 12885 12886 12887 12888 12889 12890 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 12883 class PutAssetModelInterfaceRelationshipRequest < Struct.new( :asset_model_id, :interface_asset_model_id, :property_mapping_configuration, :client_token) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
A unique case-sensitive identifier that you can provide to ensure the idempotency of the request. Don't reuse this client token if a new idempotent request is required.
A suitable default value is auto-generated. You should normally not need to pass this option.
12883 12884 12885 12886 12887 12888 12889 12890 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 12883 class PutAssetModelInterfaceRelationshipRequest < Struct.new( :asset_model_id, :interface_asset_model_id, :property_mapping_configuration, :client_token) SENSITIVE = [] include Aws::Structure end |
#interface_asset_model_id ⇒ String
The ID of the interface asset model. This can be either the actual ID in UUID format, or else externalId: followed by the external ID.
12883 12884 12885 12886 12887 12888 12889 12890 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 12883 class PutAssetModelInterfaceRelationshipRequest < Struct.new( :asset_model_id, :interface_asset_model_id, :property_mapping_configuration, :client_token) SENSITIVE = [] include Aws::Structure end |
#property_mapping_configuration ⇒ Types::PropertyMappingConfiguration
The configuration for mapping properties from the interface asset model to the asset model where the interface is applied. This configuration controls how properties are matched and created during the interface application process.
12883 12884 12885 12886 12887 12888 12889 12890 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 12883 class PutAssetModelInterfaceRelationshipRequest < Struct.new( :asset_model_id, :interface_asset_model_id, :property_mapping_configuration, :client_token) SENSITIVE = [] include Aws::Structure end |