Class: Aws::IoTSiteWise::Types::PutAssetModelInterfaceRelationshipResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotsitewise/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#asset_model_arnString

The ARN of the asset model, which has the following format. arn:${Partition}:iotsitewise:${Region}:${Account}:asset-model/${AssetModelId}

Returns:



13027
13028
13029
13030
13031
13032
13033
13034
# File 'lib/aws-sdk-iotsitewise/types.rb', line 13027

class PutAssetModelInterfaceRelationshipResponse < Struct.new(
  :asset_model_id,
  :interface_asset_model_id,
  :asset_model_arn,
  :asset_model_status)
  SENSITIVE = []
  include Aws::Structure
end

#asset_model_idString

The ID of the asset model.

Returns:



13027
13028
13029
13030
13031
13032
13033
13034
# File 'lib/aws-sdk-iotsitewise/types.rb', line 13027

class PutAssetModelInterfaceRelationshipResponse < Struct.new(
  :asset_model_id,
  :interface_asset_model_id,
  :asset_model_arn,
  :asset_model_status)
  SENSITIVE = []
  include Aws::Structure
end

#asset_model_statusTypes::AssetModelStatus

Contains current status information for an asset model. For more information, see Asset and model states in the IoT SiteWise User Guide.

Returns:



13027
13028
13029
13030
13031
13032
13033
13034
# File 'lib/aws-sdk-iotsitewise/types.rb', line 13027

class PutAssetModelInterfaceRelationshipResponse < Struct.new(
  :asset_model_id,
  :interface_asset_model_id,
  :asset_model_arn,
  :asset_model_status)
  SENSITIVE = []
  include Aws::Structure
end

#interface_asset_model_idString

The ID of the interface asset model.

Returns:



13027
13028
13029
13030
13031
13032
13033
13034
# File 'lib/aws-sdk-iotsitewise/types.rb', line 13027

class PutAssetModelInterfaceRelationshipResponse < Struct.new(
  :asset_model_id,
  :interface_asset_model_id,
  :asset_model_arn,
  :asset_model_status)
  SENSITIVE = []
  include Aws::Structure
end