Class: Aws::IoTSiteWise::Types::QuerySummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTSiteWise::Types::QuerySummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotsitewise/types.rb
Overview
Contains summary information about a query.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#completed_at ⇒ Time
The date and time when the query reached a terminal state, in Unix epoch time.
-
#query_id ⇒ String
The unique identifier for the query execution.
-
#status ⇒ String
The current query status.
-
#submitted_at ⇒ Time
The date and time when the query was submitted, in Unix epoch time.
Instance Attribute Details
#completed_at ⇒ Time
The date and time when the query reached a terminal state, in Unix epoch time.
13222 13223 13224 13225 13226 13227 13228 13229 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 13222 class QuerySummary < Struct.new( :query_id, :status, :submitted_at, :completed_at) SENSITIVE = [] include Aws::Structure end |
#query_id ⇒ String
The unique identifier for the query execution.
13222 13223 13224 13225 13226 13227 13228 13229 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 13222 class QuerySummary < Struct.new( :query_id, :status, :submitted_at, :completed_at) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current query status.
13222 13223 13224 13225 13226 13227 13228 13229 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 13222 class QuerySummary < Struct.new( :query_id, :status, :submitted_at, :completed_at) SENSITIVE = [] include Aws::Structure end |
#submitted_at ⇒ Time
The date and time when the query was submitted, in Unix epoch time.
13222 13223 13224 13225 13226 13227 13228 13229 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 13222 class QuerySummary < Struct.new( :query_id, :status, :submitted_at, :completed_at) SENSITIVE = [] include Aws::Structure end |