Class: Aws::IoTSiteWise::Types::SearchSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotsitewise/types.rb

Overview

A summary of a single search as returned by ListSearches.

Constant Summary collapse

SENSITIVE =
[:query_statement]

Instance Attribute Summary collapse

Instance Attribute Details

#group_idString

The group identifier associated with the search, if one was supplied on the request.

Returns:

  • (String)


13500
13501
13502
13503
13504
13505
13506
13507
13508
13509
13510
13511
# File 'lib/aws-sdk-iotsitewise/types.rb', line 13500

class SearchSummary < Struct.new(
  :search_id,
  :workspace_name,
  :status,
  :query_statement,
  :search_type,
  :status_reason,
  :started_at,
  :group_id)
  SENSITIVE = [:query_statement]
  include Aws::Structure
end

#query_statementString

The natural-language query that was submitted for the search.

Returns:

  • (String)


13500
13501
13502
13503
13504
13505
13506
13507
13508
13509
13510
13511
# File 'lib/aws-sdk-iotsitewise/types.rb', line 13500

class SearchSummary < Struct.new(
  :search_id,
  :workspace_name,
  :status,
  :query_statement,
  :search_type,
  :status_reason,
  :started_at,
  :group_id)
  SENSITIVE = [:query_statement]
  include Aws::Structure
end

#search_idString

The unique identifier of the search.

Returns:

  • (String)


13500
13501
13502
13503
13504
13505
13506
13507
13508
13509
13510
13511
# File 'lib/aws-sdk-iotsitewise/types.rb', line 13500

class SearchSummary < Struct.new(
  :search_id,
  :workspace_name,
  :status,
  :query_statement,
  :search_type,
  :status_reason,
  :started_at,
  :group_id)
  SENSITIVE = [:query_statement]
  include Aws::Structure
end

#search_typeString

The search strategy used for the search.

Returns:

  • (String)


13500
13501
13502
13503
13504
13505
13506
13507
13508
13509
13510
13511
# File 'lib/aws-sdk-iotsitewise/types.rb', line 13500

class SearchSummary < Struct.new(
  :search_id,
  :workspace_name,
  :status,
  :query_statement,
  :search_type,
  :status_reason,
  :started_at,
  :group_id)
  SENSITIVE = [:query_statement]
  include Aws::Structure
end

#started_atTime

The time at which the search was started.

Returns:

  • (Time)


13500
13501
13502
13503
13504
13505
13506
13507
13508
13509
13510
13511
# File 'lib/aws-sdk-iotsitewise/types.rb', line 13500

class SearchSummary < Struct.new(
  :search_id,
  :workspace_name,
  :status,
  :query_statement,
  :search_type,
  :status_reason,
  :started_at,
  :group_id)
  SENSITIVE = [:query_statement]
  include Aws::Structure
end

#statusString

The current status of the search.

Returns:

  • (String)


13500
13501
13502
13503
13504
13505
13506
13507
13508
13509
13510
13511
# File 'lib/aws-sdk-iotsitewise/types.rb', line 13500

class SearchSummary < Struct.new(
  :search_id,
  :workspace_name,
  :status,
  :query_statement,
  :search_type,
  :status_reason,
  :started_at,
  :group_id)
  SENSITIVE = [:query_statement]
  include Aws::Structure
end

#status_reasonString

A human-readable explanation of the current status. Populated when the search has FAILED.

Returns:

  • (String)


13500
13501
13502
13503
13504
13505
13506
13507
13508
13509
13510
13511
# File 'lib/aws-sdk-iotsitewise/types.rb', line 13500

class SearchSummary < Struct.new(
  :search_id,
  :workspace_name,
  :status,
  :query_statement,
  :search_type,
  :status_reason,
  :started_at,
  :group_id)
  SENSITIVE = [:query_statement]
  include Aws::Structure
end

#workspace_nameString

The name of the workspace the search runs against.

Returns:

  • (String)


13500
13501
13502
13503
13504
13505
13506
13507
13508
13509
13510
13511
# File 'lib/aws-sdk-iotsitewise/types.rb', line 13500

class SearchSummary < Struct.new(
  :search_id,
  :workspace_name,
  :status,
  :query_statement,
  :search_type,
  :status_reason,
  :started_at,
  :group_id)
  SENSITIVE = [:query_statement]
  include Aws::Structure
end