Class: Aws::IoTSiteWise::Types::StartPipelineExecutionRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotsitewise/types.rb

Overview

Request structure for StartPipelineExecution operation.

Constant Summary collapse

SENSITIVE =
[:execution_environment_variable_overrides]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If you retry a request that completed successfully using the same client token, the server returns the cached result from the original successful request without performing the operation again.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


13620
13621
13622
13623
13624
13625
13626
13627
13628
# File 'lib/aws-sdk-iotsitewise/types.rb', line 13620

class StartPipelineExecutionRequest < Struct.new(
  :workspace_name,
  :pipeline_name,
  :execution_environment_variable_overrides,
  :execution_priority,
  :client_token)
  SENSITIVE = [:execution_environment_variable_overrides]
  include Aws::Structure
end

#execution_environment_variable_overridesTypes::ExecutionEnvironmentVariables

Runtime environment variable overrides for the execution. Includes global variables that apply to all compute nodes and computeNodes for per-node overrides. These take the highest priority in the environment variable hierarchy.



13620
13621
13622
13623
13624
13625
13626
13627
13628
# File 'lib/aws-sdk-iotsitewise/types.rb', line 13620

class StartPipelineExecutionRequest < Struct.new(
  :workspace_name,
  :pipeline_name,
  :execution_environment_variable_overrides,
  :execution_priority,
  :client_token)
  SENSITIVE = [:execution_environment_variable_overrides]
  include Aws::Structure
end

#execution_priorityInteger

Scheduling priority for the execution. Lower values indicate higher priority. Defaults to 2 when not specified.

Returns:

  • (Integer)


13620
13621
13622
13623
13624
13625
13626
13627
13628
# File 'lib/aws-sdk-iotsitewise/types.rb', line 13620

class StartPipelineExecutionRequest < Struct.new(
  :workspace_name,
  :pipeline_name,
  :execution_environment_variable_overrides,
  :execution_priority,
  :client_token)
  SENSITIVE = [:execution_environment_variable_overrides]
  include Aws::Structure
end

#pipeline_nameString

The name of the pipeline to execute.

Returns:

  • (String)


13620
13621
13622
13623
13624
13625
13626
13627
13628
# File 'lib/aws-sdk-iotsitewise/types.rb', line 13620

class StartPipelineExecutionRequest < Struct.new(
  :workspace_name,
  :pipeline_name,
  :execution_environment_variable_overrides,
  :execution_priority,
  :client_token)
  SENSITIVE = [:execution_environment_variable_overrides]
  include Aws::Structure
end

#workspace_nameString

The name of the workspace containing the pipeline.

Returns:

  • (String)


13620
13621
13622
13623
13624
13625
13626
13627
13628
# File 'lib/aws-sdk-iotsitewise/types.rb', line 13620

class StartPipelineExecutionRequest < Struct.new(
  :workspace_name,
  :pipeline_name,
  :execution_environment_variable_overrides,
  :execution_priority,
  :client_token)
  SENSITIVE = [:execution_environment_variable_overrides]
  include Aws::Structure
end