Class: Aws::IoTSiteWise::Types::StartQueryRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotsitewise/types.rb

Constant Summary collapse

SENSITIVE =
[:query_statement]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique case-sensitive identifier that you can provide to ensure the idempotency of the request. Don't reuse this client token if a new idempotent request is required.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


13660
13661
13662
13663
13664
13665
13666
# File 'lib/aws-sdk-iotsitewise/types.rb', line 13660

class StartQueryRequest < Struct.new(
  :client_token,
  :workspace_name,
  :query_statement)
  SENSITIVE = [:query_statement]
  include Aws::Structure
end

#query_statementString

The SQL query to execute against the workspace telemetry, annotations, data segment, and dataset data.

Returns:

  • (String)


13660
13661
13662
13663
13664
13665
13666
# File 'lib/aws-sdk-iotsitewise/types.rb', line 13660

class StartQueryRequest < Struct.new(
  :client_token,
  :workspace_name,
  :query_statement)
  SENSITIVE = [:query_statement]
  include Aws::Structure
end

#workspace_nameString

The name of the workspace to query.

Returns:

  • (String)


13660
13661
13662
13663
13664
13665
13666
# File 'lib/aws-sdk-iotsitewise/types.rb', line 13660

class StartQueryRequest < Struct.new(
  :client_token,
  :workspace_name,
  :query_statement)
  SENSITIVE = [:query_statement]
  include Aws::Structure
end