Class: Aws::IoTSiteWise::Types::StartSearchRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotsitewise/types.rb

Overview

Input for the StartSearch operation.

Constant Summary collapse

SENSITIVE =
[:query_statement]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique, case-sensitive identifier you provide to ensure the request is idempotent. Repeating a StartSearch call with the same clientToken returns the original search rather than starting a new one. If omitted, the SDK autogenerates one.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


13720
13721
13722
13723
13724
13725
13726
13727
13728
13729
# File 'lib/aws-sdk-iotsitewise/types.rb', line 13720

class StartSearchRequest < Struct.new(
  :workspace_name,
  :query_statement,
  :client_token,
  :search_type,
  :search_filters,
  :group_id)
  SENSITIVE = [:query_statement]
  include Aws::Structure
end

#group_idString

An optional caller-supplied identifier used to group related searches together.

Returns:

  • (String)


13720
13721
13722
13723
13724
13725
13726
13727
13728
13729
# File 'lib/aws-sdk-iotsitewise/types.rb', line 13720

class StartSearchRequest < Struct.new(
  :workspace_name,
  :query_statement,
  :client_token,
  :search_type,
  :search_filters,
  :group_id)
  SENSITIVE = [:query_statement]
  include Aws::Structure
end

#query_statementString

The natural-language query describing the data to search for.

Returns:

  • (String)


13720
13721
13722
13723
13724
13725
13726
13727
13728
13729
# File 'lib/aws-sdk-iotsitewise/types.rb', line 13720

class StartSearchRequest < Struct.new(
  :workspace_name,
  :query_statement,
  :client_token,
  :search_type,
  :search_filters,
  :group_id)
  SENSITIVE = [:query_statement]
  include Aws::Structure
end

#search_filtersTypes::SearchFilters

Optional filters that restrict the search to a subset of the workspace's data.



13720
13721
13722
13723
13724
13725
13726
13727
13728
13729
# File 'lib/aws-sdk-iotsitewise/types.rb', line 13720

class StartSearchRequest < Struct.new(
  :workspace_name,
  :query_statement,
  :client_token,
  :search_type,
  :search_filters,
  :group_id)
  SENSITIVE = [:query_statement]
  include Aws::Structure
end

#search_typeString

The search strategy to use. Defaults to QUICK when omitted.

Returns:

  • (String)


13720
13721
13722
13723
13724
13725
13726
13727
13728
13729
# File 'lib/aws-sdk-iotsitewise/types.rb', line 13720

class StartSearchRequest < Struct.new(
  :workspace_name,
  :query_statement,
  :client_token,
  :search_type,
  :search_filters,
  :group_id)
  SENSITIVE = [:query_statement]
  include Aws::Structure
end

#workspace_nameString

The name of the workspace whose data is searched.

Returns:

  • (String)


13720
13721
13722
13723
13724
13725
13726
13727
13728
13729
# File 'lib/aws-sdk-iotsitewise/types.rb', line 13720

class StartSearchRequest < Struct.new(
  :workspace_name,
  :query_statement,
  :client_token,
  :search_type,
  :search_filters,
  :group_id)
  SENSITIVE = [:query_statement]
  include Aws::Structure
end