Class: Aws::IoTSiteWise::Types::TaskConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTSiteWise::Types::TaskConfiguration
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-iotsitewise/types.rb
Overview
Note:
TaskConfiguration is a union - when making an API calls you must set exactly one of the members.
Note:
TaskConfiguration is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of TaskConfiguration corresponding to the set member.
The task execution configuration. Specify a containerTaskConfiguration for a custom container workload.
Defined Under Namespace
Classes: ContainerTaskConfiguration, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#container_task_configuration ⇒ Types::ContainerTaskConfiguration
Configuration for running a custom container image on managed compute.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#container_task_configuration ⇒ Types::ContainerTaskConfiguration
Configuration for running a custom container image on managed compute.
13821 13822 13823 13824 13825 13826 13827 13828 13829 13830 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 13821 class TaskConfiguration < Struct.new( :container_task_configuration, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class ContainerTaskConfiguration < TaskConfiguration; end class Unknown < TaskConfiguration; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
13821 13822 13823 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 13821 def unknown @unknown end |