Class: Aws::IoTSiteWise::Types::TaskSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotsitewise/types.rb

Overview

Contains summary information about a task.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#created_atTime

The time the task was created, in Unix epoch time.

Returns:

  • (Time)


13862
13863
13864
13865
13866
13867
13868
13869
13870
13871
13872
# File 'lib/aws-sdk-iotsitewise/types.rb', line 13862

class TaskSummary < Struct.new(
  :task_name,
  :description,
  :task_arn,
  :version,
  :status,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description of the task.

Returns:

  • (String)


13862
13863
13864
13865
13866
13867
13868
13869
13870
13871
13872
# File 'lib/aws-sdk-iotsitewise/types.rb', line 13862

class TaskSummary < Struct.new(
  :task_name,
  :description,
  :task_arn,
  :version,
  :status,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#statusTypes::ResourceStatus

The current lifecycle status of the task.



13862
13863
13864
13865
13866
13867
13868
13869
13870
13871
13872
# File 'lib/aws-sdk-iotsitewise/types.rb', line 13862

class TaskSummary < Struct.new(
  :task_name,
  :description,
  :task_arn,
  :version,
  :status,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#task_arnString

The ARN of the task.

Returns:

  • (String)


13862
13863
13864
13865
13866
13867
13868
13869
13870
13871
13872
# File 'lib/aws-sdk-iotsitewise/types.rb', line 13862

class TaskSummary < Struct.new(
  :task_name,
  :description,
  :task_arn,
  :version,
  :status,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#task_nameString

The name of the task.

Returns:

  • (String)


13862
13863
13864
13865
13866
13867
13868
13869
13870
13871
13872
# File 'lib/aws-sdk-iotsitewise/types.rb', line 13862

class TaskSummary < Struct.new(
  :task_name,
  :description,
  :task_arn,
  :version,
  :status,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#updated_atTime

The time the task was last updated, in Unix epoch time.

Returns:

  • (Time)


13862
13863
13864
13865
13866
13867
13868
13869
13870
13871
13872
# File 'lib/aws-sdk-iotsitewise/types.rb', line 13862

class TaskSummary < Struct.new(
  :task_name,
  :description,
  :task_arn,
  :version,
  :status,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#versionString

The version of the task.

Returns:

  • (String)


13862
13863
13864
13865
13866
13867
13868
13869
13870
13871
13872
# File 'lib/aws-sdk-iotsitewise/types.rb', line 13862

class TaskSummary < Struct.new(
  :task_name,
  :description,
  :task_arn,
  :version,
  :status,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end