Class: Aws::IoTSiteWise::Types::ThrottlingException

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotsitewise/types.rb

Overview

Your request exceeded a rate limit. For example, you might have exceeded the number of IoT SiteWise assets that can be created per second, the allowed number of messages per second, and so on.

For more information, see Quotas in the IoT SiteWise User Guide.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#event_typeObject

Returns the value of attribute event_type

Returns:

  • (Object)

    the current value of event_type



13888
13889
13890
# File 'lib/aws-sdk-iotsitewise/types.rb', line 13888

def event_type
  @event_type
end

#messageString

Returns:

  • (String)


13888
13889
13890
13891
13892
13893
# File 'lib/aws-sdk-iotsitewise/types.rb', line 13888

class ThrottlingException < Struct.new(
  :message,
  :event_type)
  SENSITIVE = []
  include Aws::Structure
end