Class: Aws::IoTSiteWise::Types::TimeInterval

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotsitewise/types.rb

Overview

Contains a time interval with a start time and an end time. Use a time interval to restrict an operation, such as a search, to a specific time range.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#end_timeTypes::TimeInNanos

The end of the time interval.

Returns:



13925
13926
13927
13928
13929
13930
# File 'lib/aws-sdk-iotsitewise/types.rb', line 13925

class TimeInterval < Struct.new(
  :start_time,
  :end_time)
  SENSITIVE = []
  include Aws::Structure
end

#start_timeTypes::TimeInNanos

The start of the time interval.

Returns:



13925
13926
13927
13928
13929
13930
# File 'lib/aws-sdk-iotsitewise/types.rb', line 13925

class TimeInterval < Struct.new(
  :start_time,
  :end_time)
  SENSITIVE = []
  include Aws::Structure
end