Class: Aws::IoTSiteWise::Types::TimeseriesItem
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTSiteWise::Types::TimeseriesItem
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotsitewise/types.rb
Overview
<p>A single timeseries item to process. Exactly one of timeSeriesId or propertyAlias must be provided.</p>
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#format_settings ⇒ Types::FormatSettings
<p>The optional format settings for the output.</p>.
-
#property_alias ⇒ String
<p>The customer-friendly alias for the timeseries.
-
#time_series_id ⇒ String
<p>The unique identifier for the timeseries.
-
#trim_settings ⇒ Types::TrimSettings
<p>The trim settings for the time range to export.
Instance Attribute Details
#format_settings ⇒ Types::FormatSettings
<p>The optional format settings for the output.</p>
14022 14023 14024 14025 14026 14027 14028 14029 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 14022 class TimeseriesItem < Struct.new( :time_series_id, :property_alias, :trim_settings, :format_settings) SENSITIVE = [] include Aws::Structure end |
#property_alias ⇒ String
<p>The customer-friendly alias for the timeseries. Mutually exclusive with timeSeriesId.</p>
14022 14023 14024 14025 14026 14027 14028 14029 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 14022 class TimeseriesItem < Struct.new( :time_series_id, :property_alias, :trim_settings, :format_settings) SENSITIVE = [] include Aws::Structure end |
#time_series_id ⇒ String
<p>The unique identifier for the timeseries. Mutually exclusive with propertyAlias.</p>
14022 14023 14024 14025 14026 14027 14028 14029 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 14022 class TimeseriesItem < Struct.new( :time_series_id, :property_alias, :trim_settings, :format_settings) SENSITIVE = [] include Aws::Structure end |
#trim_settings ⇒ Types::TrimSettings
<p>The trim settings for the time range to export. Required for VIDEO and TELEMETRY data types; optional for ANNOTATION data types.</p>
14022 14023 14024 14025 14026 14027 14028 14029 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 14022 class TimeseriesItem < Struct.new( :time_series_id, :property_alias, :trim_settings, :format_settings) SENSITIVE = [] include Aws::Structure end |