Class: Aws::IoTSiteWise::Types::TransformProcessingConfig

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotsitewise/types.rb

Overview

The processing configuration for the given transform property. You can configure transforms to be kept at the edge or forwarded to the Amazon Web Services Cloud. You can also configure transforms to be computed at the edge or in the cloud.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#compute_locationString

The compute location for the given transform property.

Returns:

  • (String)


14266
14267
14268
14269
14270
14271
# File 'lib/aws-sdk-iotsitewise/types.rb', line 14266

class TransformProcessingConfig < Struct.new(
  :compute_location,
  :forwarding_config)
  SENSITIVE = []
  include Aws::Structure
end

#forwarding_configTypes::ForwardingConfig

The forwarding configuration for a given property.



14266
14267
14268
14269
14270
14271
# File 'lib/aws-sdk-iotsitewise/types.rb', line 14266

class TransformProcessingConfig < Struct.new(
  :compute_location,
  :forwarding_config)
  SENSITIVE = []
  include Aws::Structure
end