Class: Aws::IoTSiteWise::Types::UpdateAccessPolicyRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTSiteWise::Types::UpdateAccessPolicyRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotsitewise/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#access_policy_id ⇒ String
The ID of the access policy.
-
#access_policy_identity ⇒ Types::Identity
The identity for this access policy.
-
#access_policy_permission ⇒ String
The permission level for this access policy.
-
#access_policy_resource ⇒ Types::Resource
The IoT SiteWise Monitor resource for this access policy.
-
#client_token ⇒ String
A unique case-sensitive identifier that you can provide to ensure the idempotency of the request.
Instance Attribute Details
#access_policy_id ⇒ String
The ID of the access policy.
14301 14302 14303 14304 14305 14306 14307 14308 14309 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 14301 class UpdateAccessPolicyRequest < Struct.new( :access_policy_id, :access_policy_identity, :access_policy_resource, :access_policy_permission, :client_token) SENSITIVE = [] include Aws::Structure end |
#access_policy_identity ⇒ Types::Identity
The identity for this access policy. Choose an IAM Identity Center user, an IAM Identity Center group, or an IAM user.
14301 14302 14303 14304 14305 14306 14307 14308 14309 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 14301 class UpdateAccessPolicyRequest < Struct.new( :access_policy_id, :access_policy_identity, :access_policy_resource, :access_policy_permission, :client_token) SENSITIVE = [] include Aws::Structure end |
#access_policy_permission ⇒ String
The permission level for this access policy. Note that a project
ADMINISTRATOR is also known as a project owner.
14301 14302 14303 14304 14305 14306 14307 14308 14309 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 14301 class UpdateAccessPolicyRequest < Struct.new( :access_policy_id, :access_policy_identity, :access_policy_resource, :access_policy_permission, :client_token) SENSITIVE = [] include Aws::Structure end |
#access_policy_resource ⇒ Types::Resource
The IoT SiteWise Monitor resource for this access policy. Choose either a portal or a project.
14301 14302 14303 14304 14305 14306 14307 14308 14309 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 14301 class UpdateAccessPolicyRequest < Struct.new( :access_policy_id, :access_policy_identity, :access_policy_resource, :access_policy_permission, :client_token) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
A unique case-sensitive identifier that you can provide to ensure the idempotency of the request. Don't reuse this client token if a new idempotent request is required.
A suitable default value is auto-generated. You should normally not need to pass this option.
14301 14302 14303 14304 14305 14306 14307 14308 14309 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 14301 class UpdateAccessPolicyRequest < Struct.new( :access_policy_id, :access_policy_identity, :access_policy_resource, :access_policy_permission, :client_token) SENSITIVE = [] include Aws::Structure end |