Class: Aws::IoTSiteWise::Types::UpdateAssetModelCompositeModelRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTSiteWise::Types::UpdateAssetModelCompositeModelRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotsitewise/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#asset_model_composite_model_description ⇒ String
A description for the composite model.
-
#asset_model_composite_model_external_id ⇒ String
An external ID to assign to the asset model.
-
#asset_model_composite_model_id ⇒ String
The ID of a composite model on this asset model.
-
#asset_model_composite_model_name ⇒ String
A unique name for the composite model.
-
#asset_model_composite_model_properties ⇒ Array<Types::AssetModelProperty>
The property definitions of the composite model.
-
#asset_model_id ⇒ String
The ID of the asset model, in UUID format.
-
#client_token ⇒ String
A unique case-sensitive identifier that you can provide to ensure the idempotency of the request.
-
#if_match ⇒ String
The expected current entity tag (ETag) for the asset model’s latest or active version (specified using
matchForVersionType). -
#if_none_match ⇒ String
Accepts ***** to reject the update request if an active version (specified using
matchForVersionTypeasACTIVE) already exists for the asset model. -
#match_for_version_type ⇒ String
Specifies the asset model version type (
LATESTorACTIVE) used in conjunction withIf-MatchorIf-None-Matchheaders to determine the target ETag for the update operation.
Instance Attribute Details
#asset_model_composite_model_description ⇒ String
A description for the composite model.
14383 14384 14385 14386 14387 14388 14389 14390 14391 14392 14393 14394 14395 14396 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 14383 class UpdateAssetModelCompositeModelRequest < Struct.new( :asset_model_id, :asset_model_composite_model_id, :asset_model_composite_model_external_id, :asset_model_composite_model_description, :asset_model_composite_model_name, :client_token, :asset_model_composite_model_properties, :if_match, :if_none_match, :match_for_version_type) SENSITIVE = [] include Aws::Structure end |
#asset_model_composite_model_external_id ⇒ String
An external ID to assign to the asset model. You can only set the external ID of the asset model if it wasn't set when it was created, or you're setting it to the exact same thing as when it was created.
14383 14384 14385 14386 14387 14388 14389 14390 14391 14392 14393 14394 14395 14396 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 14383 class UpdateAssetModelCompositeModelRequest < Struct.new( :asset_model_id, :asset_model_composite_model_id, :asset_model_composite_model_external_id, :asset_model_composite_model_description, :asset_model_composite_model_name, :client_token, :asset_model_composite_model_properties, :if_match, :if_none_match, :match_for_version_type) SENSITIVE = [] include Aws::Structure end |
#asset_model_composite_model_id ⇒ String
The ID of a composite model on this asset model.
14383 14384 14385 14386 14387 14388 14389 14390 14391 14392 14393 14394 14395 14396 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 14383 class UpdateAssetModelCompositeModelRequest < Struct.new( :asset_model_id, :asset_model_composite_model_id, :asset_model_composite_model_external_id, :asset_model_composite_model_description, :asset_model_composite_model_name, :client_token, :asset_model_composite_model_properties, :if_match, :if_none_match, :match_for_version_type) SENSITIVE = [] include Aws::Structure end |
#asset_model_composite_model_name ⇒ String
A unique name for the composite model.
14383 14384 14385 14386 14387 14388 14389 14390 14391 14392 14393 14394 14395 14396 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 14383 class UpdateAssetModelCompositeModelRequest < Struct.new( :asset_model_id, :asset_model_composite_model_id, :asset_model_composite_model_external_id, :asset_model_composite_model_description, :asset_model_composite_model_name, :client_token, :asset_model_composite_model_properties, :if_match, :if_none_match, :match_for_version_type) SENSITIVE = [] include Aws::Structure end |
#asset_model_composite_model_properties ⇒ Array<Types::AssetModelProperty>
The property definitions of the composite model. For more information, see Inline custom composite models in the IoT SiteWise User Guide.
You can specify up to 200 properties per composite model. For more information, see Quotas in the IoT SiteWise User Guide.
14383 14384 14385 14386 14387 14388 14389 14390 14391 14392 14393 14394 14395 14396 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 14383 class UpdateAssetModelCompositeModelRequest < Struct.new( :asset_model_id, :asset_model_composite_model_id, :asset_model_composite_model_external_id, :asset_model_composite_model_description, :asset_model_composite_model_name, :client_token, :asset_model_composite_model_properties, :if_match, :if_none_match, :match_for_version_type) SENSITIVE = [] include Aws::Structure end |
#asset_model_id ⇒ String
The ID of the asset model, in UUID format.
14383 14384 14385 14386 14387 14388 14389 14390 14391 14392 14393 14394 14395 14396 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 14383 class UpdateAssetModelCompositeModelRequest < Struct.new( :asset_model_id, :asset_model_composite_model_id, :asset_model_composite_model_external_id, :asset_model_composite_model_description, :asset_model_composite_model_name, :client_token, :asset_model_composite_model_properties, :if_match, :if_none_match, :match_for_version_type) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
A unique case-sensitive identifier that you can provide to ensure the idempotency of the request. Don't reuse this client token if a new idempotent request is required.
A suitable default value is auto-generated. You should normally not need to pass this option.
14383 14384 14385 14386 14387 14388 14389 14390 14391 14392 14393 14394 14395 14396 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 14383 class UpdateAssetModelCompositeModelRequest < Struct.new( :asset_model_id, :asset_model_composite_model_id, :asset_model_composite_model_external_id, :asset_model_composite_model_description, :asset_model_composite_model_name, :client_token, :asset_model_composite_model_properties, :if_match, :if_none_match, :match_for_version_type) SENSITIVE = [] include Aws::Structure end |
#if_match ⇒ String
The expected current entity tag (ETag) for the asset model’s latest
or active version (specified using matchForVersionType). The
update request is rejected if the tag does not match the latest or
active version's current entity tag. See Optimistic locking for
asset model writes in the IoT SiteWise User Guide.
14383 14384 14385 14386 14387 14388 14389 14390 14391 14392 14393 14394 14395 14396 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 14383 class UpdateAssetModelCompositeModelRequest < Struct.new( :asset_model_id, :asset_model_composite_model_id, :asset_model_composite_model_external_id, :asset_model_composite_model_description, :asset_model_composite_model_name, :client_token, :asset_model_composite_model_properties, :if_match, :if_none_match, :match_for_version_type) SENSITIVE = [] include Aws::Structure end |
#if_none_match ⇒ String
Accepts ***** to reject the update request if an active version
(specified using matchForVersionType as ACTIVE) already exists
for the asset model.
14383 14384 14385 14386 14387 14388 14389 14390 14391 14392 14393 14394 14395 14396 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 14383 class UpdateAssetModelCompositeModelRequest < Struct.new( :asset_model_id, :asset_model_composite_model_id, :asset_model_composite_model_external_id, :asset_model_composite_model_description, :asset_model_composite_model_name, :client_token, :asset_model_composite_model_properties, :if_match, :if_none_match, :match_for_version_type) SENSITIVE = [] include Aws::Structure end |
#match_for_version_type ⇒ String
Specifies the asset model version type (LATEST or ACTIVE) used
in conjunction with If-Match or If-None-Match headers to
determine the target ETag for the update operation.
14383 14384 14385 14386 14387 14388 14389 14390 14391 14392 14393 14394 14395 14396 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 14383 class UpdateAssetModelCompositeModelRequest < Struct.new( :asset_model_id, :asset_model_composite_model_id, :asset_model_composite_model_external_id, :asset_model_composite_model_description, :asset_model_composite_model_name, :client_token, :asset_model_composite_model_properties, :if_match, :if_none_match, :match_for_version_type) SENSITIVE = [] include Aws::Structure end |