Class: Aws::IoTSiteWise::Types::UpdateAssetModelCompositeModelResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotsitewise/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#asset_model_composite_model_pathArray<Types::AssetModelCompositeModelPathSegment>

The path to the composite model listing the parent composite models.



14416
14417
14418
14419
14420
14421
14422
# File 'lib/aws-sdk-iotsitewise/types.rb', line 14416

class UpdateAssetModelCompositeModelResponse < Struct.new(
  :asset_model_composite_model_path,
  :asset_model_status,
  :asset_model_id)
  SENSITIVE = []
  include Aws::Structure
end

#asset_model_idString

The ID of the asset model.

Returns:

  • (String)


14416
14417
14418
14419
14420
14421
14422
# File 'lib/aws-sdk-iotsitewise/types.rb', line 14416

class UpdateAssetModelCompositeModelResponse < Struct.new(
  :asset_model_composite_model_path,
  :asset_model_status,
  :asset_model_id)
  SENSITIVE = []
  include Aws::Structure
end

#asset_model_statusTypes::AssetModelStatus

Contains current status information for an asset model. For more information, see Asset and model states in the IoT SiteWise User Guide.



14416
14417
14418
14419
14420
14421
14422
# File 'lib/aws-sdk-iotsitewise/types.rb', line 14416

class UpdateAssetModelCompositeModelResponse < Struct.new(
  :asset_model_composite_model_path,
  :asset_model_status,
  :asset_model_id)
  SENSITIVE = []
  include Aws::Structure
end