Class: Aws::IoTSiteWise::Types::UpdateAssetModelResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTSiteWise::Types::UpdateAssetModelResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotsitewise/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#asset_model_id ⇒ String
The ID of the asset model.
-
#asset_model_status ⇒ Types::AssetModelStatus
The status of the asset model, which contains a state (
UPDATINGafter successfully calling this operation) and any error message.
Instance Attribute Details
#asset_model_id ⇒ String
The ID of the asset model.
14562 14563 14564 14565 14566 14567 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 14562 class UpdateAssetModelResponse < Struct.new( :asset_model_id, :asset_model_status) SENSITIVE = [] include Aws::Structure end |
#asset_model_status ⇒ Types::AssetModelStatus
The status of the asset model, which contains a state (UPDATING
after successfully calling this operation) and any error message.
14562 14563 14564 14565 14566 14567 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 14562 class UpdateAssetModelResponse < Struct.new( :asset_model_id, :asset_model_status) SENSITIVE = [] include Aws::Structure end |