Class: Aws::IoTSiteWise::Types::UpdateAssetResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTSiteWise::Types::UpdateAssetResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotsitewise/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#asset_id ⇒ String
The ID of the asset.
-
#asset_status ⇒ Types::AssetStatus
The status of the asset, which contains a state (
UPDATINGafter successfully calling this operation) and any error message.
Instance Attribute Details
#asset_id ⇒ String
The ID of the asset.
14704 14705 14706 14707 14708 14709 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 14704 class UpdateAssetResponse < Struct.new( :asset_id, :asset_status) SENSITIVE = [] include Aws::Structure end |
#asset_status ⇒ Types::AssetStatus
The status of the asset, which contains a state (UPDATING after
successfully calling this operation) and any error message.
14704 14705 14706 14707 14708 14709 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 14704 class UpdateAssetResponse < Struct.new( :asset_id, :asset_status) SENSITIVE = [] include Aws::Structure end |