Class: Aws::IoTSiteWise::Types::UpdateDatasetRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotsitewise/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique case-sensitive identifier that you can provide to ensure the idempotency of the request. Don't reuse this client token if a new idempotent request is required.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


14850
14851
14852
14853
14854
14855
14856
14857
14858
14859
14860
14861
# File 'lib/aws-sdk-iotsitewise/types.rb', line 14850

class UpdateDatasetRequest < Struct.new(
  :dataset_id,
  :workspace_name,
  :dataset_name,
  :dataset_description,
  :dataset_config,
  :metadata,
  :dataset_source,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#dataset_configTypes::DatasetConfig

The updated configuration for the dataset.



14850
14851
14852
14853
14854
14855
14856
14857
14858
14859
14860
14861
# File 'lib/aws-sdk-iotsitewise/types.rb', line 14850

class UpdateDatasetRequest < Struct.new(
  :dataset_id,
  :workspace_name,
  :dataset_name,
  :dataset_description,
  :dataset_config,
  :metadata,
  :dataset_source,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#dataset_descriptionString

A description about the dataset, and its functionality.

Returns:

  • (String)


14850
14851
14852
14853
14854
14855
14856
14857
14858
14859
14860
14861
# File 'lib/aws-sdk-iotsitewise/types.rb', line 14850

class UpdateDatasetRequest < Struct.new(
  :dataset_id,
  :workspace_name,
  :dataset_name,
  :dataset_description,
  :dataset_config,
  :metadata,
  :dataset_source,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#dataset_idString

The ID of the dataset.

Returns:

  • (String)


14850
14851
14852
14853
14854
14855
14856
14857
14858
14859
14860
14861
# File 'lib/aws-sdk-iotsitewise/types.rb', line 14850

class UpdateDatasetRequest < Struct.new(
  :dataset_id,
  :workspace_name,
  :dataset_name,
  :dataset_description,
  :dataset_config,
  :metadata,
  :dataset_source,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#dataset_nameString

The name of the dataset.

Returns:

  • (String)


14850
14851
14852
14853
14854
14855
14856
14857
14858
14859
14860
14861
# File 'lib/aws-sdk-iotsitewise/types.rb', line 14850

class UpdateDatasetRequest < Struct.new(
  :dataset_id,
  :workspace_name,
  :dataset_name,
  :dataset_description,
  :dataset_config,
  :metadata,
  :dataset_source,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#dataset_sourceTypes::DatasetSource

The data source for the dataset.



14850
14851
14852
14853
14854
14855
14856
14857
14858
14859
14860
14861
# File 'lib/aws-sdk-iotsitewise/types.rb', line 14850

class UpdateDatasetRequest < Struct.new(
  :dataset_id,
  :workspace_name,
  :dataset_name,
  :dataset_description,
  :dataset_config,
  :metadata,
  :dataset_source,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#metadataHash<String,String>

The updated metadata for the dataset.

Returns:

  • (Hash<String,String>)


14850
14851
14852
14853
14854
14855
14856
14857
14858
14859
14860
14861
# File 'lib/aws-sdk-iotsitewise/types.rb', line 14850

class UpdateDatasetRequest < Struct.new(
  :dataset_id,
  :workspace_name,
  :dataset_name,
  :dataset_description,
  :dataset_config,
  :metadata,
  :dataset_source,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#workspace_nameString

The name of the workspace that contains the dataset.

Returns:

  • (String)


14850
14851
14852
14853
14854
14855
14856
14857
14858
14859
14860
14861
# File 'lib/aws-sdk-iotsitewise/types.rb', line 14850

class UpdateDatasetRequest < Struct.new(
  :dataset_id,
  :workspace_name,
  :dataset_name,
  :dataset_description,
  :dataset_config,
  :metadata,
  :dataset_source,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end