Class: Aws::IoTSiteWise::Types::UpdateGatewayCapabilityConfigurationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTSiteWise::Types::UpdateGatewayCapabilityConfigurationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotsitewise/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#capability_configuration ⇒ String
The JSON document that defines the configuration for the gateway capability.
-
#capability_namespace ⇒ String
The namespace of the gateway capability configuration to be updated.
-
#gateway_id ⇒ String
The ID of the gateway to be updated.
Instance Attribute Details
#capability_configuration ⇒ String
The JSON document that defines the configuration for the gateway capability. For more information, see Configuring data sources (CLI) in the IoT SiteWise User Guide.
14912 14913 14914 14915 14916 14917 14918 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 14912 class UpdateGatewayCapabilityConfigurationRequest < Struct.new( :gateway_id, :capability_namespace, :capability_configuration) SENSITIVE = [] include Aws::Structure end |
#capability_namespace ⇒ String
The namespace of the gateway capability configuration to be updated.
For example, if you configure OPC UA sources for an MQTT-enabled
gateway, your OPC-UA capability configuration has the namespace
iotsitewise:opcuacollector:3.
14912 14913 14914 14915 14916 14917 14918 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 14912 class UpdateGatewayCapabilityConfigurationRequest < Struct.new( :gateway_id, :capability_namespace, :capability_configuration) SENSITIVE = [] include Aws::Structure end |
#gateway_id ⇒ String
The ID of the gateway to be updated.
14912 14913 14914 14915 14916 14917 14918 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 14912 class UpdateGatewayCapabilityConfigurationRequest < Struct.new( :gateway_id, :capability_namespace, :capability_configuration) SENSITIVE = [] include Aws::Structure end |