Class: Aws::IoTSiteWise::Types::UpdatePipelineRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTSiteWise::Types::UpdatePipelineRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotsitewise/types.rb
Overview
Request structure for UpdatePipeline operation.
Constant Summary collapse
- SENSITIVE =
[:environment_variables]
Instance Attribute Summary collapse
-
#computations ⇒ Array<Types::ComputeNode>
Updated list of compute nodes forming the pipeline DAG.
-
#description ⇒ String
A new description for the pipeline.
-
#environment_variables ⇒ Hash<String,String>
Updated environment variables shared across all compute nodes.
-
#pipeline_name ⇒ String
The name of the pipeline to update.
-
#workspace_name ⇒ String
The name of the workspace.
Instance Attribute Details
#computations ⇒ Array<Types::ComputeNode>
Updated list of compute nodes forming the pipeline DAG.
14990 14991 14992 14993 14994 14995 14996 14997 14998 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 14990 class UpdatePipelineRequest < Struct.new( :workspace_name, :pipeline_name, :description, :environment_variables, :computations) SENSITIVE = [:environment_variables] include Aws::Structure end |
#description ⇒ String
A new description for the pipeline.
14990 14991 14992 14993 14994 14995 14996 14997 14998 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 14990 class UpdatePipelineRequest < Struct.new( :workspace_name, :pipeline_name, :description, :environment_variables, :computations) SENSITIVE = [:environment_variables] include Aws::Structure end |
#environment_variables ⇒ Hash<String,String>
Updated environment variables shared across all compute nodes.
14990 14991 14992 14993 14994 14995 14996 14997 14998 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 14990 class UpdatePipelineRequest < Struct.new( :workspace_name, :pipeline_name, :description, :environment_variables, :computations) SENSITIVE = [:environment_variables] include Aws::Structure end |
#pipeline_name ⇒ String
The name of the pipeline to update.
14990 14991 14992 14993 14994 14995 14996 14997 14998 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 14990 class UpdatePipelineRequest < Struct.new( :workspace_name, :pipeline_name, :description, :environment_variables, :computations) SENSITIVE = [:environment_variables] include Aws::Structure end |
#workspace_name ⇒ String
The name of the workspace.
14990 14991 14992 14993 14994 14995 14996 14997 14998 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 14990 class UpdatePipelineRequest < Struct.new( :workspace_name, :pipeline_name, :description, :environment_variables, :computations) SENSITIVE = [:environment_variables] include Aws::Structure end |