Class: Aws::IoTSiteWise::Types::UpdatePortalRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTSiteWise::Types::UpdatePortalRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotsitewise/types.rb
Constant Summary collapse
- SENSITIVE =
[:portal_contact_email, :notification_sender_email]
Instance Attribute Summary collapse
-
#alarms ⇒ Types::Alarms
Contains the configuration information of an alarm created in an IoT SiteWise Monitor portal.
-
#client_token ⇒ String
A unique case-sensitive identifier that you can provide to ensure the idempotency of the request.
-
#notification_sender_email ⇒ String
The email address that sends alarm notifications.
-
#portal_contact_email ⇒ String
The Amazon Web Services administrator's contact email address.
-
#portal_description ⇒ String
A new description for the portal.
-
#portal_id ⇒ String
The ID of the portal to update.
-
#portal_logo_image ⇒ Types::Image
Contains an image that is one of the following:.
-
#portal_name ⇒ String
A new friendly name for the portal.
-
#portal_type ⇒ String
Define the type of portal.
-
#portal_type_configuration ⇒ Hash<String,Types::PortalTypeEntry>
The configuration entry associated with the specific portal type.
-
#role_arn ⇒ String
The [ARN][1] of a service role that allows the portal's users to access your IoT SiteWise resources on your behalf.
Instance Attribute Details
#alarms ⇒ Types::Alarms
Contains the configuration information of an alarm created in an IoT SiteWise Monitor portal. You can use the alarm to monitor an asset property and get notified when the asset property value is outside a specified range. For more information, see Monitoring with alarms in the IoT SiteWise Application Guide.
15092 15093 15094 15095 15096 15097 15098 15099 15100 15101 15102 15103 15104 15105 15106 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 15092 class UpdatePortalRequest < Struct.new( :portal_id, :portal_name, :portal_description, :portal_contact_email, :portal_logo_image, :role_arn, :client_token, :notification_sender_email, :alarms, :portal_type, :portal_type_configuration) SENSITIVE = [:portal_contact_email, :notification_sender_email] include Aws::Structure end |
#client_token ⇒ String
A unique case-sensitive identifier that you can provide to ensure the idempotency of the request. Don't reuse this client token if a new idempotent request is required.
A suitable default value is auto-generated. You should normally not need to pass this option.
15092 15093 15094 15095 15096 15097 15098 15099 15100 15101 15102 15103 15104 15105 15106 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 15092 class UpdatePortalRequest < Struct.new( :portal_id, :portal_name, :portal_description, :portal_contact_email, :portal_logo_image, :role_arn, :client_token, :notification_sender_email, :alarms, :portal_type, :portal_type_configuration) SENSITIVE = [:portal_contact_email, :notification_sender_email] include Aws::Structure end |
#notification_sender_email ⇒ String
The email address that sends alarm notifications.
15092 15093 15094 15095 15096 15097 15098 15099 15100 15101 15102 15103 15104 15105 15106 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 15092 class UpdatePortalRequest < Struct.new( :portal_id, :portal_name, :portal_description, :portal_contact_email, :portal_logo_image, :role_arn, :client_token, :notification_sender_email, :alarms, :portal_type, :portal_type_configuration) SENSITIVE = [:portal_contact_email, :notification_sender_email] include Aws::Structure end |
#portal_contact_email ⇒ String
The Amazon Web Services administrator's contact email address.
15092 15093 15094 15095 15096 15097 15098 15099 15100 15101 15102 15103 15104 15105 15106 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 15092 class UpdatePortalRequest < Struct.new( :portal_id, :portal_name, :portal_description, :portal_contact_email, :portal_logo_image, :role_arn, :client_token, :notification_sender_email, :alarms, :portal_type, :portal_type_configuration) SENSITIVE = [:portal_contact_email, :notification_sender_email] include Aws::Structure end |
#portal_description ⇒ String
A new description for the portal.
15092 15093 15094 15095 15096 15097 15098 15099 15100 15101 15102 15103 15104 15105 15106 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 15092 class UpdatePortalRequest < Struct.new( :portal_id, :portal_name, :portal_description, :portal_contact_email, :portal_logo_image, :role_arn, :client_token, :notification_sender_email, :alarms, :portal_type, :portal_type_configuration) SENSITIVE = [:portal_contact_email, :notification_sender_email] include Aws::Structure end |
#portal_id ⇒ String
The ID of the portal to update.
15092 15093 15094 15095 15096 15097 15098 15099 15100 15101 15102 15103 15104 15105 15106 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 15092 class UpdatePortalRequest < Struct.new( :portal_id, :portal_name, :portal_description, :portal_contact_email, :portal_logo_image, :role_arn, :client_token, :notification_sender_email, :alarms, :portal_type, :portal_type_configuration) SENSITIVE = [:portal_contact_email, :notification_sender_email] include Aws::Structure end |
#portal_logo_image ⇒ Types::Image
Contains an image that is one of the following:
-
An image file. Choose this option to upload a new image.
-
The ID of an existing image. Choose this option to keep an existing image.
15092 15093 15094 15095 15096 15097 15098 15099 15100 15101 15102 15103 15104 15105 15106 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 15092 class UpdatePortalRequest < Struct.new( :portal_id, :portal_name, :portal_description, :portal_contact_email, :portal_logo_image, :role_arn, :client_token, :notification_sender_email, :alarms, :portal_type, :portal_type_configuration) SENSITIVE = [:portal_contact_email, :notification_sender_email] include Aws::Structure end |
#portal_name ⇒ String
A new friendly name for the portal.
15092 15093 15094 15095 15096 15097 15098 15099 15100 15101 15102 15103 15104 15105 15106 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 15092 class UpdatePortalRequest < Struct.new( :portal_id, :portal_name, :portal_description, :portal_contact_email, :portal_logo_image, :role_arn, :client_token, :notification_sender_email, :alarms, :portal_type, :portal_type_configuration) SENSITIVE = [:portal_contact_email, :notification_sender_email] include Aws::Structure end |
#portal_type ⇒ String
Define the type of portal. The value for IoT SiteWise Monitor
(Classic) is SITEWISE_PORTAL_V1. The value for IoT SiteWise
Monitor (AI-aware) is SITEWISE_PORTAL_V2.
15092 15093 15094 15095 15096 15097 15098 15099 15100 15101 15102 15103 15104 15105 15106 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 15092 class UpdatePortalRequest < Struct.new( :portal_id, :portal_name, :portal_description, :portal_contact_email, :portal_logo_image, :role_arn, :client_token, :notification_sender_email, :alarms, :portal_type, :portal_type_configuration) SENSITIVE = [:portal_contact_email, :notification_sender_email] include Aws::Structure end |
#portal_type_configuration ⇒ Hash<String,Types::PortalTypeEntry>
The configuration entry associated with the specific portal type.
The value for IoT SiteWise Monitor (Classic) is
SITEWISE_PORTAL_V1. The value for IoT SiteWise Monitor (AI-aware)
is SITEWISE_PORTAL_V2.
15092 15093 15094 15095 15096 15097 15098 15099 15100 15101 15102 15103 15104 15105 15106 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 15092 class UpdatePortalRequest < Struct.new( :portal_id, :portal_name, :portal_description, :portal_contact_email, :portal_logo_image, :role_arn, :client_token, :notification_sender_email, :alarms, :portal_type, :portal_type_configuration) SENSITIVE = [:portal_contact_email, :notification_sender_email] include Aws::Structure end |
#role_arn ⇒ String
The ARN of a service role that allows the portal's users to access your IoT SiteWise resources on your behalf. For more information, see Using service roles for IoT SiteWise Monitor in the IoT SiteWise User Guide.
15092 15093 15094 15095 15096 15097 15098 15099 15100 15101 15102 15103 15104 15105 15106 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 15092 class UpdatePortalRequest < Struct.new( :portal_id, :portal_name, :portal_description, :portal_contact_email, :portal_logo_image, :role_arn, :client_token, :notification_sender_email, :alarms, :portal_type, :portal_type_configuration) SENSITIVE = [:portal_contact_email, :notification_sender_email] include Aws::Structure end |