Class: Aws::IoTSiteWise::Types::UpdateWorkspaceRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotsitewise/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique, case-sensitive identifier that you provide to ensure that the request is idempotent. If you retry a request that completed successfully using the same client token, the retry succeeds without performing any further actions.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


15220
15221
15222
15223
15224
15225
15226
15227
# File 'lib/aws-sdk-iotsitewise/types.rb', line 15220

class UpdateWorkspaceRequest < Struct.new(
  :workspace_name,
  :workspace_description,
  :encryption_configuration,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#encryption_configurationTypes::WorkspaceEncryptionConfiguration

The encryption configuration for the workspace. Omit this field to leave encryption unchanged. After a customer managed key configuration becomes active, the key can't be changed; supplying the same key is accepted.



15220
15221
15222
15223
15224
15225
15226
15227
# File 'lib/aws-sdk-iotsitewise/types.rb', line 15220

class UpdateWorkspaceRequest < Struct.new(
  :workspace_name,
  :workspace_description,
  :encryption_configuration,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#workspace_descriptionString

A new description for the workspace.

Returns:

  • (String)


15220
15221
15222
15223
15224
15225
15226
15227
# File 'lib/aws-sdk-iotsitewise/types.rb', line 15220

class UpdateWorkspaceRequest < Struct.new(
  :workspace_name,
  :workspace_description,
  :encryption_configuration,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#workspace_nameString

The name of the workspace to update.

Returns:

  • (String)


15220
15221
15222
15223
15224
15225
15226
15227
# File 'lib/aws-sdk-iotsitewise/types.rb', line 15220

class UpdateWorkspaceRequest < Struct.new(
  :workspace_name,
  :workspace_description,
  :encryption_configuration,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end