Class: Aws::IoTSiteWise::Waiters::AssetModelNotExists

Inherits:
Object
  • Object
show all
Defined in:
sig/waiters.rbs,
lib/aws-sdk-iotsitewise/waiters.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(options) ⇒ AssetModelNotExists

Returns a new instance of AssetModelNotExists.

Parameters:

  • options (Hash)

Options Hash (options):

  • :client (required, Client)
  • :max_attempts (Integer) — default: 20
  • :delay (Integer) — default: 3
  • :before_attempt (Proc)
  • :before_wait (Proc)


177
178
# File 'lib/aws-sdk-iotsitewise/waiters.rb', line 177

def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void

Instance Attribute Details

#waiterObject (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



200
201
202
# File 'lib/aws-sdk-iotsitewise/waiters.rb', line 200

def waiter
  @waiter
end

Instance Method Details

#wait(params = {}) ⇒ Types::DescribeAssetModelResponse

Returns a response object which responds to the following methods:

Options Hash (params):

  • :asset_model_id (required, String)

    The ID of the asset model. This can be either the actual ID in UUID format, or else externalId: followed by the external ID, if it has one. For more information, see Referencing objects with external IDs in the IoT SiteWise User Guide.

  • :exclude_properties (Boolean)

    Whether or not to exclude asset model properties from the response.

  • :asset_model_version (String)

    The version alias that specifies the latest or active version of the asset model. The details are returned in the response. The default value is LATEST. See Asset model versions in the IoT SiteWise User Guide.

Returns:



195
# File 'lib/aws-sdk-iotsitewise/waiters.rb', line 195

def wait: (