Class: Aws::IoTSiteWise::Waiters::PortalNotExists
- Inherits:
-
Object
- Object
- Aws::IoTSiteWise::Waiters::PortalNotExists
- Defined in:
- sig/waiters.rbs,
lib/aws-sdk-iotsitewise/waiters.rb
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ PortalNotExists
constructor
A new instance of PortalNotExists.
-
#wait(params = {}) ⇒ Types::DescribePortalResponse
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ PortalNotExists
Returns a new instance of PortalNotExists.
283 284 |
# File 'lib/aws-sdk-iotsitewise/waiters.rb', line 283
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
306 307 308 |
# File 'lib/aws-sdk-iotsitewise/waiters.rb', line 306 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::DescribePortalResponse
Returns a response object which responds to the following methods:
- #portal_id => String
- #portal_arn => String
- #portal_name => String
- #portal_description => String
- #portal_client_id => String
- #portal_start_url => String
- #portal_contact_email => String
- #portal_status => Types::PortalStatus
- #portal_creation_date => Time
- #portal_last_update_date => Time
- #portal_logo_image_location => Types::ImageLocation
- #role_arn => String
- #portal_auth_mode => String
- #notification_sender_email => String
- #alarms => Types::Alarms
- #portal_type => String
- #portal_type_configuration => Hash<String,Types::PortalTypeEntry>
301 |
# File 'lib/aws-sdk-iotsitewise/waiters.rb', line 301
def wait: (
|