Class: Aws::IoTSiteWise::Types::Attribute
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTSiteWise::Types::Attribute
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotsitewise/types.rb
Overview
Contains an asset attribute property. For more information, see Attributes in the IoT SiteWise User Guide.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#default_value ⇒ String
The default value of the asset model property attribute.
Instance Attribute Details
#default_value ⇒ String
The default value of the asset model property attribute. All assets that you create from the asset model contain this attribute value. You can update an attribute's value after you create an asset. For more information, see Updating attribute values in the IoT SiteWise User Guide.
1714 1715 1716 1717 1718 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 1714 class Attribute < Struct.new( :default_value) SENSITIVE = [] include Aws::Structure end |