Class: Aws::IoTSiteWise::Types::BatchGetAssetPropertyValueHistoryResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTSiteWise::Types::BatchGetAssetPropertyValueHistoryResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotsitewise/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#error_entries ⇒ Array<Types::BatchGetAssetPropertyValueHistoryErrorEntry>
A list of the errors (if any) associated with the batch request.
-
#next_token ⇒ String
The token for the next set of results, or null if there are no additional results.
-
#skipped_entries ⇒ Array<Types::BatchGetAssetPropertyValueHistorySkippedEntry>
A list of entries that were not processed by this batch request.
-
#success_entries ⇒ Array<Types::BatchGetAssetPropertyValueHistorySuccessEntry>
A list of entries that were processed successfully by this batch request.
Instance Attribute Details
#error_entries ⇒ Array<Types::BatchGetAssetPropertyValueHistoryErrorEntry>
A list of the errors (if any) associated with the batch request.
Each error entry contains the entryId of the entry that failed.
2213 2214 2215 2216 2217 2218 2219 2220 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 2213 class BatchGetAssetPropertyValueHistoryResponse < Struct.new( :error_entries, :success_entries, :skipped_entries, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results, or null if there are no additional results.
2213 2214 2215 2216 2217 2218 2219 2220 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 2213 class BatchGetAssetPropertyValueHistoryResponse < Struct.new( :error_entries, :success_entries, :skipped_entries, :next_token) SENSITIVE = [] include Aws::Structure end |
#skipped_entries ⇒ Array<Types::BatchGetAssetPropertyValueHistorySkippedEntry>
A list of entries that were not processed by this batch request.
because these entries had been completely processed by previous
paginated requests. Each skipped entry contains the entryId of the
entry that skipped.
2213 2214 2215 2216 2217 2218 2219 2220 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 2213 class BatchGetAssetPropertyValueHistoryResponse < Struct.new( :error_entries, :success_entries, :skipped_entries, :next_token) SENSITIVE = [] include Aws::Structure end |
#success_entries ⇒ Array<Types::BatchGetAssetPropertyValueHistorySuccessEntry>
A list of entries that were processed successfully by this batch
request. Each success entry contains the entryId of the entry that
succeeded and the latest query result.
2213 2214 2215 2216 2217 2218 2219 2220 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 2213 class BatchGetAssetPropertyValueHistoryResponse < Struct.new( :error_entries, :success_entries, :skipped_entries, :next_token) SENSITIVE = [] include Aws::Structure end |