Class: Aws::IoTSiteWise::Types::BatchGetAssetPropertyValueResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTSiteWise::Types::BatchGetAssetPropertyValueResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotsitewise/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#error_entries ⇒ Array<Types::BatchGetAssetPropertyValueErrorEntry>
A list of the errors (if any) associated with the batch request.
-
#next_token ⇒ String
The token for the next set of results, or null if there are no additional results.
-
#skipped_entries ⇒ Array<Types::BatchGetAssetPropertyValueSkippedEntry>
A list of entries that were not processed by this batch request.
-
#success_entries ⇒ Array<Types::BatchGetAssetPropertyValueSuccessEntry>
A list of entries that were processed successfully by this batch request.
Instance Attribute Details
#error_entries ⇒ Array<Types::BatchGetAssetPropertyValueErrorEntry>
A list of the errors (if any) associated with the batch request.
Each error entry contains the entryId of the entry that failed.
2548 2549 2550 2551 2552 2553 2554 2555 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 2548 class BatchGetAssetPropertyValueResponse < Struct.new( :error_entries, :success_entries, :skipped_entries, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results, or null if there are no additional results.
2548 2549 2550 2551 2552 2553 2554 2555 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 2548 class BatchGetAssetPropertyValueResponse < Struct.new( :error_entries, :success_entries, :skipped_entries, :next_token) SENSITIVE = [] include Aws::Structure end |
#skipped_entries ⇒ Array<Types::BatchGetAssetPropertyValueSkippedEntry>
A list of entries that were not processed by this batch request.
because these entries had been completely processed by previous
paginated requests. Each skipped entry contains the entryId of the
entry that skipped.
2548 2549 2550 2551 2552 2553 2554 2555 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 2548 class BatchGetAssetPropertyValueResponse < Struct.new( :error_entries, :success_entries, :skipped_entries, :next_token) SENSITIVE = [] include Aws::Structure end |
#success_entries ⇒ Array<Types::BatchGetAssetPropertyValueSuccessEntry>
A list of entries that were processed successfully by this batch
request. Each success entry contains the entryId of the entry that
succeeded and the latest query result.
2548 2549 2550 2551 2552 2553 2554 2555 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 2548 class BatchGetAssetPropertyValueResponse < Struct.new( :error_entries, :success_entries, :skipped_entries, :next_token) SENSITIVE = [] include Aws::Structure end |