Class: Aws::IoTSiteWise::Types::ComputeNodeExecutionDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTSiteWise::Types::ComputeNodeExecutionDetails
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotsitewise/types.rb
Overview
Contains detailed execution information for a compute node within a pipeline execution.
Constant Summary collapse
- SENSITIVE =
[:execution_environment_variables]
Instance Attribute Summary collapse
-
#compute_node_name ⇒ String
The name of the compute node.
-
#depends_on ⇒ Array<String>
A list of compute node names that this node depends on.
-
#end_time ⇒ Time
The time the compute node execution completed, in Unix epoch time.
-
#execution_environment_variables ⇒ Hash<String,String>
The fully resolved environment variables used for this compute node execution.
-
#start_time ⇒ Time
The time the compute node execution started, in Unix epoch time.
-
#status ⇒ Types::ComputeNodeExecutionStatus
The current execution status of the compute node.
-
#task_arn ⇒ String
The ARN of the task.
-
#task_name ⇒ String
The name of the task executed for this compute node.
-
#task_version ⇒ String
The task version that executed for this compute node.
Instance Attribute Details
#compute_node_name ⇒ String
The name of the compute node.
3187 3188 3189 3190 3191 3192 3193 3194 3195 3196 3197 3198 3199 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 3187 class ComputeNodeExecutionDetails < Struct.new( :compute_node_name, :task_name, :task_arn, :task_version, :depends_on, :status, :start_time, :end_time, :execution_environment_variables) SENSITIVE = [:execution_environment_variables] include Aws::Structure end |
#depends_on ⇒ Array<String>
A list of compute node names that this node depends on.
3187 3188 3189 3190 3191 3192 3193 3194 3195 3196 3197 3198 3199 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 3187 class ComputeNodeExecutionDetails < Struct.new( :compute_node_name, :task_name, :task_arn, :task_version, :depends_on, :status, :start_time, :end_time, :execution_environment_variables) SENSITIVE = [:execution_environment_variables] include Aws::Structure end |
#end_time ⇒ Time
The time the compute node execution completed, in Unix epoch time.
3187 3188 3189 3190 3191 3192 3193 3194 3195 3196 3197 3198 3199 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 3187 class ComputeNodeExecutionDetails < Struct.new( :compute_node_name, :task_name, :task_arn, :task_version, :depends_on, :status, :start_time, :end_time, :execution_environment_variables) SENSITIVE = [:execution_environment_variables] include Aws::Structure end |
#execution_environment_variables ⇒ Hash<String,String>
The fully resolved environment variables used for this compute node execution.
3187 3188 3189 3190 3191 3192 3193 3194 3195 3196 3197 3198 3199 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 3187 class ComputeNodeExecutionDetails < Struct.new( :compute_node_name, :task_name, :task_arn, :task_version, :depends_on, :status, :start_time, :end_time, :execution_environment_variables) SENSITIVE = [:execution_environment_variables] include Aws::Structure end |
#start_time ⇒ Time
The time the compute node execution started, in Unix epoch time.
3187 3188 3189 3190 3191 3192 3193 3194 3195 3196 3197 3198 3199 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 3187 class ComputeNodeExecutionDetails < Struct.new( :compute_node_name, :task_name, :task_arn, :task_version, :depends_on, :status, :start_time, :end_time, :execution_environment_variables) SENSITIVE = [:execution_environment_variables] include Aws::Structure end |
#status ⇒ Types::ComputeNodeExecutionStatus
The current execution status of the compute node.
3187 3188 3189 3190 3191 3192 3193 3194 3195 3196 3197 3198 3199 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 3187 class ComputeNodeExecutionDetails < Struct.new( :compute_node_name, :task_name, :task_arn, :task_version, :depends_on, :status, :start_time, :end_time, :execution_environment_variables) SENSITIVE = [:execution_environment_variables] include Aws::Structure end |
#task_arn ⇒ String
The ARN of the task.
3187 3188 3189 3190 3191 3192 3193 3194 3195 3196 3197 3198 3199 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 3187 class ComputeNodeExecutionDetails < Struct.new( :compute_node_name, :task_name, :task_arn, :task_version, :depends_on, :status, :start_time, :end_time, :execution_environment_variables) SENSITIVE = [:execution_environment_variables] include Aws::Structure end |
#task_name ⇒ String
The name of the task executed for this compute node.
3187 3188 3189 3190 3191 3192 3193 3194 3195 3196 3197 3198 3199 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 3187 class ComputeNodeExecutionDetails < Struct.new( :compute_node_name, :task_name, :task_arn, :task_version, :depends_on, :status, :start_time, :end_time, :execution_environment_variables) SENSITIVE = [:execution_environment_variables] include Aws::Structure end |
#task_version ⇒ String
The task version that executed for this compute node.
3187 3188 3189 3190 3191 3192 3193 3194 3195 3196 3197 3198 3199 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 3187 class ComputeNodeExecutionDetails < Struct.new( :compute_node_name, :task_name, :task_arn, :task_version, :depends_on, :status, :start_time, :end_time, :execution_environment_variables) SENSITIVE = [:execution_environment_variables] include Aws::Structure end |