Class: Aws::IoTSiteWise::Types::ContainerTaskConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTSiteWise::Types::ContainerTaskConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotsitewise/types.rb
Overview
Configuration for a container task, including the container image, IAM role, and compute settings.
Constant Summary collapse
- SENSITIVE =
[:ecr_uri, :task_execution_role, :command, :environment_variables]
Instance Attribute Summary collapse
-
#command ⇒ Array<String>
The command to execute in the container.
-
#ecr_uri ⇒ String
The Amazon ECR image URI for the task container.
-
#environment_variables ⇒ Hash<String,String>
Environment variables passed to the container at runtime.
-
#processing_type ⇒ String
The processing type for compute resources.
-
#processing_unit ⇒ String
The processing unit allocation that determines the vCPU, memory, and GPU resources.
-
#task_execution_role ⇒ String
The ARN of the IAM role that grants the containerized workload permissions to access AWS resources.
-
#timeout_seconds ⇒ Integer
The timeout in seconds for task execution.
Instance Attribute Details
#command ⇒ Array<String>
The command to execute in the container.
3333 3334 3335 3336 3337 3338 3339 3340 3341 3342 3343 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 3333 class ContainerTaskConfiguration < Struct.new( :ecr_uri, :task_execution_role, :processing_type, :processing_unit, :command, :timeout_seconds, :environment_variables) SENSITIVE = [:ecr_uri, :task_execution_role, :command, :environment_variables] include Aws::Structure end |
#ecr_uri ⇒ String
The Amazon ECR image URI for the task container.
3333 3334 3335 3336 3337 3338 3339 3340 3341 3342 3343 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 3333 class ContainerTaskConfiguration < Struct.new( :ecr_uri, :task_execution_role, :processing_type, :processing_unit, :command, :timeout_seconds, :environment_variables) SENSITIVE = [:ecr_uri, :task_execution_role, :command, :environment_variables] include Aws::Structure end |
#environment_variables ⇒ Hash<String,String>
Environment variables passed to the container at runtime.
3333 3334 3335 3336 3337 3338 3339 3340 3341 3342 3343 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 3333 class ContainerTaskConfiguration < Struct.new( :ecr_uri, :task_execution_role, :processing_type, :processing_unit, :command, :timeout_seconds, :environment_variables) SENSITIVE = [:ecr_uri, :task_execution_role, :command, :environment_variables] include Aws::Structure end |
#processing_type ⇒ String
The processing type for compute resources.
3333 3334 3335 3336 3337 3338 3339 3340 3341 3342 3343 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 3333 class ContainerTaskConfiguration < Struct.new( :ecr_uri, :task_execution_role, :processing_type, :processing_unit, :command, :timeout_seconds, :environment_variables) SENSITIVE = [:ecr_uri, :task_execution_role, :command, :environment_variables] include Aws::Structure end |
#processing_unit ⇒ String
The processing unit allocation that determines the vCPU, memory, and GPU resources.
3333 3334 3335 3336 3337 3338 3339 3340 3341 3342 3343 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 3333 class ContainerTaskConfiguration < Struct.new( :ecr_uri, :task_execution_role, :processing_type, :processing_unit, :command, :timeout_seconds, :environment_variables) SENSITIVE = [:ecr_uri, :task_execution_role, :command, :environment_variables] include Aws::Structure end |
#task_execution_role ⇒ String
The ARN of the IAM role that grants the containerized workload permissions to access AWS resources.
3333 3334 3335 3336 3337 3338 3339 3340 3341 3342 3343 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 3333 class ContainerTaskConfiguration < Struct.new( :ecr_uri, :task_execution_role, :processing_type, :processing_unit, :command, :timeout_seconds, :environment_variables) SENSITIVE = [:ecr_uri, :task_execution_role, :command, :environment_variables] include Aws::Structure end |
#timeout_seconds ⇒ Integer
The timeout in seconds for task execution. Default: 3600 (1 hour).
3333 3334 3335 3336 3337 3338 3339 3340 3341 3342 3343 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 3333 class ContainerTaskConfiguration < Struct.new( :ecr_uri, :task_execution_role, :processing_type, :processing_unit, :command, :timeout_seconds, :environment_variables) SENSITIVE = [:ecr_uri, :task_execution_role, :command, :environment_variables] include Aws::Structure end |