Class: Aws::IoTSiteWise::Types::CreateApplicationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTSiteWise::Types::CreateApplicationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotsitewise/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
Unique client token for idempotent request handling.
-
#description ⇒ String
Description of the application.
-
#idc_instance_arn ⇒ String
Identity Center Instance ARN to create the application in.
-
#name ⇒ String
Name of the application.
-
#tags ⇒ Hash<String,String>
A list of key-value pairs that contain metadata for the application.
-
#workspace_name ⇒ String
Name of the workspace to associate with the underlying Application.
Instance Attribute Details
#client_token ⇒ String
Unique client token for idempotent request handling
A suitable default value is auto-generated. You should normally not need to pass this option.
3449 3450 3451 3452 3453 3454 3455 3456 3457 3458 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 3449 class CreateApplicationRequest < Struct.new( :client_token, :idc_instance_arn, :workspace_name, :name, :description, :tags) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
Description of the application
3449 3450 3451 3452 3453 3454 3455 3456 3457 3458 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 3449 class CreateApplicationRequest < Struct.new( :client_token, :idc_instance_arn, :workspace_name, :name, :description, :tags) SENSITIVE = [] include Aws::Structure end |
#idc_instance_arn ⇒ String
Identity Center Instance ARN to create the application in
3449 3450 3451 3452 3453 3454 3455 3456 3457 3458 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 3449 class CreateApplicationRequest < Struct.new( :client_token, :idc_instance_arn, :workspace_name, :name, :description, :tags) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
Name of the application
3449 3450 3451 3452 3453 3454 3455 3456 3457 3458 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 3449 class CreateApplicationRequest < Struct.new( :client_token, :idc_instance_arn, :workspace_name, :name, :description, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
A list of key-value pairs that contain metadata for the application.
3449 3450 3451 3452 3453 3454 3455 3456 3457 3458 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 3449 class CreateApplicationRequest < Struct.new( :client_token, :idc_instance_arn, :workspace_name, :name, :description, :tags) SENSITIVE = [] include Aws::Structure end |
#workspace_name ⇒ String
Name of the workspace to associate with the underlying Application
3449 3450 3451 3452 3453 3454 3455 3456 3457 3458 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 3449 class CreateApplicationRequest < Struct.new( :client_token, :idc_instance_arn, :workspace_name, :name, :description, :tags) SENSITIVE = [] include Aws::Structure end |