Class: Aws::IoTSiteWise::Types::CreateBulkImportJobRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTSiteWise::Types::CreateBulkImportJobRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotsitewise/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#adaptive_ingestion ⇒ Boolean
If set to true, ingest new data into IoT SiteWise storage.
-
#dataset_id ⇒ String
The ID of the session dataset to ingest data into.
-
#delete_files_after_import ⇒ Boolean
If set to true, your data files is deleted from S3, after ingestion into IoT SiteWise storage.
-
#error_report_location ⇒ Types::ErrorReportLocation
The Amazon S3 destination where errors associated with the job creation request are saved.
-
#files ⇒ Array<Types::File>
The files in the specified Amazon S3 bucket that contain your data.
-
#job_configuration ⇒ Types::JobConfiguration
Contains the configuration information of a job, such as the file format used to save data in Amazon S3.
-
#job_name ⇒ String
The unique name that helps identify the job request.
-
#job_role_arn ⇒ String
The [ARN][1] of the IAM role that allows IoT SiteWise to read Amazon S3 data.
-
#workspace_name ⇒ String
The name of the workspace that contains the session dataset.
Instance Attribute Details
#adaptive_ingestion ⇒ Boolean
If set to true, ingest new data into IoT SiteWise storage. Measurements with notifications, metrics and transforms are computed. If set to false, historical data is ingested into IoT SiteWise as is.
3936 3937 3938 3939 3940 3941 3942 3943 3944 3945 3946 3947 3948 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 3936 class CreateBulkImportJobRequest < Struct.new( :job_name, :job_role_arn, :files, :error_report_location, :job_configuration, :adaptive_ingestion, :delete_files_after_import, :dataset_id, :workspace_name) SENSITIVE = [] include Aws::Structure end |
#dataset_id ⇒ String
The ID of the session dataset to ingest data into. Specify this
field, together with workspaceName, to ingest data into a session
dataset in a workspace.
3936 3937 3938 3939 3940 3941 3942 3943 3944 3945 3946 3947 3948 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 3936 class CreateBulkImportJobRequest < Struct.new( :job_name, :job_role_arn, :files, :error_report_location, :job_configuration, :adaptive_ingestion, :delete_files_after_import, :dataset_id, :workspace_name) SENSITIVE = [] include Aws::Structure end |
#delete_files_after_import ⇒ Boolean
If set to true, your data files is deleted from S3, after ingestion into IoT SiteWise storage.
3936 3937 3938 3939 3940 3941 3942 3943 3944 3945 3946 3947 3948 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 3936 class CreateBulkImportJobRequest < Struct.new( :job_name, :job_role_arn, :files, :error_report_location, :job_configuration, :adaptive_ingestion, :delete_files_after_import, :dataset_id, :workspace_name) SENSITIVE = [] include Aws::Structure end |
#error_report_location ⇒ Types::ErrorReportLocation
The Amazon S3 destination where errors associated with the job creation request are saved.
3936 3937 3938 3939 3940 3941 3942 3943 3944 3945 3946 3947 3948 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 3936 class CreateBulkImportJobRequest < Struct.new( :job_name, :job_role_arn, :files, :error_report_location, :job_configuration, :adaptive_ingestion, :delete_files_after_import, :dataset_id, :workspace_name) SENSITIVE = [] include Aws::Structure end |
#files ⇒ Array<Types::File>
The files in the specified Amazon S3 bucket that contain your data. You can specify up to 100 files for each bulk import job. Each file supports the following size limits:
-
Parquet files – Up to 256 MiB.
-
Other file formats – Up to 5 GiB.
3936 3937 3938 3939 3940 3941 3942 3943 3944 3945 3946 3947 3948 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 3936 class CreateBulkImportJobRequest < Struct.new( :job_name, :job_role_arn, :files, :error_report_location, :job_configuration, :adaptive_ingestion, :delete_files_after_import, :dataset_id, :workspace_name) SENSITIVE = [] include Aws::Structure end |
#job_configuration ⇒ Types::JobConfiguration
Contains the configuration information of a job, such as the file format used to save data in Amazon S3.
3936 3937 3938 3939 3940 3941 3942 3943 3944 3945 3946 3947 3948 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 3936 class CreateBulkImportJobRequest < Struct.new( :job_name, :job_role_arn, :files, :error_report_location, :job_configuration, :adaptive_ingestion, :delete_files_after_import, :dataset_id, :workspace_name) SENSITIVE = [] include Aws::Structure end |
#job_name ⇒ String
The unique name that helps identify the job request.
3936 3937 3938 3939 3940 3941 3942 3943 3944 3945 3946 3947 3948 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 3936 class CreateBulkImportJobRequest < Struct.new( :job_name, :job_role_arn, :files, :error_report_location, :job_configuration, :adaptive_ingestion, :delete_files_after_import, :dataset_id, :workspace_name) SENSITIVE = [] include Aws::Structure end |
#job_role_arn ⇒ String
The ARN of the IAM role that allows IoT SiteWise to read Amazon S3 data.
3936 3937 3938 3939 3940 3941 3942 3943 3944 3945 3946 3947 3948 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 3936 class CreateBulkImportJobRequest < Struct.new( :job_name, :job_role_arn, :files, :error_report_location, :job_configuration, :adaptive_ingestion, :delete_files_after_import, :dataset_id, :workspace_name) SENSITIVE = [] include Aws::Structure end |
#workspace_name ⇒ String
The name of the workspace that contains the session dataset. Specify
this field together with datasetId.
3936 3937 3938 3939 3940 3941 3942 3943 3944 3945 3946 3947 3948 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 3936 class CreateBulkImportJobRequest < Struct.new( :job_name, :job_role_arn, :files, :error_report_location, :job_configuration, :adaptive_ingestion, :delete_files_after_import, :dataset_id, :workspace_name) SENSITIVE = [] include Aws::Structure end |