Class: Aws::IoTSiteWise::Types::CreateDatasetExportJobRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTSiteWise::Types::CreateDatasetExportJobRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotsitewise/types.rb
Overview
Request to create a dataset export job.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#destination_s3_uri ⇒ String
The S3 URI where output clips will be written.
-
#error_report_location ⇒ Types::ExportErrorReportLocation
The location where the error report will be written on failure.
-
#input ⇒ Types::ProcessingInput
The processing input source.
-
#workspace_name ⇒ String
The name of the workspace in which to create the dataset export job.
Instance Attribute Details
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. The AWS SDKs and CLI populate this automatically.
A suitable default value is auto-generated. You should normally not need to pass this option.
4171 4172 4173 4174 4175 4176 4177 4178 4179 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 4171 class CreateDatasetExportJobRequest < Struct.new( :workspace_name, :client_token, :destination_s3_uri, :input, :error_report_location) SENSITIVE = [] include Aws::Structure end |
#destination_s3_uri ⇒ String
The S3 URI where output clips will be written.
4171 4172 4173 4174 4175 4176 4177 4178 4179 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 4171 class CreateDatasetExportJobRequest < Struct.new( :workspace_name, :client_token, :destination_s3_uri, :input, :error_report_location) SENSITIVE = [] include Aws::Structure end |
#error_report_location ⇒ Types::ExportErrorReportLocation
The location where the error report will be written on failure.
4171 4172 4173 4174 4175 4176 4177 4178 4179 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 4171 class CreateDatasetExportJobRequest < Struct.new( :workspace_name, :client_token, :destination_s3_uri, :input, :error_report_location) SENSITIVE = [] include Aws::Structure end |
#input ⇒ Types::ProcessingInput
The processing input source.
4171 4172 4173 4174 4175 4176 4177 4178 4179 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 4171 class CreateDatasetExportJobRequest < Struct.new( :workspace_name, :client_token, :destination_s3_uri, :input, :error_report_location) SENSITIVE = [] include Aws::Structure end |
#workspace_name ⇒ String
The name of the workspace in which to create the dataset export job.
4171 4172 4173 4174 4175 4176 4177 4178 4179 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 4171 class CreateDatasetExportJobRequest < Struct.new( :workspace_name, :client_token, :destination_s3_uri, :input, :error_report_location) SENSITIVE = [] include Aws::Structure end |