Class: Aws::IoTSiteWise::Types::CreateDatasetRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTSiteWise::Types::CreateDatasetRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotsitewise/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique case-sensitive identifier that you can provide to ensure the idempotency of the request.
-
#dataset_config ⇒ Types::DatasetConfig
The configuration for the dataset.
-
#dataset_description ⇒ String
A description about the dataset, and its functionality.
-
#dataset_id ⇒ String
The ID of the dataset.
-
#dataset_name ⇒ String
The name of the dataset.
-
#dataset_source ⇒ Types::DatasetSource
The data source for the dataset.
-
#dataset_type ⇒ String
The type of dataset: a session dataset, a curated dataset, or a connection to an external datasource.
-
#metadata ⇒ Hash<String,String>
The metadata for the dataset, provided as key-value pairs.
-
#tags ⇒ Hash<String,String>
A list of key-value pairs that contain metadata for the access policy.
-
#workspace_name ⇒ String
The name of the workspace that contains the dataset.
Instance Attribute Details
#client_token ⇒ String
A unique case-sensitive identifier that you can provide to ensure the idempotency of the request. Don't reuse this client token if a new idempotent request is required.
A suitable default value is auto-generated. You should normally not need to pass this option.
4253 4254 4255 4256 4257 4258 4259 4260 4261 4262 4263 4264 4265 4266 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 4253 class CreateDatasetRequest < Struct.new( :dataset_id, :dataset_name, :dataset_description, :dataset_type, :dataset_config, :workspace_name, :metadata, :dataset_source, :client_token, :tags) SENSITIVE = [] include Aws::Structure end |
#dataset_config ⇒ Types::DatasetConfig
The configuration for the dataset.
4253 4254 4255 4256 4257 4258 4259 4260 4261 4262 4263 4264 4265 4266 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 4253 class CreateDatasetRequest < Struct.new( :dataset_id, :dataset_name, :dataset_description, :dataset_type, :dataset_config, :workspace_name, :metadata, :dataset_source, :client_token, :tags) SENSITIVE = [] include Aws::Structure end |
#dataset_description ⇒ String
A description about the dataset, and its functionality.
4253 4254 4255 4256 4257 4258 4259 4260 4261 4262 4263 4264 4265 4266 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 4253 class CreateDatasetRequest < Struct.new( :dataset_id, :dataset_name, :dataset_description, :dataset_type, :dataset_config, :workspace_name, :metadata, :dataset_source, :client_token, :tags) SENSITIVE = [] include Aws::Structure end |
#dataset_id ⇒ String
The ID of the dataset.
4253 4254 4255 4256 4257 4258 4259 4260 4261 4262 4263 4264 4265 4266 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 4253 class CreateDatasetRequest < Struct.new( :dataset_id, :dataset_name, :dataset_description, :dataset_type, :dataset_config, :workspace_name, :metadata, :dataset_source, :client_token, :tags) SENSITIVE = [] include Aws::Structure end |
#dataset_name ⇒ String
The name of the dataset.
4253 4254 4255 4256 4257 4258 4259 4260 4261 4262 4263 4264 4265 4266 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 4253 class CreateDatasetRequest < Struct.new( :dataset_id, :dataset_name, :dataset_description, :dataset_type, :dataset_config, :workspace_name, :metadata, :dataset_source, :client_token, :tags) SENSITIVE = [] include Aws::Structure end |
#dataset_source ⇒ Types::DatasetSource
The data source for the dataset.
4253 4254 4255 4256 4257 4258 4259 4260 4261 4262 4263 4264 4265 4266 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 4253 class CreateDatasetRequest < Struct.new( :dataset_id, :dataset_name, :dataset_description, :dataset_type, :dataset_config, :workspace_name, :metadata, :dataset_source, :client_token, :tags) SENSITIVE = [] include Aws::Structure end |
#dataset_type ⇒ String
The type of dataset: a session dataset, a curated dataset, or a connection to an external datasource.
4253 4254 4255 4256 4257 4258 4259 4260 4261 4262 4263 4264 4265 4266 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 4253 class CreateDatasetRequest < Struct.new( :dataset_id, :dataset_name, :dataset_description, :dataset_type, :dataset_config, :workspace_name, :metadata, :dataset_source, :client_token, :tags) SENSITIVE = [] include Aws::Structure end |
#metadata ⇒ Hash<String,String>
The metadata for the dataset, provided as key-value pairs.
4253 4254 4255 4256 4257 4258 4259 4260 4261 4262 4263 4264 4265 4266 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 4253 class CreateDatasetRequest < Struct.new( :dataset_id, :dataset_name, :dataset_description, :dataset_type, :dataset_config, :workspace_name, :metadata, :dataset_source, :client_token, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
A list of key-value pairs that contain metadata for the access policy. For more information, see Tagging your IoT SiteWise resources in the IoT SiteWise User Guide.
4253 4254 4255 4256 4257 4258 4259 4260 4261 4262 4263 4264 4265 4266 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 4253 class CreateDatasetRequest < Struct.new( :dataset_id, :dataset_name, :dataset_description, :dataset_type, :dataset_config, :workspace_name, :metadata, :dataset_source, :client_token, :tags) SENSITIVE = [] include Aws::Structure end |
#workspace_name ⇒ String
The name of the workspace that contains the dataset. Required for session and curated datasets. Omit this field for datasets that connect to an external datasource.
4253 4254 4255 4256 4257 4258 4259 4260 4261 4262 4263 4264 4265 4266 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 4253 class CreateDatasetRequest < Struct.new( :dataset_id, :dataset_name, :dataset_description, :dataset_type, :dataset_config, :workspace_name, :metadata, :dataset_source, :client_token, :tags) SENSITIVE = [] include Aws::Structure end |