Class: Aws::IoTSiteWise::Types::CreateEnrichmentJobRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTSiteWise::Types::CreateEnrichmentJobRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotsitewise/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
Optional unique token that makes the operation idempotent.
-
#job_configuration ⇒ Types::EnrichmentJobConfiguration
Configuration defining the type of enrichment analysis to perform and which video data to analyze.
-
#workspace_name ⇒ String
The name of the IoT SiteWise workspace containing the video data to analyze.
Instance Attribute Details
#client_token ⇒ String
Optional unique token that makes the operation idempotent. If you submit the same request with the same token within the idempotency window, the service returns the original job without creating a duplicate. Use a UUID or timestamp-based token for each unique request.
A suitable default value is auto-generated. You should normally not need to pass this option.
4318 4319 4320 4321 4322 4323 4324 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 4318 class CreateEnrichmentJobRequest < Struct.new( :workspace_name, :job_configuration, :client_token) SENSITIVE = [] include Aws::Structure end |
#job_configuration ⇒ Types::EnrichmentJobConfiguration
Configuration defining the type of enrichment analysis to perform and which video data to analyze. Currently supports eventDetection for generating embeddings from video data for semantic search.
4318 4319 4320 4321 4322 4323 4324 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 4318 class CreateEnrichmentJobRequest < Struct.new( :workspace_name, :job_configuration, :client_token) SENSITIVE = [] include Aws::Structure end |
#workspace_name ⇒ String
The name of the IoT SiteWise workspace containing the video data to analyze.
4318 4319 4320 4321 4322 4323 4324 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 4318 class CreateEnrichmentJobRequest < Struct.new( :workspace_name, :job_configuration, :client_token) SENSITIVE = [] include Aws::Structure end |