Class: Aws::IoTSiteWise::Types::CreatePipelineRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTSiteWise::Types::CreatePipelineRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotsitewise/types.rb
Overview
Request structure for CreatePipeline operation.
Constant Summary collapse
- SENSITIVE =
[:environment_variables]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#computations ⇒ Array<Types::ComputeNode>
The list of compute nodes that form the pipeline DAG.
-
#description ⇒ String
A description of the pipeline.
-
#environment_variables ⇒ Hash<String,String>
Environment variables shared across all compute nodes in the pipeline.
-
#pipeline_name ⇒ String
The name of the pipeline to create.
-
#tags ⇒ Hash<String,String>
A list of key-value pairs that contain metadata for the pipeline.
-
#workspace_name ⇒ String
The name of the workspace.
Instance Attribute Details
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If you retry a request that completed successfully using the same client token, the server returns the cached result from the original successful request without performing the operation again.
A suitable default value is auto-generated. You should normally not need to pass this option.
4470 4471 4472 4473 4474 4475 4476 4477 4478 4479 4480 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 4470 class CreatePipelineRequest < Struct.new( :workspace_name, :pipeline_name, :description, :environment_variables, :computations, :tags, :client_token) SENSITIVE = [:environment_variables] include Aws::Structure end |
#computations ⇒ Array<Types::ComputeNode>
The list of compute nodes that form the pipeline DAG. Each compute node references a task and can declare dependencies on other nodes.
4470 4471 4472 4473 4474 4475 4476 4477 4478 4479 4480 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 4470 class CreatePipelineRequest < Struct.new( :workspace_name, :pipeline_name, :description, :environment_variables, :computations, :tags, :client_token) SENSITIVE = [:environment_variables] include Aws::Structure end |
#description ⇒ String
A description of the pipeline.
4470 4471 4472 4473 4474 4475 4476 4477 4478 4479 4480 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 4470 class CreatePipelineRequest < Struct.new( :workspace_name, :pipeline_name, :description, :environment_variables, :computations, :tags, :client_token) SENSITIVE = [:environment_variables] include Aws::Structure end |
#environment_variables ⇒ Hash<String,String>
Environment variables shared across all compute nodes in the pipeline. Individual compute nodes can override these values with their own environment variables.
4470 4471 4472 4473 4474 4475 4476 4477 4478 4479 4480 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 4470 class CreatePipelineRequest < Struct.new( :workspace_name, :pipeline_name, :description, :environment_variables, :computations, :tags, :client_token) SENSITIVE = [:environment_variables] include Aws::Structure end |
#pipeline_name ⇒ String
The name of the pipeline to create. Must be unique within the workspace.
4470 4471 4472 4473 4474 4475 4476 4477 4478 4479 4480 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 4470 class CreatePipelineRequest < Struct.new( :workspace_name, :pipeline_name, :description, :environment_variables, :computations, :tags, :client_token) SENSITIVE = [:environment_variables] include Aws::Structure end |
#tags ⇒ Hash<String,String>
A list of key-value pairs that contain metadata for the pipeline. For more information, see Tagging your AWS IoT SiteWise resources in the AWS IoT SiteWise User Guide.
4470 4471 4472 4473 4474 4475 4476 4477 4478 4479 4480 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 4470 class CreatePipelineRequest < Struct.new( :workspace_name, :pipeline_name, :description, :environment_variables, :computations, :tags, :client_token) SENSITIVE = [:environment_variables] include Aws::Structure end |
#workspace_name ⇒ String
The name of the workspace.
4470 4471 4472 4473 4474 4475 4476 4477 4478 4479 4480 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 4470 class CreatePipelineRequest < Struct.new( :workspace_name, :pipeline_name, :description, :environment_variables, :computations, :tags, :client_token) SENSITIVE = [:environment_variables] include Aws::Structure end |