Class: Aws::IoTSiteWise::Types::CreatePortalResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTSiteWise::Types::CreatePortalResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotsitewise/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#portal_arn ⇒ String
The [ARN][1] of the portal, which has the following format.
-
#portal_id ⇒ String
The ID of the created portal.
-
#portal_start_url ⇒ String
The URL for the IoT SiteWise Monitor portal.
-
#portal_status ⇒ Types::PortalStatus
The status of the portal, which contains a state (
CREATINGafter successfully calling this operation) and any error message. -
#sso_application_id ⇒ String
The associated IAM Identity Center application ID, if the portal uses IAM Identity Center.
Instance Attribute Details
#portal_arn ⇒ String
The ARN of the portal, which has the following format.
arn:${Partition}:iotsitewise:${Region}:${Account}:portal/${PortalId}
4666 4667 4668 4669 4670 4671 4672 4673 4674 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 4666 class CreatePortalResponse < Struct.new( :portal_id, :portal_arn, :portal_start_url, :portal_status, :sso_application_id) SENSITIVE = [] include Aws::Structure end |
#portal_id ⇒ String
The ID of the created portal.
4666 4667 4668 4669 4670 4671 4672 4673 4674 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 4666 class CreatePortalResponse < Struct.new( :portal_id, :portal_arn, :portal_start_url, :portal_status, :sso_application_id) SENSITIVE = [] include Aws::Structure end |
#portal_start_url ⇒ String
The URL for the IoT SiteWise Monitor portal. You can use this URL to access portals that use IAM Identity Center for authentication. For portals that use IAM for authentication, you must use the IoT SiteWise console to get a URL that you can use to access the portal.
4666 4667 4668 4669 4670 4671 4672 4673 4674 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 4666 class CreatePortalResponse < Struct.new( :portal_id, :portal_arn, :portal_start_url, :portal_status, :sso_application_id) SENSITIVE = [] include Aws::Structure end |
#portal_status ⇒ Types::PortalStatus
The status of the portal, which contains a state (CREATING after
successfully calling this operation) and any error message.
4666 4667 4668 4669 4670 4671 4672 4673 4674 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 4666 class CreatePortalResponse < Struct.new( :portal_id, :portal_arn, :portal_start_url, :portal_status, :sso_application_id) SENSITIVE = [] include Aws::Structure end |
#sso_application_id ⇒ String
The associated IAM Identity Center application ID, if the portal uses IAM Identity Center.
4666 4667 4668 4669 4670 4671 4672 4673 4674 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 4666 class CreatePortalResponse < Struct.new( :portal_id, :portal_arn, :portal_start_url, :portal_status, :sso_application_id) SENSITIVE = [] include Aws::Structure end |