Class: Aws::IoTSiteWise::Types::CreateTaskRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTSiteWise::Types::CreateTaskRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotsitewise/types.rb
Overview
Request structure for CreateTask operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#description ⇒ String
A description of the task.
-
#tags ⇒ Hash<String,String>
A list of key-value pairs that contain metadata for the task.
-
#task_configuration ⇒ Types::TaskConfiguration
The task execution configuration.
-
#task_name ⇒ String
The name of the task to create.
-
#workspace_name ⇒ String
The name of the workspace.
Instance Attribute Details
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If you retry a request that completed successfully using the same client token, the server returns the cached result from the original successful request without performing the operation again.
A suitable default value is auto-generated. You should normally not need to pass this option.
4782 4783 4784 4785 4786 4787 4788 4789 4790 4791 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 4782 class CreateTaskRequest < Struct.new( :workspace_name, :task_name, :description, :task_configuration, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description of the task.
4782 4783 4784 4785 4786 4787 4788 4789 4790 4791 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 4782 class CreateTaskRequest < Struct.new( :workspace_name, :task_name, :description, :task_configuration, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
A list of key-value pairs that contain metadata for the task. For more information, see Tagging your AWS IoT SiteWise resources in the AWS IoT SiteWise User Guide.
4782 4783 4784 4785 4786 4787 4788 4789 4790 4791 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 4782 class CreateTaskRequest < Struct.new( :workspace_name, :task_name, :description, :task_configuration, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |
#task_configuration ⇒ Types::TaskConfiguration
The task execution configuration. Specify a containerTaskConfiguration for custom container workloads.
4782 4783 4784 4785 4786 4787 4788 4789 4790 4791 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 4782 class CreateTaskRequest < Struct.new( :workspace_name, :task_name, :description, :task_configuration, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |
#task_name ⇒ String
The name of the task to create. Must be unique within the workspace.
4782 4783 4784 4785 4786 4787 4788 4789 4790 4791 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 4782 class CreateTaskRequest < Struct.new( :workspace_name, :task_name, :description, :task_configuration, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |
#workspace_name ⇒ String
The name of the workspace.
4782 4783 4784 4785 4786 4787 4788 4789 4790 4791 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 4782 class CreateTaskRequest < Struct.new( :workspace_name, :task_name, :description, :task_configuration, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |