Class: Aws::IoTSiteWise::Types::CreateWorkspaceRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotsitewise/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique, case-sensitive identifier that you provide to ensure that the request is idempotent. If you retry a request that completed successfully using the same client token, the retry succeeds without performing any further actions.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


4852
4853
4854
4855
4856
4857
4858
4859
4860
# File 'lib/aws-sdk-iotsitewise/types.rb', line 4852

class CreateWorkspaceRequest < Struct.new(
  :workspace_name,
  :workspace_description,
  :encryption_configuration,
  :tags,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#encryption_configurationTypes::WorkspaceEncryptionConfiguration

The encryption configuration for the workspace.



4852
4853
4854
4855
4856
4857
4858
4859
4860
# File 'lib/aws-sdk-iotsitewise/types.rb', line 4852

class CreateWorkspaceRequest < Struct.new(
  :workspace_name,
  :workspace_description,
  :encryption_configuration,
  :tags,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

A list of key-value pairs that contain metadata for the workspace. For more information, see Tagging your IoT SiteWise resources in the IoT SiteWise User Guide.

Returns:

  • (Hash<String,String>)


4852
4853
4854
4855
4856
4857
4858
4859
4860
# File 'lib/aws-sdk-iotsitewise/types.rb', line 4852

class CreateWorkspaceRequest < Struct.new(
  :workspace_name,
  :workspace_description,
  :encryption_configuration,
  :tags,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#workspace_descriptionString

A description for the workspace.

Returns:

  • (String)


4852
4853
4854
4855
4856
4857
4858
4859
4860
# File 'lib/aws-sdk-iotsitewise/types.rb', line 4852

class CreateWorkspaceRequest < Struct.new(
  :workspace_name,
  :workspace_description,
  :encryption_configuration,
  :tags,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#workspace_nameString

The name of the workspace to create.

Returns:

  • (String)


4852
4853
4854
4855
4856
4857
4858
4859
4860
# File 'lib/aws-sdk-iotsitewise/types.rb', line 4852

class CreateWorkspaceRequest < Struct.new(
  :workspace_name,
  :workspace_description,
  :encryption_configuration,
  :tags,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end