Class: Aws::IoTSiteWise::Types::DatasetEnrichmentEntry
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTSiteWise::Types::DatasetEnrichmentEntry
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotsitewise/types.rb
Overview
Contains enrichment status information for a specific data type in a dataset.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#last_enriched_at ⇒ Time
The date the data was last enriched, in Unix epoch time.
-
#status ⇒ String
The enrichment status of the data type in the dataset.
Instance Attribute Details
#last_enriched_at ⇒ Time
The date the data was last enriched, in Unix epoch time.
5163 5164 5165 5166 5167 5168 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 5163 class DatasetEnrichmentEntry < Struct.new( :status, :last_enriched_at) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The enrichment status of the data type in the dataset.
5163 5164 5165 5166 5167 5168 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 5163 class DatasetEnrichmentEntry < Struct.new( :status, :last_enriched_at) SENSITIVE = [] include Aws::Structure end |