Class: Aws::IoTSiteWise::Types::DatasetSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTSiteWise::Types::DatasetSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotsitewise/types.rb
Overview
The summary details for the dataset.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The [ARN][1] of the dataset.
-
#creation_date ⇒ Time
The dataset creation date, in Unix epoch time.
-
#dataset_type ⇒ String
The type of dataset: a session dataset, a curated dataset, or a connection to an external datasource.
-
#description ⇒ String
A description about the dataset, and its functionality.
-
#enrichment_status ⇒ Types::DatasetEnrichment
The enrichment status of the dataset.
-
#id ⇒ String
The ID of the dataset.
-
#last_update_date ⇒ Time
The date the dataset was last updated, in Unix epoch time.
-
#name ⇒ String
The name of the dataset.
-
#source_type ⇒ String
The data source type of the dataset.
-
#status ⇒ Types::DatasetStatus
The status of the dataset.
Instance Attribute Details
#arn ⇒ String
The ARN of the dataset. The format is
arn:${Partition}:iotsitewise:${Region}:${Account}:dataset/${DatasetId}.
5283 5284 5285 5286 5287 5288 5289 5290 5291 5292 5293 5294 5295 5296 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 5283 class DatasetSummary < Struct.new( :id, :arn, :name, :description, :source_type, :dataset_type, :creation_date, :last_update_date, :status, :enrichment_status) SENSITIVE = [] include Aws::Structure end |
#creation_date ⇒ Time
The dataset creation date, in Unix epoch time.
5283 5284 5285 5286 5287 5288 5289 5290 5291 5292 5293 5294 5295 5296 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 5283 class DatasetSummary < Struct.new( :id, :arn, :name, :description, :source_type, :dataset_type, :creation_date, :last_update_date, :status, :enrichment_status) SENSITIVE = [] include Aws::Structure end |
#dataset_type ⇒ String
The type of dataset: a session dataset, a curated dataset, or a connection to an external datasource.
5283 5284 5285 5286 5287 5288 5289 5290 5291 5292 5293 5294 5295 5296 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 5283 class DatasetSummary < Struct.new( :id, :arn, :name, :description, :source_type, :dataset_type, :creation_date, :last_update_date, :status, :enrichment_status) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description about the dataset, and its functionality.
5283 5284 5285 5286 5287 5288 5289 5290 5291 5292 5293 5294 5295 5296 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 5283 class DatasetSummary < Struct.new( :id, :arn, :name, :description, :source_type, :dataset_type, :creation_date, :last_update_date, :status, :enrichment_status) SENSITIVE = [] include Aws::Structure end |
#enrichment_status ⇒ Types::DatasetEnrichment
The enrichment status of the dataset.
5283 5284 5285 5286 5287 5288 5289 5290 5291 5292 5293 5294 5295 5296 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 5283 class DatasetSummary < Struct.new( :id, :arn, :name, :description, :source_type, :dataset_type, :creation_date, :last_update_date, :status, :enrichment_status) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The ID of the dataset.
5283 5284 5285 5286 5287 5288 5289 5290 5291 5292 5293 5294 5295 5296 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 5283 class DatasetSummary < Struct.new( :id, :arn, :name, :description, :source_type, :dataset_type, :creation_date, :last_update_date, :status, :enrichment_status) SENSITIVE = [] include Aws::Structure end |
#last_update_date ⇒ Time
The date the dataset was last updated, in Unix epoch time.
5283 5284 5285 5286 5287 5288 5289 5290 5291 5292 5293 5294 5295 5296 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 5283 class DatasetSummary < Struct.new( :id, :arn, :name, :description, :source_type, :dataset_type, :creation_date, :last_update_date, :status, :enrichment_status) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the dataset.
5283 5284 5285 5286 5287 5288 5289 5290 5291 5292 5293 5294 5295 5296 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 5283 class DatasetSummary < Struct.new( :id, :arn, :name, :description, :source_type, :dataset_type, :creation_date, :last_update_date, :status, :enrichment_status) SENSITIVE = [] include Aws::Structure end |
#source_type ⇒ String
The data source type of the dataset.
5283 5284 5285 5286 5287 5288 5289 5290 5291 5292 5293 5294 5295 5296 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 5283 class DatasetSummary < Struct.new( :id, :arn, :name, :description, :source_type, :dataset_type, :creation_date, :last_update_date, :status, :enrichment_status) SENSITIVE = [] include Aws::Structure end |
#status ⇒ Types::DatasetStatus
The status of the dataset. This contains the state and any error
messages. The state is ACTIVE when ready to use.
5283 5284 5285 5286 5287 5288 5289 5290 5291 5292 5293 5294 5295 5296 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 5283 class DatasetSummary < Struct.new( :id, :arn, :name, :description, :source_type, :dataset_type, :creation_date, :last_update_date, :status, :enrichment_status) SENSITIVE = [] include Aws::Structure end |