Class: Aws::IoTSiteWise::Types::DeleteDataSegmentEntry
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTSiteWise::Types::DeleteDataSegmentEntry
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotsitewise/types.rb
Overview
Contains information about a data segment entry to delete.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#end_timestamp ⇒ Types::TimeInNanos
The nanosecond-precision end time of the data segment to delete.
-
#start_timestamp ⇒ Types::TimeInNanos
The nanosecond-precision start time of the data segment to delete.
-
#time_series_id ⇒ String
The ID of the time series.
Instance Attribute Details
#end_timestamp ⇒ Types::TimeInNanos
The nanosecond-precision end time of the data segment to delete.
5677 5678 5679 5680 5681 5682 5683 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 5677 class DeleteDataSegmentEntry < Struct.new( :time_series_id, :start_timestamp, :end_timestamp) SENSITIVE = [] include Aws::Structure end |
#start_timestamp ⇒ Types::TimeInNanos
The nanosecond-precision start time of the data segment to delete.
5677 5678 5679 5680 5681 5682 5683 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 5677 class DeleteDataSegmentEntry < Struct.new( :time_series_id, :start_timestamp, :end_timestamp) SENSITIVE = [] include Aws::Structure end |
#time_series_id ⇒ String
The ID of the time series.
5677 5678 5679 5680 5681 5682 5683 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 5677 class DeleteDataSegmentEntry < Struct.new( :time_series_id, :start_timestamp, :end_timestamp) SENSITIVE = [] include Aws::Structure end |