Class: Aws::IoTSiteWise::Types::DeleteWorkspaceRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTSiteWise::Types::DeleteWorkspaceRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotsitewise/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure that the request is idempotent.
-
#workspace_name ⇒ String
The name of the workspace to delete.
Instance Attribute Details
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure that the request is idempotent. If you retry a request that completed successfully using the same client token, the retry succeeds without performing any further actions.
A suitable default value is auto-generated. You should normally not need to pass this option.
5907 5908 5909 5910 5911 5912 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 5907 class DeleteWorkspaceRequest < Struct.new( :workspace_name, :client_token) SENSITIVE = [] include Aws::Structure end |
#workspace_name ⇒ String
The name of the workspace to delete.
5907 5908 5909 5910 5911 5912 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 5907 class DeleteWorkspaceRequest < Struct.new( :workspace_name, :client_token) SENSITIVE = [] include Aws::Structure end |