Class: Aws::IoTSiteWise::Types::DescribeAccessPolicyResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTSiteWise::Types::DescribeAccessPolicyResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotsitewise/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#access_policy_arn ⇒ String
The [ARN][1] of the access policy, which has the following format.
-
#access_policy_creation_date ⇒ Time
The date the access policy was created, in Unix epoch time.
-
#access_policy_id ⇒ String
The ID of the access policy.
-
#access_policy_identity ⇒ Types::Identity
The identity (IAM Identity Center user, IAM Identity Center group, or IAM user) to which this access policy applies.
-
#access_policy_last_update_date ⇒ Time
The date the access policy was last updated, in Unix epoch time.
-
#access_policy_permission ⇒ String
The access policy permission.
-
#access_policy_resource ⇒ Types::Resource
The IoT SiteWise Monitor resource (portal or project) to which this access policy provides access.
Instance Attribute Details
#access_policy_arn ⇒ String
The ARN of the access policy, which has the following format.
arn:${Partition}:iotsitewise:${Region}:${Account}:access-policy/${AccessPolicyId}
5972 5973 5974 5975 5976 5977 5978 5979 5980 5981 5982 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 5972 class DescribeAccessPolicyResponse < Struct.new( :access_policy_id, :access_policy_arn, :access_policy_identity, :access_policy_resource, :access_policy_permission, :access_policy_creation_date, :access_policy_last_update_date) SENSITIVE = [] include Aws::Structure end |
#access_policy_creation_date ⇒ Time
The date the access policy was created, in Unix epoch time.
5972 5973 5974 5975 5976 5977 5978 5979 5980 5981 5982 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 5972 class DescribeAccessPolicyResponse < Struct.new( :access_policy_id, :access_policy_arn, :access_policy_identity, :access_policy_resource, :access_policy_permission, :access_policy_creation_date, :access_policy_last_update_date) SENSITIVE = [] include Aws::Structure end |
#access_policy_id ⇒ String
The ID of the access policy.
5972 5973 5974 5975 5976 5977 5978 5979 5980 5981 5982 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 5972 class DescribeAccessPolicyResponse < Struct.new( :access_policy_id, :access_policy_arn, :access_policy_identity, :access_policy_resource, :access_policy_permission, :access_policy_creation_date, :access_policy_last_update_date) SENSITIVE = [] include Aws::Structure end |
#access_policy_identity ⇒ Types::Identity
The identity (IAM Identity Center user, IAM Identity Center group, or IAM user) to which this access policy applies.
5972 5973 5974 5975 5976 5977 5978 5979 5980 5981 5982 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 5972 class DescribeAccessPolicyResponse < Struct.new( :access_policy_id, :access_policy_arn, :access_policy_identity, :access_policy_resource, :access_policy_permission, :access_policy_creation_date, :access_policy_last_update_date) SENSITIVE = [] include Aws::Structure end |
#access_policy_last_update_date ⇒ Time
The date the access policy was last updated, in Unix epoch time.
5972 5973 5974 5975 5976 5977 5978 5979 5980 5981 5982 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 5972 class DescribeAccessPolicyResponse < Struct.new( :access_policy_id, :access_policy_arn, :access_policy_identity, :access_policy_resource, :access_policy_permission, :access_policy_creation_date, :access_policy_last_update_date) SENSITIVE = [] include Aws::Structure end |
#access_policy_permission ⇒ String
The access policy permission. Note that a project ADMINISTRATOR is
also known as a project owner.
5972 5973 5974 5975 5976 5977 5978 5979 5980 5981 5982 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 5972 class DescribeAccessPolicyResponse < Struct.new( :access_policy_id, :access_policy_arn, :access_policy_identity, :access_policy_resource, :access_policy_permission, :access_policy_creation_date, :access_policy_last_update_date) SENSITIVE = [] include Aws::Structure end |
#access_policy_resource ⇒ Types::Resource
The IoT SiteWise Monitor resource (portal or project) to which this access policy provides access.
5972 5973 5974 5975 5976 5977 5978 5979 5980 5981 5982 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 5972 class DescribeAccessPolicyResponse < Struct.new( :access_policy_id, :access_policy_arn, :access_policy_identity, :access_policy_resource, :access_policy_permission, :access_policy_creation_date, :access_policy_last_update_date) SENSITIVE = [] include Aws::Structure end |