Class: Aws::IoTSiteWise::Types::DescribeDatasetExportJobResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTSiteWise::Types::DescribeDatasetExportJobResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotsitewise/types.rb
Overview
Response for describe dataset export job request.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#completed_at ⇒ Time
The timestamp when the job completed, or null if the job is still running.
-
#destination_s3_uri ⇒ String
The S3 URI where output clips are written.
-
#error_report_location ⇒ Types::ExportErrorReportLocation
The location where the error report will be written on failure.
-
#input ⇒ Types::ProcessingInput
The processing input that was provided in the CreateDatasetExportJob request.
-
#job_id ⇒ String
The unique identifier for the dataset export job.
-
#started_at ⇒ Time
The timestamp when the job started processing.
-
#status ⇒ String
The current status of the dataset export job.
-
#workspace_name ⇒ String
The name of the workspace that contains the dataset export job.
Instance Attribute Details
#completed_at ⇒ Time
The timestamp when the job completed, or null if the job is still running.
7050 7051 7052 7053 7054 7055 7056 7057 7058 7059 7060 7061 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 7050 class DescribeDatasetExportJobResponse < Struct.new( :job_id, :workspace_name, :status, :started_at, :completed_at, :destination_s3_uri, :error_report_location, :input) SENSITIVE = [] include Aws::Structure end |
#destination_s3_uri ⇒ String
The S3 URI where output clips are written.
7050 7051 7052 7053 7054 7055 7056 7057 7058 7059 7060 7061 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 7050 class DescribeDatasetExportJobResponse < Struct.new( :job_id, :workspace_name, :status, :started_at, :completed_at, :destination_s3_uri, :error_report_location, :input) SENSITIVE = [] include Aws::Structure end |
#error_report_location ⇒ Types::ExportErrorReportLocation
The location where the error report will be written on failure.
7050 7051 7052 7053 7054 7055 7056 7057 7058 7059 7060 7061 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 7050 class DescribeDatasetExportJobResponse < Struct.new( :job_id, :workspace_name, :status, :started_at, :completed_at, :destination_s3_uri, :error_report_location, :input) SENSITIVE = [] include Aws::Structure end |
#input ⇒ Types::ProcessingInput
The processing input that was provided in the CreateDatasetExportJob request.
7050 7051 7052 7053 7054 7055 7056 7057 7058 7059 7060 7061 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 7050 class DescribeDatasetExportJobResponse < Struct.new( :job_id, :workspace_name, :status, :started_at, :completed_at, :destination_s3_uri, :error_report_location, :input) SENSITIVE = [] include Aws::Structure end |
#job_id ⇒ String
The unique identifier for the dataset export job.
7050 7051 7052 7053 7054 7055 7056 7057 7058 7059 7060 7061 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 7050 class DescribeDatasetExportJobResponse < Struct.new( :job_id, :workspace_name, :status, :started_at, :completed_at, :destination_s3_uri, :error_report_location, :input) SENSITIVE = [] include Aws::Structure end |
#started_at ⇒ Time
The timestamp when the job started processing.
7050 7051 7052 7053 7054 7055 7056 7057 7058 7059 7060 7061 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 7050 class DescribeDatasetExportJobResponse < Struct.new( :job_id, :workspace_name, :status, :started_at, :completed_at, :destination_s3_uri, :error_report_location, :input) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the dataset export job.
7050 7051 7052 7053 7054 7055 7056 7057 7058 7059 7060 7061 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 7050 class DescribeDatasetExportJobResponse < Struct.new( :job_id, :workspace_name, :status, :started_at, :completed_at, :destination_s3_uri, :error_report_location, :input) SENSITIVE = [] include Aws::Structure end |
#workspace_name ⇒ String
The name of the workspace that contains the dataset export job.
7050 7051 7052 7053 7054 7055 7056 7057 7058 7059 7060 7061 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 7050 class DescribeDatasetExportJobResponse < Struct.new( :job_id, :workspace_name, :status, :started_at, :completed_at, :destination_s3_uri, :error_report_location, :input) SENSITIVE = [] include Aws::Structure end |