Class: Aws::IoTSiteWise::Types::DescribePipelineExecutionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTSiteWise::Types::DescribePipelineExecutionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotsitewise/types.rb
Overview
Request structure for DescribePipelineExecution operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
The maximum number of compute nodes to return per request.
-
#next_token ⇒ String
The token to be used for the next set of paginated results.
-
#pipeline_execution_id ⇒ String
The unique identifier of the pipeline execution.
-
#pipeline_name ⇒ String
The name of the pipeline.
-
#workspace_name ⇒ String
The name of the workspace.
Instance Attribute Details
#max_results ⇒ Integer
The maximum number of compute nodes to return per request. This is an upper bound; the actual number of results may be less. Default: 50.
7546 7547 7548 7549 7550 7551 7552 7553 7554 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 7546 class DescribePipelineExecutionRequest < Struct.new( :workspace_name, :pipeline_name, :pipeline_execution_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token to be used for the next set of paginated results.
7546 7547 7548 7549 7550 7551 7552 7553 7554 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 7546 class DescribePipelineExecutionRequest < Struct.new( :workspace_name, :pipeline_name, :pipeline_execution_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#pipeline_execution_id ⇒ String
The unique identifier of the pipeline execution.
7546 7547 7548 7549 7550 7551 7552 7553 7554 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 7546 class DescribePipelineExecutionRequest < Struct.new( :workspace_name, :pipeline_name, :pipeline_execution_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#pipeline_name ⇒ String
The name of the pipeline.
7546 7547 7548 7549 7550 7551 7552 7553 7554 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 7546 class DescribePipelineExecutionRequest < Struct.new( :workspace_name, :pipeline_name, :pipeline_execution_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#workspace_name ⇒ String
The name of the workspace.
7546 7547 7548 7549 7550 7551 7552 7553 7554 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 7546 class DescribePipelineExecutionRequest < Struct.new( :workspace_name, :pipeline_name, :pipeline_execution_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |