Class: Aws::IoTSiteWise::Types::DescribePortalResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTSiteWise::Types::DescribePortalResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotsitewise/types.rb
Constant Summary collapse
- SENSITIVE =
[:portal_contact_email, :notification_sender_email]
Instance Attribute Summary collapse
-
#alarms ⇒ Types::Alarms
Contains the configuration information of an alarm created in an IoT SiteWise Monitor portal.
-
#notification_sender_email ⇒ String
The email address that sends alarm notifications.
-
#portal_arn ⇒ String
The [ARN][1] of the portal, which has the following format.
-
#portal_auth_mode ⇒ String
The service to use to authenticate users to the portal.
-
#portal_client_id ⇒ String
The IAM Identity Center application generated client ID (used with IAM Identity Center API operations).
-
#portal_contact_email ⇒ String
The Amazon Web Services administrator's contact email address.
-
#portal_creation_date ⇒ Time
The date the portal was created, in Unix epoch time.
-
#portal_description ⇒ String
The portal's description.
-
#portal_id ⇒ String
The ID of the portal.
-
#portal_last_update_date ⇒ Time
The date the portal was last updated, in Unix epoch time.
-
#portal_logo_image_location ⇒ Types::ImageLocation
The portal's logo image, which is available at a URL.
-
#portal_name ⇒ String
The name of the portal.
-
#portal_start_url ⇒ String
The URL for the IoT SiteWise Monitor portal.
-
#portal_status ⇒ Types::PortalStatus
The current status of the portal, which contains a state and any error message.
-
#portal_type ⇒ String
Define the type of portal.
-
#portal_type_configuration ⇒ Hash<String,Types::PortalTypeEntry>
The configuration entry associated with the specific portal type.
-
#role_arn ⇒ String
The [ARN][1] of the service role that allows the portal's users to access your IoT SiteWise resources on your behalf.
Instance Attribute Details
#alarms ⇒ Types::Alarms
Contains the configuration information of an alarm created in an IoT SiteWise Monitor portal.
7807 7808 7809 7810 7811 7812 7813 7814 7815 7816 7817 7818 7819 7820 7821 7822 7823 7824 7825 7826 7827 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 7807 class DescribePortalResponse < Struct.new( :portal_id, :portal_arn, :portal_name, :portal_description, :portal_client_id, :portal_start_url, :portal_contact_email, :portal_status, :portal_creation_date, :portal_last_update_date, :portal_logo_image_location, :role_arn, :portal_auth_mode, :notification_sender_email, :alarms, :portal_type, :portal_type_configuration) SENSITIVE = [:portal_contact_email, :notification_sender_email] include Aws::Structure end |
#notification_sender_email ⇒ String
The email address that sends alarm notifications.
7807 7808 7809 7810 7811 7812 7813 7814 7815 7816 7817 7818 7819 7820 7821 7822 7823 7824 7825 7826 7827 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 7807 class DescribePortalResponse < Struct.new( :portal_id, :portal_arn, :portal_name, :portal_description, :portal_client_id, :portal_start_url, :portal_contact_email, :portal_status, :portal_creation_date, :portal_last_update_date, :portal_logo_image_location, :role_arn, :portal_auth_mode, :notification_sender_email, :alarms, :portal_type, :portal_type_configuration) SENSITIVE = [:portal_contact_email, :notification_sender_email] include Aws::Structure end |
#portal_arn ⇒ String
The ARN of the portal, which has the following format.
arn:${Partition}:iotsitewise:${Region}:${Account}:portal/${PortalId}
7807 7808 7809 7810 7811 7812 7813 7814 7815 7816 7817 7818 7819 7820 7821 7822 7823 7824 7825 7826 7827 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 7807 class DescribePortalResponse < Struct.new( :portal_id, :portal_arn, :portal_name, :portal_description, :portal_client_id, :portal_start_url, :portal_contact_email, :portal_status, :portal_creation_date, :portal_last_update_date, :portal_logo_image_location, :role_arn, :portal_auth_mode, :notification_sender_email, :alarms, :portal_type, :portal_type_configuration) SENSITIVE = [:portal_contact_email, :notification_sender_email] include Aws::Structure end |
#portal_auth_mode ⇒ String
The service to use to authenticate users to the portal.
7807 7808 7809 7810 7811 7812 7813 7814 7815 7816 7817 7818 7819 7820 7821 7822 7823 7824 7825 7826 7827 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 7807 class DescribePortalResponse < Struct.new( :portal_id, :portal_arn, :portal_name, :portal_description, :portal_client_id, :portal_start_url, :portal_contact_email, :portal_status, :portal_creation_date, :portal_last_update_date, :portal_logo_image_location, :role_arn, :portal_auth_mode, :notification_sender_email, :alarms, :portal_type, :portal_type_configuration) SENSITIVE = [:portal_contact_email, :notification_sender_email] include Aws::Structure end |
#portal_client_id ⇒ String
The IAM Identity Center application generated client ID (used with
IAM Identity Center API operations). IoT SiteWise includes
portalClientId for only portals that use IAM Identity Center to
authenticate users.
7807 7808 7809 7810 7811 7812 7813 7814 7815 7816 7817 7818 7819 7820 7821 7822 7823 7824 7825 7826 7827 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 7807 class DescribePortalResponse < Struct.new( :portal_id, :portal_arn, :portal_name, :portal_description, :portal_client_id, :portal_start_url, :portal_contact_email, :portal_status, :portal_creation_date, :portal_last_update_date, :portal_logo_image_location, :role_arn, :portal_auth_mode, :notification_sender_email, :alarms, :portal_type, :portal_type_configuration) SENSITIVE = [:portal_contact_email, :notification_sender_email] include Aws::Structure end |
#portal_contact_email ⇒ String
The Amazon Web Services administrator's contact email address.
7807 7808 7809 7810 7811 7812 7813 7814 7815 7816 7817 7818 7819 7820 7821 7822 7823 7824 7825 7826 7827 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 7807 class DescribePortalResponse < Struct.new( :portal_id, :portal_arn, :portal_name, :portal_description, :portal_client_id, :portal_start_url, :portal_contact_email, :portal_status, :portal_creation_date, :portal_last_update_date, :portal_logo_image_location, :role_arn, :portal_auth_mode, :notification_sender_email, :alarms, :portal_type, :portal_type_configuration) SENSITIVE = [:portal_contact_email, :notification_sender_email] include Aws::Structure end |
#portal_creation_date ⇒ Time
The date the portal was created, in Unix epoch time.
7807 7808 7809 7810 7811 7812 7813 7814 7815 7816 7817 7818 7819 7820 7821 7822 7823 7824 7825 7826 7827 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 7807 class DescribePortalResponse < Struct.new( :portal_id, :portal_arn, :portal_name, :portal_description, :portal_client_id, :portal_start_url, :portal_contact_email, :portal_status, :portal_creation_date, :portal_last_update_date, :portal_logo_image_location, :role_arn, :portal_auth_mode, :notification_sender_email, :alarms, :portal_type, :portal_type_configuration) SENSITIVE = [:portal_contact_email, :notification_sender_email] include Aws::Structure end |
#portal_description ⇒ String
The portal's description.
7807 7808 7809 7810 7811 7812 7813 7814 7815 7816 7817 7818 7819 7820 7821 7822 7823 7824 7825 7826 7827 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 7807 class DescribePortalResponse < Struct.new( :portal_id, :portal_arn, :portal_name, :portal_description, :portal_client_id, :portal_start_url, :portal_contact_email, :portal_status, :portal_creation_date, :portal_last_update_date, :portal_logo_image_location, :role_arn, :portal_auth_mode, :notification_sender_email, :alarms, :portal_type, :portal_type_configuration) SENSITIVE = [:portal_contact_email, :notification_sender_email] include Aws::Structure end |
#portal_id ⇒ String
The ID of the portal.
7807 7808 7809 7810 7811 7812 7813 7814 7815 7816 7817 7818 7819 7820 7821 7822 7823 7824 7825 7826 7827 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 7807 class DescribePortalResponse < Struct.new( :portal_id, :portal_arn, :portal_name, :portal_description, :portal_client_id, :portal_start_url, :portal_contact_email, :portal_status, :portal_creation_date, :portal_last_update_date, :portal_logo_image_location, :role_arn, :portal_auth_mode, :notification_sender_email, :alarms, :portal_type, :portal_type_configuration) SENSITIVE = [:portal_contact_email, :notification_sender_email] include Aws::Structure end |
#portal_last_update_date ⇒ Time
The date the portal was last updated, in Unix epoch time.
7807 7808 7809 7810 7811 7812 7813 7814 7815 7816 7817 7818 7819 7820 7821 7822 7823 7824 7825 7826 7827 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 7807 class DescribePortalResponse < Struct.new( :portal_id, :portal_arn, :portal_name, :portal_description, :portal_client_id, :portal_start_url, :portal_contact_email, :portal_status, :portal_creation_date, :portal_last_update_date, :portal_logo_image_location, :role_arn, :portal_auth_mode, :notification_sender_email, :alarms, :portal_type, :portal_type_configuration) SENSITIVE = [:portal_contact_email, :notification_sender_email] include Aws::Structure end |
#portal_logo_image_location ⇒ Types::ImageLocation
The portal's logo image, which is available at a URL.
7807 7808 7809 7810 7811 7812 7813 7814 7815 7816 7817 7818 7819 7820 7821 7822 7823 7824 7825 7826 7827 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 7807 class DescribePortalResponse < Struct.new( :portal_id, :portal_arn, :portal_name, :portal_description, :portal_client_id, :portal_start_url, :portal_contact_email, :portal_status, :portal_creation_date, :portal_last_update_date, :portal_logo_image_location, :role_arn, :portal_auth_mode, :notification_sender_email, :alarms, :portal_type, :portal_type_configuration) SENSITIVE = [:portal_contact_email, :notification_sender_email] include Aws::Structure end |
#portal_name ⇒ String
The name of the portal.
7807 7808 7809 7810 7811 7812 7813 7814 7815 7816 7817 7818 7819 7820 7821 7822 7823 7824 7825 7826 7827 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 7807 class DescribePortalResponse < Struct.new( :portal_id, :portal_arn, :portal_name, :portal_description, :portal_client_id, :portal_start_url, :portal_contact_email, :portal_status, :portal_creation_date, :portal_last_update_date, :portal_logo_image_location, :role_arn, :portal_auth_mode, :notification_sender_email, :alarms, :portal_type, :portal_type_configuration) SENSITIVE = [:portal_contact_email, :notification_sender_email] include Aws::Structure end |
#portal_start_url ⇒ String
The URL for the IoT SiteWise Monitor portal. You can use this URL to access portals that use IAM Identity Center for authentication. For portals that use IAM for authentication, you must use the IoT SiteWise console to get a URL that you can use to access the portal.
7807 7808 7809 7810 7811 7812 7813 7814 7815 7816 7817 7818 7819 7820 7821 7822 7823 7824 7825 7826 7827 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 7807 class DescribePortalResponse < Struct.new( :portal_id, :portal_arn, :portal_name, :portal_description, :portal_client_id, :portal_start_url, :portal_contact_email, :portal_status, :portal_creation_date, :portal_last_update_date, :portal_logo_image_location, :role_arn, :portal_auth_mode, :notification_sender_email, :alarms, :portal_type, :portal_type_configuration) SENSITIVE = [:portal_contact_email, :notification_sender_email] include Aws::Structure end |
#portal_status ⇒ Types::PortalStatus
The current status of the portal, which contains a state and any error message.
7807 7808 7809 7810 7811 7812 7813 7814 7815 7816 7817 7818 7819 7820 7821 7822 7823 7824 7825 7826 7827 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 7807 class DescribePortalResponse < Struct.new( :portal_id, :portal_arn, :portal_name, :portal_description, :portal_client_id, :portal_start_url, :portal_contact_email, :portal_status, :portal_creation_date, :portal_last_update_date, :portal_logo_image_location, :role_arn, :portal_auth_mode, :notification_sender_email, :alarms, :portal_type, :portal_type_configuration) SENSITIVE = [:portal_contact_email, :notification_sender_email] include Aws::Structure end |
#portal_type ⇒ String
Define the type of portal. The value for IoT SiteWise Monitor
(Classic) is SITEWISE_PORTAL_V1. The value for IoT SiteWise
Monitor (AI-aware) is SITEWISE_PORTAL_V2.
7807 7808 7809 7810 7811 7812 7813 7814 7815 7816 7817 7818 7819 7820 7821 7822 7823 7824 7825 7826 7827 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 7807 class DescribePortalResponse < Struct.new( :portal_id, :portal_arn, :portal_name, :portal_description, :portal_client_id, :portal_start_url, :portal_contact_email, :portal_status, :portal_creation_date, :portal_last_update_date, :portal_logo_image_location, :role_arn, :portal_auth_mode, :notification_sender_email, :alarms, :portal_type, :portal_type_configuration) SENSITIVE = [:portal_contact_email, :notification_sender_email] include Aws::Structure end |
#portal_type_configuration ⇒ Hash<String,Types::PortalTypeEntry>
The configuration entry associated with the specific portal type.
The value for IoT SiteWise Monitor (Classic) is
SITEWISE_PORTAL_V1. The value for IoT SiteWise Monitor (AI-aware)
is SITEWISE_PORTAL_V2.
7807 7808 7809 7810 7811 7812 7813 7814 7815 7816 7817 7818 7819 7820 7821 7822 7823 7824 7825 7826 7827 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 7807 class DescribePortalResponse < Struct.new( :portal_id, :portal_arn, :portal_name, :portal_description, :portal_client_id, :portal_start_url, :portal_contact_email, :portal_status, :portal_creation_date, :portal_last_update_date, :portal_logo_image_location, :role_arn, :portal_auth_mode, :notification_sender_email, :alarms, :portal_type, :portal_type_configuration) SENSITIVE = [:portal_contact_email, :notification_sender_email] include Aws::Structure end |
#role_arn ⇒ String
The ARN of the service role that allows the portal's users to access your IoT SiteWise resources on your behalf. For more information, see Using service roles for IoT SiteWise Monitor in the IoT SiteWise User Guide.
7807 7808 7809 7810 7811 7812 7813 7814 7815 7816 7817 7818 7819 7820 7821 7822 7823 7824 7825 7826 7827 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 7807 class DescribePortalResponse < Struct.new( :portal_id, :portal_arn, :portal_name, :portal_description, :portal_client_id, :portal_start_url, :portal_contact_email, :portal_status, :portal_creation_date, :portal_last_update_date, :portal_logo_image_location, :role_arn, :portal_auth_mode, :notification_sender_email, :alarms, :portal_type, :portal_type_configuration) SENSITIVE = [:portal_contact_email, :notification_sender_email] include Aws::Structure end |