Class: Aws::IoTSiteWise::Types::DescribeTimeSeriesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTSiteWise::Types::DescribeTimeSeriesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotsitewise/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#alias ⇒ String
The alias that identifies the time series.
-
#asset_id ⇒ String
The ID of the asset in which the asset property was created.
-
#property_id ⇒ String
The ID of the asset property.
-
#workspace_name ⇒ String
The name of the workspace.
Instance Attribute Details
#alias ⇒ String
The alias that identifies the time series.
8206 8207 8208 8209 8210 8211 8212 8213 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 8206 class DescribeTimeSeriesRequest < Struct.new( :alias, :asset_id, :property_id, :workspace_name) SENSITIVE = [] include Aws::Structure end |
#asset_id ⇒ String
The ID of the asset in which the asset property was created. This
can be either the actual ID in UUID format, or else externalId:
followed by the external ID, if it has one. For more information,
see Referencing objects with external IDs in the IoT SiteWise
User Guide.
8206 8207 8208 8209 8210 8211 8212 8213 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 8206 class DescribeTimeSeriesRequest < Struct.new( :alias, :asset_id, :property_id, :workspace_name) SENSITIVE = [] include Aws::Structure end |
#property_id ⇒ String
The ID of the asset property. This can be either the actual ID in
UUID format, or else externalId: followed by the external ID, if
it has one. For more information, see Referencing objects with
external IDs in the IoT SiteWise User Guide.
8206 8207 8208 8209 8210 8211 8212 8213 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 8206 class DescribeTimeSeriesRequest < Struct.new( :alias, :asset_id, :property_id, :workspace_name) SENSITIVE = [] include Aws::Structure end |
#workspace_name ⇒ String
The name of the workspace.
8206 8207 8208 8209 8210 8211 8212 8213 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 8206 class DescribeTimeSeriesRequest < Struct.new( :alias, :asset_id, :property_id, :workspace_name) SENSITIVE = [] include Aws::Structure end |