Class: Aws::IoTSiteWise::Types::DescribeTimeSeriesResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotsitewise/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#aliasString

The alias that identifies the time series.

Returns:

  • (String)


8270
8271
8272
8273
8274
8275
8276
8277
8278
8279
8280
8281
8282
8283
# File 'lib/aws-sdk-iotsitewise/types.rb', line 8270

class DescribeTimeSeriesResponse < Struct.new(
  :asset_id,
  :property_id,
  :alias,
  :time_series_id,
  :data_type,
  :data_type_spec,
  :time_series_creation_date,
  :time_series_last_update_date,
  :time_series_arn,
  :workspace_name)
  SENSITIVE = []
  include Aws::Structure
end

#asset_idString

The ID of the asset in which the asset property was created.

Returns:

  • (String)


8270
8271
8272
8273
8274
8275
8276
8277
8278
8279
8280
8281
8282
8283
# File 'lib/aws-sdk-iotsitewise/types.rb', line 8270

class DescribeTimeSeriesResponse < Struct.new(
  :asset_id,
  :property_id,
  :alias,
  :time_series_id,
  :data_type,
  :data_type_spec,
  :time_series_creation_date,
  :time_series_last_update_date,
  :time_series_arn,
  :workspace_name)
  SENSITIVE = []
  include Aws::Structure
end

#data_typeString

The data type of the time series.

If you specify STRUCT, you must also specify dataTypeSpec to identify the type of the structure for this time series.

Returns:

  • (String)


8270
8271
8272
8273
8274
8275
8276
8277
8278
8279
8280
8281
8282
8283
# File 'lib/aws-sdk-iotsitewise/types.rb', line 8270

class DescribeTimeSeriesResponse < Struct.new(
  :asset_id,
  :property_id,
  :alias,
  :time_series_id,
  :data_type,
  :data_type_spec,
  :time_series_creation_date,
  :time_series_last_update_date,
  :time_series_arn,
  :workspace_name)
  SENSITIVE = []
  include Aws::Structure
end

#data_type_specString

The data type of the structure for this time series. This parameter is required for time series that have the STRUCT data type.

The options for this parameter depend on the type of the composite model in which you created the asset property that is associated with your time series. Use AWS/ALARM_STATE for alarm state in alarm composite models.

Returns:

  • (String)


8270
8271
8272
8273
8274
8275
8276
8277
8278
8279
8280
8281
8282
8283
# File 'lib/aws-sdk-iotsitewise/types.rb', line 8270

class DescribeTimeSeriesResponse < Struct.new(
  :asset_id,
  :property_id,
  :alias,
  :time_series_id,
  :data_type,
  :data_type_spec,
  :time_series_creation_date,
  :time_series_last_update_date,
  :time_series_arn,
  :workspace_name)
  SENSITIVE = []
  include Aws::Structure
end

#property_idString

The ID of the asset property, in UUID format.

Returns:

  • (String)


8270
8271
8272
8273
8274
8275
8276
8277
8278
8279
8280
8281
8282
8283
# File 'lib/aws-sdk-iotsitewise/types.rb', line 8270

class DescribeTimeSeriesResponse < Struct.new(
  :asset_id,
  :property_id,
  :alias,
  :time_series_id,
  :data_type,
  :data_type_spec,
  :time_series_creation_date,
  :time_series_last_update_date,
  :time_series_arn,
  :workspace_name)
  SENSITIVE = []
  include Aws::Structure
end

#time_series_arnString

The ARN of the time series, which has the following format.

arn:${Partition}:iotsitewise:${Region}:${Account}:time-series/${TimeSeriesId}

Returns:

  • (String)


8270
8271
8272
8273
8274
8275
8276
8277
8278
8279
8280
8281
8282
8283
# File 'lib/aws-sdk-iotsitewise/types.rb', line 8270

class DescribeTimeSeriesResponse < Struct.new(
  :asset_id,
  :property_id,
  :alias,
  :time_series_id,
  :data_type,
  :data_type_spec,
  :time_series_creation_date,
  :time_series_last_update_date,
  :time_series_arn,
  :workspace_name)
  SENSITIVE = []
  include Aws::Structure
end

#time_series_creation_dateTime

The date that the time series was created, in Unix epoch time.

Returns:

  • (Time)


8270
8271
8272
8273
8274
8275
8276
8277
8278
8279
8280
8281
8282
8283
# File 'lib/aws-sdk-iotsitewise/types.rb', line 8270

class DescribeTimeSeriesResponse < Struct.new(
  :asset_id,
  :property_id,
  :alias,
  :time_series_id,
  :data_type,
  :data_type_spec,
  :time_series_creation_date,
  :time_series_last_update_date,
  :time_series_arn,
  :workspace_name)
  SENSITIVE = []
  include Aws::Structure
end

#time_series_idString

The ID of the time series.

Returns:

  • (String)


8270
8271
8272
8273
8274
8275
8276
8277
8278
8279
8280
8281
8282
8283
# File 'lib/aws-sdk-iotsitewise/types.rb', line 8270

class DescribeTimeSeriesResponse < Struct.new(
  :asset_id,
  :property_id,
  :alias,
  :time_series_id,
  :data_type,
  :data_type_spec,
  :time_series_creation_date,
  :time_series_last_update_date,
  :time_series_arn,
  :workspace_name)
  SENSITIVE = []
  include Aws::Structure
end

#time_series_last_update_dateTime

The date that the time series was last updated, in Unix epoch time.

Returns:

  • (Time)


8270
8271
8272
8273
8274
8275
8276
8277
8278
8279
8280
8281
8282
8283
# File 'lib/aws-sdk-iotsitewise/types.rb', line 8270

class DescribeTimeSeriesResponse < Struct.new(
  :asset_id,
  :property_id,
  :alias,
  :time_series_id,
  :data_type,
  :data_type_spec,
  :time_series_creation_date,
  :time_series_last_update_date,
  :time_series_arn,
  :workspace_name)
  SENSITIVE = []
  include Aws::Structure
end

#workspace_nameString

The name of the workspace.

Returns:

  • (String)


8270
8271
8272
8273
8274
8275
8276
8277
8278
8279
8280
8281
8282
8283
# File 'lib/aws-sdk-iotsitewise/types.rb', line 8270

class DescribeTimeSeriesResponse < Struct.new(
  :asset_id,
  :property_id,
  :alias,
  :time_series_id,
  :data_type,
  :data_type_spec,
  :time_series_creation_date,
  :time_series_last_update_date,
  :time_series_arn,
  :workspace_name)
  SENSITIVE = []
  include Aws::Structure
end