Class: Aws::IoTSiteWise::Types::DescribeWorkspaceResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTSiteWise::Types::DescribeWorkspaceResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotsitewise/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The date the workspace was created, in Unix epoch time.
-
#encryption_configuration ⇒ Types::WorkspaceEncryptionConfigurationInfo
The encryption configuration information for the workspace.
-
#updated_at ⇒ Time
The date the workspace was last updated, in Unix epoch time.
-
#workspace_arn ⇒ String
The ARN of the workspace.
-
#workspace_description ⇒ String
The description of the workspace.
-
#workspace_name ⇒ String
The name of the workspace.
-
#workspace_status ⇒ Types::WorkspaceStatus
The status of the workspace, which contains the state and any error message.
Instance Attribute Details
#created_at ⇒ Time
The date the workspace was created, in Unix epoch time.
8324 8325 8326 8327 8328 8329 8330 8331 8332 8333 8334 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 8324 class DescribeWorkspaceResponse < Struct.new( :workspace_arn, :workspace_name, :workspace_description, :workspace_status, :encryption_configuration, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#encryption_configuration ⇒ Types::WorkspaceEncryptionConfigurationInfo
The encryption configuration information for the workspace.
8324 8325 8326 8327 8328 8329 8330 8331 8332 8333 8334 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 8324 class DescribeWorkspaceResponse < Struct.new( :workspace_arn, :workspace_name, :workspace_description, :workspace_status, :encryption_configuration, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The date the workspace was last updated, in Unix epoch time.
8324 8325 8326 8327 8328 8329 8330 8331 8332 8333 8334 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 8324 class DescribeWorkspaceResponse < Struct.new( :workspace_arn, :workspace_name, :workspace_description, :workspace_status, :encryption_configuration, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#workspace_arn ⇒ String
The ARN of the workspace.
8324 8325 8326 8327 8328 8329 8330 8331 8332 8333 8334 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 8324 class DescribeWorkspaceResponse < Struct.new( :workspace_arn, :workspace_name, :workspace_description, :workspace_status, :encryption_configuration, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#workspace_description ⇒ String
The description of the workspace.
8324 8325 8326 8327 8328 8329 8330 8331 8332 8333 8334 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 8324 class DescribeWorkspaceResponse < Struct.new( :workspace_arn, :workspace_name, :workspace_description, :workspace_status, :encryption_configuration, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#workspace_name ⇒ String
The name of the workspace.
8324 8325 8326 8327 8328 8329 8330 8331 8332 8333 8334 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 8324 class DescribeWorkspaceResponse < Struct.new( :workspace_arn, :workspace_name, :workspace_description, :workspace_status, :encryption_configuration, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#workspace_status ⇒ Types::WorkspaceStatus
The status of the workspace, which contains the state and any error message.
8324 8325 8326 8327 8328 8329 8330 8331 8332 8333 8334 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 8324 class DescribeWorkspaceResponse < Struct.new( :workspace_arn, :workspace_name, :workspace_description, :workspace_status, :encryption_configuration, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |