Class: Aws::IoTSiteWise::Types::ExecuteActionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTSiteWise::Types::ExecuteActionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotsitewise/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#action_definition_id ⇒ String
The ID of the action definition.
-
#action_payload ⇒ Types::ActionPayload
The JSON payload of the action.
-
#client_token ⇒ String
A unique case-sensitive identifier that you can provide to ensure the idempotency of the request.
-
#resolve_to ⇒ Types::ResolveTo
The detailed resource this action resolves to.
-
#target_resource ⇒ Types::TargetResource
The resource the action will be taken on.
Instance Attribute Details
#action_definition_id ⇒ String
The ID of the action definition.
8763 8764 8765 8766 8767 8768 8769 8770 8771 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 8763 class ExecuteActionRequest < Struct.new( :target_resource, :action_definition_id, :action_payload, :client_token, :resolve_to) SENSITIVE = [] include Aws::Structure end |
#action_payload ⇒ Types::ActionPayload
The JSON payload of the action.
8763 8764 8765 8766 8767 8768 8769 8770 8771 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 8763 class ExecuteActionRequest < Struct.new( :target_resource, :action_definition_id, :action_payload, :client_token, :resolve_to) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
A unique case-sensitive identifier that you can provide to ensure the idempotency of the request. Don't reuse this client token if a new idempotent request is required.
8763 8764 8765 8766 8767 8768 8769 8770 8771 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 8763 class ExecuteActionRequest < Struct.new( :target_resource, :action_definition_id, :action_payload, :client_token, :resolve_to) SENSITIVE = [] include Aws::Structure end |
#resolve_to ⇒ Types::ResolveTo
The detailed resource this action resolves to.
8763 8764 8765 8766 8767 8768 8769 8770 8771 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 8763 class ExecuteActionRequest < Struct.new( :target_resource, :action_definition_id, :action_payload, :client_token, :resolve_to) SENSITIVE = [] include Aws::Structure end |
#target_resource ⇒ Types::TargetResource
The resource the action will be taken on.
8763 8764 8765 8766 8767 8768 8769 8770 8771 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 8763 class ExecuteActionRequest < Struct.new( :target_resource, :action_definition_id, :action_payload, :client_token, :resolve_to) SENSITIVE = [] include Aws::Structure end |