Class: Aws::IoTSiteWise::Types::GetCaptureDataRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTSiteWise::Types::GetCaptureDataRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotsitewise/types.rb
Overview
Request to retrieve video data for a specific time range. Exactly one of timeSeriesId or propertyAlias must be provided.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#end_time ⇒ Types::TimeInNanos
The end time for the video data range.
-
#format_settings ⇒ Types::FormatSettings
The optional format settings for the output.
-
#next_token ⇒ String
The token from a previous response used to continue retrieving data.
-
#property_alias ⇒ String
The property alias that identifies the capture source.
-
#start_time ⇒ Types::TimeInNanos
The start time for the video data range.
-
#time_series_id ⇒ String
The time series ID that identifies the capture source.
-
#workspace_name ⇒ String
The name of the workspace that contains the capture source.
Instance Attribute Details
#end_time ⇒ Types::TimeInNanos
The end time for the video data range. Must be greater than startTime.
9579 9580 9581 9582 9583 9584 9585 9586 9587 9588 9589 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 9579 class GetCaptureDataRequest < Struct.new( :workspace_name, :start_time, :end_time, :time_series_id, :property_alias, :format_settings, :next_token) SENSITIVE = [] include Aws::Structure end |
#format_settings ⇒ Types::FormatSettings
The optional format settings for the output.
9579 9580 9581 9582 9583 9584 9585 9586 9587 9588 9589 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 9579 class GetCaptureDataRequest < Struct.new( :workspace_name, :start_time, :end_time, :time_series_id, :property_alias, :format_settings, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token from a previous response used to continue retrieving data.
9579 9580 9581 9582 9583 9584 9585 9586 9587 9588 9589 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 9579 class GetCaptureDataRequest < Struct.new( :workspace_name, :start_time, :end_time, :time_series_id, :property_alias, :format_settings, :next_token) SENSITIVE = [] include Aws::Structure end |
#property_alias ⇒ String
The property alias that identifies the capture source. Mutually exclusive with timeSeriesId.
9579 9580 9581 9582 9583 9584 9585 9586 9587 9588 9589 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 9579 class GetCaptureDataRequest < Struct.new( :workspace_name, :start_time, :end_time, :time_series_id, :property_alias, :format_settings, :next_token) SENSITIVE = [] include Aws::Structure end |
#start_time ⇒ Types::TimeInNanos
The start time for the video data range.
9579 9580 9581 9582 9583 9584 9585 9586 9587 9588 9589 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 9579 class GetCaptureDataRequest < Struct.new( :workspace_name, :start_time, :end_time, :time_series_id, :property_alias, :format_settings, :next_token) SENSITIVE = [] include Aws::Structure end |
#time_series_id ⇒ String
The time series ID that identifies the capture source. Mutually exclusive with propertyAlias.
9579 9580 9581 9582 9583 9584 9585 9586 9587 9588 9589 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 9579 class GetCaptureDataRequest < Struct.new( :workspace_name, :start_time, :end_time, :time_series_id, :property_alias, :format_settings, :next_token) SENSITIVE = [] include Aws::Structure end |
#workspace_name ⇒ String
The name of the workspace that contains the capture source.
9579 9580 9581 9582 9583 9584 9585 9586 9587 9588 9589 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 9579 class GetCaptureDataRequest < Struct.new( :workspace_name, :start_time, :end_time, :time_series_id, :property_alias, :format_settings, :next_token) SENSITIVE = [] include Aws::Structure end |