Class: Aws::IoTSiteWise::Types::GetQueryResultsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTSiteWise::Types::GetQueryResultsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotsitewise/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
The maximum number of results to return for each paginated request.
-
#next_token ⇒ String
The token to be used for the next set of paginated results.
-
#query_id ⇒ String
The unique identifier for the query execution.
-
#workspace_name ⇒ String
The name of the workspace associated with the query.
Instance Attribute Details
#max_results ⇒ Integer
The maximum number of results to return for each paginated request.
9794 9795 9796 9797 9798 9799 9800 9801 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 9794 class GetQueryResultsRequest < Struct.new( :workspace_name, :query_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token to be used for the next set of paginated results.
9794 9795 9796 9797 9798 9799 9800 9801 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 9794 class GetQueryResultsRequest < Struct.new( :workspace_name, :query_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#query_id ⇒ String
The unique identifier for the query execution.
9794 9795 9796 9797 9798 9799 9800 9801 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 9794 class GetQueryResultsRequest < Struct.new( :workspace_name, :query_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#workspace_name ⇒ String
The name of the workspace associated with the query.
9794 9795 9796 9797 9798 9799 9800 9801 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 9794 class GetQueryResultsRequest < Struct.new( :workspace_name, :query_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |