Class: Aws::IoTSiteWise::Types::GetSearchResultsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTSiteWise::Types::GetSearchResultsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotsitewise/types.rb
Overview
Input for the GetSearchResults operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
The maximum number of results to return in a single page.
-
#next_token ⇒ String
The pagination token returned by a previous GetSearchResults call.
-
#search_id ⇒ String
The identifier of the search whose results are retrieved.
-
#workspace_name ⇒ String
The name of the workspace the search belongs to.
Instance Attribute Details
#max_results ⇒ Integer
The maximum number of results to return in a single page. Valid range is 1 to 10,000; if omitted, a service-defined default is used.
9851 9852 9853 9854 9855 9856 9857 9858 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 9851 class GetSearchResultsRequest < Struct.new( :search_id, :workspace_name, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The pagination token returned by a previous GetSearchResults call. Provide it to retrieve the next page of results; omit it to retrieve the first page.
9851 9852 9853 9854 9855 9856 9857 9858 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 9851 class GetSearchResultsRequest < Struct.new( :search_id, :workspace_name, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#search_id ⇒ String
The identifier of the search whose results are retrieved.
9851 9852 9853 9854 9855 9856 9857 9858 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 9851 class GetSearchResultsRequest < Struct.new( :search_id, :workspace_name, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#workspace_name ⇒ String
The name of the workspace the search belongs to.
9851 9852 9853 9854 9855 9856 9857 9858 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 9851 class GetSearchResultsRequest < Struct.new( :search_id, :workspace_name, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |