Class: Aws::IoTSiteWise::Types::GreengrassV2
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTSiteWise::Types::GreengrassV2
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotsitewise/types.rb
Overview
Contains details for a gateway that runs on IoT Greengrass V2. To
create a gateway that runs on IoT Greengrass V2, you must deploy the
IoT SiteWise Edge component to your gateway device. Your Greengrass
device role must use the AWSIoTSiteWiseEdgeAccess policy. For
more information, see Using IoT SiteWise at the edge in the IoT
SiteWise User Guide.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#core_device_operating_system ⇒ String
The operating system of the core device in IoT Greengrass V2.
-
#core_device_thing_name ⇒ String
The name of the IoT thing for your IoT Greengrass V2 core device.
Instance Attribute Details
#core_device_operating_system ⇒ String
The operating system of the core device in IoT Greengrass V2.
Specifying the operating system is required for MQTT-enabled, V3
gateways (gatewayVersion 3) and not applicable for Classic
stream, V2 gateways (gatewayVersion 2).
9930 9931 9932 9933 9934 9935 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 9930 class GreengrassV2 < Struct.new( :core_device_thing_name, :core_device_operating_system) SENSITIVE = [] include Aws::Structure end |
#core_device_thing_name ⇒ String
The name of the IoT thing for your IoT Greengrass V2 core device.
9930 9931 9932 9933 9934 9935 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 9930 class GreengrassV2 < Struct.new( :core_device_thing_name, :core_device_operating_system) SENSITIVE = [] include Aws::Structure end |