Class: Aws::IoTSiteWise::Types::InterfaceRelationshipSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTSiteWise::Types::InterfaceRelationshipSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotsitewise/types.rb
Overview
Contains summary information about an interface relationship, which defines how an interface is applied to an asset model. This summary provides the essential identifiers needed to retrieve detailed information about the relationship.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#id ⇒ String
The ID of the asset model that has the interface applied to it.
Instance Attribute Details
#id ⇒ String
The ID of the asset model that has the interface applied to it.
10133 10134 10135 10136 10137 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 10133 class InterfaceRelationshipSummary < Struct.new( :id) SENSITIVE = [] include Aws::Structure end |