Class: Aws::IoTSiteWise::Types::InvokeAssistantRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTSiteWise::Types::InvokeAssistantRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotsitewise/types.rb
Constant Summary collapse
- SENSITIVE =
[:message]
Instance Attribute Summary collapse
-
#conversation_id ⇒ String
The ID assigned to a conversation.
-
#enable_trace ⇒ Boolean
Specifies if to turn trace on or not.
-
#message ⇒ String
A text message sent to the SiteWise Assistant by the user.
Instance Attribute Details
#conversation_id ⇒ String
The ID assigned to a conversation. IoT SiteWise automatically generates a unique ID for you, and this parameter is never required. However, if you prefer to have your own ID, you must specify it here in UUID format. If you specify your own ID, it must be globally unique.
10238 10239 10240 10241 10242 10243 10244 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 10238 class InvokeAssistantRequest < Struct.new( :conversation_id, :message, :enable_trace) SENSITIVE = [:message] include Aws::Structure end |
#enable_trace ⇒ Boolean
Specifies if to turn trace on or not. It is used to track the SiteWise Assistant's reasoning, and data access process.
10238 10239 10240 10241 10242 10243 10244 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 10238 class InvokeAssistantRequest < Struct.new( :conversation_id, :message, :enable_trace) SENSITIVE = [:message] include Aws::Structure end |
#message ⇒ String
A text message sent to the SiteWise Assistant by the user.
10238 10239 10240 10241 10242 10243 10244 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 10238 class InvokeAssistantRequest < Struct.new( :conversation_id, :message, :enable_trace) SENSITIVE = [:message] include Aws::Structure end |