Class: Aws::IoTSiteWise::Types::ListDatasetDataSegmentRelationshipsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTSiteWise::Types::ListDatasetDataSegmentRelationshipsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotsitewise/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dataset_id ⇒ String
The ID of the session dataset to list data segment relationships for.
-
#max_results ⇒ Integer
The maximum number of results to return for each paginated request.
-
#next_token ⇒ String
The token to be used for the next set of paginated results.
-
#workspace_name ⇒ String
The name of the workspace that contains the dataset.
Instance Attribute Details
#dataset_id ⇒ String
The ID of the session dataset to list data segment relationships for.
11256 11257 11258 11259 11260 11261 11262 11263 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 11256 class ListDatasetDataSegmentRelationshipsRequest < Struct.new( :dataset_id, :workspace_name, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return for each paginated request. Default: 50.
11256 11257 11258 11259 11260 11261 11262 11263 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 11256 class ListDatasetDataSegmentRelationshipsRequest < Struct.new( :dataset_id, :workspace_name, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token to be used for the next set of paginated results.
11256 11257 11258 11259 11260 11261 11262 11263 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 11256 class ListDatasetDataSegmentRelationshipsRequest < Struct.new( :dataset_id, :workspace_name, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#workspace_name ⇒ String
The name of the workspace that contains the dataset.
11256 11257 11258 11259 11260 11261 11262 11263 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 11256 class ListDatasetDataSegmentRelationshipsRequest < Struct.new( :dataset_id, :workspace_name, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |