Class: Aws::IoTSiteWise::Types::ListDatasetDataSegmentsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTSiteWise::Types::ListDatasetDataSegmentsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotsitewise/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dataset_id ⇒ String
The ID of the dataset.
-
#dataset_version ⇒ String
The version of the dataset to list data segments for.
-
#max_results ⇒ Integer
The maximum number of results to return for each paginated request.
-
#next_token ⇒ String
The token to be used for the next set of paginated results.
-
#workspace_name ⇒ String
The name of the workspace that contains the dataset.
Instance Attribute Details
#dataset_id ⇒ String
The ID of the dataset.
11302 11303 11304 11305 11306 11307 11308 11309 11310 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 11302 class ListDatasetDataSegmentsRequest < Struct.new( :dataset_id, :workspace_name, :dataset_version, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#dataset_version ⇒ String
The version of the dataset to list data segments for.
11302 11303 11304 11305 11306 11307 11308 11309 11310 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 11302 class ListDatasetDataSegmentsRequest < Struct.new( :dataset_id, :workspace_name, :dataset_version, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return for each paginated request. Default: 50.
11302 11303 11304 11305 11306 11307 11308 11309 11310 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 11302 class ListDatasetDataSegmentsRequest < Struct.new( :dataset_id, :workspace_name, :dataset_version, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token to be used for the next set of paginated results.
11302 11303 11304 11305 11306 11307 11308 11309 11310 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 11302 class ListDatasetDataSegmentsRequest < Struct.new( :dataset_id, :workspace_name, :dataset_version, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#workspace_name ⇒ String
The name of the workspace that contains the dataset.
11302 11303 11304 11305 11306 11307 11308 11309 11310 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 11302 class ListDatasetDataSegmentsRequest < Struct.new( :dataset_id, :workspace_name, :dataset_version, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |