Class: Aws::IoTSiteWise::Types::ListDatasetsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTSiteWise::Types::ListDatasetsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotsitewise/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dataset_type ⇒ String
The type of dataset to filter by: a session dataset, a curated dataset, or a connection to an external datasource.
-
#max_results ⇒ Integer
The maximum number of results to return for each paginated request.
-
#next_token ⇒ String
The token for the next set of results, or null if there are no additional results.
-
#source_type ⇒ String
The type of data source for the dataset.
-
#workspace_name ⇒ String
The name of the workspace to filter datasets by.
Instance Attribute Details
#dataset_type ⇒ String
The type of dataset to filter by: a session dataset, a curated dataset, or a connection to an external datasource.
11397 11398 11399 11400 11401 11402 11403 11404 11405 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 11397 class ListDatasetsRequest < Struct.new( :source_type, :workspace_name, :dataset_type, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return for each paginated request.
11397 11398 11399 11400 11401 11402 11403 11404 11405 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 11397 class ListDatasetsRequest < Struct.new( :source_type, :workspace_name, :dataset_type, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results, or null if there are no additional results.
11397 11398 11399 11400 11401 11402 11403 11404 11405 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 11397 class ListDatasetsRequest < Struct.new( :source_type, :workspace_name, :dataset_type, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#source_type ⇒ String
The type of data source for the dataset.
11397 11398 11399 11400 11401 11402 11403 11404 11405 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 11397 class ListDatasetsRequest < Struct.new( :source_type, :workspace_name, :dataset_type, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#workspace_name ⇒ String
The name of the workspace to filter datasets by.
11397 11398 11399 11400 11401 11402 11403 11404 11405 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 11397 class ListDatasetsRequest < Struct.new( :source_type, :workspace_name, :dataset_type, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |