Class: Aws::IoTSiteWise::Types::ListPipelinesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTSiteWise::Types::ListPipelinesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotsitewise/types.rb
Overview
Request structure for ListPipelines operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
The maximum number of results to return for each paginated request.
-
#next_token ⇒ String
The token to be used for the next set of paginated results.
-
#workspace_name ⇒ String
The name of the workspace.
Instance Attribute Details
#max_results ⇒ Integer
The maximum number of results to return for each paginated request. Default: 50.
11745 11746 11747 11748 11749 11750 11751 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 11745 class ListPipelinesRequest < Struct.new( :workspace_name, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token to be used for the next set of paginated results.
11745 11746 11747 11748 11749 11750 11751 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 11745 class ListPipelinesRequest < Struct.new( :workspace_name, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#workspace_name ⇒ String
The name of the workspace.
11745 11746 11747 11748 11749 11750 11751 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 11745 class ListPipelinesRequest < Struct.new( :workspace_name, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |