Class: Aws::IoTSiteWise::Types::ListSearchesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTSiteWise::Types::ListSearchesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotsitewise/types.rb
Overview
Input for the ListSearches operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#list_searches_filters ⇒ Types::ListSearchesFilters
Optional filters that restrict which searches are returned.
-
#max_results ⇒ Integer
The maximum number of searches to return in a single page.
-
#next_token ⇒ String
The pagination token returned by a previous ListSearches call.
-
#workspace_name ⇒ String
The name of the workspace whose searches are listed.
Instance Attribute Details
#list_searches_filters ⇒ Types::ListSearchesFilters
Optional filters that restrict which searches are returned.
11980 11981 11982 11983 11984 11985 11986 11987 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 11980 class ListSearchesRequest < Struct.new( :workspace_name, :max_results, :next_token, :list_searches_filters) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of searches to return in a single page. Valid range is 1 to 1,000; if omitted, a service-defined default is used.
11980 11981 11982 11983 11984 11985 11986 11987 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 11980 class ListSearchesRequest < Struct.new( :workspace_name, :max_results, :next_token, :list_searches_filters) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The pagination token returned by a previous ListSearches call. Provide it to retrieve the next page; omit it to retrieve the first page.
11980 11981 11982 11983 11984 11985 11986 11987 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 11980 class ListSearchesRequest < Struct.new( :workspace_name, :max_results, :next_token, :list_searches_filters) SENSITIVE = [] include Aws::Structure end |
#workspace_name ⇒ String
The name of the workspace whose searches are listed.
11980 11981 11982 11983 11984 11985 11986 11987 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 11980 class ListSearchesRequest < Struct.new( :workspace_name, :max_results, :next_token, :list_searches_filters) SENSITIVE = [] include Aws::Structure end |