Class: Aws::IoTSiteWise::Types::ListTasksRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTSiteWise::Types::ListTasksRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotsitewise/types.rb
Overview
Request structure for ListTasks operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
The maximum number of results to return for each paginated request.
-
#next_token ⇒ String
The token to be used for the next set of paginated results.
-
#workspace_name ⇒ String
The name of the workspace.
Instance Attribute Details
#max_results ⇒ Integer
The maximum number of results to return for each paginated request. Default: 50.
12052 12053 12054 12055 12056 12057 12058 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 12052 class ListTasksRequest < Struct.new( :workspace_name, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token to be used for the next set of paginated results.
12052 12053 12054 12055 12056 12057 12058 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 12052 class ListTasksRequest < Struct.new( :workspace_name, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#workspace_name ⇒ String
The name of the workspace.
12052 12053 12054 12055 12056 12057 12058 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 12052 class ListTasksRequest < Struct.new( :workspace_name, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |