Class: Aws::IoTSiteWise::Types::ListTasksResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTSiteWise::Types::ListTasksResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotsitewise/types.rb
Overview
Response structure for ListTasks operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
The token to be used for the next set of paginated results.
-
#task_summaries ⇒ Array<Types::TaskSummary>
A list that summarizes each task in the workspace.
Instance Attribute Details
#next_token ⇒ String
The token to be used for the next set of paginated results.
12070 12071 12072 12073 12074 12075 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 12070 class ListTasksResponse < Struct.new( :task_summaries, :next_token) SENSITIVE = [] include Aws::Structure end |
#task_summaries ⇒ Array<Types::TaskSummary>
A list that summarizes each task in the workspace.
12070 12071 12072 12073 12074 12075 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 12070 class ListTasksResponse < Struct.new( :task_summaries, :next_token) SENSITIVE = [] include Aws::Structure end |