Class: Aws::IoTSiteWise::Types::MetricProcessingConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTSiteWise::Types::MetricProcessingConfig
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotsitewise/types.rb
Overview
The processing configuration for the given metric property. You can configure metrics to be computed at the edge or in the Amazon Web Services Cloud. By default, metrics are forwarded to the cloud.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#compute_location ⇒ String
The compute location for the given metric property.
Instance Attribute Details
#compute_location ⇒ String
The compute location for the given metric property.
12270 12271 12272 12273 12274 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 12270 class MetricProcessingConfig < Struct.new( :compute_location) SENSITIVE = [] include Aws::Structure end |