Class: Aws::IoTSiteWise::Types::PutAssetModelInterfaceRelationshipResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTSiteWise::Types::PutAssetModelInterfaceRelationshipResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotsitewise/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#asset_model_arn ⇒ String
The ARN of the asset model, which has the following format.
-
#asset_model_id ⇒ String
The ID of the asset model.
-
#asset_model_status ⇒ Types::AssetModelStatus
Contains current status information for an asset model.
-
#interface_asset_model_id ⇒ String
The ID of the interface asset model.
Instance Attribute Details
#asset_model_arn ⇒ String
The ARN of the asset model, which has the following format.
arn:${Partition}:iotsitewise:${Region}:${Account}:asset-model/${AssetModelId}
12915 12916 12917 12918 12919 12920 12921 12922 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 12915 class PutAssetModelInterfaceRelationshipResponse < Struct.new( :asset_model_id, :interface_asset_model_id, :asset_model_arn, :asset_model_status) SENSITIVE = [] include Aws::Structure end |
#asset_model_id ⇒ String
The ID of the asset model.
12915 12916 12917 12918 12919 12920 12921 12922 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 12915 class PutAssetModelInterfaceRelationshipResponse < Struct.new( :asset_model_id, :interface_asset_model_id, :asset_model_arn, :asset_model_status) SENSITIVE = [] include Aws::Structure end |
#asset_model_status ⇒ Types::AssetModelStatus
Contains current status information for an asset model. For more information, see Asset and model states in the IoT SiteWise User Guide.
12915 12916 12917 12918 12919 12920 12921 12922 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 12915 class PutAssetModelInterfaceRelationshipResponse < Struct.new( :asset_model_id, :interface_asset_model_id, :asset_model_arn, :asset_model_status) SENSITIVE = [] include Aws::Structure end |
#interface_asset_model_id ⇒ String
The ID of the interface asset model.
12915 12916 12917 12918 12919 12920 12921 12922 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 12915 class PutAssetModelInterfaceRelationshipResponse < Struct.new( :asset_model_id, :interface_asset_model_id, :asset_model_arn, :asset_model_status) SENSITIVE = [] include Aws::Structure end |