Class: Aws::IoTSiteWise::Types::StartPipelineExecutionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTSiteWise::Types::StartPipelineExecutionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotsitewise/types.rb
Overview
Request structure for StartPipelineExecution operation.
Constant Summary collapse
- SENSITIVE =
[:execution_environment_variable_overrides]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#execution_environment_variable_overrides ⇒ Types::ExecutionEnvironmentVariables
Runtime environment variable overrides for the execution.
-
#execution_priority ⇒ Integer
Scheduling priority for the execution.
-
#pipeline_name ⇒ String
The name of the pipeline to execute.
-
#workspace_name ⇒ String
The name of the workspace containing the pipeline.
Instance Attribute Details
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If you retry a request that completed successfully using the same client token, the server returns the cached result from the original successful request without performing the operation again.
A suitable default value is auto-generated. You should normally not need to pass this option.
13620 13621 13622 13623 13624 13625 13626 13627 13628 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 13620 class StartPipelineExecutionRequest < Struct.new( :workspace_name, :pipeline_name, :execution_environment_variable_overrides, :execution_priority, :client_token) SENSITIVE = [:execution_environment_variable_overrides] include Aws::Structure end |
#execution_environment_variable_overrides ⇒ Types::ExecutionEnvironmentVariables
Runtime environment variable overrides for the execution. Includes global variables that apply to all compute nodes and computeNodes for per-node overrides. These take the highest priority in the environment variable hierarchy.
13620 13621 13622 13623 13624 13625 13626 13627 13628 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 13620 class StartPipelineExecutionRequest < Struct.new( :workspace_name, :pipeline_name, :execution_environment_variable_overrides, :execution_priority, :client_token) SENSITIVE = [:execution_environment_variable_overrides] include Aws::Structure end |
#execution_priority ⇒ Integer
Scheduling priority for the execution. Lower values indicate higher priority. Defaults to 2 when not specified.
13620 13621 13622 13623 13624 13625 13626 13627 13628 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 13620 class StartPipelineExecutionRequest < Struct.new( :workspace_name, :pipeline_name, :execution_environment_variable_overrides, :execution_priority, :client_token) SENSITIVE = [:execution_environment_variable_overrides] include Aws::Structure end |
#pipeline_name ⇒ String
The name of the pipeline to execute.
13620 13621 13622 13623 13624 13625 13626 13627 13628 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 13620 class StartPipelineExecutionRequest < Struct.new( :workspace_name, :pipeline_name, :execution_environment_variable_overrides, :execution_priority, :client_token) SENSITIVE = [:execution_environment_variable_overrides] include Aws::Structure end |
#workspace_name ⇒ String
The name of the workspace containing the pipeline.
13620 13621 13622 13623 13624 13625 13626 13627 13628 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 13620 class StartPipelineExecutionRequest < Struct.new( :workspace_name, :pipeline_name, :execution_environment_variable_overrides, :execution_priority, :client_token) SENSITIVE = [:execution_environment_variable_overrides] include Aws::Structure end |