Class: Aws::IoTSiteWise::Types::StartQueryRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTSiteWise::Types::StartQueryRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotsitewise/types.rb
Constant Summary collapse
- SENSITIVE =
[:query_statement]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique case-sensitive identifier that you can provide to ensure the idempotency of the request.
-
#query_statement ⇒ String
The SQL query to execute against the workspace telemetry, annotations, data segment, and dataset data.
-
#workspace_name ⇒ String
The name of the workspace to query.
Instance Attribute Details
#client_token ⇒ String
A unique case-sensitive identifier that you can provide to ensure the idempotency of the request. Don't reuse this client token if a new idempotent request is required.
A suitable default value is auto-generated. You should normally not need to pass this option.
13660 13661 13662 13663 13664 13665 13666 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 13660 class StartQueryRequest < Struct.new( :client_token, :workspace_name, :query_statement) SENSITIVE = [:query_statement] include Aws::Structure end |
#query_statement ⇒ String
The SQL query to execute against the workspace telemetry, annotations, data segment, and dataset data.
13660 13661 13662 13663 13664 13665 13666 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 13660 class StartQueryRequest < Struct.new( :client_token, :workspace_name, :query_statement) SENSITIVE = [:query_statement] include Aws::Structure end |
#workspace_name ⇒ String
The name of the workspace to query.
13660 13661 13662 13663 13664 13665 13666 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 13660 class StartQueryRequest < Struct.new( :client_token, :workspace_name, :query_statement) SENSITIVE = [:query_statement] include Aws::Structure end |