Class: Aws::IoTSiteWise::Types::StartSearchRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTSiteWise::Types::StartSearchRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotsitewise/types.rb
Overview
Input for the StartSearch operation.
Constant Summary collapse
- SENSITIVE =
[:query_statement]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique, case-sensitive identifier you provide to ensure the request is idempotent.
-
#group_id ⇒ String
An optional caller-supplied identifier used to group related searches together.
-
#query_statement ⇒ String
The natural-language query describing the data to search for.
-
#search_filters ⇒ Types::SearchFilters
Optional filters that restrict the search to a subset of the workspace's data.
-
#search_type ⇒ String
The search strategy to use.
-
#workspace_name ⇒ String
The name of the workspace whose data is searched.
Instance Attribute Details
#client_token ⇒ String
A unique, case-sensitive identifier you provide to ensure the
request is idempotent. Repeating a StartSearch call with the same
clientToken returns the original search rather than starting a new
one. If omitted, the SDK autogenerates one.
A suitable default value is auto-generated. You should normally not need to pass this option.
13720 13721 13722 13723 13724 13725 13726 13727 13728 13729 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 13720 class StartSearchRequest < Struct.new( :workspace_name, :query_statement, :client_token, :search_type, :search_filters, :group_id) SENSITIVE = [:query_statement] include Aws::Structure end |
#group_id ⇒ String
An optional caller-supplied identifier used to group related searches together.
13720 13721 13722 13723 13724 13725 13726 13727 13728 13729 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 13720 class StartSearchRequest < Struct.new( :workspace_name, :query_statement, :client_token, :search_type, :search_filters, :group_id) SENSITIVE = [:query_statement] include Aws::Structure end |
#query_statement ⇒ String
The natural-language query describing the data to search for.
13720 13721 13722 13723 13724 13725 13726 13727 13728 13729 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 13720 class StartSearchRequest < Struct.new( :workspace_name, :query_statement, :client_token, :search_type, :search_filters, :group_id) SENSITIVE = [:query_statement] include Aws::Structure end |
#search_filters ⇒ Types::SearchFilters
Optional filters that restrict the search to a subset of the workspace's data.
13720 13721 13722 13723 13724 13725 13726 13727 13728 13729 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 13720 class StartSearchRequest < Struct.new( :workspace_name, :query_statement, :client_token, :search_type, :search_filters, :group_id) SENSITIVE = [:query_statement] include Aws::Structure end |
#search_type ⇒ String
The search strategy to use. Defaults to QUICK when omitted.
13720 13721 13722 13723 13724 13725 13726 13727 13728 13729 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 13720 class StartSearchRequest < Struct.new( :workspace_name, :query_statement, :client_token, :search_type, :search_filters, :group_id) SENSITIVE = [:query_statement] include Aws::Structure end |
#workspace_name ⇒ String
The name of the workspace whose data is searched.
13720 13721 13722 13723 13724 13725 13726 13727 13728 13729 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 13720 class StartSearchRequest < Struct.new( :workspace_name, :query_statement, :client_token, :search_type, :search_filters, :group_id) SENSITIVE = [:query_statement] include Aws::Structure end |