Class: Aws::IoTSiteWise::Types::TaskSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTSiteWise::Types::TaskSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotsitewise/types.rb
Overview
Contains summary information about a task.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The time the task was created, in Unix epoch time.
-
#description ⇒ String
The description of the task.
-
#status ⇒ Types::ResourceStatus
The current lifecycle status of the task.
-
#task_arn ⇒ String
The ARN of the task.
-
#task_name ⇒ String
The name of the task.
-
#updated_at ⇒ Time
The time the task was last updated, in Unix epoch time.
-
#version ⇒ String
The version of the task.
Instance Attribute Details
#created_at ⇒ Time
The time the task was created, in Unix epoch time.
13862 13863 13864 13865 13866 13867 13868 13869 13870 13871 13872 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 13862 class TaskSummary < Struct.new( :task_name, :description, :task_arn, :version, :status, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the task.
13862 13863 13864 13865 13866 13867 13868 13869 13870 13871 13872 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 13862 class TaskSummary < Struct.new( :task_name, :description, :task_arn, :version, :status, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#status ⇒ Types::ResourceStatus
The current lifecycle status of the task.
13862 13863 13864 13865 13866 13867 13868 13869 13870 13871 13872 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 13862 class TaskSummary < Struct.new( :task_name, :description, :task_arn, :version, :status, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#task_arn ⇒ String
The ARN of the task.
13862 13863 13864 13865 13866 13867 13868 13869 13870 13871 13872 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 13862 class TaskSummary < Struct.new( :task_name, :description, :task_arn, :version, :status, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#task_name ⇒ String
The name of the task.
13862 13863 13864 13865 13866 13867 13868 13869 13870 13871 13872 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 13862 class TaskSummary < Struct.new( :task_name, :description, :task_arn, :version, :status, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The time the task was last updated, in Unix epoch time.
13862 13863 13864 13865 13866 13867 13868 13869 13870 13871 13872 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 13862 class TaskSummary < Struct.new( :task_name, :description, :task_arn, :version, :status, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#version ⇒ String
The version of the task.
13862 13863 13864 13865 13866 13867 13868 13869 13870 13871 13872 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 13862 class TaskSummary < Struct.new( :task_name, :description, :task_arn, :version, :status, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |