Class: Aws::IoTSiteWise::Types::TransformProcessingConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTSiteWise::Types::TransformProcessingConfig
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotsitewise/types.rb
Overview
The processing configuration for the given transform property. You can configure transforms to be kept at the edge or forwarded to the Amazon Web Services Cloud. You can also configure transforms to be computed at the edge or in the cloud.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#compute_location ⇒ String
The compute location for the given transform property.
-
#forwarding_config ⇒ Types::ForwardingConfig
The forwarding configuration for a given property.
Instance Attribute Details
#compute_location ⇒ String
The compute location for the given transform property.
14127 14128 14129 14130 14131 14132 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 14127 class TransformProcessingConfig < Struct.new( :compute_location, :forwarding_config) SENSITIVE = [] include Aws::Structure end |
#forwarding_config ⇒ Types::ForwardingConfig
The forwarding configuration for a given property.
14127 14128 14129 14130 14131 14132 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 14127 class TransformProcessingConfig < Struct.new( :compute_location, :forwarding_config) SENSITIVE = [] include Aws::Structure end |