Class: Aws::IoTSiteWise::Types::UpdateAssetModelCompositeModelResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTSiteWise::Types::UpdateAssetModelCompositeModelResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotsitewise/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#asset_model_composite_model_path ⇒ Array<Types::AssetModelCompositeModelPathSegment>
The path to the composite model listing the parent composite models.
-
#asset_model_id ⇒ String
The ID of the asset model.
-
#asset_model_status ⇒ Types::AssetModelStatus
Contains current status information for an asset model.
Instance Attribute Details
#asset_model_composite_model_path ⇒ Array<Types::AssetModelCompositeModelPathSegment>
The path to the composite model listing the parent composite models.
14416 14417 14418 14419 14420 14421 14422 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 14416 class UpdateAssetModelCompositeModelResponse < Struct.new( :asset_model_composite_model_path, :asset_model_status, :asset_model_id) SENSITIVE = [] include Aws::Structure end |
#asset_model_id ⇒ String
The ID of the asset model.
14416 14417 14418 14419 14420 14421 14422 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 14416 class UpdateAssetModelCompositeModelResponse < Struct.new( :asset_model_composite_model_path, :asset_model_status, :asset_model_id) SENSITIVE = [] include Aws::Structure end |
#asset_model_status ⇒ Types::AssetModelStatus
Contains current status information for an asset model. For more information, see Asset and model states in the IoT SiteWise User Guide.
14416 14417 14418 14419 14420 14421 14422 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 14416 class UpdateAssetModelCompositeModelResponse < Struct.new( :asset_model_composite_model_path, :asset_model_status, :asset_model_id) SENSITIVE = [] include Aws::Structure end |