Class: Aws::IoTSiteWise::Types::UpdateDatasetRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTSiteWise::Types::UpdateDatasetRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotsitewise/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique case-sensitive identifier that you can provide to ensure the idempotency of the request.
-
#dataset_config ⇒ Types::DatasetConfig
The updated configuration for the dataset.
-
#dataset_description ⇒ String
A description about the dataset, and its functionality.
-
#dataset_id ⇒ String
The ID of the dataset.
-
#dataset_name ⇒ String
The name of the dataset.
-
#dataset_source ⇒ Types::DatasetSource
The data source for the dataset.
-
#metadata ⇒ Hash<String,String>
The updated metadata for the dataset.
-
#workspace_name ⇒ String
The name of the workspace that contains the dataset.
Instance Attribute Details
#client_token ⇒ String
A unique case-sensitive identifier that you can provide to ensure the idempotency of the request. Don't reuse this client token if a new idempotent request is required.
A suitable default value is auto-generated. You should normally not need to pass this option.
14850 14851 14852 14853 14854 14855 14856 14857 14858 14859 14860 14861 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 14850 class UpdateDatasetRequest < Struct.new( :dataset_id, :workspace_name, :dataset_name, :dataset_description, :dataset_config, :metadata, :dataset_source, :client_token) SENSITIVE = [] include Aws::Structure end |
#dataset_config ⇒ Types::DatasetConfig
The updated configuration for the dataset.
14850 14851 14852 14853 14854 14855 14856 14857 14858 14859 14860 14861 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 14850 class UpdateDatasetRequest < Struct.new( :dataset_id, :workspace_name, :dataset_name, :dataset_description, :dataset_config, :metadata, :dataset_source, :client_token) SENSITIVE = [] include Aws::Structure end |
#dataset_description ⇒ String
A description about the dataset, and its functionality.
14850 14851 14852 14853 14854 14855 14856 14857 14858 14859 14860 14861 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 14850 class UpdateDatasetRequest < Struct.new( :dataset_id, :workspace_name, :dataset_name, :dataset_description, :dataset_config, :metadata, :dataset_source, :client_token) SENSITIVE = [] include Aws::Structure end |
#dataset_id ⇒ String
The ID of the dataset.
14850 14851 14852 14853 14854 14855 14856 14857 14858 14859 14860 14861 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 14850 class UpdateDatasetRequest < Struct.new( :dataset_id, :workspace_name, :dataset_name, :dataset_description, :dataset_config, :metadata, :dataset_source, :client_token) SENSITIVE = [] include Aws::Structure end |
#dataset_name ⇒ String
The name of the dataset.
14850 14851 14852 14853 14854 14855 14856 14857 14858 14859 14860 14861 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 14850 class UpdateDatasetRequest < Struct.new( :dataset_id, :workspace_name, :dataset_name, :dataset_description, :dataset_config, :metadata, :dataset_source, :client_token) SENSITIVE = [] include Aws::Structure end |
#dataset_source ⇒ Types::DatasetSource
The data source for the dataset.
14850 14851 14852 14853 14854 14855 14856 14857 14858 14859 14860 14861 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 14850 class UpdateDatasetRequest < Struct.new( :dataset_id, :workspace_name, :dataset_name, :dataset_description, :dataset_config, :metadata, :dataset_source, :client_token) SENSITIVE = [] include Aws::Structure end |
#metadata ⇒ Hash<String,String>
The updated metadata for the dataset.
14850 14851 14852 14853 14854 14855 14856 14857 14858 14859 14860 14861 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 14850 class UpdateDatasetRequest < Struct.new( :dataset_id, :workspace_name, :dataset_name, :dataset_description, :dataset_config, :metadata, :dataset_source, :client_token) SENSITIVE = [] include Aws::Structure end |
#workspace_name ⇒ String
The name of the workspace that contains the dataset.
14850 14851 14852 14853 14854 14855 14856 14857 14858 14859 14860 14861 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 14850 class UpdateDatasetRequest < Struct.new( :dataset_id, :workspace_name, :dataset_name, :dataset_description, :dataset_config, :metadata, :dataset_source, :client_token) SENSITIVE = [] include Aws::Structure end |