Class: Aws::IoTSiteWise::Types::UpdateWorkspaceResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTSiteWise::Types::UpdateWorkspaceResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotsitewise/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#workspace_status ⇒ Types::WorkspaceStatus
The status of the workspace after the update, which is
UPDATINGwhen the operation returns.
Instance Attribute Details
#workspace_status ⇒ Types::WorkspaceStatus
The status of the workspace after the update, which is UPDATING
when the operation returns.
15234 15235 15236 15237 15238 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 15234 class UpdateWorkspaceResponse < Struct.new( :workspace_status) SENSITIVE = [] include Aws::Structure end |