Class: Aws::IoTSiteWise::Types::WorkspaceSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotsitewise/types.rb

Overview

Contains summary information about a workspace, including its name, ARN, status, and creation and update timestamps.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The ARN of the workspace.

Returns:

  • (String)


15462
15463
15464
15465
15466
15467
15468
15469
15470
# File 'lib/aws-sdk-iotsitewise/types.rb', line 15462

class WorkspaceSummary < Struct.new(
  :name,
  :arn,
  :status,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

The date the workspace was created, in Unix epoch time.

Returns:

  • (Time)


15462
15463
15464
15465
15466
15467
15468
15469
15470
# File 'lib/aws-sdk-iotsitewise/types.rb', line 15462

class WorkspaceSummary < Struct.new(
  :name,
  :arn,
  :status,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the workspace.

Returns:

  • (String)


15462
15463
15464
15465
15466
15467
15468
15469
15470
# File 'lib/aws-sdk-iotsitewise/types.rb', line 15462

class WorkspaceSummary < Struct.new(
  :name,
  :arn,
  :status,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#statusTypes::WorkspaceStatus

The status of the workspace.



15462
15463
15464
15465
15466
15467
15468
15469
15470
# File 'lib/aws-sdk-iotsitewise/types.rb', line 15462

class WorkspaceSummary < Struct.new(
  :name,
  :arn,
  :status,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#updated_atTime

The date the workspace was last updated, in Unix epoch time.

Returns:

  • (Time)


15462
15463
15464
15465
15466
15467
15468
15469
15470
# File 'lib/aws-sdk-iotsitewise/types.rb', line 15462

class WorkspaceSummary < Struct.new(
  :name,
  :arn,
  :status,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end