Class: Aws::IoTSiteWise::Types::WorkspaceSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTSiteWise::Types::WorkspaceSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotsitewise/types.rb
Overview
Contains summary information about a workspace, including its name, ARN, status, and creation and update timestamps.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The ARN of the workspace.
-
#created_at ⇒ Time
The date the workspace was created, in Unix epoch time.
-
#name ⇒ String
The name of the workspace.
-
#status ⇒ Types::WorkspaceStatus
The status of the workspace.
-
#updated_at ⇒ Time
The date the workspace was last updated, in Unix epoch time.
Instance Attribute Details
#arn ⇒ String
The ARN of the workspace.
15462 15463 15464 15465 15466 15467 15468 15469 15470 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 15462 class WorkspaceSummary < Struct.new( :name, :arn, :status, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The date the workspace was created, in Unix epoch time.
15462 15463 15464 15465 15466 15467 15468 15469 15470 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 15462 class WorkspaceSummary < Struct.new( :name, :arn, :status, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the workspace.
15462 15463 15464 15465 15466 15467 15468 15469 15470 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 15462 class WorkspaceSummary < Struct.new( :name, :arn, :status, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#status ⇒ Types::WorkspaceStatus
The status of the workspace.
15462 15463 15464 15465 15466 15467 15468 15469 15470 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 15462 class WorkspaceSummary < Struct.new( :name, :arn, :status, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The date the workspace was last updated, in Unix epoch time.
15462 15463 15464 15465 15466 15467 15468 15469 15470 |
# File 'lib/aws-sdk-iotsitewise/types.rb', line 15462 class WorkspaceSummary < Struct.new( :name, :arn, :status, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |